(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    284609,      10473]*)
(*NotebookOutlinePosition[    285253,      10495]*)
(*  CellTagsIndexPosition[    285209,      10491]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Mortality in the Barro-Becker Model", "Title"],

Cell[BoxData[
    \(<< Graphics`Legend`\)], "Input"],

Cell["The utility function:", "Text"],

Cell[BoxData[
    \(u[N_] := \[Sum]\+\(n = 0\)\%N\((\((In - N\ f - n\ p)\)\^\(1 - \
\[Sigma]\)\/\(1 - \[Sigma]\) + \ \(n\^\[Epsilon]\) \[Beta]\ V)\) 
          Binomial[N, n] \(s\^n\) \((1 - s)\)\^\(N - n\)\)], "Input"],

Cell[BoxData[
    \(Survivors[
        N_] := \[Sum]\+\(n = 0\)\%N 
            n\ Binomial[N, n] \(s\^n\) \((1 - s)\)\^\(N - n\) /. 
        par\)], "Input"],

Cell["\<\
The following computes optimal fertility for fixed children's utility\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(computemax[sin_] := 
      Module[{local}, \[IndentingNewLine]par = 
          Join[prepar, {s \[Rule] sin}]; \[IndentingNewLine]Nmax = 
          Floor[In/\((f + p)\) /. par]; \[IndentingNewLine]Nutil = 
          Table[u[N] /. par, {N, Nmax}]; \[IndentingNewLine]For[i = 1, 
          i <= Nmax, \(i++\), 
          If[Nutil[\([i]\)] == Max[Nutil], 
            Nopt = i]]; \[IndentingNewLine]Nopt\[IndentingNewLine]]\)], \
"Input"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(Nopt\)\" is similar to \
existing symbol \"\!\(Not\)\"."\)], "Message"]
}, Open  ]],

Cell["Trying to hit actual values with calibrated parameters", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(prepar = {\[Sigma] \[Rule]  .5, \[Epsilon] \[Rule]  .5, \[Beta] \
\[Rule] 1, f \[Rule] 1/12, p \[Rule] 5/12, V \[Rule]  .54, 
          In \[Rule] 14};\)\), "\[IndentingNewLine]", 
    \({computemax[ .73], Survivors[computemax[ .73]], 
      u[computemax[ .73]] /. par, \((V/u[computemax[ .73]])\) /. 
        par}\), "\[IndentingNewLine]", 
    \({computemax[ .965], Survivors[computemax[ .965]], 
      u[computemax[ .965]] /. par, \((V/u[computemax[ .965]])\) /. 
        par}\), "\[IndentingNewLine]", 
    \(\(trubeta = V/u[computemax[ .73]] /. par;\)\), "\[IndentingNewLine]", 
    \(\(Vtru = u[computemax[ .73]] /. par;\)\)}], "Input"],

Cell[BoxData[
    \({5, 3.6499999999999995`, 7.965397176880935`, 
      0.06779322964174544`}\)], "Output"],

Cell[BoxData[
    \({4, 3.86`, 8.004424722059776`, 0.0674626870450525`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(iind = 1;\)\), "\[IndentingNewLine]", 
    \(\(jind = 1;\)\), "\[IndentingNewLine]", 
    \(\(While[
        iind < 5, \[IndentingNewLine]While[
          jind < 5, \[IndentingNewLine]\[IndentingNewLine]sigmaset =  .01 + \
\((iind - 1)\)\  .98/
                  4; \[IndentingNewLine]epsset =  .01 + \((jind - 1)\)\  .98/
                  4; \[IndentingNewLine]\[IndentingNewLine]\[IndentingNewLine]\
Vlo = 0; \[IndentingNewLine]Vstart = 0.5; \[IndentingNewLine]Vhi = 
            1000; \[IndentingNewLine]Vin = Vstart; \[IndentingNewLine]crit = 
            1; \[IndentingNewLine]While[
            crit > 0.01, \[IndentingNewLine]prepar = {\[Sigma] \[Rule] 
                  sigmaset, \[Epsilon] \[Rule] epsset, \[Beta] \[Rule] 1, 
                f \[Rule] 1/12, p \[Rule] 5/12, V \[Rule] Vin, 
                In \[Rule] 14}; \[IndentingNewLine]If[computemax[ .73] < 5, 
              Vlo = Vin; Vin =  .5\ Vin +  .5\ Vhi, Vhi = Vin; 
              Vin =  .5\ Vin +  .5\ Vlo]; \[IndentingNewLine]crit = 
              Abs[computemax[ .73] - 
                  5];\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]Print[
            Vin]; \[IndentingNewLine]\[IndentingNewLine]prepar = {\[Sigma] \
\[Rule] sigmaset, \[Epsilon] \[Rule] epsset, \[Beta] \[Rule] 1, 
              f \[Rule] 1/12, p \[Rule] 5/12, V \[Rule] Vin, 
              In \[Rule] 14}; \[IndentingNewLine]biplot = 
            Plot[{computemax[s], Survivors[computemax[s]]}, {s, 0.01,  .99}, 
              PlotRange \[Rule] {{0, 1}, {0, 10}}, 
              PlotRange \[Rule] {{0, 1}, {0, 8}}, 
              AxesLabel \[Rule] {"\<s\>", "\<Children\>"}, 
              PlotStyle \[Rule] {{Thickness[ .008]}, {Dashing[{ .02,  .02}], 
                    Thickness[ .008]}}]; \ \[IndentingNewLine]\
\[IndentingNewLine]jind = 
            jind + 1;\[IndentingNewLine]]; \[IndentingNewLine]jind = 
          1; \[IndentingNewLine]iind = 
          iind + 1;\[IndentingNewLine]];\)\)}], "Input"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(jind\)\" is similar to \
existing symbol \"\!\(iind\)\"."\)], "Message"],

Cell[BoxData[
    \(62.96875`\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.0618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(10)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.39036 .61803 m
.39036 .61803 L
.39162 .61803 L
.39298 .61803 L
.39853 .61803 L
.40832 .61803 L
.41752 .61803 L
.42264 .61803 L
.42405 .61803 L
.42481 .61803 L
.42553 .61803 L
.42679 .55623 L
.42746 .55623 L
.42817 .55623 L
.43782 .55623 L
.44905 .55623 L
.45942 .55623 L
.46452 .55623 L
.46576 .55623 L
.46709 .55623 L
.46785 .49443 L
.46855 .49443 L
.46992 .49443 L
.48133 .49443 L
.49207 .49443 L
.50205 .49443 L
.50692 .49443 L
.5115 .49443 L
.51404 .49443 L
.51474 .49443 L
.51547 .49443 L
.51679 .43262 L
.51797 .43262 L
.51907 .43262 L
.52158 .43262 L
.5429 .43262 L
.55365 .43262 L
.56383 .43262 L
.56827 .43262 L
.57298 .43262 L
.57416 .43262 L
.57543 .43262 L
.57616 .37082 L
.57683 .37082 L
.57814 .37082 L
.58292 .37082 L
.60404 .37082 L
.62368 .37082 L
.63343 .37082 L
.63822 .37082 L
Mistroke
.64263 .37082 L
.64511 .37082 L
.64635 .37082 L
.64706 .37082 L
.64772 .30902 L
.64844 .30902 L
.64911 .30902 L
.65038 .30902 L
.65324 .30902 L
.66289 .30902 L
.70223 .30902 L
.7225 .30902 L
.72834 .30902 L
.7312 .30902 L
.73245 .30902 L
.73312 .30902 L
.73383 .30902 L
.73507 .24721 L
.73623 .24721 L
.73876 .24721 L
.74409 .24721 L
.78669 .24721 L
.80802 .24721 L
.8174 .24721 L
.82238 .24721 L
.82774 .24721 L
.83025 .24721 L
.83289 .24721 L
.83399 .24721 L
.83515 .24721 L
.83643 .18541 L
.83762 .18541 L
.84689 .18541 L
.86722 .18541 L
.88774 .18541 L
.90996 .18541 L
.92038 .18541 L
.9314 .18541 L
.93594 .18541 L
.93843 .18541 L
.93967 .18541 L
.9408 .18541 L
.94214 .12361 L
.94285 .12361 L
.9436 .12361 L
.94615 .12361 L
.95114 .12361 L
.98994 .12361 L
.99 .12361 L
Mfstroke
[ .02 .02 ] 0 setdash
.01 .01731 m
.04976 .0861 L
.09311 .16113 L
.11419 .19761 L
.13383 .2316 L
.1385 .23967 L
.14356 .24843 L
.14588 .25244 L
.14715 .25464 L
.14834 .2567 L
.14935 .25845 L
.15044 .25104 L
.15165 .25305 L
.15275 .2549 L
.15401 .25699 L
.15535 .25923 L
.15612 .26052 L
.15682 .25199 L
.15752 .25312 L
.15819 .25419 L
.16067 .25817 L
.16135 .25927 L
.16206 .26042 L
.16335 .25239 L
.1645 .25416 L
.16573 .25606 L
.16795 .25949 L
.1693 .26159 L
.17059 .25303 L
.17174 .25474 L
.17299 .2566 L
.17539 .26016 L
.17674 .26216 L
.17798 .253 L
.17907 .25454 L
.18026 .25624 L
.18266 .25965 L
.18404 .26161 L
.18534 .26345 L
.18606 .25298 L
.18683 .25403 L
.18819 .25588 L
.19085 .2595 L
.19334 .26288 L
.19459 .26458 L
.19594 .25431 L
.19671 .2553 L
.19744 .25625 L
.1988 .25802 L
.2018 .26192 L
Mistroke
.20326 .26381 L
.20459 .26553 L
.20583 .25441 L
.20699 .25585 L
.20955 .25902 L
.21235 .26248 L
.21371 .26416 L
.21496 .2657 L
.21615 .25382 L
.21728 .25514 L
.21976 .25806 L
.2225 .26127 L
.22503 .26424 L
.22631 .26574 L
.2275 .26715 L
.22875 .25447 L
.22941 .25521 L
.23012 .256 L
.23566 .26216 L
.23817 .26495 L
.23939 .26631 L
.2405 .26754 L
.24167 .25392 L
.24293 .25524 L
.24559 .25803 L
.24992 .26258 L
.25222 .26499 L
.25348 .26632 L
.25468 .26758 L
.25603 .25318 L
.25727 .2544 L
.25968 .25679 L
.26498 .26202 L
.26718 .2642 L
.26952 .26651 L
.27074 .26772 L
.27208 .25224 L
.27331 .25337 L
.27446 .25444 L
.27948 .25909 L
.28476 .26399 L
.28753 .26655 L
.28829 .26726 L
.2891 .26801 L
.28986 .2508 L
.29056 .2514 L
.29587 .256 L
.30085 .26031 L
.30358 .26267 L
.30613 .26488 L
Mistroke
.3083 .26676 L
.30952 .26781 L
.31063 .24958 L
.31185 .25055 L
.31318 .25162 L
.31559 .25356 L
.32096 .25788 L
.32669 .26247 L
.32947 .26471 L
.33083 .26581 L
.33209 .26681 L
.33323 .26773 L
.33444 .24803 L
.33565 .24893 L
.33698 .24992 L
.3473 .25757 L
.35238 .26134 L
.35461 .26299 L
.35707 .26482 L
.35842 .26582 L
.35969 .24453 L
.36103 .24544 L
.36247 .24642 L
.36834 .25041 L
.3786 .25739 L
.38337 .26063 L
.38599 .26241 L
.38846 .26409 L
.38914 .26455 L
.38986 .26504 L
.39066 .24144 L
.39139 .24189 L
.39404 .24353 L
.39924 .24674 L
.40971 .25321 L
.41548 .25678 L
.41832 .25854 L
.42095 .26016 L
.4234 .26167 L
.4241 .26211 L
.42476 .26252 L
.426 .23695 L
.42667 .23732 L
.42737 .23772 L
.42864 .23842 L
.43149 .24001 L
.44111 .24536 L
.45098 .25085 L
.45996 .25584 L
.46237 .25719 L
Mistroke
.46364 .25789 L
.46499 .25864 L
.46617 .2593 L
.46746 .23113 L
.46864 .23171 L
.46975 .23226 L
.48022 .23744 L
.49911 .24677 L
.50421 .2493 L
.50978 .25205 L
.51233 .25331 L
.51373 .254 L
.51504 .25465 L
.51628 .25526 L
.51761 .22393 L
.51882 .22445 L
.51993 .22493 L
.53899 .23318 L
.55835 .24156 L
.56366 .24385 L
.56934 .24631 L
.5721 .2475 L
.57346 .24809 L
.57471 .24863 L
.57585 .21354 L
.57706 .21399 L
.57961 .21493 L
.61844 .22933 L
.62813 .23293 L
.63834 .23671 L
.64369 .23869 L
.64515 .23923 L
.64596 .23953 L
.64672 .23982 L
.64742 .20006 L
.64819 .2003 L
.64953 .20072 L
.6598 .20389 L
.67984 .21008 L
.70189 .2169 L
.71198 .22002 L
.72283 .22337 L
.72808 .22499 L
.73067 .22579 L
.73193 .22618 L
.73307 .22653 L
.73418 .1815 L
.73524 .18176 L
.73754 .18233 L
.74243 .18354 L
Mistroke
.78214 .19335 L
.80228 .19833 L
.81295 .20097 L
.82437 .2038 L
.83003 .20519 L
.83281 .20588 L
.83403 .20618 L
.83538 .20652 L
.83659 .15511 L
.83771 .15532 L
.84019 .15578 L
.84541 .15675 L
.86504 .16039 L
.90489 .16778 L
.92554 .17161 L
.93057 .17254 L
.93592 .17353 L
.93751 .17382 L
.93901 .1741 L
.94035 .17435 L
.94111 .17449 L
.9418 .11641 L
.94307 .11657 L
.94446 .11674 L
.94727 .11709 L
.98882 .12222 L
.99 .12237 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool2
0004Ool20003Ool4000POol20004Ool20005Ool3000POol20004Ool20003Ool3000QOol20004Ool2
0004Ool2000WOol5000BOol004Eoo`04001oogoo0008Ool00`00Oomoo`0POol01000Oomoo`002goo
00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`0027oo00@007ooOol0
02Qoo`03001oogoo019oo`00AGoo00@007ooOol000Uoo`03001oogoo01moo`04001oogoo0008Ool5
000OOol01000Oomoo`0027oo00@007ooOol001moo`04001oogoo0008Ool01000Oomoo`00:7oo00<0
07ooOol04Woo0015Ool01000Oomoo`002Woo00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo
000POol01000Oomoo`0027oo0`0087oo00@007ooOol000Uoo`8002Uoo`03001oogoo019oo`00AGoo
00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`002Goo00<007oo000087oo00@007ooOol0
00Uoo`03001oogoo01moo`04001oogoo0008Ool01000Oomoo`00:7oo00<007ooOol04Woo0016Ool2
000:Ool2000QOol2000;Ool2000QOol2000:Ool3000POol2000:Ool2000XOol2000DOol00?moob5o
o`00ogoo8Goo003oOolQOol00?mooaAoo`<000Yoo`00ogoo5goo00<007ooOol01goo000NOoo^0007
Ool3000:Ool001ioo`03001oogoo02aoo`03001oogoo02aoo`03001oogoo02eoo`03001oogoo02ao
o`03001oogoo02eoo`03001oogoo00Eoo`@000Uoo`007Woo00<007ooOol0ogoo000NOol00`00Oomo
o`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001io
o`03001oogoo0?moo`007Woo00D007ooOomoo`000?eoo`007Woo00D007ooOomoo`000?eoo`007Woo
00<007ooOol00Woo00<007ooOol0nWoo000NOol00`00Oomoo`02Ool00`00Oomoo`3jOol001ioo`03
001oogoo00=oo`03001oogoo0?Uoo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001io
o`03001oogoo0?moo`007Woo00<007ooOol01Woo00<007ooOol0mWoo000NOol00`00Oomoo`06Ool0
0`00Oomoo`3fOol001ioo`03001oogoo00Moo`03001oogoo0?Eoo`007Woo00<007ooOol01goo00<0
07ooOol0mGoo000NOol00`00Oomoo`08Ool00`00Oomoo`3dOol001ioo`03001oogoo0?moo`007Woo
00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo00]oo`03001oogoo0?5oo`00
7Woo00<007ooOol02goo00<007ooOol0lGoo000NOol00`00Oomoo`0<Ool00`00Oomoo`3`Ool001Io
o`@000Aoo`03001oogoo00aoo`03001oogoo0<eoo`80025oo`005Woo00<007ooOol01Goo00<007oo
Ool03Goo00<007ooOol0c7oo00<007ooOol00goo1P005goo000GOol00`00Oomoo`04Ool2003MOol<
000GOol001Qoo`03001oogoo00=oo`03001oogoo0=aoo`03001oogoo021oo`005Woo00@007ooOol0
00Aoo`03001oogoo0=aoo`03001oogoo021oo`005goo0P001Goo00<007ooOol03goo00<007ooOol0
bWoo00<007ooOol087oo000NOol00`00Oomoo`0@Ool00`00Oomoo`39Ool00`00Oomoo`0POol001io
o`03001oogoo011oo`03001oogoo0<Uoo`03001oogoo021oo`007Woo00<007ooOol04Goo00<007oo
Ool0b7oo00<007ooOol087oo000NOol00`00Oomoo`0BOol00`00Oomoo`2^Ool2000GOol00`00Oomo
o`0POol001ioo`03001oogoo0<=oo`03001oo`0001Ioo`03001oogoo021oo`007Woo00<007ooOol0
`goo00<007ooOol017oo0`003goo00<007ooOol087oo000NOol00`00Oomoo`33Ool00`00Oomoo`07
Ool30003Ool30006Ool00`00Oomoo`0POol001ioo`03001oogoo01Aoo`03001oogoo0;moo`<000=o
o`03001oogoo021oo`007Woo00<007ooOol057oo00<007ooOol0aGoo00<007ooOol087oo000NOol0
0`00Oomoo`0EOol00`00Oomoo`34Ool00`00Oomoo`0POol001ioo`03001oogoo01Eoo`03001oogoo
09=oo`8001IooaX0029oo`007Woo00<007ooOol05Woo00<007ooOol0TGoo00<007ooOol017oo0P00
47oo00<007ooOol0>Goo000NOol00`00Oomoo`2cOol3000=Ool00`00Oomoo`0iOol001ioo`03001o
ogoo0;Yoo`03001oogoo00Ioo`03001oogoo03Uoo`007Woo00<007ooOol0V7oo00<007ooOol087oo
100017oo00<007ooOol0>Goo000NOol00`00Oomoo`2IOol2000XOol00`00Oomoo`0iOol001ioo`03
001oogoo01Uoo`03001oogoo07moo`8000eoo`03001oogoo01Ioo`03001oogoo03Uoo`007Woo00<0
07ooOol06Goo00<007ooOol0JGoo0P003goo00<007ooOol027oo00<007ooOol01Woo00<007ooOol0
5Woo00<007ooOol0>Goo000NOol00`00Oomoo`0JOol00`00Oomoo`1ZOol2000=Ool00`00Oomoo`09
Ool20006Ool00`00Oomoo`0EOol00`00Oomoo`0jOol001ioo`03001oogoo01Yoo`03001oogoo06ao
o`8000]oo`03001oogoo00]oo`8000Aoo`03001oogoo01Eoo`03001oogoo03Yoo`007Woo00<007oo
Ool06goo00<007ooOol0FGoo00<007ooOol077oo00<007ooOol04Goo00<007ooOol05Goo00<007oo
Ool0>Woo000NOol00`00Oomoo`1[Ool2000:Ool01@00Oomoogoo00002Goo00<007ooOol01Woo0P00
1Woo00<007ooOol0:Goo00<007ooOol0>Woo000NOol00`00Oomoo`1[Ool2000:Ool00`00Oomoo`02
Ool20007Ool00`00Oomoo`08Ool40002Ool00`00Oomoo`0YOol00`00Oomoo`0jOol001Qoo`<000=o
o`03001oogoo069oo`8000Moo`03001oogoo00Uoo`03001oogoo00Aoo`<000Aoo`03001oogoo03Yo
o`03001oogoo03Yoo`006Goo00<007ooOol00Woo00<007ooOol07Woo00<007ooOol0>7oo0P002Goo
00<007ooOol017oo00<007ooOol00goo00<007ooOol00goo00<007ooOol02goo00<007ooOol0>Woo
00<007ooOol0>Woo000FOol50003Ool2000POol00`00Oomoo`0ZOol00`00Oomoo`0:Ool00`00Ool0
0009Ool20004Ool00`00Oomoo`04Ool20003Ool00`00Oomoo`0:Ool2000UOolH000lOol001Ioo`04
001oogoo0004Ool00`00Oomoo`0OOol01000Oomoo`000Woo00D007ooOomoo`0001aoo`8000Aoo`03
001oogoo00Aoo`8000Aoo`03001oogoo01Qoo`8003Eoo`03001oogoo055oo`005goo00<007oo0000
17oo00<007ooOol07goo0P0000Aoo`00001oo`800003Ool0000000Ioo`04001oogoo0002Ool00`00
Oomoo`0:Ool00`00Oomoo`030003Ool00`00Oomoo`03Ool01000Oomoo`002Goo00<007oo0000BGoo
00<007ooOol0DGoo000HOol20004Ool00`00Oomoo`0POol01000Ool000000Woo0`0000Uoo`00Ool0
07oo001oo`00Ool00P000goo00@007ooOol000Aoo`03001oogoo009oo`03001oo`0000Eoo`07001o
ogooOol007oo00000goo0P0027oo0P00BGoo00<007ooOol0DGoo000NOol00`00Oomoo`0VOol01P00
Oomoogoo001oo`800007Ool007ooOol007oo00000goo00<007ooOol00`000Woo0P000Woo0P001Woo
00<007ooOol00Woo00<007ooOol03Goo00<007ooOol0Agoo00<007ooOol0DGoo000NOol00`00Oomo
o`0_Ool00`00Oomoo`07Ool00`00Oomoo`020003Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00
Oomoo`1GOol00`00Oomoo`1AOol001ioo`03001oogoo0:]oo`03001oogoo055oo`007Woo00<007oo
Ool0Zgoo00<007ooOol0DGoo000NOol00`00Oomoo`2ZOol00`00Oomoo`1BOol001ioo`03001oogoo
0:Yoo`03001oogoo059oo`007Woo00<007ooOol0ZWoo00<007ooOol0DWoo000NOol00`00Oomoo`2Z
Ool00`00Oomoo`1BOol001ioo`03001oogoo0:Yoo`03001oogoo059oo`007Woo00<007ooOol0ZWoo
00<007ooOol0DWoo000NOol00`00Oomoo`2ZOol00`00Oomoo`1BOol001ioo`03001oogoo09IooaD0
05Aoo`007Woo00<007ooOol0UWoo00<007ooOol0IWoo000NOol00`00Oomoo`2FOol00`00Oomoo`1V
Ool001ioo`03001oogoo09Ioo`03001oogoo06Ioo`007Woo00<007ooOol0UWoo00<007ooOol0IWoo
000NOol00`00Oomoo`2FOol00`00Oomoo`1VOol001ioo`03001oogoo09Ioo`03001oogoo06Ioo`00
7Woo00<007ooOol0UWoo00<007ooOol0IWoo000NOol00`00Oomoo`2FOol00`00Oomoo`1VOol001io
o`03001oogoo09Ioo`03001oogoo06Ioo`007Woo00<007ooOol0UWoo00<007ooOol0IWoo000NOol0
0`00Oomoo`2FOol00`00Oomoo`1VOol001Ioo`<000Eoo`03001oogoo09Ioo`03001oogoo06Ioo`00
5Woo00@007ooOol000Aoo`03001oogoo09Ioo`03001oogoo06Ioo`005Woo00@007ooOol000Aoo`80
08Iooa8006Qoo`005Woo0`001Goo00<007ooOol0QGoo00<007ooOol0Mgoo000GOol00`00Oomoo`04
Ool00`00Oomoo`25Ool00`00Oomoo`1gOol001Moo`<000Aoo`03001oogoo08Eoo`03001oogoo07Mo
o`007Woo00<007ooOol0QGoo00<007ooOol0Mgoo000NOol00`00Oomoo`25Ool00`00Oomoo`1gOol0
01ioo`03001oogoo08Eoo`03001oogoo07Moo`007Woo00<007ooOol0QGoo00<007ooOol0Mgoo000N
Ool00`00Oomoo`25Ool00`00Oomoo`1gOol001ioo`03001oogoo08Eoo`03001oogoo07Moo`007Woo
00<007ooOol0QGoo00<007ooOol0Mgoo000NOol00`00Oomoo`25Ool00`00Oomoo`1gOol001ioo`03
001oogoo08Eoo`03001oogoo07Moo`007Woo00<007ooOol0QGoo00<007ooOol0Mgoo000NOol00`00
Oomoo`25Ool00`00Oomoo`1gOol001ioo`03001oogoo07Moo`l007Uoo`007Woo00<007ooOol0Mgoo
00<007ooOol0QGoo000NOol00`00Oomoo`1gOol00`00Oomoo`25Ool001ioo`03001oogoo07Moo`03
001oogoo08Eoo`007Woo00<007ooOol0Mgoo00<007ooOol0QGoo000NOol00`00Oomoo`1gOol00`00
Oomoo`25Ool001ioo`03001oogoo07Moo`03001oogoo08Eoo`007Woo00<007ooOol0Mgoo00<007oo
Ool0QGoo000NOol00`00Oomoo`1gOol00`00Oomoo`25Ool001ioo`03001oogoo07Moo`03001oogoo
08Eoo`007Woo00<007ooOol0Mgoo00<007ooOol0QGoo000NOol00`00Oomoo`1gOol00`00Oomoo`25
Ool001ioo`03001oogoo07Moo`03001oogoo08Eoo`005goo0P001Goo00<007ooOol0Mgoo00<007oo
Ool0QGoo000FOol01000Oomoo`0017oo00<007ooOol0Mgoo00<007ooOol0QGoo000FOol01000Oomo
o`0017oo0P00K7oo3@00Qgoo000GOol20005Ool00`00Oomoo`1[Ool00`00Oomoo`2AOol001Ioo`04
001oogoo0004Ool00`00Oomoo`1[Ool00`00Oomoo`2AOol001Moo`8000Eoo`03001oogoo06]oo`03
001oogoo095oo`007Woo00<007ooOol0Jgoo00<007ooOol0TGoo000NOol00`00Oomoo`1[Ool00`00
Oomoo`2AOol001ioo`03001oogoo06]oo`03001oogoo095oo`007Woo00<007ooOol0Jgoo00<007oo
Ool0TGoo000NOol00`00Oomoo`1[Ool00`00Oomoo`2AOol001ioo`03001oogoo06]oo`03001oogoo
095oo`007Woo00<007ooOol0Jgoo00<007ooOol0TGoo000NOol00`00Oomoo`1[Ool00`00Oomoo`2A
Ool001ioo`03001oogoo06]oo`03001oogoo095oo`007Woo00<007ooOol0Jgoo00<007ooOol0TGoo
000NOol00`00Oomoo`1ROol:002COol001ioo`03001oogoo069oo`03001oogoo09Yoo`007Woo00<0
07ooOol0HWoo00<007ooOol0VWoo000NOol00`00Oomoo`1ROol00`00Oomoo`2JOol001ioo`03001o
ogoo069oo`03001oogoo09Yoo`007Woo00<007ooOol0HWoo00<007ooOol0VWoo000NOol00`00Oomo
o`1ROol00`00Oomoo`2JOol001ioo`03001oogoo069oo`03001oogoo09Yoo`007Woo00<007ooOol0
HGoo00<007ooOol0Vgoo000NOol00`00Oomoo`1QOol00`00Oomoo`2KOol001ioo`03001oogoo065o
o`03001oogoo09]oo`007Woo00<007ooOol0HGoo00<007ooOol0Vgoo000NOol00`00Oomoo`1QOol0
0`00Oomoo`2KOol0011oo`D0009oo`8000Eoo`03001oogoo065oo`03001oogoo09]oo`004Woo00D0
07ooOomoo`00009oo`03001oogoo009oo`03001oogoo05Uoo`03001oogoo00Eoo`03001oogoo09]o
o`004Woo00D007ooOomoo`00009oo`03001oogoo009oo`8005Yoo`T009eoo`004Woo00D007ooOomo
o`00009oo`03001oogoo0?moo`Eoo`004Woo00D007ooOomoo`00009oo`03001oogoo0?moo`Eoo`00
4Goo0P0017oo0P00ogoo27oo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol000Qoo`<00005Ool00000001oo`020002Ool30002Ool30004Ool400000goo
000000020003Ool300000goo00000002Ool2003ZOol000Moo`03001oogoo00=oo`04001oogoo0004
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0
0goo00@007ooOol00>]oo`001goo00<007ooOol00goo00@007ooOol000Aoo`03001oogoo009oo`03
001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool40002Ool01000Oomoo`00jgoo0007Ool0
0`00Oomoo`03Ool30004Ool20004Ool00`00Oomoo`03Ool30002Ool40003Ool20002Ool4003/Ool0
00Moo`04001oogoo0002Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`3kOol000Qoo`<0
0003Ool0000000Moo`04001oogooOol20006Ool2003mOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.8167, \
0.00421906, 0.0682658}}],

Cell[BoxData[
    \(4.892333984375`\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.0618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(10)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.01 .0618 m
.01231 .0618 L
.01478 .0618 L
.01598 .0618 L
.01711 .0618 L
.01813 .0618 L
.01924 .24721 L
.02055 .43262 L
.02179 .61803 L
s
.02179 .61803 m
.02179 .61803 L
s
.29407 .61803 m
.29407 .61803 L
.29539 .61803 L
.31525 .61803 L
.32069 .61803 L
.32643 .61803 L
.33133 .61803 L
.33267 .61803 L
.33341 .61803 L
.33411 .61803 L
.33546 .55623 L
.3367 .55623 L
.3555 .55623 L
.36619 .55623 L
.37621 .55623 L
.38125 .55623 L
.38373 .55623 L
.38494 .55623 L
.38604 .55623 L
.38732 .49443 L
.38802 .49443 L
.38868 .49443 L
.39156 .49443 L
.39661 .49443 L
.41825 .49443 L
.42829 .49443 L
.4389 .49443 L
.44327 .49443 L
.44568 .49443 L
.44796 .49443 L
.44925 .49443 L
.44998 .43262 L
.45065 .43262 L
.4531 .43262 L
.45791 .43262 L
.47874 .43262 L
.4983 .43262 L
.51698 .43262 L
.5221 .43262 L
.52489 .43262 L
.52749 .43262 L
.52864 .43262 L
.52972 .43262 L
.53096 .37082 L
.5321 .37082 L
.53713 .37082 L
.5767 .37082 L
.59674 .37082 L
.60737 .37082 L
.61879 .37082 L
Mistroke
.6244 .37082 L
.62973 .37082 L
.63205 .37082 L
.63332 .37082 L
.63452 .37082 L
.6352 .37082 L
.63594 .30902 L
.63722 .30902 L
.63973 .30902 L
.65933 .30902 L
.70156 .30902 L
.74223 .30902 L
.7627 .30902 L
.77164 .30902 L
.77635 .30902 L
.77893 .30902 L
.78019 .30902 L
.78135 .30902 L
.78258 .24721 L
.7839 .24721 L
.78672 .24721 L
.79168 .24721 L
.80145 .24721 L
.82299 .24721 L
.8638 .24721 L
.90305 .24721 L
.94483 .24721 L
.98505 .24721 L
.99 .24721 L
Mfstroke
[ .02 .02 ] 0 setdash
.01 .00062 m
.02935 .03447 L
.03921 .05574 L
.04181 .05943 L
.04318 .06138 L
.04393 .06244 L
.04463 .06344 L
.0459 .06808 L
.04657 .06908 L
.0473 .07015 L
.04976 .0738 L
.05126 .07603 L
.05268 .07815 L
.05397 .08005 L
.05469 .08112 L
.05536 .0787 L
.05666 .08054 L
.05783 .08221 L
.06047 .08595 L
.06294 .08946 L
.06561 .09326 L
.06683 .095 L
.06813 .09684 L
.06923 .09841 L
.07045 .09579 L
.07118 .09678 L
.07197 .09785 L
.07341 .09981 L
.07611 .10348 L
.07763 .10555 L
.07926 .10776 L
.07992 .10867 L
.08064 .10964 L
.08143 .10568 L
.08217 .10665 L
.08495 .11025 L
.08788 .11405 L
.09038 .1173 L
.09106 .11819 L
.09179 .11914 L
.09311 .11509 L
.09438 .11666 L
.09578 .11839 L
.0986 .12187 L
.10124 .12514 L
.10239 .12656 L
.10365 .12812 L
.10441 .1226 L
.10511 .12343 L
.1065 .12506 L
Mistroke
.10955 .12865 L
.1124 .13199 L
.1138 .13363 L
.11508 .13513 L
.11631 .13658 L
.11761 .13084 L
.11892 .13229 L
.12035 .13388 L
.12512 .13919 L
.12779 .14217 L
.12856 .14302 L
.12929 .14383 L
.12994 .14456 L
.13065 .13727 L
.13196 .13864 L
.13334 .14009 L
.13581 .14269 L
.14053 .14765 L
.1431 .15034 L
.14435 .15166 L
.14548 .15285 L
.14674 .1451 L
.14808 .14643 L
.15091 .14923 L
.15589 .15415 L
.15815 .15639 L
.16054 .15875 L
.16179 .15999 L
.1625 .16069 L
.16316 .15126 L
.16433 .15234 L
.16558 .1535 L
.17471 .16197 L
.17734 .16441 L
.17878 .16574 L
.18014 .167 L
.18129 .16806 L
.18253 .15793 L
.1832 .15851 L
.1839 .15912 L
.18516 .16021 L
.19106 .16531 L
.19654 .17006 L
.199 .17218 L
.20132 .17419 L
.2026 .1753 L
.20332 .17593 L
.20399 .1639 L
.20517 .16484 L
.20642 .16585 L
Mistroke
.21724 .17454 L
.22221 .17853 L
.22466 .1805 L
.22693 .18233 L
.22819 .18334 L
.22954 .17023 L
.23031 .1708 L
.23103 .17134 L
.23238 .17234 L
.23736 .17603 L
.24634 .18269 L
.2511 .18622 L
.25371 .18816 L
.25619 .19 L
.2575 .19097 L
.25823 .19152 L
.25891 .17602 L
.26012 .17684 L
.2614 .17771 L
.26625 .18101 L
.27687 .18823 L
.28591 .19437 L
.28839 .19606 L
.28969 .19694 L
.29105 .19787 L
.29226 .19869 L
.29357 .18144 L
.29477 .18218 L
.29588 .18287 L
.30672 .18956 L
.31695 .19588 L
.32613 .20156 L
.32865 .20311 L
.33131 .20476 L
.33358 .20616 L
.33487 .20696 L
.33608 .18694 L
.33737 .18766 L
.33874 .18842 L
.34121 .18979 L
.3468 .1929 L
.35697 .19856 L
.36692 .20409 L
.37605 .20917 L
.38122 .21205 L
.38382 .21349 L
.38453 .21389 L
.3853 .21431 L
.38602 .21471 L
.38667 .19118 L
Mistroke
.38739 .19153 L
.38814 .19191 L
.3895 .19258 L
.39257 .1941 L
.39814 .19685 L
.41891 .20712 L
.42859 .21191 L
.439 .21706 L
.44404 .21955 L
.44653 .22078 L
.44774 .22137 L
.44884 .22192 L
.44991 .19464 L
.45092 .19508 L
.45314 .19604 L
.45783 .19807 L
.49749 .21523 L
.518 .2241 L
.52298 .22625 L
.52573 .22744 L
.52833 .22857 L
.52904 .22887 L
.5298 .2292 L
.53063 .19677 L
.53139 .19705 L
.53419 .19809 L
.53967 .20012 L
.5785 .21452 L
.60007 .22252 L
.60952 .22602 L
.61986 .22986 L
.62471 .23166 L
.6299 .23358 L
.63241 .23451 L
.63365 .23497 L
.63479 .23539 L
.63583 .19648 L
.63693 .19682 L
.63924 .19754 L
.65965 .20384 L
.69863 .21589 L
.74012 .22871 L
.75923 .23461 L
.76932 .23773 L
.77485 .23944 L
.77757 .24028 L
.78006 .24105 L
.78145 .24148 L
.78215 .2417 L
.78291 .19355 L
Mistroke
.78368 .19374 L
.7845 .19394 L
.78599 .19431 L
.79136 .19564 L
.80184 .19823 L
.82252 .20334 L
.86512 .21387 L
.90617 .22402 L
.94565 .23378 L
.98765 .24416 L
.99 .24474 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool2
0004Ool20003Ool4000POol20004Ool20005Ool3000POol20004Ool20003Ool3000QOol20004Ool2
0004Ool2000WOol5000BOol004Eoo`04001oogoo0008Ool00`00Oomoo`0POol01000Oomoo`002goo
00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`0027oo00@007ooOol0
02Qoo`03001oogoo019oo`00AGoo00@007ooOol000Uoo`03001oogoo01moo`04001oogoo0008Ool5
000OOol01000Oomoo`0027oo00@007ooOol001moo`04001oogoo0008Ool01000Oomoo`00:7oo00<0
07ooOol04Woo0015Ool01000Oomoo`002Woo00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo
000POol01000Oomoo`0027oo0`0087oo00@007ooOol000Uoo`8002Uoo`03001oogoo019oo`00AGoo
00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`002Goo00<007oo000087oo00@007ooOol0
00Uoo`03001oogoo01moo`04001oogoo0008Ool01000Oomoo`00:7oo00<007ooOol04Woo0016Ool2
000:Ool2000QOol2000;Ool2000QOol2000:Ool3000POol2000:Ool2000XOol2000DOol00?moob5o
o`00ogoo8Goo003oOolQOol00?mooaAoo`<000Yoo`00ogoo5goo00<007ooOol01goo000NOoo^0007
Ool3000:Ool001ioo`03001oogoo02aoo`03001oogoo02aoo`03001oogoo02eoo`03001oogoo02ao
o`03001oogoo02eoo`03001oogoo00Eoo`@000Uoo`007Woo00@007ooOol00?ioo`007Woo00@007oo
Ool00?ioo`007Woo00D007ooOomoo`000?eoo`007Woo00D007ooOomoo`000?eoo`007Woo00<007oo
Ool00Woo00<007ooOol0nWoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<0
07ooOol0ogoo000NOol00`00Oomoo`04Ool00`00Oomoo`3hOol001ioo`03001oogoo00Eoo`03001o
ogoo0?Moo`007Woo00<007ooOol01Goo00<007ooOol0mgoo000NOol00`00Oomoo`06Ool00`00Oomo
o`3fOol001ioo`03001oo`00008000Aoo`800?Moo`007Woo00D007ooOomoo`000?eoo`007Woo00D0
07ooOomoo`000?eoo`007Woo00D007ooOomoo`000?eoo`007Woo00D007ooOomoo`0000Moo`800?Ao
o`007Woo00D007ooOomoo`0000Moo`800?Aoo`007Woo00D007ooOomoo`0000Uoo`03001oogoo0?5o
o`007Woo00D007ooOomoo`0000Uoo`800?9oo`007Woo00D007ooOomoo`000?eoo`007Woo00D007oo
Oomoo`000?eoo`007Woo00D007ooOomoo`0000aoo`800>moo`007Woo00D007ooOomoo`0000eoo`80
0>ioo`007Woo00D007ooOomoo`0000ioo`800>eoo`005Woo100017oo00D007ooOomoo`000?eoo`00
5Woo00<007ooOol01Goo00D007ooOomoo`00015oo`800>Yoo`005goo00<007ooOol017oo0P000Woo
00<007ooOol04Goo0P00j7oo000HOol00`00Oomoo`03Ool01@00Oomoogoo00004goo0P00j7oo000F
Ool01000Oomoo`0017oo00D007ooOomoo`0001Moo`03001oogoo0>=oo`005goo0P001Goo00D007oo
Oomoo`0001Moo`03001oogoo0>=oo`007Woo00D007ooOomoo`0001Qoo`800>=oo`007Woo00D007oo
Oomoo`0001Uoo`04001oogooOol2003NOol001ioo`05001oogooOol0000LOol30002Ool00`00Oomo
o`3IOol001ioo`05001oogooOol0000MOol01000Oomoogoo0P00fWoo000NOol01@00Oomoogoo0000
8Goo00<007oo00000Woo00<007ooOol0e7oo000NOol01@00Oomoogoo000097oo00@007ooOol00=Eo
o`007Woo00D007ooOomoo`0002Qoo`03001oogoo00800=1oo`007Woo00D007ooOomoo`0002Uoo`05
001oogooOol00003Ool2003:Ool001ioo`05001oogooOol0000^Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`32Ool001ioo`05001oogooOol0000_Ool20003Ool01000Oomoogoo0`00`Woo
000NOol01@00Oomoogoo0000=Goo00H007ooOol007oo0032Ool001ioo`05001oogooOol00010Ool0
1000Oomoo`001Woo0P00/Goo000NOol01@00Oomoogoo0000?Woo00<007oo00000goo0P0017oo00<0
07ooOol02Goo0P00G7oo00<007ooOol0AWoo000NOol01@00Oomoogoo0000?Woo0`001Goo00D007oo
Oomoo`0000]oo`04001oo`00000;Ool00`00Oomoo`0@Ool00`00Oomoo`0FOol2000QOol50014Ool0
01ioo`05001oogooOol00010Ool00`00Oomoo`04Ool01000Oomoo`0017oo00<007ooOol017oo00D0
07ooOomoo`0000Yoo`03001oogoo011oo`03001oogoo01Ioo`04001oo`00000OOol00`00Oomoo`16
Ool001ioo`05001oogooOol0001@Ool30003Ool00`00Oomoo`0<Ool01000Oomoogoo0`0037oo00<0
07ooOol00Woo00<007ooOol04Goo00<007ooOol017oo0P006Woo00<007ooOol01Goo0`00?Woo000N
Ool01@00Oomoogoo0000Dgoo0P0000=oo`00Ool01Woo00<007ooOol017oo00<007ooOol017oo0`00
2Goo00<007ooOol00goo0P006Woo0P008goo0`00>goo000NOol01@00Oomoogoo0000Ggoo0P0017oo
00<007ooOol047oo00<007ooOol01Goo0P006Woo0P00:7oo0`00=7oo000NOol01@00Oomoogoo0000
HGoo0P003goo00<007ooOol00goo00<007ooOol02goo0P006Goo0`009Goo0P00<Woo000NOol01@00
Oomoogoo0000Lgoo0P004goo0P006Woo0`00:7oo00<007ooOol0:goo000NOol01@00Oomoogoo0000
MGoo0`004Woo00<007ooOol017oo00<007ooOol087oo00<007ooOol06Goo1000:Goo000NOol01@00
Oomoogoo0000Sgoo00<007oo000067oo0P0027oo00<007ooOol08Goo0P008goo000NOol01@00Oomo
ogoo0000T7oo0P006Woo100017oo00<007ooOol08goo10007goo000HOol30003Ool01@00Oomoogoo
0000]7oo00<007ooOol0AWoo000IOol00`00Oomoo`02Ool01@00Oomoogoo0000/goo0P00;7oo1@00
5goo000FOol50003Ool20002Ool00`00Oomoo`2bOolb000GOol001Ioo`04001oogoo0004Ool01@00
Oomoogoo0000]7oo00<007ooOol0AWoo000GOol00`00Ool00004Ool01@00Oomoogoo0000]7oo00<0
07ooOol0AWoo000HOol20004Ool01@00Oomoogoo0000]7oo00<007ooOol0AWoo000NOol01@00Oomo
ogoo0000]7oo00<007ooOol0AWoo000NOol01@00Oomoogoo0000]7oo00<007ooOol0AWoo000NOol0
1@00Oomoogoo0000]7oo00<007ooOol0AWoo000NOol01@00Oomoogoo0000]7oo00<007ooOol0AWoo
000NOol01@00Oomoogoo0000]7oo00<007ooOol0AWoo000NOol01@00Oomoogoo0000]7oo00<007oo
Ool0AWoo000NOol01@00Oomoogoo0000]7oo00<007ooOol0AWoo000NOol01@00Oomoogoo0000]7oo
00<007ooOol0AWoo000NOol01@00Oomoogoo0000]7oo00<007ooOol0AWoo000NOol01@00Oomoogoo
0000]7oo00<007ooOol0AWoo000NOol01@00Oomoogoo0000]7oo00<007ooOol0AWoo000NOol01@00
Oomoogoo0000TGoo9000B7oo000NOol01@00Oomoogoo0000TGoo00<007ooOol0JGoo000NOol01@00
Oomoogoo0000TGoo00<007ooOol0JGoo000NOol01@00Oomoogoo0000TGoo00<007ooOol0JGoo000N
Ool01@00Oomoogoo0000TGoo00<007ooOol0JGoo000NOol01@00Oomoogoo0000TGoo00<007ooOol0
JGoo000NOol01@00Oomoogoo0000TGoo00<007ooOol0JGoo000NOol01@00Oomoogoo0000TGoo00<0
07ooOol0JGoo000NOol01@00Oomoogoo0000TGoo00<007ooOol0JGoo000NOol01@00Oomoogoo0000
TGoo00<007ooOol0JGoo000NOol01@00Oomoogoo0000TGoo00<007ooOol0JGoo000NOol01@00Oomo
ogoo0000TGoo00<007ooOol0JGoo000FOol30005Ool01@00Oomoogoo0000TGoo00<007ooOol0JGoo
000FOol01000Oomoo`0017oo00D007ooOomoo`00095oo`03001oogoo06Uoo`005Woo00@007ooOol0
00Aoo`80009oo`03001oogoo07IooaX006]oo`005Woo0`001Goo00D007ooOomoo`0007Qoo`03001o
ogoo089oo`005goo00<007ooOol017oo00D007ooOomoo`0007Qoo`03001oogoo089oo`005goo0`00
17oo00D007ooOomoo`0007Qoo`03001oogoo089oo`007Woo00D007ooOomoo`0007Qoo`03001oogoo
089oo`007Woo00D007ooOomoo`0007Qoo`03001oogoo089oo`007Woo00D007ooOomoo`0007Qoo`03
001oogoo089oo`007Woo00D007ooOomoo`0007Qoo`03001oogoo089oo`007Woo00D007ooOomoo`00
07Qoo`03001oogoo089oo`007Woo00D007ooOomoo`0007Qoo`03001oogoo089oo`007Woo00D007oo
Oomoo`0007Qoo`03001oogoo089oo`007Woo00D007ooOomoo`0007Qoo`03001oogoo089oo`007Woo
00D007ooOomoo`0007Qoo`03001oogoo089oo`007Woo00D007ooOomoo`0007Qoo`03001oogoo089o
o`007Woo00D007ooOomoo`0007Qoo`03001oogoo089oo`007Woo00D007ooOomoo`0006Eooa@008Ao
o`007Woo00D007ooOomoo`0006Eoo`03001oogoo09Eoo`007Woo00D007ooOomoo`0006Eoo`03001o
ogoo09Eoo`007Woo00D007ooOomoo`0006Eoo`03001oogoo09Eoo`007Woo00D007ooOomoo`0006Eo
o`03001oogoo09Eoo`007Woo00D007ooOomoo`0006Eoo`03001oogoo09Eoo`007Woo00D007ooOomo
o`0006Eoo`03001oogoo09Eoo`007Woo00D007ooOomoo`0006Eoo`03001oogoo09Eoo`007Woo00D0
07ooOomoo`0006Eoo`03001oogoo09Eoo`007Woo00D007ooOomoo`0006Eoo`03001oogoo09Eoo`00
7Woo00D007ooOomoo`0006Eoo`03001oogoo09Eoo`007Woo00D007ooOomoo`0006Eoo`03001oogoo
09Eoo`007Woo00D007ooOomoo`0006Eoo`03001oogoo09Eoo`005goo0P001Goo00D007ooOomoo`00
06Eoo`03001oogoo09Eoo`005Woo00@007ooOol000Aoo`05001oogooOol0001UOol00`00Oomoo`2E
Ool001Ioo`04001oogoo0004Ool20002Ool00`00Oomoo`1DOol@002GOol001Moo`8000Eoo`05001o
ogooOol0001FOol00`00Oomoo`2TOol001Ioo`04001oogoo0004Ool01@00Oomoogoo0000EWoo00<0
07ooOol0Y7oo000GOol20005Ool01@00Oomoogoo0000EWoo00<007ooOol0Y7oo000NOol01@00Oomo
ogoo0000EWoo00<007ooOol0Y7oo000NOol01@00Oomoogoo0000EWoo00<007ooOol0Y7oo000NOol0
1@00Oomoogoo0000EWoo00<007ooOol0Y7oo000NOol01@00Oomoogoo0000EWoo00<007ooOol0Y7oo
000NOol00`00Oomoo`02Ool00`00Oomoo`1COol00`00Oomoo`2TOol001ioo`03001oogoo009oo`03
001oogoo05=oo`03001oogoo0:Aoo`007Woo00<007ooOol00Woo00<007ooOol0Dgoo00<007ooOol0
Y7oo000NOol00`00Oomoo`02Ool00`00Oomoo`1COol00`00Oomoo`2TOol001ioo`03001oogoo009o
o`03001oogoo05=oo`03001oogoo0:Aoo`007Woo00<007ooOol00Woo00<007ooOol0Dgoo00<007oo
Ool0Y7oo000NOol00`00Oomoo`02Ool00`00Oomoo`17Ool=002VOol001ioo`03001oogoo009oo`03
001oogoo04Moo`03001oogoo0;1oo`007Woo00<007ooOol00Woo00<007ooOol0Agoo00<007ooOol0
/7oo000NOol00`00Oomoo`02Ool00`00Oomoo`17Ool00`00Oomoo`2`Ool001ioo`03001oogoo009o
o`03001oogoo04Moo`03001oogoo0;1oo`007Woo00<007ooOol00Woo00<007ooOol0Agoo00<007oo
Ool0/7oo000NOol00`00Oomoo`02Ool00`00Oomoo`17Ool00`00Oomoo`2`Ool001ioo`03001oogoo
009oo`03001oogoo04Moo`03001oogoo0;1oo`007Woo00<007ooOol00Woo00<007ooOol0Agoo00<0
07ooOol0/7oo000NOol00`00Oomoo`02Ool00`00Oomoo`17Ool00`00Oomoo`2`Ool001ioo`03001o
ogoo009oo`03001oogoo04Moo`03001oogoo0;1oo`007Woo00<007ooOol00Woo00<007ooOol0Agoo
00<007ooOol0/7oo000NOol00`00Oomoo`02Ool00`00Oomoo`17Ool00`00Oomoo`2`Ool0011oo`D0
009oo`8000Eoo`03001oogoo009oo`03001oogoo04Moo`03001oogoo0;1oo`004Woo00D007ooOomo
o`00009oo`03001oogoo009oo`04001oogooOol2000oOol00`00Oomoo`07Ool00`00Oomoo`2`Ool0
019oo`05001oogooOol00002Ool00`00Oomoo`02Ool20003Ool00`00Oomoo`0mOol;002bOol0019o
o`05001oogooOol00002Ool00`00Oomoo`3oOol5Ool0019oo`05001oogooOol00002Ool00`00Oomo
o`3oOol5Ool0015oo`8000Aoo`800?moo`Qoo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo0008Ool300001Goo00000000Ool00P000Woo0`000Woo0`00
17oo100000=oo`0000000P000goo0`0000=oo`0000000Woo0P00jWoo0007Ool00`00Oomoo`03Ool0
1000Oomoo`0017oo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000=oo`03001oogoo009o
o`03001oogoo00=oo`04001oogoo003[Ool000Moo`03001oogoo00=oo`04001oogoo0004Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000goo00<007ooOol00Woo10000Woo00@007ooOol0
0>]oo`001goo00<007ooOol00goo0`0017oo0P0017oo00<007ooOol00goo0`000Woo10000goo0P00
0Woo1000k7oo0007Ool01000Oomoo`000Woo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol0
ngoo0008Ool300000goo00000007Ool01000Oomoogoo0P001Woo0P00oGoo003oOolQOol00?moob5o
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.8167, \
0.00421906, 0.0682658}}],

Cell[BoxData[
    \(1.7200927734375`\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.0618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(10)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.01 .0618 m
.02935 .0618 L
.04976 .0618 L
.05493 .0618 L
.05778 .0618 L
.06047 .0618 L
.06297 .0618 L
.06366 .0618 L
.06439 .0618 L
.06569 .12361 L
.06686 .12361 L
.06796 .12361 L
.06916 .18541 L
.07045 .18541 L
.07185 .18541 L
.07262 .18541 L
.07335 .18541 L
.07421 .24721 L
.07499 .24721 L
.07652 .24721 L
.07722 .24721 L
.07796 .24721 L
.07929 .30902 L
.08003 .30902 L
.08072 .30902 L
.08228 .30902 L
.08369 .30902 L
.08502 .30902 L
.08621 .30902 L
.08751 .37082 L
.08818 .37082 L
.08892 .37082 L
.09042 .37082 L
.09311 .37082 L
.09553 .37082 L
.09619 .37082 L
.0969 .37082 L
.09817 .43262 L
.09886 .43262 L
.09961 .43262 L
.10096 .43262 L
.1035 .43262 L
.10803 .43262 L
.11302 .43262 L
.11437 .43262 L
.11582 .43262 L
.11653 .43262 L
.11719 .43262 L
.11844 .49443 L
.11913 .49443 L
Mistroke
.11987 .49443 L
.12119 .49443 L
.12419 .49443 L
.13448 .49443 L
.17732 .49443 L
.19884 .49443 L
.21861 .49443 L
.22861 .49443 L
.23793 .49443 L
.24263 .49443 L
.24399 .49443 L
.24527 .49443 L
.24641 .49443 L
.24766 .43262 L
.24894 .43262 L
.25035 .43262 L
.25321 .43262 L
.25833 .43262 L
.29975 .43262 L
.3188 .43262 L
.32959 .43262 L
.33485 .43262 L
.33961 .43262 L
.34208 .43262 L
.34476 .43262 L
.34599 .43262 L
.34728 .43262 L
.34839 .43262 L
.34961 .37082 L
.35032 .37082 L
.351 .37082 L
.35227 .37082 L
.35512 .37082 L
.36028 .37082 L
.382 .37082 L
.42141 .37082 L
.44133 .37082 L
.45192 .37082 L
.45748 .37082 L
.46334 .37082 L
.46584 .37082 L
.46722 .37082 L
.46852 .37082 L
.46926 .37082 L
.47006 .30902 L
.47079 .30902 L
.47146 .30902 L
.47419 .30902 L
.48415 .30902 L
.50371 .30902 L
Mistroke
.54422 .30902 L
.58318 .30902 L
.60484 .30902 L
.61512 .30902 L
.62465 .30902 L
.62709 .30902 L
.62939 .30902 L
.63067 .30902 L
.63138 .30902 L
.63204 .24721 L
.63321 .24721 L
.63444 .24721 L
.64512 .24721 L
.66457 .24721 L
.70366 .24721 L
.74528 .24721 L
.78534 .24721 L
.82792 .24721 L
.84923 .24721 L
.8586 .24721 L
.86358 .24721 L
.86619 .24721 L
.86894 .24721 L
.87013 .24721 L
.8714 .24721 L
.87213 .18541 L
.8728 .18541 L
.87409 .18541 L
.87881 .18541 L
.88808 .18541 L
.9084 .18541 L
.94956 .18541 L
.98917 .18541 L
.99 .18541 L
Mfstroke
[ .02 .02 ] 0 setdash
.01 .00062 m
.02935 .00181 L
.04976 .00308 L
.05493 .00339 L
.05778 .00357 L
.06047 .00374 L
.06297 .00389 L
.06366 .00393 L
.06439 .00398 L
.06569 .00812 L
.06686 .00826 L
.06796 .0084 L
.06916 .01282 L
.07045 .01306 L
.07185 .01332 L
.07262 .01347 L
.07335 .0136 L
.07421 .01835 L
.07499 .01854 L
.07652 .01892 L
.07722 .01909 L
.07796 .01927 L
.07929 .0245 L
.08003 .02473 L
.08072 .02494 L
.08228 .02543 L
.08369 .02586 L
.08502 .02627 L
.08621 .02664 L
.08751 .03245 L
.08818 .0327 L
.08892 .03297 L
.09042 .03353 L
.09311 .03453 L
.09553 .03542 L
.09619 .03567 L
.0969 .03593 L
.09817 .04247 L
.09886 .04277 L
.09961 .04309 L
.10096 .04368 L
.1035 .04478 L
.10803 .04674 L
.11302 .0489 L
.11437 .04948 L
.11582 .05011 L
.11653 .05041 L
.11719 .0507 L
.11844 .05856 L
.11913 .0589 L
Mistroke
.11987 .05927 L
.12119 .05992 L
.12419 .0614 L
.13448 .06649 L
.17732 .08767 L
.19884 .09831 L
.21861 .10808 L
.22861 .11303 L
.23793 .11764 L
.24263 .11996 L
.24399 .12063 L
.24527 .12127 L
.24641 .12183 L
.24766 .10714 L
.24894 .1077 L
.25035 .10831 L
.25321 .10954 L
.25833 .11176 L
.29975 .12968 L
.3188 .13792 L
.32959 .14259 L
.33485 .14486 L
.33961 .14692 L
.34208 .14799 L
.34476 .14915 L
.34599 .14968 L
.34728 .15024 L
.34839 .15072 L
.34961 .12964 L
.35032 .12991 L
.351 .13016 L
.35227 .13063 L
.35512 .13169 L
.36028 .1336 L
.382 .14165 L
.42141 .15627 L
.44133 .16365 L
.45192 .16758 L
.45748 .16964 L
.46334 .17182 L
.46584 .17274 L
.46722 .17326 L
.46852 .17374 L
.46926 .17401 L
.47006 .14526 L
.47079 .14548 L
.47146 .14569 L
.47419 .14653 L
.48415 .14961 L
.50371 .15566 L
Mistroke
.54422 .16817 L
.58318 .18021 L
.60484 .18691 L
.61512 .19008 L
.62465 .19303 L
.62709 .19378 L
.62939 .19449 L
.63067 .19489 L
.63138 .19511 L
.63204 .15625 L
.63321 .15654 L
.63444 .15684 L
.64512 .15948 L
.66457 .16429 L
.70366 .17396 L
.74528 .18424 L
.78534 .19415 L
.82792 .20467 L
.84923 .20994 L
.8586 .21226 L
.86358 .21349 L
.86619 .21413 L
.86894 .21481 L
.87013 .21511 L
.8714 .21542 L
.87213 .1617 L
.8728 .16183 L
.87409 .16207 L
.87881 .16294 L
.88808 .16466 L
.9084 .16843 L
.94956 .17606 L
.98917 .1834 L
.99 .18356 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool2
0004Ool20003Ool4000POol20004Ool20005Ool3000POol20004Ool20003Ool3000QOol20004Ool2
0004Ool2000WOol5000BOol004Eoo`04001oogoo0008Ool00`00Oomoo`0POol01000Oomoo`002goo
00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`0027oo00@007ooOol0
02Qoo`03001oogoo019oo`00AGoo00@007ooOol000Uoo`03001oogoo01moo`04001oogoo0008Ool5
000OOol01000Oomoo`0027oo00@007ooOol001moo`04001oogoo0008Ool01000Oomoo`00:7oo00<0
07ooOol04Woo0015Ool01000Oomoo`002Woo00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo
000POol01000Oomoo`0027oo0`0087oo00@007ooOol000Uoo`8002Uoo`03001oogoo019oo`00AGoo
00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`002Goo00<007oo000087oo00@007ooOol0
00Uoo`03001oogoo01moo`04001oogoo0008Ool01000Oomoo`00:7oo00<007ooOol04Woo0016Ool2
000:Ool2000QOol2000;Ool2000QOol2000:Ool3000POol2000:Ool2000XOol2000DOol00?moob5o
o`00ogoo8Goo003oOolQOol00?mooaAoo`<000Yoo`00ogoo5goo00<007ooOol01goo000NOoo^0007
Ool3000:Ool001ioo`03001oogoo00aoo`03001oogoo01eoo`03001oogoo02aoo`03001oogoo02eo
o`03001oogoo02aoo`03001oogoo02eoo`03001oogoo00Eoo`@000Uoo`007Woo00<007ooOol03Goo
00<007ooOol0kgoo000NOol00`00Oomoo`0=Ool2003`Ool001ioo`03001oogoo00ioo`03001oogoo
0>ioo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo015oo`800>ao
o`007Woo00<007ooOol04goo00<007ooOol0jGoo000NOol00`00Oomoo`0COol00`00Oomoo`3YOol0
01ioo`03001oogoo01Aoo`03001oogoo0>Qoo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`0H
Ool00`00Oomoo`3TOol001ioo`03001oogoo01Uoo`03001oogoo0>=oo`007Woo00<007oo00003@00
lWoo000NOol00`00Oomoo`0<Ool00`00Oomoo`0=Ool2003QOol001ioo`03001oogoo00aoo`03001o
ogoo00moo`800=moo`007Woo00<007ooOol037oo00<007ooOol04Goo0P00gGoo000NOol00`00Oomo
o`0<Ool00`00Oomoo`3`Ool001ioo`03001oogoo00aoo`03001oogoo0?1oo`007Woo00<007ooOol0
37oo00<007ooOol05Woo0`00egoo000NOol00`00Oomoo`0<Ool00`00Oomoo`0IOol00`00Oomoo`3D
Ool001ioo`03001oogoo00aoo`03001oogoo01Yoo`03001oogoo0==oo`007Woo00<007ooOol037oo
00<007ooOol0l7oo000NOol00`00Oomoo`0<Ool00`00Oomoo`0NOol2003@Ool001ioo`03001oogoo
00aoo`03001oogoo021oo`8000Ioo`03001oogoo0<Eoo`007Woo00<007ooOol037oo00<007ooOol0
8Woo0P0017oo00<007ooOol0aGoo000FOol40004Ool00`00Oomoo`0<Ool00`00Oomoo`0XOol00`00
Oomoo`02Ool00`00Oomoo`30Ool001Ioo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo02Mo
o`8000Eoo`800<1oo`005goo00<007ooOol017oo0P003Goo0P00<Goo0P00_Woo000HOol00`00Oomo
o`03Ool00`00Oomoo`0=Ool00`00Oomoo`3_Ool001Ioo`04001oogoo0004Ool00`00Oomoo`0=Ool0
0`00Oomoo`0dOol2000<Ool00`00Oomoo`2ZOol001Moo`8000Eoo`03001oogoo00eoo`03001oogoo
03Ioo`<000Yoo`800:Yoo`007Woo00<007ooOol03Goo00<007ooOol0>Goo00<007ooOol00goo00<0
07ooOol00goo0P00Z7oo000NOol00`00Oomoo`0=Ool00`00Oomoo`0mOol00`00Ool0000:Ool2002S
Ool001ioo`03001oogoo00eoo`03001oogoo03ioo`8000aoo`80015oo`8008ioo`007Woo00<007oo
Ool03Goo00<007ooOol0CWoo0P0037oo00<007ooOol00Woo0`00Rgoo000NOol00`00Oomoo`0=Ool0
0`00Oomoo`1LOol00`00Oomoo`0TOol4001XOol001ioo`03001oogoo00eoo`03001oogoo05=oo`@0
00Eoo`03001oogoo00Uoo`8001eoo`80039oo`80039oo`007Woo00<007ooOol03Goo00<007ooOol0
Egoo0P000goo00<007ooOol02goo0`0087oo0P00;7oo00<007ooOol00goo1000:Woo000NOol00`00
Oomoo`0=Ool00`00Oomoo`1LOol00`00Oomoo`0BOol00`00Oomoo`0>Ool00`00Oomoo`0:Ool3000Y
Ool00`00Oomoo`07Ool00`00Oomoo`0WOol001ioo`03001oogoo00eoo`03001oogoo079oo`8000io
o`03001oogoo015oo`03001oogoo029oo`03001oogoo00aoo`D0021oo`007Woo00<007ooOol03Goo
00<007ooOol0M7oo0P0037oo00<007ooOol04Woo0P008Woo00<007ooOol04Goo00@007ooOomoo`80
01Yoo`007Woo00<007ooOol03Goo0P00Ngoo00<007ooOol01Goo00<007ooOol057oo0P0087oo7@00
5goo000NOol00`00Oomoo`0>Ool00`00Oomoo`1jOol20005Ool00`00Oomoo`0JOol3000IOol00`00
Oomoo`0aOol001ioo`03001oogoo00ioo`03001oogoo07aoo`8000=oo`03001oogoo01eoo`<001Io
o`03001oogoo035oo`007Woo00<007ooOol03Woo00<007ooOol0Ygoo0`0047oo00<007ooOol0<Goo
000NOol00`00Oomoo`0>Ool00`00Oomoo`2ZOol3000=Ool00`00Oomoo`0aOol001ioo`03001oogoo
00ioo`03001oogoo0;1oo`<000Moo`03001oogoo035oo`007Woo00<007ooOol03Woo00<007ooOol0
/goo0`0017oo00<007ooOol0<Goo000NOol00`00Oomoo`0>Ool00`00Oomoo`2jOol00`00Oomoo`0a
Ool001ioo`03001oogoo00ioo`03001oogoo0;Yoo`03001oogoo035oo`007Woo00<007ooOol03Woo
00<007ooOol0^Woo00<007ooOol0<Goo000NOol00`00Oomoo`0>Ool00`00Oomoo`2jOol00`00Oomo
o`0aOol001ioo`03001oogoo00ioo`03001oogoo0;Yoo`03001oogoo035oo`007Woo00<007ooOol0
3Woo00<007ooOol0^Woo00<007ooOol0<Goo000HOol30003Ool00`00Oomoo`0>Ool00`00Oomoo`2j
Ool00`00Oomoo`0aOol001Uoo`03001oogoo009oo`03001oogoo00ioo`03001oogoo0;Yoo`03001o
ogoo035oo`005Woo1@000goo0P003goo0P00PWoo>P00<goo000FOol01000Oomoo`0017oo00<007oo
Ool03goo00<007ooOol0P7oo00<007ooOol0JWoo000GOol00`00Ool00004Ool00`00Oomoo`0?Ool0
0`00Oomoo`20Ool00`00Oomoo`1ZOol001Qoo`8000Aoo`03001oogoo00moo`03001oogoo081oo`03
001oogoo06Yoo`007Woo00<007ooOol03goo00<007ooOol0P7oo00<007ooOol0JWoo000NOol00`00
Oomoo`0?Ool00`00Oomoo`20Ool00`00Oomoo`1ZOol001ioo`03001oogoo00moo`03001oogoo081o
o`03001oogoo06Yoo`007Woo00<007ooOol03goo00<007ooOol0P7oo00<007ooOol0JWoo000NOol0
0`00Oomoo`0?Ool00`00Oomoo`20Ool00`00Oomoo`1ZOol001ioo`03001oogoo00moo`03001oogoo
081oo`03001oogoo06Yoo`007Woo00<007ooOol03goo00<007ooOol0P7oo00<007ooOol0JWoo000N
Ool00`00Oomoo`0?Ool00`00Oomoo`20Ool00`00Oomoo`1ZOol001ioo`03001oogoo00moo`03001o
ogoo081oo`03001oogoo06Yoo`007Woo00<007ooOol03goo00<007ooOol0P7oo00<007ooOol0JWoo
000NOol00`00Oomoo`0?Ool00`00Oomoo`20Ool00`00Oomoo`1ZOol001ioo`03001oogoo00moo`<0
05YoobL006aoo`007Woo00<007ooOol04Goo00<007ooOol0F7oo00<007ooOol0T7oo000NOol00`00
Oomoo`0AOol00`00Oomoo`1HOol00`00Oomoo`2@Ool001ioo`03001oogoo015oo`03001oogoo05Qo
o`03001oogoo091oo`007Woo00<007ooOol04Goo00<007ooOol0F7oo00<007ooOol0T7oo000NOol0
0`00Oomoo`0AOol00`00Oomoo`1HOol00`00Oomoo`2@Ool001ioo`03001oogoo015oo`03001oogoo
05Qoo`03001oogoo091oo`007Woo00<007ooOol04Goo00<007ooOol0F7oo00<007ooOol0T7oo000N
Ool00`00Oomoo`0AOol00`00Oomoo`1HOol00`00Oomoo`2@Ool001ioo`03001oogoo015oo`03001o
ogoo05Qoo`03001oogoo091oo`007Woo00<007ooOol04Goo00<007ooOol0F7oo00<007ooOol0T7oo
000NOol00`00Oomoo`0AOol00`00Oomoo`1HOol00`00Oomoo`2@Ool001Ioo`<000Eoo`03001oogoo
015oo`03001oogoo05Qoo`03001oogoo091oo`005Woo00@007ooOol000Aoo`03001oogoo015oo`03
001oogoo05Qoo`03001oogoo091oo`005Woo00@007ooOol000Aoo`80019oo`<003]ooah0099oo`00
5Woo0`001Goo00<007ooOol04goo00<007ooOol0>Goo00<007ooOol0[Goo000GOol00`00Oomoo`04
Ool00`00Oomoo`0COol00`00Oomoo`0iOol00`00Oomoo`2]Ool001Moo`<000Aoo`03001oogoo01=o
o`03001oogoo03Uoo`03001oogoo0:eoo`007Woo00<007ooOol04goo00<007ooOol0>Goo00<007oo
Ool0[Goo000NOol00`00Oomoo`0COol00`00Oomoo`0iOol00`00Oomoo`2]Ool001ioo`03001oogoo
01=oo`03001oogoo03Uoo`03001oogoo0:eoo`007Woo00<007ooOol04goo00<007ooOol0>Goo00<0
07ooOol0[Goo000NOol00`00Oomoo`0DOol00`00Oomoo`0hOol00`00Oomoo`2]Ool001ioo`03001o
ogoo01Aoo`03001oogoo03Qoo`03001oogoo0:eoo`007Woo00<007ooOol057oo00<007ooOol0>7oo
00<007ooOol0[Goo000NOol00`00Oomoo`0DOol00`00Oomoo`0hOol00`00Oomoo`2]Ool001ioo`03
001oogoo01Aoo`03001oogoo03Qoo`03001oogoo0:eoo`007Woo00<007ooOol057oo00<007ooOol0
>7oo00<007ooOol0[Goo000NOol00`00Oomoo`0DOol00`00Oomoo`0hOol00`00Oomoo`2]Ool001io
o`03001oogoo01Aoo`D001iooaT00:moo`007Woo00<007ooOol067oo00<007ooOol077oo00<007oo
Ool0aGoo000NOol00`00Oomoo`0HOol00`00Oomoo`0LOol00`00Oomoo`35Ool001ioo`03001oogoo
01Qoo`03001oogoo01aoo`03001oogoo0<Eoo`007Woo00<007ooOol067oo00<007ooOol077oo00<0
07ooOol0aGoo000NOol00`00Oomoo`0HOol00`00Oomoo`0LOol00`00Oomoo`35Ool001ioo`03001o
ogoo01Qoo`03001oogoo01aoo`03001oogoo0<Eoo`007Woo00<007ooOol067oo00<007ooOol077oo
00<007ooOol0aGoo000NOol00`00Oomoo`0IOol00`00Oomoo`0KOol00`00Oomoo`35Ool001ioo`03
001oogoo01Uoo`03001oogoo01]oo`03001oogoo0<Eoo`007Woo00<007ooOol06Goo00<007ooOol0
6goo00<007ooOol0aGoo000NOol00`00Oomoo`0IOol00`00Oomoo`0KOol00`00Oomoo`35Ool001io
o`03001oogoo01Uoo`03001oogoo01]oo`03001oogoo0<Eoo`005goo0P001Goo00<007ooOol06Goo
00<007ooOol06goo00<007ooOol0aGoo000FOol01000Oomoo`0017oo00<007ooOol06Goo00<007oo
Ool06goo00<007ooOol0aGoo000FOol01000Oomoo`0017oo0P006Woo7`00agoo000GOol20005Ool0
0`00Oomoo`3oOol001Ioo`04001oogoo0004Ool00`00Oomoo`3oOol001Moo`8000Eoo`03001oogoo
0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo
00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0
ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol0
0`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3o
Ool001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03
001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?mo
o`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol0011oo`D0009oo`8000Eoo`03001oogoo
0?moo`004Woo00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo0?moo`004Woo00D007oo
Oomoo`00009oo`03001oogoo009oo`800?moo`5oo`004Woo00D007ooOomoo`00009oo`03001oogoo
0?moo`Eoo`004Woo00D007ooOomoo`00009oo`03001oogoo0?moo`Eoo`004Goo0P0017oo0P00ogoo
27oo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
00Qoo`<00005Ool00000001oo`020002Ool30002Ool30004Ool400000goo000000020003Ool30000
0goo00000002Ool2003ZOol000Moo`03001oogoo00=oo`04001oogoo0004Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol00goo00@007ooOol00>]o
o`001goo00<007ooOol00goo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo009oo`04001o
ogoo0003Ool00`00Oomoo`02Ool40002Ool01000Oomoo`00jgoo0007Ool00`00Oomoo`03Ool30004
Ool20004Ool00`00Oomoo`03Ool30002Ool40003Ool20002Ool4003/Ool000Moo`04001oogoo0002
Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`3kOol000Qoo`<00003Ool0000000Moo`04
001oogooOol20006Ool2003mOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.8167, \
0.00421906, 0.0682658}}],

Cell[BoxData[
    \(0.9422836303710938`\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.0618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(10)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.01 .0618 m
.04976 .0618 L
.09311 .0618 L
.11419 .0618 L
.13383 .0618 L
.15275 .0618 L
.1582 .0618 L
.16088 .0618 L
.16335 .0618 L
.16559 .0618 L
.16673 .0618 L
.16797 .12361 L
.16922 .12361 L
.17056 .12361 L
.17299 .12361 L
.18339 .12361 L
.18624 .12361 L
.1878 .12361 L
.18857 .12361 L
.18928 .12361 L
.18994 .18541 L
.19065 .18541 L
.19214 .18541 L
.19474 .18541 L
.20472 .18541 L
.21021 .18541 L
.21541 .18541 L
.22047 .18541 L
.22186 .18541 L
.22262 .18541 L
.22334 .18541 L
.22459 .24721 L
.22526 .24721 L
.22598 .24721 L
.23562 .24721 L
.25448 .24721 L
.27511 .24721 L
.28548 .24721 L
.28832 .24721 L
.29135 .24721 L
.29282 .24721 L
.29422 .24721 L
.29546 .24721 L
.29682 .30902 L
.29809 .30902 L
.29924 .30902 L
.30185 .30902 L
.30656 .30902 L
.31727 .30902 L
.33892 .30902 L
Mistroke
.37984 .30902 L
.41919 .30902 L
.46107 .30902 L
.50139 .30902 L
.54423 .30902 L
.58551 .30902 L
.62523 .30902 L
.66748 .30902 L
.70817 .30902 L
.74729 .30902 L
.76909 .30902 L
.78894 .30902 L
.79882 .30902 L
.80402 .30902 L
.80687 .30902 L
.80827 .30902 L
.80954 .30902 L
.81067 .30902 L
.81186 .24721 L
.81306 .24721 L
.81436 .24721 L
.81967 .24721 L
.82903 .24721 L
.87082 .24721 L
.91106 .24721 L
.95381 .24721 L
.99 .24721 L
Mfstroke
[ .02 .02 ] 0 setdash
.01 .00062 m
.04976 .00308 L
.09311 .00575 L
.11419 .00706 L
.13383 .00827 L
.15275 .00944 L
.1582 .00978 L
.16088 .00994 L
.16335 .0101 L
.16559 .01023 L
.16673 .0103 L
.16797 .02076 L
.16922 .02092 L
.17056 .02108 L
.17299 .02138 L
.18339 .02267 L
.18624 .02302 L
.1878 .02321 L
.18857 .02331 L
.18928 .0234 L
.18994 .03522 L
.19065 .03535 L
.19214 .03562 L
.19474 .03611 L
.20472 .03796 L
.21021 .03897 L
.21541 .03994 L
.22047 .04088 L
.22186 .04114 L
.22262 .04128 L
.22334 .04141 L
.22459 .05552 L
.22526 .05569 L
.22598 .05587 L
.23562 .05825 L
.25448 .06291 L
.27511 .06801 L
.28548 .07057 L
.28832 .07128 L
.29135 .07203 L
.29282 .07239 L
.29422 .07273 L
.29546 .07304 L
.29682 .09172 L
.29809 .09211 L
.29924 .09247 L
.30185 .09328 L
.30656 .09473 L
.31727 .09804 L
.33892 .10473 L
Mistroke
.37984 .11738 L
.41919 .12954 L
.46107 .14248 L
.50139 .15494 L
.54423 .16818 L
.58551 .18093 L
.62523 .19321 L
.66748 .20626 L
.70817 .21884 L
.74729 .23093 L
.76909 .23766 L
.78894 .2438 L
.79882 .24685 L
.80402 .24846 L
.80687 .24934 L
.80827 .24977 L
.80954 .25016 L
.81067 .25051 L
.81186 .2007 L
.81306 .201 L
.81436 .20132 L
.81967 .20263 L
.82903 .20495 L
.87082 .21528 L
.91106 .22523 L
.95381 .23579 L
.99 .24474 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool2
0004Ool20003Ool4000POol20004Ool20005Ool3000POol20004Ool20003Ool3000QOol20004Ool2
0004Ool2000WOol5000BOol004Eoo`04001oogoo0008Ool00`00Oomoo`0POol01000Oomoo`002goo
00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`0027oo00@007ooOol0
02Qoo`03001oogoo019oo`00AGoo00@007ooOol000Uoo`03001oogoo01moo`04001oogoo0008Ool5
000OOol01000Oomoo`0027oo00@007ooOol001moo`04001oogoo0008Ool01000Oomoo`00:7oo00<0
07ooOol04Woo0015Ool01000Oomoo`002Woo00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo
000POol01000Oomoo`0027oo0`0087oo00@007ooOol000Uoo`8002Uoo`03001oogoo019oo`00AGoo
00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`002Goo00<007oo000087oo00@007ooOol0
00Uoo`03001oogoo01moo`04001oogoo0008Ool01000Oomoo`00:7oo00<007ooOol04Woo0016Ool2
000:Ool2000QOol2000;Ool2000QOol2000:Ool3000POol2000:Ool2000XOol2000DOol00?moob5o
o`00ogoo8Goo003oOolQOol00?mooaAoo`<000Yoo`00ogoo5goo00<007ooOol01goo000NOoo^0007
Ool3000:Ool001ioo`03001oogoo00aoo`H000=oo`H0015oo`03001oogoo02aoo`03001oogoo02eo
o`03001oogoo02aoo`03001oogoo02eoo`03001oogoo00Eoo`@000Uoo`007Woo00<007ooOol07goo
1P00fWoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol09Woo1000
eGoo000NOol00`00Oomoo`0YOol00`00Oomoo`3COol001ioo`03001oogoo02Uoo`03001oogoo0==o
o`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`0]Ool5003=Ool001ioo`03001oogoo035oo`03
001oogoo0<]oo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo03=o
o`<00<Uoo`007Woo00<007oo00009@004Goo0`00aWoo000NOol00`00Oomoo`0TOol00`00Oomoo`0E
Ool00`00Oomoo`30Ool001ioo`03001oogoo02Aoo`03001oogoo01Ioo`D00;eoo`007Woo00<007oo
Ool097oo00<007ooOol06Woo00<007ooOol0^goo000NOol00`00Oomoo`0TOol00`00Oomoo`3HOol0
01ioo`03001oogoo02Aoo`03001oogoo0=Qoo`007Woo00<007ooOol097oo00<007ooOol077oo00<0
07ooOol0^Goo000NOol00`00Oomoo`0TOol00`00Oomoo`0LOol00`00Oomoo`2iOol001ioo`03001o
ogoo02Aoo`03001oogoo01eoo`<00;Qoo`007Woo00<007ooOol097oo00<007ooOol0f7oo000NOol0
0`00Oomoo`0TOol00`00Oomoo`0TOol3002aOol001ioo`03001oogoo02Aoo`03001oogoo02Uoo`80
0:eoo`007Woo00<007ooOol097oo00<007ooOol0:goo0P00Zgoo000FOol40004Ool00`00Oomoo`0T
Ool00`00Oomoo`0]Ool2002YOol001Ioo`03001oogoo00Eoo`03001oogoo02Aoo`03001oogoo039o
o`800:Aoo`005goo00<007ooOol017oo0P009Goo1P00<Goo0P00XWoo000HOol00`00Oomoo`03Ool0
0`00Oomoo`0YOol00`00Oomoo`0aOol2002POol001Ioo`04001oogoo0004Ool00`00Oomoo`0YOol0
0`00Oomoo`0fOol3002JOol001Moo`8000Eoo`03001oogoo02Uoo`03001oogoo03Uoo`<009Moo`00
7Woo00<007ooOol0:Goo00<007ooOol0dgoo000NOol00`00Oomoo`0YOol00`00Oomoo`10Ool2002A
Ool001ioo`03001oogoo02Uoo`03001oogoo049oo`<008ioo`007Woo00<007ooOol0:Goo00<007oo
Ool0dgoo000NOol00`00Oomoo`0ZOol00`00Oomoo`18Ool20028Ool001ioo`03001oogoo02Yoo`03
001oogoo04Yoo`<008Eoo`007Woo00<007ooOol0:Woo00<007ooOol0DGoo00<007ooOol0OWoo000N
Ool00`00Oomoo`0ZOol00`00Oomoo`1BOol2001nOol001ioo`03001oogoo02Yoo`03001oogoo05Ao
o`8007aoo`007Woo00<007ooOol0:Woo00<007ooOol0FWoo00<007ooOol0MGoo000NOol00`00Oomo
o`0ZOol8001FOol2001eOol001ioo`03001oogoo035oo`03001oogoo05Ioo`8007=oo`007Woo00<0
07ooOol0<Goo00<007ooOol0G7oo0`00K7oo000NOol00`00Oomoo`0aOol00`00Oomoo`1OOol2001Z
Ool001ioo`03001oogoo035oo`03001oogoo08Uoo`80041oo`007Woo00<007ooOol0<Goo00<007oo
Ool0IGoo0`008Goo00@007oo000003ioo`007Woo00<007ooOol0<Goo00<007ooOol0J7oo0P007goo
00<007ooOol017oo0`00>7oo000NOol00`00Oomoo`0aOol00`00Oomoo`2COol3000eOol001ioo`03
001oogoo039oo`03001oogoo06eoo`<002Qoo`<002moo`007Woo00<007ooOol0<Woo00<007ooOol0
L7oo0P00:Goo0`00;7oo000NOol00`00Oomoo`0bOol00`00Oomoo`1fOol2000ZOol00`00Oomoo`0U
Ool001ioo`03001oogoo039oo`03001oogoo07Qoo`8000ioo`03001oogoo01Qoo`8002Eoo`007Woo
00<007ooOol0<Woo00<007ooOol0NWoo00<007ooOol02goo00<007ooOol06Woo0P008goo000HOol3
0003Ool00`00Oomoo`0bOol00`00Oomoo`1oOol20007Ool00`00Oomoo`0POol2000MOol001Uoo`03
001oogoo009oo`03001oogoo039oo`03001oogoo085oo`<000Aoo`03001oogoo029oo`<001Yoo`00
5Woo1@000goo0P00<goo4P00MGoo00@007ooOomoob/001Moo`005Woo00@007ooOol000Aoo`03001o
ogoo04=oo`03001oogoo07Moo`03001oogoo03moo`005goo00<007oo000017oo00<007ooOol0@goo
00<007ooOol0Mgoo00<007ooOol0?goo000HOol20004Ool00`00Oomoo`13Ool00`00Oomoo`1gOol0
0`00Oomoo`0oOol001ioo`03001oogoo04=oo`03001oogoo07Moo`03001oogoo03moo`007Woo00<0
07ooOol0@goo00<007ooOol0Mgoo00<007ooOol0?goo000NOol00`00Oomoo`13Ool00`00Oomoo`1g
Ool00`00Oomoo`0oOol001ioo`03001oogoo04=oo`03001oogoo07Moo`03001oogoo03moo`007Woo
00<007ooOol0@goo00<007ooOol0Mgoo00<007ooOol0?goo000NOol00`00Oomoo`13Ool00`00Oomo
o`1gOol00`00Oomoo`0oOol001ioo`03001oogoo04=oo`03001oogoo07Moo`03001oogoo03moo`00
7Woo00<007ooOol0@goo00<007ooOol0Mgoo00<007ooOol0?goo000NOol00`00Oomoo`13Ool00`00
Oomoo`1gOol00`00Oomoo`0oOol001ioo`03001oogoo04=oo`03001oogoo07Moo`03001oogoo03mo
o`007Woo00<007ooOol0@goo00<007ooOol0Mgoo00<007ooOol0?goo000NOol00`00Oomoo`13Oomk
0011Ool001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001io
o`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo
0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo
00<007ooOol0ogoo000FOol30005Ool00`00Oomoo`3oOol001Ioo`04001oogoo0004Ool00`00Oomo
o`3oOol001Ioo`04001oogoo0004Ool2003oOol1Ool001Ioo`<000Eoo`03001oogoo0?moo`005goo
00<007ooOol017oo00<007ooOol0ogoo000GOol30004Ool00`00Oomoo`3oOol001ioo`03001oogoo
0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo
00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0
ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol0
0`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3o
Ool001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03
001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?mo
o`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001Moo`8000Eoo`03001oogoo0?moo`00
5Woo00@007ooOol000Aoo`03001oogoo0?moo`005Woo00@007ooOol000Aoo`800?moo`5oo`005goo
0P001Goo00<007ooOol0ogoo000FOol01000Oomoo`0017oo00<007ooOol0ogoo000GOol20005Ool0
0`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3o
Ool001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03
001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?mo
o`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<0
07ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo
000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00
Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000@Ool50002Ool20005Ool0
0`00Oomoo`3oOol0019oo`05001oogooOol00002Ool00`00Oomoo`02Ool00`00Oomoo`3oOol0019o
o`05001oogooOol00002Ool00`00Oomoo`02Ool2003oOol1Ool0019oo`05001oogooOol00002Ool0
0`00Oomoo`3oOol5Ool0019oo`05001oogooOol00002Ool00`00Oomoo`3oOol5Ool0015oo`8000Ao
o`800?moo`Qoo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo0008Ool300001Goo00000000Ool00P000Woo0`000Woo0`0017oo100000=oo`0000000P00
0goo0`0000=oo`0000000Woo0P00jWoo0007Ool00`00Oomoo`03Ool01000Oomoo`0017oo00<007oo
Ool00Woo00<007ooOol00Woo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00=oo`04001o
ogoo003[Ool000Moo`03001oogoo00=oo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool01000Oomoo`000goo00<007ooOol00Woo10000Woo00@007ooOol00>]oo`001goo00<007ooOol0
0goo0`0017oo0P0017oo00<007ooOol00goo0`000Woo10000goo0P000Woo1000k7oo0007Ool01000
Oomoo`000Woo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol0ngoo0008Ool300000goo0000
0007Ool01000Oomoogoo0P001Woo0P00oGoo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.8167, \
0.00421906, 0.0682658}}],

Cell[BoxData[
    \(31.734375`\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.0618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(10)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.38362 .61803 m
.38362 .61803 L
.38476 .61803 L
.38996 .61803 L
.40091 .61803 L
.40561 .61803 L
.41073 .61803 L
.41307 .61803 L
.41435 .61803 L
.41556 .61803 L
.41669 .61803 L
.41791 .55623 L
.41902 .55623 L
.42004 .55623 L
.43947 .55623 L
.44479 .55623 L
.45048 .55623 L
.45325 .55623 L
.45586 .55623 L
.457 .55623 L
.4582 .55623 L
.45953 .49443 L
.46075 .49443 L
.48107 .49443 L
.48996 .49443 L
.49967 .49443 L
.50224 .49443 L
.50498 .49443 L
.50631 .49443 L
.50756 .49443 L
.50868 .43262 L
.5099 .43262 L
.51963 .43262 L
.54111 .43262 L
.55172 .43262 L
.56162 .43262 L
.56418 .43262 L
.56544 .43262 L
.5666 .43262 L
.56794 .37082 L
.56865 .37082 L
.5694 .37082 L
.57195 .37082 L
.58329 .37082 L
.60355 .37082 L
.62213 .37082 L
.63182 .37082 L
.63417 .37082 L
.63669 .37082 L
.63744 .37082 L
Mistroke
.63814 .37082 L
.63945 .30902 L
.64069 .30902 L
.64202 .30902 L
.66348 .30902 L
.68352 .30902 L
.69415 .30902 L
.70557 .30902 L
.71119 .30902 L
.71651 .30902 L
.7213 .30902 L
.72261 .30902 L
.724 .30902 L
.72532 .30902 L
.72651 .24721 L
.72774 .24721 L
.72904 .24721 L
.73136 .24721 L
.73661 .24721 L
.74611 .24721 L
.78522 .24721 L
.80701 .24721 L
.81733 .24721 L
.82186 .24721 L
.82444 .24721 L
.82686 .24721 L
.82798 .24721 L
.82916 .24721 L
.83046 .18541 L
.83165 .18541 L
.83673 .18541 L
.84745 .18541 L
.86694 .18541 L
.90619 .18541 L
.91659 .18541 L
.9264 .18541 L
.93183 .18541 L
.93332 .18541 L
.93489 .18541 L
.93623 .18541 L
.93699 .18541 L
.93771 .12361 L
.93904 .12361 L
.94029 .12361 L
.94266 .12361 L
.94797 .12361 L
.98736 .12361 L
.99 .12361 L
Mfstroke
[ .02 .02 ] 0 setdash
.01 .01731 m
.04976 .0861 L
.09311 .16113 L
.11419 .19761 L
.12448 .21541 L
.13383 .2316 L
.1385 .23967 L
.14095 .24392 L
.1423 .24625 L
.14356 .24843 L
.14465 .25032 L
.14583 .24335 L
.14714 .24553 L
.14834 .24753 L
.14942 .24934 L
.1506 .25131 L
.15172 .24379 L
.15275 .24546 L
.15402 .2475 L
.1554 .24971 L
.1567 .25179 L
.15789 .24395 L
.15897 .24562 L
.16016 .24745 L
.16255 .25115 L
.16325 .25223 L
.16391 .25326 L
.16516 .24497 L
.16649 .24696 L
.16795 .24912 L
.16922 .251 L
.17057 .253 L
.17172 .25471 L
.17299 .2459 L
.17424 .24768 L
.17541 .24934 L
.17679 .25131 L
.17805 .2531 L
.17938 .25498 L
.18063 .24559 L
.18195 .24739 L
.18338 .24933 L
.18578 .25261 L
.1871 .2544 L
.18833 .25607 L
.18938 .24579 L
.19051 .24725 L
.1929 .25036 L
.19565 .25393 L
.19711 .25582 L
Mistroke
.1979 .25685 L
.19865 .25783 L
.19937 .24643 L
.20014 .24739 L
.20149 .24905 L
.20411 .2523 L
.20671 .25551 L
.20813 .25726 L
.20945 .2589 L
.21058 .24728 L
.2118 .2487 L
.21436 .25172 L
.21701 .25482 L
.21846 .25653 L
.21982 .25812 L
.22097 .25948 L
.22221 .2472 L
.22289 .24795 L
.22359 .24874 L
.22486 .25014 L
.23031 .25621 L
.2318 .25787 L
.23262 .25878 L
.23339 .25964 L
.23411 .26044 L
.23489 .24679 L
.2356 .24754 L
.23626 .24823 L
.24146 .2537 L
.24633 .25881 L
.24758 .26013 L
.24878 .26138 L
.24943 .24665 L
.25015 .24736 L
.2514 .2486 L
.25698 .25411 L
.25937 .25648 L
.26195 .25903 L
.26314 .26021 L
.26439 .26145 L
.26546 .2461 L
.26663 .24718 L
.2773 .25707 L
.28008 .25965 L
.28145 .26091 L
.28271 .26208 L
.28341 .24522 L
.28416 .24587 L
.28573 .24723 L
.28849 .24961 L
Mistroke
.29393 .25432 L
.29631 .25638 L
.29891 .25863 L
.30016 .25971 L
.30149 .26086 L
.30274 .26195 L
.30388 .24415 L
.30505 .24509 L
.30631 .2461 L
.3086 .24794 L
.31367 .25202 L
.31902 .25632 L
.32128 .25813 L
.3237 .26008 L
.32442 .26065 L
.32509 .26119 L
.32636 .24204 L
.32755 .24292 L
.32884 .24388 L
.33786 .25057 L
.34252 .25403 L
.34754 .25775 L
.34894 .25879 L
.35042 .25988 L
.35168 .26082 L
.35239 .23957 L
.35305 .24002 L
.35822 .24353 L
.36935 .2511 L
.37481 .25481 L
.37721 .25644 L
.37984 .25823 L
.38107 .25907 L
.38238 .25996 L
.38362 .23709 L
.38476 .23779 L
.38996 .24101 L
.40091 .24778 L
.40561 .25068 L
.41073 .25384 L
.41307 .25529 L
.41435 .25609 L
.41556 .25683 L
.41669 .25753 L
.41791 .23246 L
.41902 .23307 L
.42004 .23364 L
.43947 .24445 L
.44479 .24741 L
.45048 .25057 L
Mistroke
.45325 .25211 L
.45586 .25356 L
.457 .2542 L
.4582 .25487 L
.45953 .2272 L
.46075 .22781 L
.48107 .23785 L
.48996 .24225 L
.49967 .24705 L
.50224 .24832 L
.50498 .24967 L
.50631 .25033 L
.50756 .25095 L
.50868 .22007 L
.5099 .2206 L
.51963 .22481 L
.54111 .2341 L
.55172 .23869 L
.56162 .24297 L
.56418 .24408 L
.56544 .24462 L
.5666 .24513 L
.56794 .21061 L
.56865 .21087 L
.5694 .21115 L
.57195 .21209 L
.58329 .2163 L
.60355 .22381 L
.62213 .2307 L
.63182 .23429 L
.63417 .23516 L
.63669 .2361 L
.63744 .23637 L
.63814 .23663 L
.63945 .1976 L
.64069 .19798 L
.64202 .1984 L
.66348 .20503 L
.68352 .21122 L
.69415 .2145 L
.70557 .21803 L
.71119 .21977 L
.71651 .22141 L
.7213 .22289 L
.72261 .2233 L
.724 .22373 L
.72532 .22414 L
.72651 .1796 L
.72774 .17991 L
.72904 .18023 L
Mistroke
.73136 .1808 L
.73661 .1821 L
.74611 .18445 L
.78522 .19412 L
.80701 .1995 L
.81733 .20205 L
.82186 .20317 L
.82444 .20381 L
.82686 .20441 L
.82798 .20469 L
.82916 .20498 L
.83046 .15398 L
.83165 .1542 L
.83673 .15514 L
.84745 .15713 L
.86694 .16074 L
.90619 .16802 L
.91659 .16995 L
.9264 .17176 L
.93183 .17277 L
.93332 .17305 L
.93489 .17334 L
.93623 .17359 L
.93699 .17373 L
.93771 .11591 L
.93904 .11607 L
.94029 .11623 L
.94266 .11652 L
.94797 .11718 L
.98736 .12205 L
.99 .12237 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool2
0004Ool20003Ool4000POol20004Ool20005Ool3000POol20004Ool20003Ool3000QOol20004Ool2
0004Ool2000WOol5000BOol004Eoo`04001oogoo0008Ool00`00Oomoo`0POol01000Oomoo`002goo
00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`0027oo00@007ooOol0
02Qoo`03001oogoo019oo`00AGoo00@007ooOol000Uoo`03001oogoo01moo`04001oogoo0008Ool5
000OOol01000Oomoo`0027oo00@007ooOol001moo`04001oogoo0008Ool01000Oomoo`00:7oo00<0
07ooOol04Woo0015Ool01000Oomoo`002Woo00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo
000POol01000Oomoo`0027oo0`0087oo00@007ooOol000Uoo`8002Uoo`03001oogoo019oo`00AGoo
00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`002Goo00<007oo000087oo00@007ooOol0
00Uoo`03001oogoo01moo`04001oogoo0008Ool01000Oomoo`00:7oo00<007ooOol04Woo0016Ool2
000:Ool2000QOol2000;Ool2000QOol2000:Ool3000POol2000:Ool2000XOol2000DOol00?moob5o
o`00ogoo8Goo003oOolQOol00?mooaAoo`<000Yoo`00ogoo5goo00<007ooOol01goo000NOoo^0007
Ool3000:Ool001ioo`03001oogoo02aoo`03001oogoo02aoo`03001oogoo02eoo`03001oogoo02ao
o`03001oogoo02eoo`03001oogoo00Eoo`@000Uoo`007Woo00<007ooOol0ogoo000NOol00`00Oomo
o`3oOol001ioo`03001oo`000?moo`007Woo00<007oo0000ogoo000NOol01000Oomoo`00oWoo000N
Ool00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomo
o`03Ool00`00Oomoo`3iOol001ioo`03001oogoo00=oo`03001oogoo0?Uoo`007Woo00<007ooOol0
17oo00<007ooOol0n7oo000NOol00`00Oomoo`04Ool00`00Oomoo`3hOol001ioo`03001oogoo00Eo
o`03001oogoo0?Moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo
0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`08Ool00`00Oomoo`3dOol001ioo`03001o
ogoo00Qoo`03001oogoo0?Aoo`007Woo00<007ooOol02Goo00<007ooOol0lgoo000NOol00`00Oomo
o`09Ool00`00Oomoo`3cOol001ioo`03001oogoo00Yoo`03001oogoo0?9oo`007Woo00<007ooOol0
ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`005Woo100017oo00<007ooOol037oo
00<007ooOol0cGoo0`0087oo000FOol00`00Oomoo`05Ool00`00Oomoo`0=Ool00`00Oomoo`3?Ool3
0003Ool3000GOol001Moo`03001oogoo00Aoo`8000ioo`03001oogoo0<]oo`d001Moo`0067oo00<0
07ooOol00goo00<007ooOol03Woo00<007ooOol0bWoo00<007ooOol08Goo000FOol01000Oomoo`00
17oo00<007ooOol03goo00<007ooOol0bGoo00<007ooOol08Goo000GOol20005Ool00`00Oomoo`3K
Ool00`00Oomoo`0QOol001ioo`03001oogoo0=]oo`03001oogoo025oo`007Woo00<007ooOol0fgoo
00<007ooOol08Goo000NOol00`00Oomoo`0AOol00`00Oomoo`37Ool00`00Oomoo`0QOol001ioo`03
001oogoo019oo`03001oogoo0<Ioo`03001oogoo025oo`007Woo00<007ooOol04Woo00<007ooOol0
[goo1P004Goo00<007ooOol08Goo000NOol00`00Oomoo`0COol00`00Oomoo`2[Ool00`00Oomoo`09
Ool3000;Ool00`00Oomoo`0QOol001ioo`03001oogoo01=oo`03001oogoo0:]oo`03001oogoo00ao
o`<000Qoo`03001oogoo025oo`007Woo00<007ooOol0`Goo00<007ooOol04goo0`0000=oo`00Ool0
8Woo000NOol00`00Oomoo`31Ool00`00Oomoo`0FOol2000SOol001ioo`03001oogoo0<5oo`03001o
ogoo01Moo`03001oogoo025oo`007Woo00<007ooOol05Woo00<007ooOol0T7oo00<007oo00000P00
4goo6`008goo000NOol00`00Oomoo`0GOol00`00Oomoo`2?Ool00`00Oomoo`02Ool2000AOol00`00
Oomoo`0kOol001ioo`03001oogoo01Moo`03001oogoo08moo`03001oogoo00Qoo`8000]oo`03001o
ogoo03]oo`007Woo00<007ooOol067oo00<007ooOol0NGoo00<007ooOol04Woo00<007ooOol02Woo
0`0027oo00<007ooOol0>goo000NOol00`00Oomoo`0HOol00`00Oomoo`1iOol4000AOol00`00Oomo
o`0AOol20002Ool00`00Oomoo`0kOol001ioo`03001oogoo09Aoo`03001oogoo02Qoo`<003eoo`00
7Woo00<007ooOol0Pgoo00<007ooOol05Goo0P0097oo00<007ooOol0>goo000NOol00`00Oomoo`23
Ool3000GOol4000POol00`00Oomoo`0kOol001ioo`03001oogoo01Yoo`03001oogoo06Ioo`03001o
ogoo01ioo`03001oogoo01Yoo`03001oogoo03]oo`007Woo00<007ooOol06goo00<007ooOol0F7oo
00<007ooOol02Woo00<007ooOol00goo0P006Woo100067oo00<007ooOol0>goo000NOol00`00Oomo
o`0KOol00`00Oomoo`1IOol2000:Ool00`00Oomoo`05Ool30006Ool00`00Oomoo`0AOol00`00Oomo
o`0FOol00`00Oomoo`0kOol001ioo`03001oogoo01aoo`03001oogoo04aoo`03001oogoo00]oo`80
01Uoo`03001oogoo02Yoo`03001oogoo03]oo`007Woo00<007ooOol077oo00<007ooOol0CGoo0P00
1goo00<007ooOol06Woo0`00;7oo00<007ooOol0>goo000HOol30003Ool00`00Oomoo`0MOol00`00
Oomoo`0`Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`02Ool30004
Ool00`00Oomoo`07Ool2000COol00`00Oomoo`0ZOol00`00Oomoo`0kOol001Uoo`03001oogoo009o
o`03001oogoo01moo`8002Aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Ioo`8000Eo
o`03001oogoo00<000=oo`03001oogoo00Uoo`03001oogoo00Uoo`<003eoo`03001oogoo03]oo`00
5Woo1@000goo0P0087oo0P0000Eoo`00Ool007oo00800005Ool00000Ool00004Ool00`00Oomoo`02
0002Ool00`00Oomoo`020003Ool01000Oomoogoo0`000goo0P0017oo00<007ooOol027oo0P000Woo
00<007ooOol017oo00@007ooOol000]oo`03001oogoo00]oo`03001oogoo02=ooaT003eoo`005Woo
00@007ooOol000Aoo`03001oogoo021oo`04001oogoo0002Ool20002Ool01000Ool000000goo00<0
07ooOol00P000Woo00<007ooOol00Woo00D007ooOomoo`0000Eoo`06001oogoo001oo`000goo00D0
07ooOomoo`0000Yoo`03001oogoo00Eoo`03001oo`0000Yoo`8003=oo`03001oogoo05=oo`005goo
00<007oo000017oo00<007ooOol08goo00D007ooOomoo`0000=oo`05001oogoo001oo`020002Ool0
0`00Ool00002Ool20003Ool01000Oomoogoo0P0017oo00<007ooOol01Goo00<007ooOol00Woo0`00
1goo00<007ooOol01Woo0P00?goo00<007ooOol0Dgoo000HOol20004Ool00`00Oomoo`0^Ool01000
Oomoo`0027oo00<007ooOol00Woo00@007ooOomoo`8000]oo`03001oogoo00Aoo`03001oogoo04mo
o`03001oogoo05=oo`007Woo00<007ooOol0ZGoo00<007ooOol0Dgoo000NOol00`00Oomoo`2YOol0
0`00Oomoo`1COol001ioo`03001oogoo0:Uoo`03001oogoo05=oo`007Woo00<007ooOol0ZGoo00<0
07ooOol0Dgoo000NOol00`00Oomoo`2XOol00`00Oomoo`1DOol001ioo`03001oogoo0:Qoo`03001o
ogoo05Aoo`007Woo00<007ooOol0Z7oo00<007ooOol0E7oo000NOol00`00Oomoo`2XOol00`00Oomo
o`1DOol001ioo`03001oogoo0:Qoo`03001oogoo05Aoo`007Woo00<007ooOol0Z7oo00<007ooOol0
E7oo000NOol00`00Oomoo`2XOol00`00Oomoo`1DOol001ioo`03001oogoo09AooaD005Ioo`007Woo
00<007ooOol0U7oo00<007ooOol0J7oo000NOol00`00Oomoo`2DOol00`00Oomoo`1XOol001ioo`03
001oogoo09Aoo`03001oogoo06Qoo`007Woo00<007ooOol0U7oo00<007ooOol0J7oo000NOol00`00
Oomoo`2DOol00`00Oomoo`1XOol001ioo`03001oogoo09Aoo`03001oogoo06Qoo`007Woo00<007oo
Ool0U7oo00<007ooOol0J7oo000NOol00`00Oomoo`2DOol00`00Oomoo`1XOol001ioo`03001oogoo
09Aoo`03001oogoo06Qoo`007Woo00<007ooOol0U7oo00<007ooOol0J7oo000NOol00`00Oomoo`2D
Ool00`00Oomoo`1XOol001Ioo`<000Eoo`03001oogoo09Aoo`03001oogoo06Qoo`005Woo00@007oo
Ool000Aoo`03001oogoo09Aoo`03001oogoo06Qoo`005Woo00@007ooOol000Aoo`8008Aooa8006Yo
o`005Woo0`001Goo00<007ooOol0Pgoo00<007ooOol0NGoo000GOol00`00Oomoo`04Ool00`00Oomo
o`23Ool00`00Oomoo`1iOol001Moo`<000Aoo`03001oogoo08=oo`03001oogoo07Uoo`007Woo00<0
07ooOol0Pgoo00<007ooOol0NGoo000NOol00`00Oomoo`23Ool00`00Oomoo`1iOol001ioo`03001o
ogoo08=oo`03001oogoo07Uoo`007Woo00<007ooOol0Pgoo00<007ooOol0NGoo000NOol00`00Oomo
o`23Ool00`00Oomoo`1iOol001ioo`03001oogoo08=oo`03001oogoo07Uoo`007Woo00<007ooOol0
Pgoo00<007ooOol0NGoo000NOol00`00Oomoo`23Ool00`00Oomoo`1iOol001ioo`03001oogoo08=o
o`03001oogoo07Uoo`007Woo00<007ooOol0Pgoo00<007ooOol0NGoo000NOol00`00Oomoo`23Ool0
0`00Oomoo`1iOol001ioo`03001oogoo07Eoo`l007]oo`007Woo00<007ooOol0MGoo00<007ooOol0
Qgoo000NOol00`00Oomoo`1eOol00`00Oomoo`27Ool001ioo`03001oogoo07Eoo`03001oogoo08Mo
o`007Woo00<007ooOol0MGoo00<007ooOol0Qgoo000NOol00`00Oomoo`1eOol00`00Oomoo`27Ool0
01ioo`03001oogoo07Eoo`03001oogoo08Moo`007Woo00<007ooOol0MGoo00<007ooOol0Qgoo000N
Ool00`00Oomoo`1eOol00`00Oomoo`27Ool001ioo`03001oogoo07Eoo`03001oogoo08Moo`007Woo
00<007ooOol0MGoo00<007ooOol0Qgoo000NOol00`00Oomoo`1eOol00`00Oomoo`27Ool001ioo`03
001oogoo07Eoo`03001oogoo08Moo`005goo0P001Goo00<007ooOol0MGoo00<007ooOol0Qgoo000F
Ool01000Oomoo`0017oo00<007ooOol0MGoo00<007ooOol0Qgoo000FOol01000Oomoo`0017oo0P00
JWoo3@00RGoo000GOol20005Ool00`00Oomoo`1YOol00`00Oomoo`2COol001Ioo`04001oogoo0004
Ool00`00Oomoo`1YOol00`00Oomoo`2COol001Moo`8000Eoo`03001oogoo06Uoo`03001oogoo09=o
o`007Woo00<007ooOol0JGoo00<007ooOol0Tgoo000NOol00`00Oomoo`1YOol00`00Oomoo`2COol0
01ioo`03001oogoo06Uoo`03001oogoo09=oo`007Woo00<007ooOol0JGoo00<007ooOol0Tgoo000N
Ool00`00Oomoo`1YOol00`00Oomoo`2COol001ioo`03001oogoo06Uoo`03001oogoo09=oo`007Woo
00<007ooOol0JGoo00<007ooOol0Tgoo000NOol00`00Oomoo`1YOol00`00Oomoo`2COol001ioo`03
001oogoo06Uoo`03001oogoo09=oo`007Woo00<007ooOol0JGoo00<007ooOol0Tgoo000NOol00`00
Oomoo`1POol:002EOol001ioo`03001oogoo061oo`03001oogoo09aoo`007Woo00<007ooOol0H7oo
00<007ooOol0W7oo000NOol00`00Oomoo`1POol00`00Oomoo`2LOol001ioo`03001oogoo061oo`03
001oogoo09aoo`007Woo00<007ooOol0H7oo00<007ooOol0W7oo000NOol00`00Oomoo`1POol00`00
Oomoo`2LOol001ioo`03001oogoo061oo`03001oogoo09aoo`007Woo00<007ooOol0Ggoo00<007oo
Ool0WGoo000NOol00`00Oomoo`1OOol00`00Oomoo`2MOol001ioo`03001oogoo05moo`03001oogoo
09eoo`007Woo00<007ooOol0Ggoo00<007ooOol0WGoo000NOol00`00Oomoo`1OOol00`00Oomoo`2M
Ool0011oo`D0009oo`8000Eoo`03001oogoo05moo`03001oogoo09eoo`004Woo00D007ooOomoo`00
009oo`03001oogoo009oo`03001oogoo05Moo`03001oogoo00Eoo`03001oogoo09eoo`004Woo00D0
07ooOomoo`00009oo`03001oogoo009oo`8005Qoo`T009moo`004Woo00D007ooOomoo`00009oo`03
001oogoo0?moo`Eoo`004Woo00D007ooOomoo`00009oo`03001oogoo0?moo`Eoo`004Goo0P0017oo
0P00ogoo27oo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol000Qoo`<00005Ool00000001oo`020002Ool30002Ool30004Ool400000goo000000020003
Ool300000goo00000002Ool2003ZOol000Moo`03001oogoo00=oo`04001oogoo0004Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol00goo00@007oo
Ool00>]oo`001goo00<007ooOol00goo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo009o
o`04001oogoo0003Ool00`00Oomoo`02Ool40002Ool01000Oomoo`00jgoo0007Ool00`00Oomoo`03
Ool30004Ool20004Ool00`00Oomoo`03Ool30002Ool40003Ool20002Ool4003/Ool000Moo`04001o
ogoo0002Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`3kOol000Qoo`<00003Ool00000
00Moo`04001oogooOol20006Ool2003mOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.8167, \
0.00421906, 0.0682658}}],

Cell[BoxData[
    \(2.6961669921875`\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.0618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(10)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.01 .0618 m
.01231 .0618 L
.01478 .0618 L
.01598 .0618 L
.01711 .0618 L
.01813 .24721 L
.01924 .43262 L
s
.01924 .43262 m
.02077 .61803 L
s
.29597 .61803 m
.29597 .61803 L
.29668 .61803 L
.29791 .61803 L
.30341 .61803 L
.31303 .61803 L
.32278 .61803 L
.33188 .61803 L
.33431 .61803 L
.33662 .61803 L
.33789 .61803 L
.33861 .55623 L
.33928 .55623 L
.34169 .55623 L
.35245 .55623 L
.36365 .55623 L
.37414 .55623 L
.38342 .55623 L
.38609 .55623 L
.38741 .55623 L
.38863 .55623 L
.38974 .55623 L
.39091 .49443 L
.39222 .49443 L
.3934 .49443 L
.41462 .49443 L
.43442 .49443 L
.43984 .49443 L
.44557 .49443 L
.45047 .49443 L
.45181 .49443 L
.45254 .49443 L
.45324 .49443 L
.4546 .43262 L
.45584 .43262 L
.49527 .43262 L
.51561 .43262 L
.52588 .43262 L
.52869 .43262 L
.53173 .43262 L
.53312 .43262 L
.53459 .43262 L
.53585 .43262 L
.53656 .37082 L
.53722 .37082 L
.57738 .37082 L
.59786 .37082 L
.62007 .37082 L
.63046 .37082 L
.63615 .37082 L
Mistroke
.63893 .37082 L
.64147 .37082 L
.64258 .37082 L
.64379 .37082 L
.64494 .30902 L
.646 .30902 L
.65086 .30902 L
.6612 .30902 L
.70151 .30902 L
.74434 .30902 L
.76584 .30902 L
.77527 .30902 L
.78561 .30902 L
.79043 .30902 L
.79309 .30902 L
.79439 .30902 L
.7956 .30902 L
.79674 .24721 L
.79794 .24721 L
.80048 .24721 L
.80492 .24721 L
.82531 .24721 L
.8642 .24721 L
.90561 .24721 L
.94546 .24721 L
.98784 .24721 L
.99 .24721 L
Mfstroke
[ .02 .02 ] 0 setdash
.01 .00062 m
.02935 .03628 L
.03921 .05574 L
.04976 .0738 L
.05264 .07808 L
.05406 .08018 L
.05536 .08212 L
.05655 .08039 L
.05781 .08218 L
.06047 .08595 L
.06522 .0927 L
.06652 .09455 L
.06792 .09654 L
.06924 .09842 L
.07045 .09579 L
.07118 .09678 L
.07184 .09768 L
.07333 .0997 L
.076 .10334 L
.0775 .10538 L
.07913 .10759 L
.07987 .1086 L
.08066 .10967 L
.08133 .11058 L
.08207 .10651 L
.08281 .10747 L
.08351 .10838 L
.08482 .11009 L
.08778 .11393 L
.09033 .11724 L
.09103 .11815 L
.09178 .11912 L
.09311 .11509 L
.09428 .11654 L
.09556 .11812 L
.09814 .12131 L
.10056 .1243 L
.10275 .12701 L
.10409 .12867 L
.10536 .12372 L
.10669 .12528 L
.10814 .12698 L
.11052 .12978 L
.11315 .13287 L
.11433 .13426 L
.1156 .13575 L
.1168 .13716 L
.1179 .13116 L
.11914 .13254 L
.12048 .13403 L
Mistroke
.12293 .13676 L
.1252 .13928 L
.12762 .14197 L
.12879 .14327 L
.1299 .1445 L
.13089 .14561 L
.13196 .13864 L
.13324 .13999 L
.13441 .14122 L
.13703 .14397 L
.14176 .14895 L
.14441 .15173 L
.14514 .15249 L
.14591 .1533 L
.14656 .14493 L
.14729 .14565 L
.15251 .15082 L
.15791 .15615 L
.15938 .15761 L
.16093 .15914 L
.16226 .16045 L
.16301 .16119 L
.16371 .15177 L
.16437 .15238 L
.16508 .15304 L
.16637 .15423 L
.16879 .15647 L
.1742 .1615 L
.17664 .16375 L
.17925 .16618 L
.18052 .16735 L
.18172 .16846 L
.1828 .16946 L
.18397 .15918 L
.18525 .16029 L
.18667 .16151 L
.18954 .164 L
.1947 .16846 L
.20007 .17311 L
.20154 .17438 L
.20309 .17573 L
.20442 .17687 L
.20517 .16484 L
.20587 .1654 L
.21636 .17384 L
.22155 .178 L
.22428 .1802 L
.22717 .18252 L
.22839 .1835 L
.2297 .18455 L
Mistroke
.23045 .18516 L
.23114 .17142 L
.23249 .17242 L
.23739 .17606 L
.24664 .18292 L
.25172 .18669 L
.25651 .19024 L
.25906 .19213 L
.25976 .19265 L
.2605 .1932 L
.26183 .178 L
.26302 .17881 L
.26413 .17956 L
.26665 .18128 L
.27606 .18767 L
.28636 .19468 L
.28932 .19669 L
.29213 .1986 L
.29335 .19943 L
.29465 .20031 L
.29532 .20077 L
.29607 .18298 L
.29739 .1838 L
.31731 .19611 L
.32277 .19948 L
.32851 .20303 L
.33342 .20606 L
.33476 .20689 L
.33619 .20778 L
.33755 .20862 L
.33878 .18844 L
.34001 .18912 L
.34116 .18976 L
.34377 .19122 L
.34906 .19416 L
.35853 .19943 L
.36952 .20554 L
.37994 .21133 L
.38478 .21403 L
.38744 .21551 L
.38874 .21623 L
.38994 .2169 L
.39063 .19314 L
.39136 .1935 L
.39291 .19426 L
.39559 .19559 L
.40083 .19818 L
.41991 .20762 L
.4297 .21245 L
.44017 .21763 L
Mistroke
.44526 .22015 L
.44775 .22138 L
.45006 .22252 L
.45215 .22356 L
.45321 .22408 L
.45437 .19657 L
.45554 .19708 L
.45679 .19762 L
.45906 .1986 L
.47933 .20737 L
.50146 .21695 L
.51171 .22138 L
.52264 .22611 L
.52795 .22841 L
.53056 .22953 L
.53296 .23057 L
.53514 .23152 L
.53624 .23199 L
.53745 .1993 L
.53866 .19975 L
.53996 .20023 L
.54231 .2011 L
.58486 .21688 L
.60615 .22477 L
.61551 .22824 L
.62585 .23208 L
.63059 .23384 L
.63571 .23573 L
.63806 .2366 L
.64053 .23752 L
.64265 .23831 L
.64385 .23875 L
.64496 .1993 L
.64623 .1997 L
.64761 .20012 L
.65011 .20089 L
.65478 .20234 L
.66528 .20558 L
.70737 .21859 L
.7479 .23111 L
.76826 .23741 L
.77717 .24016 L
.78688 .24316 L
.78945 .24395 L
.7922 .2448 L
.79353 .24522 L
.79479 .2456 L
.79592 .24595 L
.79714 .19706 L
.79831 .19735 L
Mistroke
.79961 .19767 L
.80221 .19832 L
.80688 .19947 L
.82837 .20478 L
.87001 .21508 L
.91009 .22499 L
.95269 .23552 L
.99 .24474 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool2
0004Ool20003Ool4000POol20004Ool20005Ool3000POol20004Ool20003Ool3000QOol20004Ool2
0004Ool2000WOol5000BOol004Eoo`04001oogoo0008Ool00`00Oomoo`0POol01000Oomoo`002goo
00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`0027oo00@007ooOol0
02Qoo`03001oogoo019oo`00AGoo00@007ooOol000Uoo`03001oogoo01moo`04001oogoo0008Ool5
000OOol01000Oomoo`0027oo00@007ooOol001moo`04001oogoo0008Ool01000Oomoo`00:7oo00<0
07ooOol04Woo0015Ool01000Oomoo`002Woo00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo
000POol01000Oomoo`0027oo0`0087oo00@007ooOol000Uoo`8002Uoo`03001oogoo019oo`00AGoo
00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`002Goo00<007oo000087oo00@007ooOol0
00Uoo`03001oogoo01moo`04001oogoo0008Ool01000Oomoo`00:7oo00<007ooOol04Woo0016Ool2
000:Ool2000QOol2000;Ool2000QOol2000:Ool3000POol2000:Ool2000XOol2000DOol00?moob5o
o`00ogoo8Goo003oOolQOol00?mooaAoo`<000Yoo`00ogoo5goo00<007ooOol01goo000NOoo^0007
Ool3000:Ool001ioo`04001oogoo000[Ool00`00Oomoo`0/Ool00`00Oomoo`0]Ool00`00Oomoo`0/
Ool00`00Oomoo`0]Ool00`00Oomoo`05Ool40009Ool001ioo`03001oogoo0?moo`007Woo00<007oo
Ool0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo009oo`03001oogoo0?Yoo`007Woo00<0
07ooOol00Woo00<007ooOol0nWoo000NOol00`00Oomoo`03Ool00`00Oomoo`3iOol001ioo`03001o
ogoo00=oo`03001oogoo0?Uoo`007Woo00<007ooOol017oo00<007ooOol0n7oo000NOol00`00Oomo
o`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001io
o`03001oo`00008000Aoo`03001oogoo0?Ioo`007Woo00D007ooOomoo`0000Eoo`03001oogoo0?Eo
o`007Woo00D007ooOomoo`0000Eoo`03001oogoo0?Eoo`007Woo00D007ooOomoo`0000Ioo`03001o
ogoo0?Aoo`007Woo00D007ooOomoo`0000Moo`03001oogoo0?=oo`007Woo00D007ooOomoo`000?eo
o`007Woo00D007ooOomoo`000?eoo`007Woo00D007ooOomoo`0000Uoo`800?9oo`007Woo00D007oo
Oomoo`0000Yoo`800?5oo`007Woo00D007ooOomoo`0000]oo`800?1oo`007Woo00D007ooOomoo`00
0?eoo`007Woo00D007ooOomoo`000?eoo`007Woo00D007ooOomoo`0000moo`03001oogoo0>]oo`00
5Woo100017oo00D007ooOomoo`0000moo`<00>]oo`005Woo00<007ooOol01Goo00D007ooOomoo`00
011oo`03001oogoo0>Yoo`005goo00<007ooOol017oo0P000Woo00<007ooOol04Woo00<007ooOol0
iWoo000HOol00`00Oomoo`03Ool01@00Oomoogoo000057oo0P00igoo000FOol01000Oomoo`0017oo
00D007ooOomoo`0001Eoo`<00>Eoo`005goo0P001Goo00D007ooOomoo`0001Ioo`03001oo`000>Ao
o`007Woo00D007ooOomoo`0001Qoo`800>=oo`007Woo00D007ooOomoo`0001Uoo`80009oo`03001o
ogoo0=eoo`007Woo00D007ooOomoo`0001aoo`<0009oo`03001oogoo0=Uoo`007Woo00D007ooOomo
o`0001eoo`04001oogooOol2003JOol001ioo`05001oogooOol0000QOol00`00Ool00002Ool00`00
Oomoo`3DOol001ioo`05001oogooOol0000TOol01000Ool00000eGoo000NOol01@00Oomoogoo0000
:7oo0P0000=oo`00Ool0d7oo000NOol01@00Oomoogoo0000:Goo00<007ooOol00P00cgoo000NOol0
1@00Oomoogoo0000;Woo00<007ooOol0c7oo000NOol01@00Oomoogoo0000<Goo00<007oo00001Goo
0P00`Woo000NOol01@00Oomoogoo0000<Goo00<007ooOol00P001Goo00<007ooOol00goo00<007oo
Ool0^Goo000NOol01@00Oomoogoo0000=Woo0P0017oo00<007ooOol00Woo00<007ooOol01goo00<0
07ooOol0[goo000NOol01@00Oomoogoo0000@Goo00D007ooOomoo`0000Eoo`8000Yoo`03001oogoo
0:=oo`007Woo00D007ooOomoo`00045oo`03001oogoo009oo`03001oogoo009oo`03001oo`0000Uo
o`<00:=oo`007Woo00D007ooOomoo`00041oo`8000Eoo`03001oogoo00eoo`03001oogoo00aoo`03
001oogoo02Yoo`80029oo`03001oogoo009oo`8003moo`007Woo00D007ooOomoo`0004Qoo`8000Mo
o`8000Aoo`03001oogoo00=oo`03001oogoo00Ioo`05001oogooOol0000?Ool00`00Oomoo`02000D
Ool00`00Oomoo`02Ool2000MOol00`00Oomoo`04Ool2000mOol001ioo`05001oogooOol0001COol2
0009Ool00`00Oomoo`05Ool00`00Oomoo`02Ool2000=Ool00`00Oomoo`02Ool2000BOol00`00Oomo
o`04Ool2000KOol00`00Oomoo`06Ool2000kOol001ioo`05001oogooOol0001EOol00`00Oomoo`07
Ool40003Ool00`00Oomoo`04Ool2000;Ool00`00Oomoo`04Ool2000@Ool00`00Oomoo`06Ool2000I
Ool00`00Oomoo`0;Ool2000fOol001ioo`05001oogooOol0001VOol00`00Oomoo`0:Ool00`00Oomo
o`04Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool2000DOol00`00Oomoo`0=Ool4
000bOol001ioo`05001oogooOol0001VOol00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0:
Ool2000JOol2000BOol00`00Oomoo`0EOol2000/Ool001ioo`05001oogooOol0001eOol30002Ool0
0`00Oomoo`0<Ool3000IOol2000ZOol3000YOol001ioo`05001oogooOol0002ZOol4000ZOol2000S
Ool001ioo`05001oogooOol0002?Ool3000LOol2000ZOol3000POol001Qoo`<000=oo`05001oogoo
Ool0002BOol2001YOol001Uoo`03001oogoo009oo`05001oogooOol0002dOol4000YOol2000JOol0
01Ioo`D000=oo`80009oo`03001oogoo0;Aooc0001Moo`005Woo00@007ooOol000Aoo`05001oogoo
Ool0002gOol00`00Oomoo`13Ool001Moo`03001oo`0000Aoo`05001oogooOol0002gOol00`00Oomo
o`13Ool001Qoo`8000Aoo`05001oogooOol0002gOol00`00Oomoo`13Ool001ioo`05001oogooOol0
002gOol00`00Oomoo`13Ool001ioo`05001oogooOol0002gOol00`00Oomoo`13Ool001ioo`05001o
ogooOol0002gOol00`00Oomoo`13Ool001ioo`05001oogooOol0002gOol00`00Oomoo`13Ool001io
o`05001oogooOol0002gOol00`00Oomoo`13Ool001ioo`05001oogooOol0002gOol00`00Oomoo`13
Ool001ioo`05001oogooOol0002gOol00`00Oomoo`13Ool001ioo`05001oogooOol0002gOol00`00
Oomoo`13Ool001ioo`05001oogooOol0002gOol00`00Oomoo`13Ool001ioo`05001oogooOol0002g
Ool00`00Oomoo`13Ool001ioo`05001oogooOol0002gOol00`00Oomoo`13Ool001ioo`05001oogoo
Ool0002COolU0015Ool001ioo`05001oogooOol0002COol00`00Oomoo`1WOol001ioo`05001oogoo
Ool0002COol00`00Oomoo`1WOol001ioo`05001oogooOol0002COol00`00Oomoo`1WOol001ioo`05
001oogooOol0002COol00`00Oomoo`1WOol001ioo`05001oogooOol0002COol00`00Oomoo`1WOol0
01ioo`05001oogooOol0002COol00`00Oomoo`1WOol001ioo`05001oogooOol0002COol00`00Oomo
o`1WOol001ioo`05001oogooOol0002COol00`00Oomoo`1WOol001ioo`05001oogooOol0002COol0
0`00Oomoo`1WOol001ioo`05001oogooOol0002COol00`00Oomoo`1WOol001ioo`05001oogooOol0
002COol00`00Oomoo`1WOol001Ioo`<000Eoo`05001oogooOol0002COol00`00Oomoo`1WOol001Io
o`04001oogoo0004Ool01@00Oomoogoo0000Tgoo00<007ooOol0Igoo000FOol01000Oomoo`0017oo
0P000Woo00<007ooOol0N7oo6P00JGoo000FOol30005Ool01@00Oomoogoo0000NWoo00<007ooOol0
P7oo000GOol00`00Oomoo`04Ool01@00Oomoogoo0000NWoo00<007ooOol0P7oo000GOol30004Ool0
1@00Oomoogoo0000NWoo00<007ooOol0P7oo000NOol01@00Oomoogoo0000NWoo00<007ooOol0P7oo
000NOol01@00Oomoogoo0000NWoo00<007ooOol0P7oo000NOol01@00Oomoogoo0000NWoo00<007oo
Ool0P7oo000NOol01@00Oomoogoo0000NWoo00<007ooOol0P7oo000NOol01@00Oomoogoo0000NWoo
00<007ooOol0P7oo000NOol01@00Oomoogoo0000NWoo00<007ooOol0P7oo000NOol01@00Oomoogoo
0000NWoo00<007ooOol0P7oo000NOol01@00Oomoogoo0000NWoo00<007ooOol0P7oo000NOol01@00
Oomoogoo0000NWoo00<007ooOol0P7oo000NOol01@00Oomoogoo0000NWoo00<007ooOol0P7oo000N
Ool01@00Oomoogoo0000NWoo00<007ooOol0P7oo000NOol01@00Oomoogoo0000IWoo5@00PWoo000N
Ool01@00Oomoogoo0000IWoo00<007ooOol0U7oo000NOol01@00Oomoogoo0000IWoo00<007ooOol0
U7oo000NOol01@00Oomoogoo0000IWoo00<007ooOol0U7oo000NOol01@00Oomoogoo0000IWoo00<0
07ooOol0U7oo000NOol01@00Oomoogoo0000IWoo00<007ooOol0U7oo000NOol01@00Oomoogoo0000
IWoo00<007ooOol0U7oo000NOol01@00Oomoogoo0000IWoo00<007ooOol0U7oo000NOol01@00Oomo
ogoo0000IWoo00<007ooOol0U7oo000NOol01@00Oomoogoo0000IWoo00<007ooOol0U7oo000NOol0
1@00Oomoogoo0000IWoo00<007ooOol0U7oo000NOol01@00Oomoogoo0000IWoo00<007ooOol0U7oo
000NOol01@00Oomoogoo0000IWoo00<007ooOol0U7oo000GOol20005Ool01@00Oomoogoo0000IWoo
00<007ooOol0U7oo000FOol01000Oomoo`0017oo00D007ooOomoo`0006Ioo`03001oogoo09Aoo`00
5Woo00@007ooOol000Aoo`80009oo`03001oogoo05Eooa0009Ioo`005goo0P001Goo00D007ooOomo
o`0005Moo`03001oogoo0:=oo`005Woo00@007ooOol000Aoo`05001oogooOol0001GOol00`00Oomo
o`2SOol001Moo`8000Eoo`05001oogooOol0001GOol00`00Oomoo`2SOol001ioo`05001oogooOol0
001GOol00`00Oomoo`2SOol001ioo`05001oogooOol0001GOol00`00Oomoo`2SOol001ioo`05001o
ogooOol0001GOol00`00Oomoo`2SOol001ioo`05001oogooOol0001GOol00`00Oomoo`2SOol001io
o`05001oogooOol0001GOol00`00Oomoo`2SOol001ioo`05001oogooOol0001GOol00`00Oomoo`2S
Ool001ioo`05001oogooOol0001GOol00`00Oomoo`2SOol001ioo`05001oogooOol0001GOol00`00
Oomoo`2SOol001ioo`05001oogooOol0001GOol00`00Oomoo`2SOol001ioo`05001oogooOol0001G
Ool00`00Oomoo`2SOol001ioo`05001oogooOol0001;Ool=002UOol001ioo`05001oogooOol0001;
Ool00`00Oomoo`2_Ool001ioo`05001oogooOol0001;Ool00`00Oomoo`2_Ool001ioo`05001oogoo
Ool0001;Ool00`00Oomoo`2_Ool001ioo`05001oogooOol0001;Ool00`00Oomoo`2_Ool001ioo`05
001oogooOol0001;Ool00`00Oomoo`2_Ool001ioo`05001oogooOol0001;Ool00`00Oomoo`2_Ool0
01ioo`05001oogooOol0001;Ool00`00Oomoo`2_Ool001ioo`05001oogooOol0001;Ool00`00Oomo
o`2_Ool001ioo`05001oogooOol0001;Ool00`00Oomoo`2_Ool001ioo`05001oogooOol0001;Ool0
0`00Oomoo`2_Ool001ioo`05001oogooOol0001;Ool00`00Oomoo`2_Ool001ioo`05001oogooOol0
001;Ool00`00Oomoo`2_Ool0011oo`D0009oo`8000Eoo`05001oogooOol0001;Ool00`00Oomoo`2_
Ool0019oo`05001oogooOol00002Ool00`00Oomoo`02Ool01@00Oomoogoo0000@7oo00<007ooOol0
27oo00<007ooOol0[goo000BOol01@00Oomoogoo00000Woo00<007ooOol00Woo0P000Woo00<007oo
Ool0?goo2`00/Goo000BOol01@00Oomoogoo00000Woo00<007ooOol0ogoo1Goo000BOol01@00Oomo
ogoo00000Woo00<007ooOol0ogoo1Goo000AOol20004Ool2003oOol8Ool00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`0027oo0`0000Eoo`00000007oo
0080009oo`<0009oo`<000Aoo`@00003Ool00000008000=oo`<00003Ool00000009oo`800>Yoo`00
1goo00<007ooOol00goo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo009oo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01000Oomoo`00jgoo0007Ool00`00Oomoo`03Ool0
1000Oomoo`0017oo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000=oo`03001oogoo009o
o`@0009oo`04001oogoo003[Ool000Moo`03001oogoo00=oo`<000Aoo`8000Aoo`03001oogoo00=o
o`<0009oo`@000=oo`80009oo`@00>aoo`001goo00@007ooOol0009oo`03001oogoo00Yoo`03001o
ogoo00Eoo`03001oogoo0?]oo`0027oo0`0000=oo`0000001goo00@007ooOomoo`8000Ioo`800?eo
o`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.8167, \
0.00421906, 0.0682658}}],

Cell[BoxData[
    \(1.049041748046875`\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.0618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(10)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.01 .0618 m
.02935 .0618 L
.03921 .0618 L
.04463 .0618 L
.04976 .0618 L
.05106 .0618 L
.05178 .0618 L
.05245 .0618 L
.05317 .12361 L
.05396 .12361 L
.05468 .12361 L
.05536 .12361 L
.05665 .18541 L
.05782 .18541 L
.05909 .24721 L
.0598 .24721 L
.06047 .24721 L
.06177 .24721 L
.063 .30902 L
.0641 .30902 L
.0653 .30902 L
.0666 .37082 L
.06726 .37082 L
.06798 .37082 L
.06916 .37082 L
.07045 .37082 L
.07124 .43262 L
.07197 .43262 L
.07341 .43262 L
.07611 .43262 L
.07678 .43262 L
.0775 .43262 L
.0783 .49443 L
.07905 .49443 L
.08217 .49443 L
.08495 .49443 L
.08635 .49443 L
.08714 .49443 L
.08788 .55623 L
.0892 .55623 L
.09041 .55623 L
.09311 .55623 L
.0981 .55623 L
.10083 .55623 L
.10216 .55623 L
.10338 .55623 L
.1045 .55623 L
.10556 .61803 L
.10668 .61803 L
.10789 .61803 L
Mistroke
.11285 .61803 L
.13425 .61803 L
.15623 .61803 L
.17613 .61803 L
.18612 .61803 L
.19691 .61803 L
.20186 .61803 L
.20457 .61803 L
.20709 .61803 L
.2082 .61803 L
.20925 .61803 L
.21046 .55623 L
.21156 .55623 L
.21645 .55623 L
.25594 .55623 L
.27633 .55623 L
.28129 .55623 L
.28389 .55623 L
.2853 .55623 L
.28662 .55623 L
.28733 .55623 L
.28808 .49443 L
.28892 .49443 L
.28968 .49443 L
.29248 .49443 L
.29796 .49443 L
.31941 .49443 L
.33916 .49443 L
.35842 .49443 L
.36813 .49443 L
.37079 .49443 L
.37225 .49443 L
.37364 .49443 L
.37493 .49443 L
.37566 .43262 L
.37634 .43262 L
.37879 .43262 L
.41917 .43262 L
.45798 .43262 L
.46766 .43262 L
.47786 .43262 L
.48044 .43262 L
.48186 .43262 L
.4832 .43262 L
.48396 .37082 L
.48479 .37082 L
.48623 .37082 L
.48905 .37082 L
.49931 .37082 L
.54139 .37082 L
Mistroke
.5819 .37082 L
.60225 .37082 L
.61114 .37082 L
.62085 .37082 L
.62343 .37082 L
.62484 .37082 L
.62617 .37082 L
.62741 .30902 L
.62876 .30902 L
.6311 .30902 L
.64084 .30902 L
.66233 .30902 L
.70454 .30902 L
.74519 .30902 L
.78429 .30902 L
.80606 .30902 L
.81637 .30902 L
.8259 .30902 L
.83069 .30902 L
.83185 .30902 L
.8331 .30902 L
.83382 .24721 L
.83447 .24721 L
.83576 .24721 L
.84648 .24721 L
.86596 .24721 L
.90676 .24721 L
.94599 .24721 L
.98775 .24721 L
.99 .24721 L
Mfstroke
[ .02 .02 ] 0 setdash
.01 .00062 m
.02935 .00181 L
.03921 .00242 L
.04463 .00276 L
.04976 .00308 L
.05106 .00316 L
.05178 .0032 L
.05245 .00324 L
.05317 .00657 L
.05396 .00667 L
.05468 .00676 L
.05536 .00684 L
.05665 .0105 L
.05782 .01072 L
.05909 .01461 L
.0598 .01478 L
.06047 .01495 L
.06177 .01527 L
.063 .01947 L
.0641 .01981 L
.0653 .02018 L
.0666 .0247 L
.06726 .02494 L
.06798 .02521 L
.06916 .02565 L
.07045 .02612 L
.07124 .03082 L
.07197 .03113 L
.07341 .03176 L
.07611 .03292 L
.07678 .03322 L
.0775 .03353 L
.0783 .03871 L
.07905 .03908 L
.08217 .04063 L
.08495 .042 L
.08635 .04269 L
.08714 .04308 L
.08788 .04888 L
.0892 .04962 L
.09041 .05029 L
.09311 .05179 L
.13425 .08297 L
.17384 .10744 L
.19429 .12008 L
.19926 .12315 L
.2046 .12645 L
.20617 .12742 L
.20766 .12834 L
.209 .12917 L
Mistroke
.20976 .12964 L
.21046 .11706 L
.21118 .11746 L
.21185 .11784 L
.21311 .11854 L
.21594 .12011 L
.25566 .14221 L
.27622 .15364 L
.28122 .15642 L
.28397 .15795 L
.28532 .1587 L
.28657 .1594 L
.28728 .15979 L
.28804 .14241 L
.2888 .14279 L
.28964 .14321 L
.29244 .14459 L
.29791 .14729 L
.31953 .15799 L
.33933 .16778 L
.35876 .17738 L
.36853 .18221 L
.3712 .18353 L
.37267 .18426 L
.37339 .18462 L
.37406 .18494 L
.37535 .16239 L
.37603 .16268 L
.37675 .16299 L
.3792 .16405 L
.41824 .18094 L
.43997 .19034 L
.4598 .19892 L
.46963 .20317 L
.47482 .20542 L
.47766 .20665 L
.48033 .2078 L
.48146 .20829 L
.48264 .2088 L
.48394 .17946 L
.48514 .1799 L
.49044 .18187 L
.4998 .18534 L
.53898 .19987 L
.58069 .21533 L
.59994 .22247 L
.61008 .22623 L
.62083 .23022 L
.62345 .23119 L
.62489 .23172 L
Mistroke
.62626 .23223 L
.62703 .23252 L
.62788 .19402 L
.62864 .19426 L
.62935 .19448 L
.63224 .19537 L
.64277 .19863 L
.6635 .20503 L
.70378 .21748 L
.74659 .23071 L
.78784 .24346 L
.80677 .2493 L
.81751 .25262 L
.82275 .25424 L
.82753 .25572 L
.82997 .25647 L
.83126 .25687 L
.83196 .25709 L
.83262 .25729 L
.83381 .20613 L
.83513 .20645 L
.83744 .20703 L
.84806 .20965 L
.86974 .21501 L
.90957 .22486 L
.95193 .23533 L
.99 .24474 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool2
0004Ool20003Ool4000POol20004Ool20005Ool3000POol20004Ool20003Ool3000QOol20004Ool2
0004Ool2000WOol5000BOol004Eoo`04001oogoo0008Ool00`00Oomoo`0POol01000Oomoo`002goo
00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`0027oo00@007ooOol0
02Qoo`03001oogoo019oo`00AGoo00@007ooOol000Uoo`03001oogoo01moo`04001oogoo0008Ool5
000OOol01000Oomoo`0027oo00@007ooOol001moo`04001oogoo0008Ool01000Oomoo`00:7oo00<0
07ooOol04Woo0015Ool01000Oomoo`002Woo00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo
000POol01000Oomoo`0027oo0`0087oo00@007ooOol000Uoo`8002Uoo`03001oogoo019oo`00AGoo
00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`002Goo00<007oo000087oo00@007ooOol0
00Uoo`03001oogoo01moo`04001oogoo0008Ool01000Oomoo`00:7oo00<007ooOol04Woo0016Ool2
000:Ool2000QOol2000;Ool2000QOol2000:Ool3000POol2000:Ool2000XOol2000DOol00?moob5o
o`00ogoo8Goo003oOolQOol00?mooaAoo`<000Yoo`00ogoo5goo00<007ooOol01goo000NOoo^0007
Ool3000:Ool001ioo`03001oogoo00Uoo`03001oogoo021oo`03001oogoo02aoo`03001oogoo02eo
o`03001oogoo02aoo`03001oogoo02eoo`03001oogoo00Eoo`@000Uoo`007Woo00<007ooOol0ogoo
000NOol00`00Oomoo`3oOol001ioo`03001oogoo00aoo`03001oogoo0?1oo`007Woo00<007ooOol0
37oo0P00lGoo000NOol00`00Oomoo`0=Ool00`00Oomoo`3_Ool001ioo`03001oogoo00eoo`<00>mo
o`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<0
07ooOol04Goo0P00k7oo000NOol00`00Oomoo`0COol00`00Oomoo`3YOol001ioo`03001oogoo01Ao
o`03001oogoo0>Qoo`007Woo00<007oo00002P002goo00<007ooOol0igoo000NOol00`00Oomoo`09
Ool00`00Oomoo`3cOol001ioo`03001oogoo00Uoo`03001oogoo00eoo`03001oogoo0>=oo`007Woo
00<007ooOol02Goo00<007ooOol03Woo00<007ooOol0hWoo000NOol00`00Oomoo`09Ool00`00Oomo
o`0?Ool00`00Oomoo`3QOol001ioo`03001oogoo00Uoo`03001oogoo011oo`03001oogoo0>1oo`00
7Woo00<007ooOol02Goo00<007ooOol0lgoo000NOol00`00Oomoo`09Ool00`00Oomoo`3cOol001io
o`03001oogoo00Uoo`03001oogoo01Aoo`03001oogoo0=aoo`007Woo00<007ooOol02Goo00<007oo
Ool05Goo0P00g7oo000NOol00`00Oomoo`09Ool00`00Oomoo`0GOol2003JOol001ioo`03001oogoo
00Uoo`03001oogoo0?=oo`007Woo00<007ooOol02Goo00<007ooOol0lgoo000FOol40004Ool00`00
Oomoo`09Ool00`00Oomoo`0LOol20004Ool2003?Ool001Ioo`03001oogoo00Eoo`03001oogoo00Uo
o`03001oogoo01ioo`80009oo`<00<ioo`005goo00<007ooOol017oo0P002Woo0P008Goo00<007oo
Ool00Woo0P00c7oo000HOol00`00Oomoo`03Ool00`00Oomoo`0:Ool00`00Oomoo`3bOol001Ioo`04
001oogoo0004Ool00`00Oomoo`0:Ool00`00Oomoo`3bOol001Moo`8000Eoo`03001oogoo00Yoo`03
001oogoo02Uoo`800<Moo`007Woo00<007ooOol02Woo00<007ooOol0:goo0P00aGoo000NOol00`00
Oomoo`0:Ool00`00Oomoo`0]Ool00`00Oomoo`32Ool001ioo`03001oogoo00Yoo`03001oogoo03Ao
o`04001oo`00002jOol001ioo`03001oogoo00Yoo`03001oogoo039oo`03001oo`0000=oo`800;Qo
o`007Woo00<007ooOol02Woo00<007ooOol0<Woo0`001Goo0P00]Woo000NOol00`00Oomoo`0:Ool0
0`00Oomoo`3bOol001ioo`03001oogoo00Yoo`03001oogoo03moo`8000Moo`05001oogooOol0002U
Ool001ioo`03001oogoo00Yoo`03001oogoo045oo`8000Eoo`03001oogoo009oo`800:=oo`007Woo
00<007ooOol02Woo00<007ooOol0@goo00<007ooOol00Woo00<007ooOol017oo0P00XGoo000NOol0
0`00Oomoo`0:Ool00`00Oomoo`18Ool00`00Oomoo`0GOol2002>Ool001ioo`03001oogoo00Yoo`03
001oogoo04Moo`8000]oo`03001oogoo00]oo`03001oo`0008eoo`007Woo00<007ooOol02Woo00<0
07ooOol0EGoo0P002goo00<007ooOol00goo0P00R7oo000NOol00`00Oomoo`0:Ool00`00Oomoo`1G
Ool30008Ool00`00Oomoo`05Ool20026Ool001ioo`03001oogoo00Yoo`03001oogoo06aoo`8001Uo
o`03001oogoo06Qoo`007Woo00<007ooOol02Woo00<007ooOol0GGoo00<007ooOol0:7oo0P00J7oo
000NOol00`00Oomoo`0:Ool00`00Oomoo`1NOol3000@Ool3000@Ool00`00Oomoo`03Ool2000YOol0
0`00Oomoo`0jOol001ioo`03001oogoo00Yoo`03001oogoo065oo`03001oogoo011oo`<000eoo`03
001oogoo00Uoo`03001oogoo029oo`8003]oo`007Woo00<007ooOol02Woo00<007ooOol0Q7oo00<0
07ooOol02Woo0P008Woo00<007ooOol00goo1000<goo000NOol00`00Oomoo`0;Ool00`00Oomoo`1i
Ool20008Ool00`00Oomoo`0<Ool2000POol00`00Oomoo`07Ool2000aOol001ioo`03001oogoo00]o
o`03001oogoo07]oo`<000Eoo`03001oogoo019oo`8001Yoo`03001oogoo00aoo`8002aoo`007Woo
00<007ooOol02goo00<007ooOol0OWoo00<007ooOol06Goo0`00:7oo1000:7oo000NOol00`00Oomo
o`0;Ool00`00Oomoo`22Ool20018Ool2000SOol001ioo`03001oogoo00]oo`03001oogoo0:5oo`80
02]oo`<0021oo`0067oo0`000goo00<007ooOol02goo00<007ooOol0Xgoo0`00:goo00<007ooOol0
7Goo000IOol00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`2ZOol00`00Oomoo`07Ool00`00
Oomoo`0OOol2000IOol001Ioo`D000=oo`8000aoo`03001oogoo0:]oo`8000MoobH001Moo`005Woo
00@007ooOol000Aoo`03001oogoo00]oo`03001oogoo0:eoo`<000Aoo`03001oogoo03Yoo`005goo
00<007oo000017oo00<007ooOol02goo00<007ooOol0/goo0P00?7oo000HOol20004Ool00`00Oomo
o`0;Ool00`00Oomoo`2dOol00`00Oomoo`0jOol001ioo`03001oogoo00]oo`03001oogoo0;Aoo`03
001oogoo03Yoo`007Woo00<007ooOol02goo00<007ooOol0]7oo00<007ooOol0>Woo000NOol00`00
Oomoo`0;Ool00`00Oomoo`2dOol00`00Oomoo`0jOol001ioo`03001oogoo00]oo`03001oogoo0;Ao
o`03001oogoo03Yoo`007Woo00<007ooOol02goo00<007ooOol0]7oo00<007ooOol0>Woo000NOol0
0`00Oomoo`0;Ool00`00Oomoo`2dOol00`00Oomoo`0jOol001ioo`03001oogoo00]oo`03001oogoo
0;Aoo`03001oogoo03Yoo`007Woo00<007ooOol02goo00<007ooOol0]7oo00<007ooOol0>Woo000N
Ool00`00Oomoo`0;Ool00`00Oomoo`2dOol00`00Oomoo`0jOol001ioo`03001oogoo00]oo`03001o
ogoo0;Aoo`03001oogoo03Yoo`007Woo00<007ooOol02goo00<007ooOol0]7oo00<007ooOol0>Woo
000NOol00`00Oomoo`0;Ool20024Oolb000lOol001ioo`03001oogoo00aoo`03001oogoo089oo`03
001oogoo06]oo`007Woo00<007ooOol037oo00<007ooOol0PWoo00<007ooOol0Jgoo000NOol00`00
Oomoo`0<Ool00`00Oomoo`22Ool00`00Oomoo`1[Ool001ioo`03001oogoo00aoo`03001oogoo089o
o`03001oogoo06]oo`007Woo00<007ooOol037oo00<007ooOol0PWoo00<007ooOol0Jgoo000NOol0
0`00Oomoo`0<Ool00`00Oomoo`22Ool00`00Oomoo`1[Ool001ioo`03001oogoo00aoo`03001oogoo
089oo`03001oogoo06]oo`007Woo00<007ooOol037oo00<007ooOol0PWoo00<007ooOol0Jgoo000N
Ool00`00Oomoo`0<Ool00`00Oomoo`22Ool00`00Oomoo`1[Ool001ioo`03001oogoo00aoo`03001o
ogoo089oo`03001oogoo06]oo`007Woo00<007ooOol037oo00<007ooOol0PWoo00<007ooOol0Jgoo
000FOol30005Ool00`00Oomoo`0<Ool00`00Oomoo`22Ool00`00Oomoo`1[Ool001Ioo`04001oogoo
0004Ool00`00Oomoo`0<Ool00`00Oomoo`22Ool00`00Oomoo`1[Ool001Ioo`04001oogoo0004Ool2
000=Ool2001QOolS001]Ool001Ioo`<000Eoo`03001oogoo00eoo`03001oogoo05moo`03001oogoo
08eoo`005goo00<007ooOol017oo00<007ooOol03Goo00<007ooOol0Ggoo00<007ooOol0SGoo000G
Ool30004Ool00`00Oomoo`0=Ool00`00Oomoo`1OOol00`00Oomoo`2=Ool001ioo`03001oogoo00eo
o`03001oogoo05moo`03001oogoo08eoo`007Woo00<007ooOol03Goo00<007ooOol0Ggoo00<007oo
Ool0SGoo000NOol00`00Oomoo`0=Ool00`00Oomoo`1OOol00`00Oomoo`2=Ool001ioo`03001oogoo
00eoo`03001oogoo05moo`03001oogoo08eoo`007Woo00<007ooOol03Goo00<007ooOol0Ggoo00<0
07ooOol0SGoo000NOol00`00Oomoo`0=Ool00`00Oomoo`1OOol00`00Oomoo`2=Ool001ioo`03001o
ogoo00eoo`03001oogoo05moo`03001oogoo08eoo`007Woo00<007ooOol03Goo00<007ooOol0Ggoo
00<007ooOol0SGoo000NOol00`00Oomoo`0=Ool00`00Oomoo`1OOol00`00Oomoo`2=Ool001ioo`03
001oogoo00eoo`03001oogoo05moo`03001oogoo08eoo`007Woo00<007ooOol03Goo00<007ooOol0
Ggoo00<007ooOol0SGoo000NOol00`00Oomoo`0=Ool30016OolJ002?Ool001ioo`03001oogoo00mo
o`03001oogoo04Aoo`03001oogoo0:Ioo`007Woo00<007ooOol03goo00<007ooOol0A7oo00<007oo
Ool0YWoo000NOol00`00Oomoo`0?Ool00`00Oomoo`14Ool00`00Oomoo`2VOol001ioo`03001oogoo
00moo`03001oogoo04Aoo`03001oogoo0:Ioo`007Woo00<007ooOol03goo00<007ooOol0A7oo00<0
07ooOol0YWoo000NOol00`00Oomoo`0?Ool00`00Oomoo`14Ool00`00Oomoo`2VOol001ioo`03001o
ogoo00moo`03001oogoo04Aoo`03001oogoo0:Ioo`007Woo00<007ooOol03goo00<007ooOol0@goo
00<007ooOol0Ygoo000NOol00`00Oomoo`0?Ool00`00Oomoo`13Ool00`00Oomoo`2WOol001ioo`03
001oogoo00moo`03001oogoo04=oo`03001oogoo0:Moo`007Woo00<007ooOol03goo00<007ooOol0
@goo00<007ooOol0Ygoo000NOol00`00Oomoo`0?Ool00`00Oomoo`13Ool00`00Oomoo`2WOol001Mo
o`8000Eoo`03001oogoo00moo`03001oogoo04=oo`03001oogoo0:Moo`005Woo00@007ooOol000Ao
o`03001oogoo00moo`03001oogoo04=oo`03001oogoo0:Moo`005Woo00@007ooOol000Aoo`80011o
o`<002mooaD00:Uoo`005goo0P001Goo00<007ooOol04Goo00<007ooOol0;Goo00<007ooOol0^goo
000FOol01000Oomoo`0017oo00<007ooOol04Goo00<007ooOol0;Goo00<007ooOol0^goo000GOol2
0005Ool00`00Oomoo`0AOol00`00Oomoo`0]Ool00`00Oomoo`2kOol001ioo`03001oogoo015oo`03
001oogoo02eoo`03001oogoo0;]oo`007Woo00<007ooOol04Goo00<007ooOol0;Goo00<007ooOol0
^goo000NOol00`00Oomoo`0AOol00`00Oomoo`0]Ool00`00Oomoo`2kOol001ioo`03001oogoo015o
o`03001oogoo02eoo`03001oogoo0;]oo`007Woo00<007ooOol04Goo00<007ooOol0;Goo00<007oo
Ool0^goo000NOol00`00Oomoo`0AOol00`00Oomoo`0]Ool00`00Oomoo`2kOol001ioo`03001oogoo
015oo`03001oogoo02eoo`03001oogoo0;]oo`007Woo00<007ooOol04Goo00<007ooOol0;Goo00<0
07ooOol0^goo000NOol00`00Oomoo`0AOol00`00Oomoo`0]Ool00`00Oomoo`2kOol001ioo`03001o
ogoo015oo`03001oogoo02eoo`03001oogoo0;]oo`007Woo00<007ooOol04Goo1@0067oo5000_Goo
000NOol00`00Oomoo`0EOol00`00Oomoo`0FOol00`00Oomoo`3>Ool001ioo`03001oogoo01Eoo`03
001oogoo01Ioo`03001oogoo0<ioo`007Woo00<007ooOol05Goo00<007ooOol05Woo00<007ooOol0
cWoo000NOol00`00Oomoo`0EOol00`00Oomoo`0FOol00`00Oomoo`3>Ool001ioo`03001oogoo01Eo
o`03001oogoo01Ioo`03001oogoo0<ioo`007Woo00<007ooOol05Goo00<007ooOol05Woo00<007oo
Ool0cWoo000NOol00`00Oomoo`0EOol00`00Oomoo`0FOol00`00Oomoo`3>Ool001ioo`03001oogoo
01Ioo`03001oogoo01Eoo`03001oogoo0<ioo`007Woo00<007ooOol05Woo00<007ooOol05Goo00<0
07ooOol0cWoo000NOol00`00Oomoo`0FOol00`00Oomoo`0EOol00`00Oomoo`3>Ool001ioo`03001o
ogoo01Ioo`03001oogoo01Eoo`03001oogoo0<ioo`007Woo00<007ooOol05Woo00<007ooOol05Goo
00<007ooOol0cWoo000@Ool50002Ool20005Ool00`00Oomoo`0FOol00`00Oomoo`0EOol00`00Oomo
o`3>Ool0019oo`05001oogooOol00002Ool00`00Oomoo`02Ool00`00Oomoo`0FOol00`00Oomoo`0E
Ool00`00Oomoo`3>Ool0019oo`05001oogooOol00002Ool00`00Oomoo`02Ool2000GOolI003@Ool0
019oo`05001oogooOol00002Ool00`00Oomoo`3oOol5Ool0019oo`05001oogooOol00002Ool00`00
Oomoo`3oOol5Ool0015oo`8000Aoo`800?moo`Qoo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo0008Ool300001Goo00000000Ool00P000Woo0`000Woo
0`0017oo100000=oo`0000000P000goo0`0000=oo`0000000Woo0P00jWoo0007Ool00`00Oomoo`03
Ool01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000=oo`03001oogoo
009oo`03001oogoo00=oo`04001oogoo003[Ool000Moo`03001oogoo00=oo`04001oogoo0004Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000goo00<007ooOol00Woo10000Woo00@007oo
Ool00>]oo`001goo00<007ooOol00goo0`0017oo0P0017oo00<007ooOol00goo0`000Woo10000goo
0P000Woo1000k7oo0007Ool01000Oomoo`000Woo00<007ooOol02Woo00<007ooOol01Goo00<007oo
Ool0ngoo0008Ool300000goo00000007Ool01000Oomoogoo0P001Woo0P00oGoo003oOolQOol00?mo
ob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.8167, \
0.00421906, 0.0682658}}],

Cell[BoxData[
    \(0.5152511596679688`\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.0618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(10)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.01 .0618 m
.04976 .0618 L
.09311 .0618 L
.11419 .0618 L
.13383 .0618 L
.14356 .0618 L
.14834 .0618 L
.15044 .0618 L
.15275 .0618 L
.15403 .0618 L
.15522 .12361 L
.15648 .12361 L
.15783 .12361 L
.16335 .12361 L
.16802 .12361 L
.17058 .12361 L
.17184 .12361 L
.17299 .12361 L
.17435 .18541 L
.17507 .18541 L
.17582 .18541 L
.17838 .18541 L
.18339 .18541 L
.18926 .18541 L
.19474 .18541 L
.1995 .18541 L
.20087 .18541 L
.20216 .18541 L
.20333 .24721 L
.20459 .24721 L
.21541 .24721 L
.23576 .24721 L
.24603 .24721 L
.24885 .24721 L
.25033 .24721 L
.25188 .24721 L
.25255 .24721 L
.25325 .24721 L
.25403 .30902 L
.25475 .30902 L
.25738 .30902 L
.30008 .30902 L
.34122 .30902 L
.3808 .30902 L
.42291 .30902 L
.46345 .30902 L
.50244 .30902 L
.54395 .30902 L
.5839 .30902 L
.62637 .30902 L
Mistroke
.66729 .30902 L
.70664 .30902 L
.74852 .30902 L
.78884 .30902 L
.80943 .30902 L
.83168 .30902 L
.84215 .30902 L
.84786 .30902 L
.85319 .30902 L
.85553 .30902 L
.85775 .30902 L
.85897 .30902 L
.8603 .24721 L
.86151 .24721 L
.86262 .24721 L
.87296 .24721 L
.91342 .24721 L
.95232 .24721 L
.99 .24721 L
Mfstroke
[ .02 .02 ] 0 setdash
.01 .00062 m
.04976 .00308 L
.09311 .00575 L
.11419 .00706 L
.13383 .00827 L
.14356 .00887 L
.14834 .00917 L
.15044 .0093 L
.15275 .00944 L
.15403 .00952 L
.15522 .01919 L
.15648 .01934 L
.15783 .01951 L
.16335 .02019 L
.16802 .02077 L
.17058 .02108 L
.17184 .02124 L
.17299 .02138 L
.17435 .03233 L
.17507 .03246 L
.17582 .0326 L
.17838 .03307 L
.18339 .034 L
.18926 .03509 L
.19474 .03611 L
.1995 .03699 L
.20087 .03724 L
.20216 .03748 L
.20333 .05027 L
.20459 .05058 L
.21541 .05325 L
.23576 .05828 L
.24603 .06082 L
.24885 .06152 L
.25033 .06188 L
.25188 .06227 L
.25255 .06243 L
.25325 .06261 L
.25403 .0785 L
.25475 .07872 L
.25738 .07953 L
.30008 .09273 L
.34122 .10544 L
.3808 .11767 L
.42291 .13069 L
.46345 .14321 L
.50244 .15526 L
.54395 .16809 L
.5839 .18043 L
.62637 .19356 L
Mistroke
.66729 .2062 L
.70664 .21836 L
.74852 .2313 L
.78884 .24376 L
.80943 .25013 L
.83168 .257 L
.84215 .26024 L
.84786 .262 L
.85319 .26365 L
.85553 .26437 L
.85775 .26506 L
.85897 .26544 L
.8603 .21268 L
.86151 .21298 L
.86262 .21325 L
.87296 .21581 L
.91342 .22581 L
.95232 .23543 L
.99 .24474 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool2
0004Ool20003Ool4000POol20004Ool20005Ool3000POol20004Ool20003Ool3000QOol20004Ool2
0004Ool2000WOol5000BOol004Eoo`04001oogoo0008Ool00`00Oomoo`0POol01000Oomoo`002goo
00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`0027oo00@007ooOol0
02Qoo`03001oogoo019oo`00AGoo00@007ooOol000Uoo`03001oogoo01moo`04001oogoo0008Ool5
000OOol01000Oomoo`0027oo00@007ooOol001moo`04001oogoo0008Ool01000Oomoo`00:7oo00<0
07ooOol04Woo0015Ool01000Oomoo`002Woo00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo
000POol01000Oomoo`0027oo0`0087oo00@007ooOol000Uoo`8002Uoo`03001oogoo019oo`00AGoo
00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`002Goo00<007oo000087oo00@007ooOol0
00Uoo`03001oogoo01moo`04001oogoo0008Ool01000Oomoo`00:7oo00<007ooOol04Woo0016Ool2
000:Ool2000QOol2000;Ool2000QOol2000:Ool3000POol2000:Ool2000XOol2000DOol00?moob5o
o`00ogoo8Goo003oOolQOol00?mooaAoo`<000Yoo`00ogoo5goo00<007ooOol01goo000NOoo^0007
Ool3000:Ool001ioo`03001oogoo00]oo`<000=oo`H000Aoo`<000ioo`03001oogoo02aoo`03001o
ogoo02eoo`03001oogoo02aoo`03001oogoo02eoo`03001oogoo00Eoo`@000Uoo`007Woo00<007oo
Ool07Woo0`00gWoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo029oo`<00=Yoo`007Woo00<0
07ooOol09Goo0P00f7oo000NOol00`00Oomoo`0VOol00`00Oomoo`3FOol001ioo`03001oogoo0?mo
o`007Woo00<007ooOol0:Goo1000dWoo000NOol00`00Oomoo`0/Ool00`00Oomoo`3@Ool001ioo`03
001oogoo02eoo`03001oogoo0<moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`0`Ool2003=
Ool001ioo`03001oogoo039oo`@00<Uoo`007Woo00<007oo00008P00gGoo000NOol00`00Oomoo`0Q
Ool00`00Oomoo`0EOol00`00Oomoo`33Ool001ioo`03001oogoo025oo`03001oogoo01Eoo`03001o
ogoo0<=oo`007Woo00<007ooOol08Goo00<007ooOol05Goo00<007ooOol0`goo000NOol00`00Oomo
o`0QOol00`00Oomoo`0EOol20034Ool001ioo`03001oogoo025oo`03001oogoo01Ioo`03001oogoo
0<9oo`007Woo00<007ooOol08Goo00<007ooOol06goo0P00_Woo000NOol00`00Oomoo`0QOol00`00
Oomoo`0MOol3002kOol001ioo`03001oogoo025oo`03001oogoo0=]oo`007Woo00<007ooOol08Goo
00<007ooOol097oo0P00]Goo000NOol00`00Oomoo`0QOol00`00Oomoo`0VOol3002bOol001ioo`03
001oogoo025oo`03001oogoo0=]oo`007Woo00<007ooOol08Goo00<007ooOol0;Goo0P00[7oo000F
Ool40004Ool00`00Oomoo`0QOol00`00Oomoo`0_Ool3002YOol001Ioo`03001oogoo00Eoo`03001o
ogoo025oo`03001oogoo03Ioo`03001oogoo0:9oo`005goo00<007ooOol017oo0P008Woo1P00=7oo
0P00XWoo000HOol00`00Oomoo`03Ool00`00Oomoo`0VOol00`00Oomoo`0dOol2002POol001Ioo`04
001oogoo0004Ool00`00Oomoo`0VOol00`00Oomoo`0jOol2002JOol001Moo`8000Eoo`03001oogoo
02Ioo`03001oogoo03aoo`8009Qoo`007Woo00<007ooOol09Woo00<007ooOol0?Woo0P00UWoo000N
Ool00`00Oomoo`0VOol00`00Oomoo`13Ool3002@Ool001ioo`03001oogoo02Ioo`03001oogoo04Io
o`<008eoo`007Woo00<007ooOol09Woo00<007ooOol0eWoo000NOol00`00Oomoo`0VOol00`00Oomo
o`1<Ool30027Ool001ioo`03001oogoo02Ioo`03001oogoo04moo`<008Aoo`007Woo00<007ooOol0
9Woo00<007ooOol0eWoo000NOol00`00Oomoo`0VOol00`00Oomoo`1EOol3001nOol001ioo`03001o
ogoo02Ioo`03001oogoo05Qoo`<007]oo`007Woo00<007ooOol09Woo00<007ooOol0GWoo0P00MWoo
000NOol00`00Oomoo`0VOol7001LOol2001dOol001ioo`03001oogoo02aoo`03001oogoo05aoo`80
079oo`007Woo00<007ooOol0;7oo00<007ooOol0HGoo0P00KGoo000NOol00`00Oomoo`0/Ool00`00
Oomoo`1SOol2001[Ool001ioo`03001oogoo02aoo`03001oogoo06Eoo`8006Uoo`007Woo00<007oo
Ool0;7oo00<007ooOol0Jgoo0P00Hgoo000NOol00`00Oomoo`0/Ool00`00Oomoo`1]Ool2001QOol0
01ioo`03001oogoo02aoo`03001oogoo06moo`03001oogoo02Moo`8003Eoo`007Woo00<007ooOol0
;Goo00<007ooOol0Lgoo0`008Woo00<007ooOol00Woo0`00;goo000NOol00`00Oomoo`0]Ool00`00
Oomoo`1fOol2000POol00`00Oomoo`05Ool3000/Ool001ioo`03001oogoo02eoo`03001oogoo09Qo
o`03001oogoo00aoo`03001oogoo02Eoo`007Woo00<007ooOol0;Goo00<007ooOol0O7oo0`006Goo
00<007ooOol03Goo0P009Goo000NOol00`00Oomoo`0]Ool00`00Oomoo`1oOol2000YOol2000SOol0
01Qoo`<000=oo`03001oogoo02eoo`03001oogoo0;1oo`8001eoo`006Goo00<007ooOol00Woo00<0
07ooOol0;Goo00<007ooOol0QGoo0`00:Woo0`006Woo000FOol50003Ool2000^Ool=001nOol2000>
OolP000GOol001Ioo`04001oogoo0004Ool00`00Oomoo`0iOol00`00Oomoo`22Ool20008Ool00`00
Oomoo`0dOol001Moo`03001oo`0000Aoo`03001oogoo03Uoo`03001oogoo08Aoo`<000Eoo`03001o
ogoo03Aoo`0067oo0P0017oo00<007ooOol0>Goo00<007ooOol0QWoo00<007ooOol00goo00<007oo
Ool0=7oo000NOol00`00Oomoo`0iOol00`00Oomoo`2;Ool2000fOol001ioo`03001oogoo03Uoo`03
001oogoo08aoo`03001oogoo03Aoo`007Woo00<007ooOol0>Goo00<007ooOol0S7oo00<007ooOol0
=7oo000NOol00`00Oomoo`0iOol00`00Oomoo`2<Ool00`00Oomoo`0dOol001ioo`03001oogoo03Uo
o`03001oogoo08aoo`03001oogoo03Aoo`007Woo00<007ooOol0>Goo00<007ooOol0S7oo00<007oo
Ool0=7oo000NOol00`00Oomoo`0iOol00`00Oomoo`2<Ool00`00Oomoo`0dOol001ioo`03001oogoo
03Uoo`03001oogoo08aoo`03001oogoo03Aoo`007Woo00<007ooOol0>Goo00<007ooOol0S7oo00<0
07ooOol0=7oo000NOol00`00Oomoo`0iOol00`00Oomoo`2<Ool00`00Oomoo`0dOol001ioo`03001o
ogoo03Uoo`03001oogoo08aoo`03001oogoo03Aoo`007Woo00<007ooOol0>GooT000=Woo000NOol0
0`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3o
Ool001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03
001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?mo
o`005Woo0`001Goo00<007ooOol0ogoo000FOol01000Oomoo`0017oo00<007ooOol0ogoo000FOol0
1000Oomoo`0017oo0P00ogoo0Goo000FOol30005Ool00`00Oomoo`3oOol001Moo`03001oogoo00Ao
o`03001oogoo0?moo`005goo0`0017oo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03
001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?mo
o`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<0
07ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo
000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00
Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol0
01ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001o
ogoo0?moo`007Woo00<007ooOol0ogoo000GOol20005Ool00`00Oomoo`3oOol001Ioo`04001oogoo
0004Ool00`00Oomoo`3oOol001Ioo`04001oogoo0004Ool2003oOol1Ool001Moo`8000Eoo`03001o
ogoo0?moo`005Woo00@007ooOol000Aoo`03001oogoo0?moo`005goo0P001Goo00<007ooOol0ogoo
000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00
Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol0
01ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001o
ogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`00
7Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007oo
Ool0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000N
Ool00`00Oomoo`3oOol001ioo`03001oogoo0?moo`0047oo1@000Woo0P001Goo00<007ooOol0ogoo
000BOol01@00Oomoogoo00000Woo00<007ooOol00Woo00<007ooOol0ogoo000BOol01@00Oomoogoo
00000Woo00<007ooOol00Woo0P00ogoo0Goo000BOol01@00Oomoogoo00000Woo00<007ooOol0ogoo
1Goo000BOol01@00Oomoogoo00000Woo00<007ooOol0ogoo1Goo000AOol20004Ool2003oOol8Ool0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`0027oo
0`0000Eoo`00000007oo0080009oo`<0009oo`<000Aoo`@00003Ool00000008000=oo`<00003Ool0
0000009oo`800>Yoo`001goo00<007ooOol00goo00@007ooOol000Aoo`03001oogoo009oo`03001o
ogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01000Oomoo`00jgoo0007
Ool00`00Oomoo`03Ool01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0
00=oo`03001oogoo009oo`@0009oo`04001oogoo003[Ool000Moo`03001oogoo00=oo`<000Aoo`80
00Aoo`03001oogoo00=oo`<0009oo`@000=oo`80009oo`@00>aoo`001goo00@007ooOol0009oo`03
001oogoo00Yoo`03001oogoo00Eoo`03001oogoo0?]oo`0027oo0`0000=oo`0000001goo00@007oo
Oomoo`8000Ioo`800?eoo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.8167, \
0.00421906, 0.0682658}}],

Cell[BoxData[
    \(16.1171875`\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.0618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(10)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.37599 .61803 m
.37599 .61803 L
.37728 .61803 L
.37851 .61803 L
.3808 .61803 L
.38597 .61803 L
.39531 .61803 L
.40024 .61803 L
.40548 .61803 L
.40703 .61803 L
.4085 .61803 L
.40981 .61803 L
.41055 .61803 L
.41123 .55623 L
.41246 .55623 L
.41382 .55623 L
.41656 .55623 L
.43669 .55623 L
.44248 .55623 L
.44533 .55623 L
.44796 .55623 L
.45035 .55623 L
.45156 .55623 L
.45288 .49443 L
.45421 .49443 L
.45564 .49443 L
.45823 .49443 L
.4785 .49443 L
.48921 .49443 L
.49509 .49443 L
.49798 .49443 L
.49924 .49443 L
.49991 .49443 L
.50063 .49443 L
.50197 .43262 L
.50323 .43262 L
.50597 .43262 L
.51174 .43262 L
.52181 .43262 L
.54148 .43262 L
.55194 .43262 L
.55481 .43262 L
.55638 .43262 L
.55786 .43262 L
.55911 .43262 L
.56046 .37082 L
.56119 .37082 L
.56195 .37082 L
.56333 .37082 L
.58403 .37082 L
Mistroke
.60456 .37082 L
.61352 .37082 L
.62323 .37082 L
.62585 .37082 L
.62863 .37082 L
.62977 .37082 L
.631 .37082 L
.63234 .30902 L
.6336 .30902 L
.6434 .30902 L
.66495 .30902 L
.68527 .30902 L
.69599 .30902 L
.70742 .30902 L
.71315 .30902 L
.71596 .30902 L
.7172 .30902 L
.71855 .30902 L
.71977 .24721 L
.72091 .24721 L
.7234 .24721 L
.72864 .24721 L
.74832 .24721 L
.78839 .24721 L
.79888 .24721 L
.81028 .24721 L
.8155 .24721 L
.81836 .24721 L
.82105 .24721 L
.82216 .24721 L
.82332 .24721 L
.82461 .18541 L
.82578 .18541 L
.831 .18541 L
.87025 .18541 L
.89215 .18541 L
.91203 .18541 L
.92197 .18541 L
.9272 .18541 L
.93005 .18541 L
.93145 .18541 L
.93273 .18541 L
.93393 .18541 L
.93506 .12361 L
.93626 .12361 L
.93757 .12361 L
.94289 .12361 L
.95225 .12361 L
.99 .12361 L
Mfstroke
[ .02 .02 ] 0 setdash
.01 .01731 m
.04976 .0861 L
.09311 .16113 L
.11419 .19761 L
.12448 .21541 L
.13383 .2316 L
.1361 .23551 L
.1385 .23967 L
.13975 .24183 L
.14046 .23439 L
.14113 .2355 L
.14356 .23955 L
.14474 .24153 L
.14587 .24341 L
.14688 .23602 L
.14799 .2378 L
.14918 .23972 L
.15046 .24177 L
.15166 .2437 L
.15275 .23602 L
.15402 .23797 L
.15536 .24004 L
.15776 .24375 L
.15909 .24581 L
.16034 .23783 L
.16106 .23889 L
.16171 .23986 L
.16317 .24203 L
.16559 .24562 L
.16625 .2466 L
.16695 .24764 L
.16822 .23912 L
.16939 .24078 L
.17049 .24234 L
.1717 .24406 L
.17299 .2459 L
.1743 .24777 L
.17549 .23862 L
.17669 .24024 L
.17782 .24178 L
.18057 .24552 L
.18178 .24716 L
.18311 .24897 L
.18439 .23932 L
.18559 .24087 L
.18822 .24428 L
.19089 .24775 L
.19166 .24875 L
.19239 .2497 L
.19305 .25055 L
Mistroke
.19376 .2395 L
.19505 .2411 L
.19627 .2426 L
.19855 .24542 L
.2012 .2487 L
.20236 .25014 L
.20364 .25171 L
.20475 .24043 L
.20578 .24164 L
.20804 .2443 L
.2128 .24989 L
.2141 .25142 L
.21482 .25225 L
.21549 .25304 L
.21667 .24103 L
.21797 .24248 L
.22358 .24873 L
.22598 .25139 L
.22728 .25284 L
.2285 .25419 L
.22982 .24146 L
.23051 .24219 L
.23126 .24297 L
.23378 .24563 L
.23626 .24823 L
.23894 .25105 L
.24017 .25234 L
.24147 .2537 L
.24258 .25487 L
.2438 .24108 L
.24499 .24226 L
.24607 .24333 L
.2485 .24573 L
.25289 .25007 L
.25544 .25259 L
.25668 .25382 L
.25783 .25495 L
.25903 .24013 L
.26032 .24133 L
.26308 .24388 L
.26796 .24841 L
.27251 .25263 L
.2749 .25485 L
.27625 .2561 L
.27747 .24008 L
.27881 .24124 L
.28026 .2425 L
.2829 .24478 L
.28856 .24968 L
.29133 .25207 L
Mistroke
.29386 .25426 L
.29501 .25526 L
.29626 .25634 L
.29745 .23898 L
.29855 .23986 L
.30358 .24391 L
.3092 .24842 L
.31429 .25251 L
.31688 .2546 L
.31759 .25517 L
.31834 .25577 L
.31968 .23709 L
.32094 .23802 L
.32211 .23889 L
.32477 .24086 L
.33012 .24483 L
.33593 .24914 L
.33864 .25115 L
.34152 .25329 L
.34398 .25511 L
.34466 .25561 L
.34538 .25615 L
.3467 .2357 L
.34793 .23654 L
.34929 .23746 L
.35202 .23931 L
.35689 .24263 L
.36168 .24588 L
.36679 .24936 L
.36927 .25104 L
.37161 .25263 L
.37371 .25406 L
.3749 .25487 L
.37599 .23237 L
.37728 .23317 L
.37851 .23393 L
.3808 .23535 L
.38597 .23855 L
.39531 .24432 L
.40024 .24736 L
.40548 .2506 L
.40703 .25156 L
.4085 .25246 L
.40981 .25328 L
.41055 .25373 L
.41123 .22874 L
.41246 .22943 L
.41382 .23018 L
.41656 .2317 L
.43669 .2429 L
Mistroke
.44248 .24612 L
.44533 .24771 L
.44796 .24917 L
.45035 .2505 L
.45156 .25117 L
.45288 .22392 L
.45421 .22457 L
.45564 .22528 L
.45823 .22656 L
.4785 .23658 L
.48921 .24188 L
.49509 .24479 L
.49798 .24621 L
.49924 .24684 L
.49991 .24717 L
.50063 .24753 L
.50197 .21717 L
.50323 .21771 L
.50597 .21889 L
.51174 .22139 L
.52181 .22575 L
.54148 .23426 L
.55194 .23878 L
.55481 .24002 L
.55638 .2407 L
.55786 .24134 L
.55911 .24188 L
.56046 .20783 L
.56119 .2081 L
.56195 .20838 L
.56333 .20889 L
.58403 .21657 L
.60456 .22418 L
.61352 .22751 L
.62323 .23111 L
.62585 .23208 L
.62863 .23311 L
.62977 .23353 L
.631 .23399 L
.63234 .1954 L
.6336 .19579 L
.6434 .19882 L
.66495 .20548 L
.68527 .21176 L
.69599 .21507 L
.70742 .2186 L
.71315 .22038 L
.71596 .22125 L
.7172 .22163 L
.71855 .22204 L
Mistroke
.71977 .17794 L
.72091 .17822 L
.7234 .17883 L
.72864 .18013 L
.74832 .18499 L
.78839 .1949 L
.79888 .19749 L
.81028 .20031 L
.8155 .2016 L
.81836 .20231 L
.82105 .20297 L
.82216 .20325 L
.82332 .20354 L
.82461 .15289 L
.82578 .15311 L
.831 .15408 L
.87025 .16135 L
.89215 .16541 L
.91203 .1691 L
.92197 .17094 L
.9272 .17191 L
.93005 .17244 L
.93145 .1727 L
.93273 .17294 L
.93393 .17316 L
.93506 .11558 L
.93626 .11573 L
.93757 .11589 L
.94289 .11655 L
.95225 .1177 L
.99 .12237 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool2
0004Ool20003Ool4000POol20004Ool20005Ool3000POol20004Ool20003Ool3000QOol20004Ool2
0004Ool2000WOol5000BOol004Eoo`04001oogoo0008Ool00`00Oomoo`0POol01000Oomoo`002goo
00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`0027oo00@007ooOol0
02Qoo`03001oogoo019oo`00AGoo00@007ooOol000Uoo`03001oogoo01moo`04001oogoo0008Ool5
000OOol01000Oomoo`0027oo00@007ooOol001moo`04001oogoo0008Ool01000Oomoo`00:7oo00<0
07ooOol04Woo0015Ool01000Oomoo`002Woo00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo
000POol01000Oomoo`0027oo0`0087oo00@007ooOol000Uoo`8002Uoo`03001oogoo019oo`00AGoo
00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`002Goo00<007oo000087oo00@007ooOol0
00Uoo`03001oogoo01moo`04001oogoo0008Ool01000Oomoo`00:7oo00<007ooOol04Woo0016Ool2
000:Ool2000QOol2000;Ool2000QOol2000:Ool3000POol2000:Ool2000XOol2000DOol00?moob5o
o`00ogoo8Goo003oOolQOol00?mooaAoo`<000Yoo`00ogoo5goo00<007ooOol01goo000NOoo^0007
Ool3000:Ool001ioo`03001oogoo02aoo`03001oogoo02aoo`03001oogoo02eoo`03001oogoo02ao
o`03001oogoo02eoo`03001oogoo00Eoo`@000Uoo`007Woo00<007ooOol0ogoo000NOol00`00Oomo
o`3oOol001ioo`03001oo`000?moo`007Woo00<007oo0000ogoo000NOol01000Oomoo`00oWoo000N
Ool01000Oomoo`00oWoo000NOol01@00Oomoogoo0000oGoo000NOol00`00Oomoo`3oOol001ioo`03
001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`04Ool00`00Oomoo`3hOol001io
o`03001oogoo00Aoo`03001oogoo0?Qoo`007Woo00<007ooOol01Goo00<007ooOol0mgoo000NOol0
0`00Oomoo`05Ool00`00Oomoo`3gOol001ioo`03001oogoo00Ioo`03001oogoo0?Ioo`007Woo00<0
07ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol02Goo
00<007ooOol0lgoo000NOol00`00Oomoo`09Ool00`00Oomoo`3cOol001ioo`03001oogoo00Yoo`03
001oogoo0?9oo`007Woo00<007ooOol02Woo00<007ooOol0lWoo000NOol00`00Oomoo`0;Ool00`00
Oomoo`3aOol001ioo`03001oogoo00]oo`03001oogoo0?5oo`007Woo00<007ooOol0ogoo000FOol4
0004Ool00`00Oomoo`3JOol3000ROol001Ioo`03001oogoo00Eoo`03001oogoo0=Yoo`03001oogoo
00Aoo`D001Uoo`005goo00<007ooOol017oo0P003Woo00<007ooOol0bWoo3P005goo000HOol00`00
Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`39Ool00`00Oomoo`0ROol001Ioo`04001oogoo0004
Ool00`00Oomoo`0>Ool00`00Oomoo`39Ool00`00Oomoo`0ROol001Moo`8000Eoo`03001oogoo00mo
o`03001oogoo0<Qoo`03001oogoo029oo`007Woo00<007ooOol047oo00<007ooOol0agoo00<007oo
Ool08Woo000NOol00`00Oomoo`3JOol00`00Oomoo`0ROol001ioo`03001oogoo0=Yoo`03001oogoo
029oo`007Woo00<007ooOol0`7oo0`005goo00<007ooOol08Woo000NOol00`00Oomoo`0BOol00`00
Oomoo`2^Ool20004Ool00`00Oomoo`0>Ool00`00Oomoo`0ROol001ioo`03001oogoo01=oo`03001o
ogoo0;Aoo`@000aoo`03001oogoo029oo`007Woo00<007ooOol04goo00<007ooOol0_7oo0P001Woo
00<007ooOol08Woo000NOol00`00Oomoo`0DOol00`00Oomoo`2mOol40002Ool00`00Oomoo`0ROol0
01ioo`03001oogoo01Aoo`03001oogoo0:Uoo`03001oogoo01Moo`03001oogoo029oo`007Woo00<0
07ooOol0Ygoo0`005Woo00<007ooOol05goo00<007ooOol08Woo000NOol00`00Oomoo`2WOol01000
Oomoo`005Goo6`0097oo000NOol00`00Oomoo`2_Ool3000>Ool00`00Oomoo`0lOol001ioo`03001o
ogoo01Moo`03001oogoo09Qoo`<000]oo`03001oogoo03aoo`007Woo00<007ooOol067oo00<007oo
Ool0Mgoo00<007ooOol08goo100017oo00<007ooOol0?7oo000NOol00`00Oomoo`0HOol00`00Oomo
o`1gOol00`00Oomoo`02Ool2000SOol20002Ool00`00Oomoo`0lOol001ioo`03001oogoo01Uoo`03
001oogoo07Ioo`03001oogoo00Aoo`8000aoo`03001oogoo01Ioo`03001oogoo03aoo`007Woo00<0
07ooOol06Goo00<007ooOol0MWoo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol05Woo00<0
07ooOol0?7oo000NOol00`00Oomoo`21Ool00`00Oomoo`02000<Ool00`00Oomoo`0;Ool30004Ool0
0`00Oomoo`0FOol00`00Oomoo`0lOol001ioo`03001oogoo07Aoo`03001oogoo00Yoo`03001oogoo
009oo`8000Yoo`03001oogoo00ioo`<00003Ool007oo01Moo`03001oogoo03aoo`007Woo00<007oo
Ool0Lgoo00@007oo000000Yoo`03001oogoo00Aoo`8001eoo`03001oogoo01Ioo`03001oogoo03ao
o`007Woo00<007ooOol077oo00<007ooOol0BGoo0P002Goo00<007ooOol02goo00<007ooOol02Goo
0P00<Goo00<007ooOol0?7oo000NOol00`00Oomoo`0LOol00`00Oomoo`0oOol20008Ool01000Ool0
00003Woo0P001Goo00<007ooOol02goo0P00;goo00<007ooOol0?7oo000NOol00`00Oomoo`0MOol0
1@00Ool007oo0000;Goo00<007ooOol037oo00<007ooOol06goo0P000goo00<007ooOol03Goo0P00
;Goo00<007ooOol0?7oo000HOol30003Ool00`00Oomoo`0MOol500001Goo000007oo00008Goo0P00
1Goo0P001Woo0P001Goo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol037oo00<007ooOol0
?goo00<007ooOol0?7oo000IOol00`00Oomoo`02Ool00`00Oomoo`0NOol00`00Ool00002Ool20002
Ool20004Ool01000Oomoo`000goo00<007ooOol00goo00D007ooOomoo`0000Eoo`03001oogoo00=o
o`05001oogooOol00007Ool00`00Oomoo`020003Ool00`00Oomoo`03Ool00`00Oomoo`09Ool00`00
Oomoo`1=Ool00`00Oomoo`0lOol001Ioo`D000=oo`8002Eoo`03001oogoo008000=oo`80009oo`<0
0003Ool0000000Aoo`05001oogooOol00006Ool20004Ool200000goo001oo`06Ool00`00Oomoo`02
Ool01000Oomoo`001Woo0P002Woo0`00<goo6P00?Woo000FOol01000Oomoo`0017oo00<007ooOol0
:7oo00@007oo001oo`8000Aoo`03001oogoo00800004Ool000000002Ool20002Ool20004Ool00`00
Oomoo`04Ool00`00Oomoo`03Ool2000AOol2000nOol00`00Oomoo`1EOol001Moo`03001oo`0000Ao
o`03001oogoo03Ioo`03001oogoo008000=oo`04001oogooOol20003Ool00`00Oomoo`0;Ool00`00
Oomoo`1?Ool00`00Oomoo`1EOol001Qoo`8000Aoo`03001oogoo0:Moo`03001oogoo05Eoo`007Woo
00<007ooOol0Ygoo00<007ooOol0EGoo000NOol00`00Oomoo`2WOol00`00Oomoo`1EOol001ioo`03
001oogoo0:Moo`03001oogoo05Eoo`007Woo00<007ooOol0Ygoo00<007ooOol0EGoo000NOol00`00
Oomoo`2WOol00`00Oomoo`1EOol001ioo`03001oogoo0:Moo`03001oogoo05Eoo`007Woo00<007oo
Ool0Ygoo00<007ooOol0EGoo000NOol00`00Oomoo`2WOol00`00Oomoo`1EOol001ioo`03001oogoo
0:Moo`03001oogoo05Eoo`007Woo00<007ooOol0Ygoo00<007ooOol0EGoo000NOol00`00Oomoo`2W
Ool00`00Oomoo`1EOol001ioo`03001oogoo099ooaH005Moo`007Woo00<007ooOol0TWoo00<007oo
Ool0JWoo000NOol00`00Oomoo`2BOol00`00Oomoo`1ZOol001ioo`03001oogoo099oo`03001oogoo
06Yoo`007Woo00<007ooOol0TWoo00<007ooOol0JWoo000NOol00`00Oomoo`2BOol00`00Oomoo`1Z
Ool001ioo`03001oogoo099oo`03001oogoo06Yoo`007Woo00<007ooOol0TWoo00<007ooOol0JWoo
000NOol00`00Oomoo`2BOol00`00Oomoo`1ZOol001ioo`03001oogoo099oo`03001oogoo06Yoo`00
7Woo00<007ooOol0TWoo00<007ooOol0JWoo000NOol00`00Oomoo`2BOol00`00Oomoo`1ZOol001Io
o`<000Eoo`03001oogoo099oo`03001oogoo06Yoo`005Woo00@007ooOol000Aoo`03001oogoo099o
o`03001oogoo06Yoo`005Woo00@007ooOol000Aoo`80089ooa8006aoo`005Woo0`001Goo00<007oo
Ool0PGoo00<007ooOol0Ngoo000GOol00`00Oomoo`04Ool00`00Oomoo`21Ool00`00Oomoo`1kOol0
01Moo`<000Aoo`03001oogoo085oo`03001oogoo07]oo`007Woo00<007ooOol0PGoo00<007ooOol0
Ngoo000NOol00`00Oomoo`21Ool00`00Oomoo`1kOol001ioo`03001oogoo085oo`03001oogoo07]o
o`007Woo00<007ooOol0PGoo00<007ooOol0Ngoo000NOol00`00Oomoo`21Ool00`00Oomoo`1kOol0
01ioo`03001oogoo085oo`03001oogoo07]oo`007Woo00<007ooOol0PGoo00<007ooOol0Ngoo000N
Ool00`00Oomoo`21Ool00`00Oomoo`1kOol001ioo`03001oogoo085oo`03001oogoo07]oo`007Woo
00<007ooOol0PGoo00<007ooOol0Ngoo000NOol00`00Oomoo`21Ool00`00Oomoo`1kOol001ioo`03
001oogoo07Aoo`h007eoo`007Woo00<007ooOol0M7oo00<007ooOol0R7oo000NOol00`00Oomoo`1d
Ool00`00Oomoo`28Ool001ioo`03001oogoo07Aoo`03001oogoo08Qoo`007Woo00<007ooOol0M7oo
00<007ooOol0R7oo000NOol00`00Oomoo`1dOol00`00Oomoo`28Ool001ioo`03001oogoo07Aoo`03
001oogoo08Qoo`007Woo00<007ooOol0M7oo00<007ooOol0R7oo000NOol00`00Oomoo`1cOol00`00
Oomoo`29Ool001ioo`03001oogoo07=oo`03001oogoo08Uoo`007Woo00<007ooOol0Lgoo00<007oo
Ool0RGoo000NOol00`00Oomoo`1cOol00`00Oomoo`29Ool001ioo`03001oogoo07=oo`03001oogoo
08Uoo`005goo0P001Goo00<007ooOol0Lgoo00<007ooOol0RGoo000FOol01000Oomoo`0017oo00<0
07ooOol0Lgoo00<007ooOol0RGoo000FOol01000Oomoo`0017oo0P00JGoo3000Rgoo000GOol20005
Ool00`00Oomoo`1XOol00`00Oomoo`2DOol001Ioo`04001oogoo0004Ool00`00Oomoo`1XOol00`00
Oomoo`2DOol001Moo`8000Eoo`03001oogoo06Qoo`03001oogoo09Aoo`007Woo00<007ooOol0J7oo
00<007ooOol0U7oo000NOol00`00Oomoo`1XOol00`00Oomoo`2DOol001ioo`03001oogoo06Qoo`03
001oogoo09Aoo`007Woo00<007ooOol0J7oo00<007ooOol0U7oo000NOol00`00Oomoo`1XOol00`00
Oomoo`2DOol001ioo`03001oogoo06Qoo`03001oogoo09Aoo`007Woo00<007ooOol0J7oo00<007oo
Ool0U7oo000NOol00`00Oomoo`1XOol00`00Oomoo`2DOol001ioo`03001oogoo06Qoo`03001oogoo
09Aoo`007Woo00<007ooOol0J7oo00<007ooOol0U7oo000NOol00`00Oomoo`1NOol;002FOol001io
o`03001oogoo05ioo`03001oogoo09ioo`007Woo00<007ooOol0GWoo00<007ooOol0WWoo000NOol0
0`00Oomoo`1NOol00`00Oomoo`2NOol001ioo`03001oogoo05ioo`03001oogoo09ioo`007Woo00<0
07ooOol0GWoo00<007ooOol0WWoo000NOol00`00Oomoo`1NOol00`00Oomoo`2NOol001ioo`03001o
ogoo05ioo`03001oogoo09ioo`007Woo00<007ooOol0GWoo00<007ooOol0WWoo000NOol00`00Oomo
o`1NOol00`00Oomoo`2NOol001ioo`03001oogoo05ioo`03001oogoo09ioo`007Woo00<007ooOol0
GWoo00<007ooOol0WWoo000NOol00`00Oomoo`1NOol00`00Oomoo`2NOol0011oo`D0009oo`8000Eo
o`03001oogoo05ioo`03001oogoo09ioo`004Woo00D007ooOomoo`00009oo`03001oogoo009oo`03
001oogoo05Eoo`03001oogoo00Ioo`03001oogoo09ioo`004Woo00D007ooOomoo`00009oo`03001o
ogoo009oo`8005Moo`T00:1oo`004Woo00D007ooOomoo`00009oo`03001oogoo0?moo`Eoo`004Woo
00D007ooOomoo`00009oo`03001oogoo0?moo`Eoo`004Goo0P0017oo0P00ogoo27oo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol000Qoo`<00005Ool0
0000001oo`020002Ool30002Ool30004Ool400000goo000000020003Ool300000goo00000002Ool2
003ZOol000Moo`03001oogoo00=oo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol00goo00@007ooOol00>]oo`001goo00<007oo
Ool00goo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo009oo`04001oogoo0003Ool00`00
Oomoo`02Ool40002Ool01000Oomoo`00jgoo0007Ool00`00Oomoo`03Ool30004Ool20004Ool00`00
Oomoo`03Ool30002Ool40003Ool20002Ool4003/Ool000Moo`04001oogoo0002Ool00`00Oomoo`0:
Ool00`00Oomoo`05Ool00`00Oomoo`3kOol000Qoo`<00003Ool0000000Moo`04001oogooOol20006
Ool2003mOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.8167, \
0.00421906, 0.0682658}}],

Cell[BoxData[
    \(0.988037109375`\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.0618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(10)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.01 .0618 m
.01478 .0618 L
.01924 .0618 L
.02175 .0618 L
.02412 .0618 L
.02544 .0618 L
.02618 .0618 L
.02686 .12361 L
.02935 .30902 L
.03162 .43262 L
.03288 .49443 L
.03407 .55623 L
.03474 .55623 L
.03547 .55623 L
.03675 .61803 L
s
.03675 .61803 m
.03675 .61803 L
s
.18588 .61803 m
.18588 .61803 L
.18696 .61803 L
.18934 .61803 L
.19434 .61803 L
.20541 .61803 L
.21086 .61803 L
.21326 .61803 L
.21453 .61803 L
.21591 .61803 L
.21721 .61803 L
.21841 .55623 L
.21956 .55623 L
.22076 .55623 L
.22592 .55623 L
.23682 .55623 L
.24682 .55623 L
.25118 .55623 L
.25348 .55623 L
.25591 .55623 L
.25716 .55623 L
.25787 .49443 L
.25853 .49443 L
.26095 .49443 L
.26572 .49443 L
.2762 .49443 L
.29509 .49443 L
.30021 .49443 L
.30291 .49443 L
.30439 .49443 L
.30512 .49443 L
.30578 .49443 L
.30711 .43262 L
.30781 .43262 L
.30855 .43262 L
.31105 .43262 L
.31594 .43262 L
.33501 .43262 L
.34477 .43262 L
.35523 .43262 L
.3603 .43262 L
.3628 .43262 L
.3651 .43262 L
.3672 .43262 L
.36825 .43262 L
.36942 .37082 L
.37058 .37082 L
.37183 .37082 L
.3741 .37082 L
.39434 .37082 L
Mistroke
.41646 .37082 L
.42668 .37082 L
.43759 .37082 L
.44289 .37082 L
.4455 .37082 L
.44664 .37082 L
.44789 .37082 L
.44902 .30902 L
.45008 .30902 L
.45238 .30902 L
.45725 .30902 L
.49722 .30902 L
.51756 .30902 L
.52829 .30902 L
.53971 .30902 L
.54546 .30902 L
.55087 .30902 L
.55323 .30902 L
.55572 .30902 L
.55702 .30902 L
.55776 .24721 L
.55845 .24721 L
.56096 .24721 L
.58065 .24721 L
.62076 .24721 L
.66339 .24721 L
.68475 .24721 L
.69413 .24721 L
.69911 .24721 L
.70447 .24721 L
.70712 .24721 L
.70843 .24721 L
.70964 .24721 L
.71073 .18541 L
.7119 .18541 L
.71437 .18541 L
.72365 .18541 L
.74399 .18541 L
.78676 .18541 L
.82798 .18541 L
.86763 .18541 L
.88774 .18541 L
.89839 .18541 L
.90981 .18541 L
.91545 .18541 L
.9208 .18541 L
.92312 .18541 L
.9244 .18541 L
.9256 .18541 L
.92688 .12361 L
Mistroke
.92757 .12361 L
.92831 .12361 L
.93082 .12361 L
.95043 .12361 L
.99 .12361 L
Mfstroke
[ .02 .02 ] 0 setdash
.01 .00062 m
.04976 .04305 L
.05489 .0475 L
.05742 .04968 L
.05975 .0517 L
.06106 .05283 L
.06171 .05721 L
.06244 .05788 L
.06535 .06059 L
.07045 .06531 L
.07337 .06801 L
.07498 .06951 L
.07651 .07093 L
.07792 .07224 L
.07873 .07298 L
.07947 .06876 L
.08078 .0699 L
.08218 .07111 L
.09311 .08057 L
.0984 .08514 L
.10117 .08754 L
.10411 .09008 L
.10535 .09115 L
.10668 .09231 L
.10745 .09297 L
.10814 .08689 L
.10884 .08745 L
.1095 .08798 L
.11447 .09197 L
.12374 .09942 L
.12628 .10146 L
.12768 .10258 L
.12898 .10363 L
.13009 .10452 L
.13129 .09737 L
.13262 .09835 L
.13383 .09926 L
.14325 .10624 L
.14842 .11007 L
.1533 .1137 L
.15465 .1147 L
.15539 .11524 L
.15608 .11575 L
.15682 .10661 L
.15764 .10717 L
.15909 .10815 L
.16434 .11172 L
.17461 .1187 L
.17973 .12219 L
.18113 .12314 L
Mistroke
.18263 .12416 L
.18335 .12465 L
.18404 .12512 L
.18531 .11453 L
.18655 .1153 L
.18786 .1161 L
.1902 .11755 L
.19548 .12081 L
.20546 .12698 L
.20982 .12968 L
.21456 .1326 L
.21582 .13339 L
.21717 .13422 L
.21832 .12143 L
.21958 .12214 L
.22433 .12478 L
.2348 .1306 L
.24401 .13572 L
.24902 .13851 L
.25368 .14111 L
.25609 .14244 L
.25744 .14319 L
.25866 .12789 L
.26 .12855 L
.26146 .12927 L
.26409 .13058 L
.27363 .13529 L
.28386 .14035 L
.2951 .14591 L
.30022 .14843 L
.30303 .14983 L
.30442 .15051 L
.3057 .15115 L
.3069 .13277 L
.30818 .13332 L
.31087 .13449 L
.3156 .13653 L
.33726 .14591 L
.34689 .15007 L
.35727 .15457 L
.36205 .15663 L
.36465 .15776 L
.36592 .15831 L
.36708 .15881 L
.36815 .15927 L
.36915 .13689 L
.37022 .13728 L
.37137 .13771 L
.37608 .13946 L
.3961 .14688 L
Mistroke
.41815 .15506 L
.42823 .1588 L
.43379 .16086 L
.43907 .16282 L
.44396 .16463 L
.44531 .16513 L
.44673 .16566 L
.44808 .16616 L
.4493 .13884 L
.45051 .13922 L
.45162 .13956 L
.45412 .14033 L
.45866 .14173 L
.49931 .1543 L
.51977 .16062 L
.53841 .16638 L
.54335 .1679 L
.54873 .16957 L
.55119 .17033 L
.5538 .17113 L
.55604 .17182 L
.55731 .17222 L
.5585 .13807 L
.55976 .13838 L
.56113 .13872 L
.56391 .1394 L
.56886 .14063 L
.58002 .14339 L
.62178 .15371 L
.66198 .16365 L
.68249 .16872 L
.69328 .17139 L
.69918 .17285 L
.7047 .17421 L
.70723 .17484 L
.70847 .17514 L
.70962 .17543 L
.71094 .13182 L
.71164 .13195 L
.71238 .13208 L
.71491 .13255 L
.72612 .13463 L
.74586 .13829 L
.78873 .14624 L
.83003 .1539 L
.86977 .16126 L
.88994 .165 L
.90062 .16698 L
.91204 .1691 L
.91771 .17015 L
Mistroke
.9205 .17067 L
.92307 .17115 L
.92541 .17158 L
.92658 .1718 L
.92788 .11469 L
.92918 .11485 L
.93058 .11503 L
.93311 .11534 L
.95275 .11777 L
.99 .12237 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool2
0004Ool20003Ool4000POol20004Ool20005Ool3000POol20004Ool20003Ool3000QOol20004Ool2
0004Ool2000WOol5000BOol004Eoo`04001oogoo0008Ool00`00Oomoo`0POol01000Oomoo`002goo
00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`0027oo00@007ooOol0
02Qoo`03001oogoo019oo`00AGoo00@007ooOol000Uoo`03001oogoo01moo`04001oogoo0008Ool5
000OOol01000Oomoo`0027oo00@007ooOol001moo`04001oogoo0008Ool01000Oomoo`00:7oo00<0
07ooOol04Woo0015Ool01000Oomoo`002Woo00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo
000POol01000Oomoo`0027oo0`0087oo00@007ooOol000Uoo`8002Uoo`03001oogoo019oo`00AGoo
00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`002Goo00<007oo000087oo00@007ooOol0
00Uoo`03001oogoo01moo`04001oogoo0008Ool01000Oomoo`00:7oo00<007ooOol04Woo0016Ool2
000:Ool2000QOol2000;Ool2000QOol2000:Ool3000POol2000:Ool2000XOol2000DOol00?moob5o
o`00ogoo8Goo003oOolQOol00?mooaAoo`<000Yoo`00ogoo5goo00<007ooOol01goo000NOoo^0007
Ool3000:Ool001ioo`04001oogoo000[Ool00`00Oomoo`0/Ool00`00Oomoo`0]Ool00`00Oomoo`0/
Ool00`00Oomoo`0]Ool00`00Oomoo`05Ool40009Ool001ioo`03001oogoo0?moo`007Woo00<007oo
Ool0ogoo000NOol00`00Oomoo`03Ool00`00Oomoo`3iOol001ioo`03001oogoo00Aoo`03001oogoo
0?Qoo`007Woo00<007ooOol017oo00<007ooOol0n7oo000NOol00`00Oomoo`05Ool00`00Oomoo`3g
Ool001ioo`03001oogoo00Ioo`03001oogoo0?Ioo`007Woo00<007ooOol0ogoo000NOol00`00Oomo
o`3oOol001ioo`03001oogoo00Yoo`03001oogoo0?9oo`007Woo00<007ooOol02goo00<007ooOol0
lGoo000NOol00`00Oomoo`0;Ool00`00Oomoo`3aOol001ioo`03001oo`0000@000Qoo`03001oogoo
0?1oo`007Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol0kgoo000NOol00`00Oomoo`03
Ool00`00Oomoo`0:Ool00`00Oomoo`3/Ool001ioo`03001oogoo00=oo`03001oogoo00]oo`03001o
ogoo0>]oo`007Woo00<007ooOol00goo00<007ooOol037oo00<007ooOol0jWoo000NOol00`00Oomo
o`03Ool00`00Oomoo`0=Ool00`00Oomoo`3YOol001ioo`03001oogoo00=oo`03001oogoo011oo`03
001oogoo0>Ioo`007Woo00<007ooOol00goo00<007ooOol04Goo0P00iWoo000NOol00`00Oomoo`03
Ool00`00Oomoo`0COol00`00Oomoo`3SOol001ioo`03001oogoo00=oo`03001oogoo01Aoo`03001o
o`000>9oo`007Woo00<007ooOol00goo00<007ooOol05goo00<007ooOol0ggoo000NOol00`00Oomo
o`03Ool00`00Oomoo`0HOol01@00Oomoogoo0000g7oo000NOol00`00Oomoo`03Ool00`00Oomoo`0I
Ool20002Ool00`00Oomoo`3IOol001Ioo`@000Aoo`03001oogoo00=oo`03001oogoo01ioo`80009o
o`03001oogoo0:moo`D0021oo`005Woo00<007ooOol01Goo00<007ooOol00goo00<007ooOol087oo
00<007oo0000]Woo00<007ooOol00Woo0P006Goo000GOol00`00Oomoo`04Ool20004Ool00`00Oomo
o`0QOol20003Ool00`00Oomoo`03Ool00`00Oomoo`2SOol@000GOol001Qoo`03001oogoo00=oo`03
001oogoo00=oo`03001oogoo02Moo`8000Aoo`8000Eoo`8009aoo`03001oogoo02Aoo`005Woo00@0
07ooOol000Aoo`03001oogoo00=oo`03001oogoo02Uoo`8000Aoo`03001oogoo009oo`03001oo`00
00Qoo`8005moo`@002ioo`03001oogoo02Aoo`005goo0P001Goo00<007ooOol00goo00<007ooOol0
<7oo00D007ooOomoo`0000Yoo`03001oo`0000aoo`80015oo`03001oogoo01Qoo`03001oogoo02Eo
o`8002aoo`03001oogoo02Aoo`007Woo00<007ooOol00goo00<007ooOol0=7oo00<007ooOol00goo
00<007ooOol01Goo0P002Woo00<007oo000047oo0`0067oo0`00:Woo0`009Woo00<007ooOol097oo
000NOol00`00Oomoo`03Ool00`00Oomoo`0kOol2000AOol00`00Oomoo`03Ool2000;Ool00`00Oomo
o`0KOol2000[Ool30004Ool2000MOol00`00Oomoo`0TOol001ioo`03001oogoo00=oo`03001oogoo
03eoo`8000Qoo`<000Aoo`03001oogoo00Eoo`8000Uoo`03001oogoo00Aoo`8001]oo`8001Qoo`03
001oogoo01=oo`<001Yoo`03001oogoo02Aoo`007Woo00<007ooOol00goo00<007ooOol0BWoo0`00
7Goo0`003Woo00<007ooOol02Goo0`005Goo00<007ooOol06Woo0`004goo00<007ooOol097oo000N
Ool00`00Oomoo`03Ool00`00Oomoo`1LOol00`00Oomoo`0BOol00`00Oomoo`07Ool00`00Oomoo`0@
Ool3000>Ool00`00Oomoo`0MOol3000@Ool00`00Oomoo`0TOol001ioo`03001oogoo00=oo`03001o
ogoo05eoo`<0019oo`8000Moo`03001oogoo01=oo`<000]oo`03001oogoo02=oo`8000]oo`03001o
ogoo02Aoo`007Woo00<007ooOol00goo00<007ooOol0H7oo00<007ooOol04Goo0`0017oo00<007oo
Ool06Goo00<007ooOol01Goo00<007ooOol09Goo10001goo00<007ooOol097oo000NOol00`00Oomo
o`03Ool00`00Oomoo`1jOol2000LOol5000bOol4000VOol001ioo`03001oogoo00=oo`03001oogoo
0=9oo`03001oogoo02Aoo`007Woo00<007ooOol00goo00<007ooOol0dWoo00<007ooOol097oo000N
Ool00`00Oomoo`03Ool00`00Oomoo`2OOold000VOol001ioo`03001oogoo00=oo`03001oogoo09mo
o`03001oogoo05Moo`007Woo00<007ooOol00goo00<007ooOol0Wgoo00<007ooOol0Egoo000NOol0
0`00Oomoo`03Ool00`00Oomoo`2OOol00`00Oomoo`1GOol001ioo`03001oogoo00=oo`03001oogoo
09moo`03001oogoo05Moo`007Woo00<007ooOol00goo00<007ooOol0Wgoo00<007ooOol0Egoo000N
Ool00`00Oomoo`03Ool00`00Oomoo`2OOol00`00Oomoo`1GOol001ioo`03001oogoo00=oo`03001o
ogoo09moo`03001oogoo05Moo`007Woo00<007ooOol00goo00<007ooOol0Wgoo00<007ooOol0Egoo
000NOol00`00Oomoo`03Ool00`00Oomoo`2OOol00`00Oomoo`1GOol001ioo`03001oogoo00=oo`03
001oogoo09moo`03001oogoo05Moo`007Woo00<007ooOol00goo00<007ooOol0Wgoo00<007ooOol0
Egoo000NOol00`00Oomoo`03Ool00`00Oomoo`2OOol00`00Oomoo`1GOol001Qoo`<000=oo`03001o
ogoo00=oo`03001oogoo09moo`03001oogoo05Moo`006Goo00<007ooOol00Woo00<007ooOol00goo
00<007ooOol0Wgoo00<007ooOol0Egoo000FOol50003Ool20004Ool00`00Oomoo`1kOolU001IOol0
01Ioo`04001oogoo0004Ool00`00Oomoo`03Ool00`00Oomoo`1kOol00`00Oomoo`1kOol001Moo`03
001oo`0000Aoo`03001oogoo00=oo`03001oogoo07]oo`03001oogoo07]oo`0067oo0P0017oo00<0
07ooOol00goo00<007ooOol0Ngoo00<007ooOol0Ngoo000NOol00`00Oomoo`03Ool00`00Oomoo`1k
Ool00`00Oomoo`1kOol001ioo`03001oogoo00=oo`03001oogoo07]oo`03001oogoo07]oo`007Woo
00<007ooOol00goo00<007ooOol0Ngoo00<007ooOol0Ngoo000NOol00`00Oomoo`03Ool00`00Oomo
o`1kOol00`00Oomoo`1kOol001ioo`03001oogoo00=oo`03001oogoo07]oo`03001oogoo07]oo`00
7Woo00<007ooOol00goo00<007ooOol0Ngoo00<007ooOol0Ngoo000NOol00`00Oomoo`03Ool00`00
Oomoo`1kOol00`00Oomoo`1kOol001ioo`03001oogoo00=oo`03001oogoo07]oo`03001oogoo07]o
o`007Woo00<007ooOol00goo00<007ooOol0Ngoo00<007ooOol0Ngoo000NOol00`00Oomoo`03Ool0
0`00Oomoo`1kOol00`00Oomoo`1kOol001ioo`03001oogoo00=oo`03001oogoo07]oo`03001oogoo
07]oo`007Woo00<007ooOol00goo00<007ooOol0HGoo6`00OGoo000NOol00`00Oomoo`03Ool00`00
Oomoo`1QOol00`00Oomoo`2EOol001ioo`03001oogoo00=oo`03001oogoo065oo`03001oogoo09Eo
o`007Woo00<007ooOol00goo00<007ooOol0HGoo00<007ooOol0UGoo000NOol00`00Oomoo`03Ool0
0`00Oomoo`1QOol00`00Oomoo`2EOol001ioo`03001oogoo00=oo`03001oogoo065oo`03001oogoo
09Eoo`007Woo00<007ooOol00goo00<007ooOol0HGoo00<007ooOol0UGoo000NOol00`00Oomoo`03
Ool00`00Oomoo`1QOol00`00Oomoo`2EOol001ioo`03001oogoo00=oo`03001oogoo065oo`03001o
ogoo09Eoo`007Woo00<007ooOol00goo00<007ooOol0HGoo00<007ooOol0UGoo000NOol00`00Oomo
o`03Ool00`00Oomoo`1QOol00`00Oomoo`2EOol001ioo`03001oogoo00=oo`03001oogoo065oo`03
001oogoo09Eoo`005Woo0`001Goo00<007ooOol00goo00<007ooOol0HGoo00<007ooOol0UGoo000F
Ool01000Oomoo`0017oo00<007ooOol00goo00<007ooOol0HGoo00<007ooOol0UGoo000FOol01000
Oomoo`0017oo0P0017oo00<007ooOol0CWoo5000Ugoo000FOol30005Ool00`00Oomoo`04Ool00`00
Oomoo`1=Ool00`00Oomoo`2XOol001Moo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo04eo
o`03001oogoo0:Qoo`005goo0`0017oo00<007ooOol017oo00<007ooOol0CGoo00<007ooOol0Z7oo
000NOol00`00Oomoo`04Ool00`00Oomoo`1=Ool00`00Oomoo`2XOol001ioo`03001oogoo00Aoo`03
001oogoo04eoo`03001oogoo0:Qoo`007Woo00<007ooOol017oo00<007ooOol0CGoo00<007ooOol0
Z7oo000NOol00`00Oomoo`04Ool00`00Oomoo`1=Ool00`00Oomoo`2XOol001ioo`03001oogoo00Ao
o`03001oogoo04eoo`03001oogoo0:Qoo`007Woo00<007ooOol017oo00<007ooOol0CGoo00<007oo
Ool0Z7oo000NOol00`00Oomoo`04Ool00`00Oomoo`1=Ool00`00Oomoo`2XOol001ioo`03001oogoo
00Aoo`03001oogoo04eoo`03001oogoo0:Qoo`007Woo00<007ooOol017oo00<007ooOol0CGoo00<0
07ooOol0Z7oo000NOol00`00Oomoo`04Ool00`00Oomoo`1=Ool00`00Oomoo`2XOol001ioo`03001o
ogoo00Aoo`03001oogoo04eoo`03001oogoo0:Qoo`007Woo00<007ooOol017oo00<007ooOol0?Woo
4000ZWoo000NOol00`00Oomoo`04Ool00`00Oomoo`0nOol00`00Oomoo`2gOol001ioo`03001oogoo
00Aoo`03001oogoo03ioo`03001oogoo0;Moo`007Woo00<007ooOol017oo00<007ooOol0?Woo00<0
07ooOol0]goo000NOol00`00Oomoo`04Ool00`00Oomoo`0nOol00`00Oomoo`2gOol001ioo`03001o
ogoo00Aoo`03001oogoo03ioo`03001oogoo0;Moo`007Woo00<007ooOol017oo00<007ooOol0?Woo
00<007ooOol0]goo000NOol00`00Oomoo`04Ool00`00Oomoo`0nOol00`00Oomoo`2gOol001ioo`03
001oogoo00Aoo`03001oogoo03ioo`03001oogoo0;Moo`007Woo00<007ooOol017oo00<007ooOol0
?Woo00<007ooOol0]goo000NOol00`00Oomoo`04Ool00`00Oomoo`0nOol00`00Oomoo`2gOol001io
o`03001oogoo00Aoo`03001oogoo03ioo`03001oogoo0;Moo`007Woo00<007ooOol017oo00<007oo
Ool0?Woo00<007ooOol0]goo000GOol20005Ool00`00Oomoo`04Ool00`00Oomoo`0nOol00`00Oomo
o`2gOol001Ioo`04001oogoo0004Ool00`00Oomoo`04Ool00`00Oomoo`0nOol00`00Oomoo`2gOol0
01Ioo`04001oogoo0004Ool20005Ool00`00Oomoo`0cOol<002iOol001Moo`8000Eoo`03001oogoo
00Aoo`03001oogoo03=oo`03001oogoo0<9oo`005Woo00@007ooOol000Aoo`03001oogoo00Aoo`03
001oogoo03=oo`03001oogoo0<9oo`005goo0P001Goo00<007ooOol017oo00<007ooOol0<goo00<0
07ooOol0`Woo000NOol00`00Oomoo`04Ool00`00Oomoo`0cOol00`00Oomoo`32Ool001ioo`03001o
ogoo00Aoo`03001oogoo03=oo`03001oogoo0<9oo`007Woo00<007ooOol017oo00<007ooOol0<goo
00<007ooOol0`Woo000NOol00`00Oomoo`04Ool00`00Oomoo`0bOol00`00Oomoo`33Ool001ioo`03
001oogoo00Eoo`03001oogoo035oo`03001oogoo0<=oo`007Woo00<007ooOol01Goo00<007ooOol0
<Goo00<007ooOol0`goo000NOol00`00Oomoo`05Ool00`00Oomoo`0aOol00`00Oomoo`33Ool001io
o`03001oogoo00Eoo`03001oogoo035oo`03001oogoo0<=oo`007Woo00<007ooOol01Goo00<007oo
Ool0<Goo00<007ooOol0`goo000NOol00`00Oomoo`05Ool00`00Oomoo`0aOol00`00Oomoo`33Ool0
01ioo`03001oogoo00Eoo`03001oogoo02Qoo`X00<Eoo`007Woo00<007ooOol01Goo00<007ooOol0
:7oo00<007ooOol0c7oo000NOol00`00Oomoo`05Ool00`00Oomoo`0XOol00`00Oomoo`3<Ool001io
o`03001oogoo00Eoo`03001oogoo02Qoo`03001oogoo0<aoo`007Woo00<007ooOol01Goo00<007oo
Ool0:7oo00<007ooOol0c7oo000NOol00`00Oomoo`05Ool00`00Oomoo`0XOol00`00Oomoo`3<Ool0
01ioo`03001oogoo00Eoo`03001oogoo02Qoo`03001oogoo0<aoo`007Woo00<007ooOol01Goo00<0
07ooOol0:7oo00<007ooOol0c7oo000NOol00`00Oomoo`05Ool00`00Oomoo`0XOol00`00Oomoo`3<
Ool001ioo`03001oogoo00Eoo`03001oogoo02Qoo`03001oogoo0<aoo`007Woo00<007ooOol01Goo
00<007ooOol0:7oo00<007ooOol0c7oo000NOol00`00Oomoo`05Ool00`00Oomoo`0XOol00`00Oomo
o`3<Ool001ioo`03001oogoo00Eoo`03001oogoo02Qoo`03001oogoo0<aoo`0047oo1@000Woo0P00
1Goo00<007ooOol01Goo00<007ooOol0:7oo00<007ooOol0c7oo000BOol01@00Oomoogoo00000Woo
00<007ooOol00Woo00<007ooOol01Goo00<007ooOol087oo00<007ooOol01Goo00<007ooOol0c7oo
000BOol01@00Oomoogoo00000Woo00<007ooOol00Woo0P001Woo00<007ooOol08Goo2000cWoo000B
Ool01@00Oomoogoo00000Woo00<007ooOol0ogoo1Goo000BOol01@00Oomoogoo00000Woo00<007oo
Ool0ogoo1Goo000AOol20004Ool2003oOol8Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`0027oo0`0000Eoo`00000007oo0080009oo`<0009oo`<0
00Aoo`@00003Ool00000008000=oo`<00003Ool00000009oo`800>Yoo`001goo00<007ooOol00goo
00@007ooOol000Aoo`03001oogoo009oo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool01000Oomoo`00jgoo0007Ool00`00Oomoo`03Ool01000Oomoo`0017oo00<0
07ooOol00Woo00<007ooOol00Woo00@007ooOol000=oo`03001oogoo009oo`@0009oo`04001oogoo
003[Ool000Moo`03001oogoo00=oo`<000Aoo`8000Aoo`03001oogoo00=oo`<0009oo`@000=oo`80
009oo`@00>aoo`001goo00@007ooOol0009oo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo
0?]oo`0027oo0`0000=oo`0000001goo00@007ooOomoo`8000Ioo`800?eoo`00ogoo8Goo003oOolQ
Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.8167, \
0.00421906, 0.0682658}}],

Cell[BoxData[
    \(0.5305023193359375`\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.0618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(10)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.01 .0618 m
.02935 .0618 L
.03921 .0618 L
.04976 .0618 L
.05264 .0618 L
.05406 .0618 L
.05536 .0618 L
.05655 .12361 L
.05781 .12361 L
.05908 .18541 L
.05979 .18541 L
.06047 .18541 L
.06176 .18541 L
.06298 .24721 L
.06408 .24721 L
.06528 .24721 L
.06657 .24721 L
.0673 .30902 L
.06796 .30902 L
.07045 .30902 L
.07118 .30902 L
.07187 .30902 L
.07258 .37082 L
.07337 .37082 L
.07605 .37082 L
.07684 .37082 L
.07759 .37082 L
.07825 .37082 L
.07898 .43262 L
.07977 .43262 L
.08061 .43262 L
.08212 .43262 L
.08463 .43262 L
.08734 .43262 L
.0881 .43262 L
.0889 .43262 L
.08958 .49443 L
.09032 .49443 L
.09311 .49443 L
.09855 .49443 L
.10122 .49443 L
.10369 .49443 L
.10592 .49443 L
.10705 .49443 L
.10829 .55623 L
.10954 .55623 L
.11088 .55623 L
.11329 .55623 L
.13485 .55623 L
.17732 .55623 L
Mistroke
.19855 .55623 L
.20888 .55623 L
.21376 .55623 L
.21824 .55623 L
.21943 .55623 L
.22053 .55623 L
.22169 .49443 L
.22296 .49443 L
.22806 .49443 L
.2373 .49443 L
.25759 .49443 L
.27681 .49443 L
.28694 .49443 L
.29768 .49443 L
.3031 .49443 L
.30458 .49443 L
.30536 .49443 L
.30618 .49443 L
.3069 .43262 L
.30768 .43262 L
.30906 .43262 L
.31958 .43262 L
.3403 .43262 L
.36221 .43262 L
.38209 .43262 L
.39203 .43262 L
.39726 .43262 L
.40012 .43262 L
.4028 .43262 L
.40399 .43262 L
.40513 .43262 L
.40644 .37082 L
.40764 .37082 L
.41296 .37082 L
.42232 .37082 L
.46173 .37082 L
.48165 .37082 L
.50366 .37082 L
.51367 .37082 L
.51893 .37082 L
.52447 .37082 L
.52934 .37082 L
.53068 .37082 L
.53141 .37082 L
.5321 .37082 L
.53345 .30902 L
.53467 .30902 L
.54403 .30902 L
.58358 .30902 L
.62565 .30902 L
Mistroke
.66616 .30902 L
.68651 .30902 L
.69541 .30902 L
.70011 .30902 L
.70512 .30902 L
.70655 .30902 L
.7079 .30902 L
.70912 .30902 L
.71043 .24721 L
.71168 .24721 L
.713 .24721 L
.71537 .24721 L
.7251 .24721 L
.74659 .24721 L
.78569 .24721 L
.8273 .24721 L
.86736 .24721 L
.90994 .24721 L
.93125 .24721 L
.95096 .24721 L
.9699 .24721 L
.97945 .24721 L
.98207 .24721 L
.98489 .24721 L
.98619 .24721 L
.9869 .24721 L
.98756 .24721 L
.98872 .18541 L
.99 .18541 L
Mfstroke
[ .02 .02 ] 0 setdash
.01 .00062 m
.02935 .00181 L
.03921 .00242 L
.04976 .00308 L
.05264 .00325 L
.05406 .00334 L
.05536 .00342 L
.05655 .00699 L
.05781 .00715 L
.05908 .01095 L
.05979 .01109 L
.06047 .01121 L
.06176 .01145 L
.06298 .01557 L
.06408 .01584 L
.06528 .01614 L
.06657 .01646 L
.0673 .0208 L
.06796 .021 L
.07045 .02177 L
.07118 .022 L
.07187 .02221 L
.07258 .02692 L
.07337 .02721 L
.07605 .0282 L
.07684 .02849 L
.07759 .02877 L
.07825 .02902 L
.07898 .03417 L
.07977 .03451 L
.08061 .03487 L
.08212 .03553 L
.08463 .03661 L
.08734 .03779 L
.0881 .03811 L
.0889 .03846 L
.08958 .04429 L
.09032 .04466 L
.09311 .04604 L
.13485 .07501 L
.17503 .09736 L
.19552 .10875 L
.20631 .11475 L
.21221 .11804 L
.21509 .11964 L
.21773 .12111 L
.21893 .12178 L
.22025 .12251 L
.22149 .10951 L
.22264 .11008 L
Mistroke
.22792 .11269 L
.23913 .11823 L
.25887 .12799 L
.27825 .13757 L
.28844 .14261 L
.29919 .14793 L
.30184 .14924 L
.30468 .15064 L
.30551 .15105 L
.30631 .15145 L
.30702 .13282 L
.30779 .13316 L
.31069 .13441 L
.32126 .13899 L
.34203 .14797 L
.36202 .15662 L
.38405 .16615 L
.3941 .1705 L
.39938 .17278 L
.40226 .17403 L
.40366 .17463 L
.40493 .17518 L
.40615 .15061 L
.40729 .15103 L
.40981 .15197 L
.41515 .15395 L
.42451 .15742 L
.46414 .17211 L
.48423 .17956 L
.5063 .18775 L
.51643 .1915 L
.522 .19357 L
.52729 .19553 L
.52967 .19641 L
.53097 .1969 L
.5322 .19735 L
.53352 .16487 L
.53422 .16508 L
.53497 .16532 L
.53754 .16611 L
.5469 .169 L
.5892 .18207 L
.62994 .19466 L
.66912 .20677 L
.68928 .213 L
.69508 .21479 L
.70056 .21649 L
.70548 .21801 L
.70683 .21842 L
.70826 .21887 L
Mistroke
.70948 .21924 L
.71083 .17573 L
.71215 .17605 L
.71339 .17636 L
.71618 .17705 L
.72127 .17831 L
.73081 .18067 L
.7523 .18598 L
.79259 .19594 L
.8354 .20652 L
.87664 .21672 L
.91633 .22653 L
.93646 .23151 L
.95855 .23697 L
.9664 .23891 L
.97482 .24099 L
.9789 .242 L
.98276 .24295 L
.98623 .24381 L
.98718 .24404 L
.98819 .24429 L
.98905 .18338 L
.99 .18356 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool2
0004Ool20003Ool4000POol20004Ool20005Ool3000POol20004Ool20003Ool3000QOol20004Ool2
0004Ool2000WOol5000BOol004Eoo`04001oogoo0008Ool00`00Oomoo`0POol01000Oomoo`002goo
00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`0027oo00@007ooOol0
02Qoo`03001oogoo019oo`00AGoo00@007ooOol000Uoo`03001oogoo01moo`04001oogoo0008Ool5
000OOol01000Oomoo`0027oo00@007ooOol001moo`04001oogoo0008Ool01000Oomoo`00:7oo00<0
07ooOol04Woo0015Ool01000Oomoo`002Woo00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo
000POol01000Oomoo`0027oo0`0087oo00@007ooOol000Uoo`8002Uoo`03001oogoo019oo`00AGoo
00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`002Goo00<007oo000087oo00@007ooOol0
00Uoo`03001oogoo01moo`04001oogoo0008Ool01000Oomoo`00:7oo00<007ooOol04Woo0016Ool2
000:Ool2000QOol2000;Ool2000QOol2000:Ool3000POol2000:Ool2000XOol2000DOol00?moob5o
o`00ogoo8Goo003oOolQOol00?mooaAoo`<000Yoo`00ogoo5goo00<007ooOol01goo000NOoo^0007
Ool3000:Ool001ioo`03001oogoo00Yoo`03001oogoo01moo`03001oogoo02aoo`03001oogoo02eo
o`03001oogoo02aoo`03001oogoo02eoo`03001oogoo00Eoo`@000Uoo`007Woo00<007ooOol02goo
00<007ooOol0lGoo000NOol00`00Oomoo`0;Ool2003bOol001ioo`03001oogoo00aoo`03001oogoo
0?1oo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo00moo`03001o
ogoo0>eoo`007Woo00<007ooOol03goo0`00kGoo000NOol00`00Oomoo`0AOol2003/Ool001ioo`03
001oogoo019oo`03001oogoo0>Yoo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`0EOol00`00
Oomoo`3WOol001ioo`03001oogoo01Ioo`03001oogoo0>Ioo`007Woo00<007oo00002`0037oo0P00
iWoo000NOol00`00Oomoo`0:Ool00`00Oomoo`0<Ool00`00Oomoo`3SOol001ioo`03001oogoo00Yo
o`03001oogoo0?9oo`007Woo00<007ooOol02Woo00<007ooOol0lWoo000NOol00`00Oomoo`0:Ool0
0`00Oomoo`0@Ool00`00Oomoo`3OOol001ioo`03001oogoo00Yoo`03001oogoo015oo`800=moo`00
7Woo00<007ooOol02Woo00<007ooOol04goo0P00gGoo000NOol00`00Oomoo`0:Ool00`00Oomoo`3b
Ool001ioo`03001oogoo00Yoo`03001oogoo01Uoo`03001oogoo0=Ioo`007Woo00<007ooOol02Woo
00<007ooOol06Goo00<007ooOol0eWoo000NOol00`00Oomoo`0:Ool00`00Oomoo`0JOol2003FOol0
01ioo`03001oogoo00Yoo`03001oogoo01aoo`800=Aoo`007Woo00<007ooOol02Woo00<007ooOol0
lWoo000FOol40004Ool00`00Oomoo`0:Ool00`00Oomoo`0QOol01000Oomoo`000Woo00<007ooOol0
b7oo000FOol00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`0ROol30003Ool20038Ool001Mo
o`03001oogoo00Aoo`8000]oo`03001oogoo02Aoo`03001oogoo00=oo`800<Ioo`0067oo00<007oo
Ool00goo00<007ooOol02Woo00<007ooOol0lWoo000FOol01000Oomoo`0017oo00<007ooOol02Woo
00<007ooOol0;goo00<007ooOol01Woo00<007ooOol0]goo000GOol20005Ool00`00Oomoo`0:Ool0
0`00Oomoo`0`Ool30005Ool00`00Oomoo`2gOol001ioo`03001oogoo00Yoo`03001oogoo03=oo`80
00=oo`03001oogoo009oo`03001oogoo0;9oo`007Woo00<007ooOol02Woo00<007ooOol0>7oo00<0
07ooOol00goo0P00/Woo000NOol00`00Oomoo`0:Ool00`00Oomoo`0hOol00`00Oomoo`05Ool2002`
Ool001ioo`03001oogoo00Yoo`03001oogoo059oo`03001oogoo09eoo`007Woo00<007ooOol02goo
00<007ooOol0AGoo00<007ooOol02Woo0P00WGoo000NOol00`00Oomoo`0;Ool00`00Oomoo`16Ool2
0007Ool00`00Oomoo`02Ool2002KOol001ioo`03001oogoo00]oo`03001oogoo04Qoo`8000Eoo`03
001oogoo00Qoo`80019oo`03001oogoo081oo`007Woo00<007ooOol02goo00<007ooOol0Cgoo00<0
07ooOol02Woo0P004Goo1000OWoo000NOol00`00Oomoo`0;Ool00`00Oomoo`1=Ool3000>Ool00`00
Oomoo`2@Ool001ioo`03001oogoo00]oo`03001oogoo07Moo`80021oo`@005Aoo`007Woo00<007oo
Ool02goo00<007ooOol0Hgoo0P0027oo00<007ooOol02Goo0`008Goo00<007ooOol0>Goo00<007oo
Ool05Goo000NOol00`00Oomoo`0;Ool00`00Oomoo`1UOol30005Ool00`00Oomoo`0@Ool00`00Oomo
o`0DOol00`00Oomoo`08Ool3000dOol00`00Oomoo`0EOol001ioo`03001oogoo00]oo`03001oogoo
06eoo`03001oogoo015oo`8001Aoo`03001oogoo00]oo`<0035oo`03001oogoo01Eoo`007Woo00<0
07ooOol02goo00<007ooOol0K7oo0P005Goo0P004Woo00<007ooOol04Goo0`00:goo00<007ooOol0
5Goo000NOol00`00Oomoo`0;Ool00`00Oomoo`29Ool00`00Oomoo`0;Ool00`00Oomoo`0DOol3000X
Ool00`00Oomoo`0EOol001ioo`03001oogoo00]oo`03001oogoo08Yoo`8000]oo`03001oogoo01Yo
o`8002=oo`03001oogoo01Eoo`007Woo00<007ooOol02goo00<007ooOol0S7oo0P002Goo00<007oo
Ool077oo0P008Goo00<007ooOol05Goo000NOol00`00Oomoo`0;Ool00`00Oomoo`2BOol2000TOol2
000OOol00`00Oomoo`0EOol001ioo`03001oogoo00]oo`03001oogoo09Aoo`<002Moo`8001Uoo`03
001oogoo01Eoo`007Woo00<007ooOol02goo00<007ooOol0`7oo0`005Woo00<007ooOol05Goo000N
Ool00`00Oomoo`0;Ool00`00Oomoo`37Ool3000?Ool00`00Oomoo`0EOol001ioo`03001oogoo00]o
o`03001oogoo0<Yoo`8000eoo`03001oogoo01Eoo`007Woo00<007ooOol02goo00<007ooOol0d7oo
00<007ooOol01Woo00<007ooOol05Goo000HOol30003Ool00`00Oomoo`0;Ool00`00Oomoo`3AOol5
0003Ool00`00Oomoo`0EOol001Uoo`03001oogoo009oo`03001oogoo00]oo`03001oogoo0=Uoo`03
001oogoo01Eoo`005Woo1@000goo0P0037oo0P00V7oo@`005goo000FOol01000Oomoo`0017oo00<0
07ooOol037oo00<007ooOol0UWoo00<007ooOol0Egoo000GOol00`00Ool00004Ool00`00Oomoo`0<
Ool00`00Oomoo`2FOol00`00Oomoo`1GOol001Qoo`8000Aoo`03001oogoo00aoo`03001oogoo09Io
o`03001oogoo05Moo`007Woo00<007ooOol037oo00<007ooOol0UWoo00<007ooOol0Egoo000NOol0
0`00Oomoo`0<Ool00`00Oomoo`2FOol00`00Oomoo`1GOol001ioo`03001oogoo00aoo`03001oogoo
09Ioo`03001oogoo05Moo`007Woo00<007ooOol037oo00<007ooOol0UWoo00<007ooOol0Egoo000N
Ool00`00Oomoo`0<Ool00`00Oomoo`2FOol00`00Oomoo`1GOol001ioo`03001oogoo00aoo`03001o
ogoo09Ioo`03001oogoo05Moo`007Woo00<007ooOol037oo00<007ooOol0UWoo00<007ooOol0Egoo
000NOol00`00Oomoo`0<Ool00`00Oomoo`2FOol00`00Oomoo`1GOol001ioo`03001oogoo00aoo`03
001oogoo09Ioo`03001oogoo05Moo`007Woo00<007ooOol037oo00<007ooOol0UWoo00<007ooOol0
Egoo000NOol00`00Oomoo`0<Ool00`00Oomoo`2FOol00`00Oomoo`1GOol001ioo`03001oogoo00ao
o`<006aoob/005Uoo`007Woo00<007ooOol03Woo00<007ooOol0JWoo00<007ooOol0PGoo000NOol0
0`00Oomoo`0>Ool00`00Oomoo`1ZOol00`00Oomoo`21Ool001ioo`03001oogoo00ioo`03001oogoo
06Yoo`03001oogoo085oo`007Woo00<007ooOol03Woo00<007ooOol0JWoo00<007ooOol0PGoo000N
Ool00`00Oomoo`0>Ool00`00Oomoo`1ZOol00`00Oomoo`21Ool001ioo`03001oogoo00ioo`03001o
ogoo06Yoo`03001oogoo085oo`007Woo00<007ooOol03Woo00<007ooOol0JWoo00<007ooOol0PGoo
000NOol00`00Oomoo`0>Ool00`00Oomoo`1ZOol00`00Oomoo`21Ool001ioo`03001oogoo00ioo`03
001oogoo06Yoo`03001oogoo085oo`007Woo00<007ooOol03Woo00<007ooOol0JWoo00<007ooOol0
PGoo000NOol00`00Oomoo`0>Ool00`00Oomoo`1ZOol00`00Oomoo`21Ool001Ioo`<000Eoo`03001o
ogoo00ioo`03001oogoo06Yoo`03001oogoo085oo`005Woo00@007ooOol000Aoo`03001oogoo00io
o`03001oogoo06Yoo`03001oogoo085oo`005Woo00@007ooOol000Aoo`8000moo`8004eooal008=o
o`005Woo0`001Goo00<007ooOol03goo00<007ooOol0Bgoo00<007ooOol0Wgoo000GOol00`00Oomo
o`04Ool00`00Oomoo`0?Ool00`00Oomoo`1;Ool00`00Oomoo`2OOol001Moo`<000Aoo`03001oogoo
00moo`03001oogoo04]oo`03001oogoo09moo`007Woo00<007ooOol03goo00<007ooOol0Bgoo00<0
07ooOol0Wgoo000NOol00`00Oomoo`0?Ool00`00Oomoo`1;Ool00`00Oomoo`2OOol001ioo`03001o
ogoo00moo`03001oogoo04]oo`03001oogoo09moo`007Woo00<007ooOol03goo00<007ooOol0Bgoo
00<007ooOol0Wgoo000NOol00`00Oomoo`0?Ool00`00Oomoo`1;Ool00`00Oomoo`2OOol001ioo`03
001oogoo00moo`03001oogoo04]oo`03001oogoo09moo`007Woo00<007ooOol03goo00<007ooOol0
Bgoo00<007ooOol0Wgoo000NOol00`00Oomoo`0?Ool00`00Oomoo`1;Ool00`00Oomoo`2OOol001io
o`03001oogoo00moo`03001oogoo04]oo`03001oogoo09moo`007Woo00<007ooOol03goo00<007oo
Ool0Bgoo00<007ooOol0Wgoo000NOol00`00Oomoo`0?Ool00`00Oomoo`1;Ool00`00Oomoo`2OOol0
01ioo`03001oogoo00moo`@0039ooaT00:5oo`007Woo00<007ooOol04Woo00<007ooOol0<7oo00<0
07ooOol0]goo000NOol00`00Oomoo`0BOol00`00Oomoo`0`Ool00`00Oomoo`2gOol001ioo`03001o
ogoo019oo`03001oogoo031oo`03001oogoo0;Moo`007Woo00<007ooOol04Woo00<007ooOol0<7oo
00<007ooOol0]goo000NOol00`00Oomoo`0BOol00`00Oomoo`0`Ool00`00Oomoo`2gOol001ioo`03
001oogoo019oo`03001oogoo031oo`03001oogoo0;Moo`007Woo00<007ooOol04Woo00<007ooOol0
<7oo00<007ooOol0]goo000NOol00`00Oomoo`0BOol00`00Oomoo`0`Ool00`00Oomoo`2gOol001io
o`03001oogoo019oo`03001oogoo031oo`03001oogoo0;Moo`007Woo00<007ooOol04Woo00<007oo
Ool0<7oo00<007ooOol0]goo000NOol00`00Oomoo`0BOol00`00Oomoo`0`Ool00`00Oomoo`2gOol0
01ioo`03001oogoo019oo`03001oogoo031oo`03001oogoo0;Moo`005goo0P001Goo00<007ooOol0
4Woo00<007ooOol0<7oo00<007ooOol0]goo000FOol01000Oomoo`0017oo00<007ooOol04Woo00<0
07ooOol0<7oo00<007ooOol0]goo000FOol01000Oomoo`0017oo0P004goo1@006Woo5@00^Goo000G
Ool20005Ool00`00Oomoo`0FOol00`00Oomoo`0HOol00`00Oomoo`3;Ool001Ioo`04001oogoo0004
Ool00`00Oomoo`0FOol00`00Oomoo`0HOol00`00Oomoo`3;Ool001Moo`8000Eoo`03001oogoo01Io
o`03001oogoo01Qoo`03001oogoo0<]oo`007Woo00<007ooOol05Woo00<007ooOol067oo00<007oo
Ool0bgoo000NOol00`00Oomoo`0FOol00`00Oomoo`0HOol00`00Oomoo`3;Ool001ioo`03001oogoo
01Ioo`03001oogoo01Qoo`03001oogoo0<]oo`007Woo00<007ooOol05Woo00<007ooOol067oo00<0
07ooOol0bgoo000NOol00`00Oomoo`0FOol00`00Oomoo`0HOol00`00Oomoo`3;Ool001ioo`03001o
ogoo01Ioo`03001oogoo01Qoo`03001oogoo0<]oo`007Woo00<007ooOol05Woo00<007ooOol067oo
00<007ooOol0bgoo000NOol00`00Oomoo`0FOol00`00Oomoo`0HOol00`00Oomoo`3;Ool001ioo`03
001oogoo01Ioo`03001oogoo01Qoo`03001oogoo0<]oo`007Woo00<007ooOol05Woo00<007ooOol0
67oo00<007ooOol0bgoo000NOol00`00Oomoo`0FOolL003=Ool001ioo`03001oogoo0?moo`007Woo
00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0
ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol0
0`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3o
Ool0011oo`D0009oo`8000Eoo`03001oogoo0?moo`004Woo00D007ooOomoo`00009oo`03001oogoo
009oo`03001oogoo0?moo`004Woo00D007ooOomoo`00009oo`03001oogoo009oo`800?moo`5oo`00
4Woo00D007ooOomoo`00009oo`03001oogoo0?moo`Eoo`004Woo00D007ooOomoo`00009oo`03001o
ogoo0?moo`Eoo`004Goo0P0017oo0P00ogoo27oo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol000Qoo`<00005Ool00000001oo`020002Ool30002Ool3
0004Ool400000goo000000020003Ool300000goo00000002Ool2003ZOol000Moo`03001oogoo00=o
o`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000goo00<007ooOol0
0Woo00<007ooOol00goo00@007ooOol00>]oo`001goo00<007ooOol00goo00@007ooOol000Aoo`03
001oogoo009oo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool40002Ool01000Oomo
o`00jgoo0007Ool00`00Oomoo`03Ool30004Ool20004Ool00`00Oomoo`03Ool30002Ool40003Ool2
0002Ool4003/Ool000Moo`04001oogoo0002Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomo
o`3kOol000Qoo`<00003Ool0000000Moo`04001oogooOol20006Ool2003mOol00?moob5oo`00ogoo
8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.8167, \
0.00421906, 0.0682658}}],

Cell[BoxData[
    \(0.265625`\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.0618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(10)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.01 .0618 m
.04976 .0618 L
.09311 .0618 L
.11419 .0618 L
.13383 .0618 L
.14356 .0618 L
.15275 .0618 L
.15783 .0618 L
.15923 .0618 L
.15999 .0618 L
.1607 .0618 L
.16196 .12361 L
.16263 .12361 L
.16335 .12361 L
.17299 .12361 L
.17802 .12361 L
.18079 .12361 L
.18214 .12361 L
.18339 .12361 L
.18411 .12361 L
.18487 .18541 L
.18564 .18541 L
.18648 .18541 L
.18928 .18541 L
.19474 .18541 L
.20555 .18541 L
.21541 .18541 L
.21781 .18541 L
.22035 .18541 L
.22168 .18541 L
.22243 .18541 L
.22314 .24721 L
.22438 .24721 L
.22572 .24721 L
.23549 .24721 L
.25701 .24721 L
.27723 .24721 L
.29934 .24721 L
.30955 .24721 L
.31517 .24721 L
.32046 .24721 L
.3254 .24721 L
.32676 .24721 L
.3275 .24721 L
.32819 .24721 L
.32941 .30902 L
.33076 .30902 L
.34011 .30902 L
.38006 .30902 L
.42254 .30902 L
Mistroke
.46345 .30902 L
.50281 .30902 L
.51326 .30902 L
.51838 .30902 L
.52063 .30902 L
.52182 .30902 L
.52309 .30902 L
.52381 .24721 L
.52446 .24721 L
.52574 .24721 L
.52854 .24721 L
.53442 .24721 L
.54468 .24721 L
.58574 .24721 L
.62523 .24721 L
.66725 .24721 L
.70771 .24721 L
.74661 .24721 L
.78803 .24721 L
.8279 .24721 L
.87028 .24721 L
.91111 .24721 L
.95038 .24721 L
.99 .24721 L
Mfstroke
[ .02 .02 ] 0 setdash
.01 .00062 m
.04976 .00308 L
.09311 .00575 L
.11419 .00706 L
.13383 .00827 L
.14356 .00887 L
.15275 .00944 L
.15783 .00975 L
.15923 .00984 L
.15999 .00989 L
.1607 .00993 L
.16196 .02002 L
.16263 .0201 L
.16335 .02019 L
.17299 .02138 L
.17802 .02201 L
.18079 .02235 L
.18214 .02251 L
.18339 .02267 L
.18411 .02276 L
.18487 .03428 L
.18564 .03442 L
.18648 .03457 L
.18928 .03509 L
.19474 .03611 L
.20555 .03811 L
.21541 .03994 L
.21781 .04038 L
.22035 .04086 L
.22168 .0411 L
.22243 .04124 L
.22314 .05516 L
.22438 .05547 L
.22572 .0558 L
.23549 .05822 L
.25701 .06354 L
.27723 .06853 L
.29934 .074 L
.30955 .07653 L
.31517 .07791 L
.32046 .07922 L
.3254 .08044 L
.32676 .08078 L
.3275 .08096 L
.32819 .08113 L
.32941 .10179 L
.33076 .10221 L
.34011 .1051 L
.38006 .11745 L
.42254 .13057 L
Mistroke
.46345 .14321 L
.50281 .15538 L
.51326 .15861 L
.51838 .16019 L
.52063 .16088 L
.52182 .16125 L
.52309 .16164 L
.52381 .12949 L
.52446 .12965 L
.52574 .12997 L
.52854 .13066 L
.53442 .13212 L
.54468 .13465 L
.58574 .1448 L
.62523 .15457 L
.66725 .16495 L
.70771 .17496 L
.74661 .18457 L
.78803 .19481 L
.8279 .20467 L
.87028 .21515 L
.91111 .22524 L
.95038 .23495 L
.99 .24474 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool2
0004Ool20003Ool4000POol20004Ool20005Ool3000POol20004Ool20003Ool3000QOol20004Ool2
0004Ool2000WOol5000BOol004Eoo`04001oogoo0008Ool00`00Oomoo`0POol01000Oomoo`002goo
00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`0027oo00@007ooOol0
02Qoo`03001oogoo019oo`00AGoo00@007ooOol000Uoo`03001oogoo01moo`04001oogoo0008Ool5
000OOol01000Oomoo`0027oo00@007ooOol001moo`04001oogoo0008Ool01000Oomoo`00:7oo00<0
07ooOol04Woo0015Ool01000Oomoo`002Woo00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo
000POol01000Oomoo`0027oo0`0087oo00@007ooOol000Uoo`8002Uoo`03001oogoo019oo`00AGoo
00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`002Goo00<007oo000087oo00@007ooOol0
00Uoo`03001oogoo01moo`04001oogoo0008Ool01000Oomoo`00:7oo00<007ooOol04Woo0016Ool2
000:Ool2000QOol2000;Ool2000QOol2000:Ool3000POol2000:Ool2000XOol2000DOol00?moob5o
o`00ogoo8Goo003oOolQOol00?mooaAoo`<000Yoo`00ogoo5goo00<007ooOol01goo000NOoo^0007
Ool3000:Ool001ioo`03001oogoo00eoo`<000=oo`H001=oo`03001oogoo02aoo`03001oogoo02eo
o`03001oogoo02aoo`03001oogoo02eoo`03001oogoo00Eoo`@000Uoo`007Woo00<007ooOol07Goo
1P00g7oo000NOol00`00Oomoo`3oOol001ioo`03001oogoo02Aoo`03001oogoo0=Qoo`007Woo00<0
07ooOol09Goo1000eWoo000NOol00`00Oomoo`0XOol00`00Oomoo`3DOol001ioo`03001oogoo0?mo
o`007Woo00<007ooOol0:goo00<007ooOol0dGoo000NOol00`00Oomoo`0/Ool5003>Ool001ioo`03
001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`0aOol00`00Oomoo`3;Ool001io
o`03001oogoo035oo`@00<Yoo`007Woo00<007oo000090004Goo0P00b7oo000NOol00`00Oomoo`0S
Ool00`00Oomoo`0DOol20033Ool001ioo`03001oogoo02=oo`03001oogoo01Ioo`@00;moo`007Woo
00<007ooOol08goo00<007ooOol07Woo00<007ooOol0^7oo000NOol00`00Oomoo`0SOol00`00Oomo
o`0OOol4002fOol001ioo`03001oogoo02=oo`03001oogoo0=Uoo`007Woo00<007ooOol08goo00<0
07ooOol0fGoo000NOol00`00Oomoo`0SOol00`00Oomoo`0TOol00`00Oomoo`2bOol001ioo`03001o
ogoo02=oo`03001oogoo02Aoo`03001oogoo0;9oo`007Woo00<007ooOol08goo00<007ooOol09Goo
00<007ooOol0/Goo000NOol00`00Oomoo`0SOol00`00Oomoo`0UOol3002aOol001ioo`03001oogoo
02=oo`03001oogoo0=Uoo`007Woo00<007ooOol08goo00<007ooOol0:goo0`00Zgoo000FOol40004
Ool00`00Oomoo`0SOol00`00Oomoo`0^Ool3002XOol001Ioo`03001oogoo00Eoo`03001oogoo02=o
o`03001oogoo0=Uoo`005goo00<007ooOol017oo0P0097oo1P00<Goo0`00XWoo000HOol00`00Oomo
o`03Ool00`00Oomoo`0XOol00`00Oomoo`0bOol3000IOol20024Ool001Ioo`04001oogoo0004Ool0
0`00Oomoo`0XOol00`00Oomoo`0gOol3000DOol00`00Ool00023Ool001Moo`8000Eoo`03001oogoo
02Qoo`03001oogoo03Yoo`<0015oo`03001oogoo00=oo`<007eoo`007Woo00<007ooOol0:7oo00<0
07ooOol0CWoo00<007ooOol01Woo0`00NWoo000NOol00`00Oomoo`0XOol00`00Oomoo`10Ool3000J
Ool3001dOol001ioo`03001oogoo02Qoo`03001oogoo04=oo`<001Yoo`<0075oo`007Woo00<007oo
Ool0:7oo00<007ooOol0Igoo00<007ooOol0JWoo000NOol00`00Oomoo`0XOol00`00Oomoo`19Ool4
000KOol2001ZOol001ioo`03001oogoo02Qoo`03001oogoo04eoo`8001]oo`8006Qoo`007Woo00<0
07ooOol0:7oo00<007ooOol0L7oo0P00HWoo000NOol00`00Oomoo`0XOol00`00Oomoo`1bOol3001O
Ool001ioo`03001oogoo02Qoo`03001oogoo07Uoo`<005Qoo`007Woo00<007ooOol0:7oo00<007oo
Ool0O7oo0`00EGoo000NOol00`00Oomoo`0XOol:001kOol3001?Ool001ioo`03001oogoo035oo`03
001oogoo07aoo`<004aoo`007Woo00<007ooOol0<Goo00<007ooOol0bgoo000NOol00`00Oomoo`0a
Ool00`00Oomoo`22Ool30016Ool001ioo`03001oogoo035oo`03001oogoo08Eoo`<004=oo`007Woo
00<007ooOol0<Goo00<007ooOol0S7oo0`00?7oo000NOol00`00Oomoo`0aOol00`00Oomoo`2?Ool2
000jOol001ioo`03001oogoo035oo`03001oogoo09Eoo`03001oogoo03=oo`007Woo00<007ooOol0
<Goo00<007ooOol0UWoo1000<Goo000NOol00`00Oomoo`0aOol00`00Oomoo`2NOol00`00Oomoo`0Z
Ool001ioo`03001oogoo035oo`03001oogoo09moo`D002Moo`007Woo00<007ooOol0<Goo00<007oo
Ool0bgoo000NOol00`00Oomoo`0aOol00`00Oomoo`2WOol4000POol001Qoo`<000=oo`03001oogoo
035oo`03001oogoo0:]oo`8001ioo`006Goo00<007ooOol00Woo00<007ooOol0<Goo00<007ooOol0
/Goo00<007ooOol05goo000FOol50003Ool2000bOolJ000^Oom_000GOol001Ioo`04001oogoo0004
Ool00`00Oomoo`1:Ool00`00Oomoo`0/Ool00`00Oomoo`23Ool001Moo`03001oo`0000Aoo`03001o
ogoo04Yoo`03001oogoo02aoo`03001oogoo08=oo`0067oo0P0017oo00<007ooOol0BWoo00<007oo
Ool0;7oo00<007ooOol0Pgoo000NOol00`00Oomoo`1:Ool00`00Oomoo`0/Ool00`00Oomoo`23Ool0
01ioo`03001oogoo04Yoo`03001oogoo02aoo`03001oogoo08=oo`007Woo00<007ooOol0BWoo00<0
07ooOol0;7oo00<007ooOol0Pgoo000NOol00`00Oomoo`1:Ool00`00Oomoo`0/Ool00`00Oomoo`23
Ool001ioo`03001oogoo04]oo`03001oogoo02]oo`03001oogoo08=oo`007Woo00<007ooOol0Bgoo
00<007ooOol0:goo00<007ooOol0Pgoo000NOol00`00Oomoo`1;Ool00`00Oomoo`0[Ool00`00Oomo
o`23Ool001ioo`03001oogoo04]oo`03001oogoo02]oo`03001oogoo08=oo`007Woo00<007ooOol0
Bgoo00<007ooOol0:goo00<007ooOol0Pgoo000NOol00`00Oomoo`1;Ool00`00Oomoo`0[Ool00`00
Oomoo`23Ool001ioo`03001oogoo04]oo`03001oogoo02]oo`03001oogoo08=oo`007Woo00<007oo
Ool0Bgoo;`00QGoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0
ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol0
0`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3o
Ool001ioo`03001oogoo0?moo`005Woo0`001Goo00<007ooOol0ogoo000FOol01000Oomoo`0017oo
00<007ooOol0ogoo000FOol01000Oomoo`0017oo0P00ogoo0Goo000FOol30005Ool00`00Oomoo`3o
Ool001Moo`03001oogoo00Aoo`03001oogoo0?moo`005goo0`0017oo00<007ooOol0ogoo000NOol0
0`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3o
Ool001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03
001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?mo
o`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<0
07ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo
000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00
Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000GOol20005Ool00`00Oomo
o`3oOol001Ioo`04001oogoo0004Ool00`00Oomoo`3oOol001Ioo`04001oogoo0004Ool2003oOol1
Ool001Moo`8000Eoo`03001oogoo0?moo`005Woo00@007ooOol000Aoo`03001oogoo0?moo`005goo
0P001Goo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<0
07ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo
000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00
Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol0
01ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001o
ogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`00
7Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`0047oo1@000Woo
0P001Goo00<007ooOol0ogoo000BOol01@00Oomoogoo00000Woo00<007ooOol00Woo00<007ooOol0
ogoo000BOol01@00Oomoogoo00000Woo00<007ooOol00Woo0P00ogoo0Goo000BOol01@00Oomoogoo
00000Woo00<007ooOol0ogoo1Goo000BOol01@00Oomoogoo00000Woo00<007ooOol0ogoo1Goo000A
Ool20004Ool2003oOol8Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`0027oo0`0000Eoo`00000007oo0080009oo`<0009oo`<000Aoo`@00003Ool0
0000008000=oo`<00003Ool00000009oo`800>Yoo`001goo00<007ooOol00goo00@007ooOol000Ao
o`03001oogoo009oo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool01000Oomoo`00jgoo0007Ool00`00Oomoo`03Ool01000Oomoo`0017oo00<007ooOol00Woo00<0
07ooOol00Woo00@007ooOol000=oo`03001oogoo009oo`@0009oo`04001oogoo003[Ool000Moo`03
001oogoo00=oo`<000Aoo`8000Aoo`03001oogoo00=oo`<0009oo`@000=oo`80009oo`@00>aoo`00
1goo00@007ooOol0009oo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo0?]oo`0027oo0`00
00=oo`0000001goo00@007ooOomoo`8000Ioo`800?eoo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.8167, \
0.00421906, 0.0682658}}],

Cell[BoxData[
    \(8.30859375`\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.0618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(10)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.3708 .61803 m
.3708 .61803 L
.37155 .61803 L
.37311 .61803 L
.37584 .61803 L
.38118 .61803 L
.3909 .61803 L
.39625 .61803 L
.39889 .61803 L
.40133 .61803 L
.40362 .61803 L
.40489 .61803 L
.40605 .55623 L
.40732 .55623 L
.4087 .55623 L
.41119 .55623 L
.42018 .55623 L
.43083 .55623 L
.44076 .55623 L
.44333 .55623 L
.44459 .55623 L
.44576 .55623 L
.4471 .49443 L
.44781 .49443 L
.44856 .49443 L
.45111 .49443 L
.46245 .49443 L
.47213 .49443 L
.48254 .49443 L
.48758 .49443 L
.49007 .49443 L
.49237 .49443 L
.49344 .49443 L
.49445 .49443 L
.49562 .43262 L
.49667 .43262 L
.50137 .43262 L
.52027 .43262 L
.531 .43262 L
.54103 .43262 L
.54611 .43262 L
.55092 .43262 L
.55221 .43262 L
.55358 .43262 L
.55429 .43262 L
.55508 .37082 L
.5558 .37082 L
.55647 .37082 L
.56153 .37082 L
.58321 .37082 L
Mistroke
.60221 .37082 L
.61298 .37082 L
.61823 .37082 L
.623 .37082 L
.6242 .37082 L
.62546 .37082 L
.62612 .37082 L
.62685 .30902 L
.62813 .30902 L
.63297 .30902 L
.64361 .30902 L
.66532 .30902 L
.687 .30902 L
.69728 .30902 L
.70682 .30902 L
.71156 .30902 L
.71293 .30902 L
.71422 .30902 L
.71537 .24721 L
.71662 .24721 L
.7273 .24721 L
.74676 .24721 L
.7669 .24721 L
.78899 .24721 L
.79915 .24721 L
.80474 .24721 L
.81004 .24721 L
.81496 .24721 L
.81631 .24721 L
.81774 .24721 L
.81896 .24721 L
.82031 .18541 L
.82152 .18541 L
.82263 .18541 L
.82514 .18541 L
.82966 .18541 L
.87048 .18541 L
.90973 .18541 L
.92013 .18541 L
.92524 .18541 L
.92748 .18541 L
.92994 .18541 L
.9306 .18541 L
.93131 .18541 L
.93258 .12361 L
.93333 .12361 L
.93404 .12361 L
.93537 .12361 L
.94125 .12361 L
.95151 .12361 L
Mistroke
.99 .12361 L
Mfstroke
[ .02 .02 ] 0 setdash
.01 .01731 m
.04976 .0861 L
.09311 .16113 L
.11419 .19761 L
.12448 .21541 L
.12934 .22382 L
.13148 .22752 L
.13269 .22963 L
.13383 .2316 L
.13492 .23348 L
.1361 .2271 L
.13735 .22919 L
.1385 .23111 L
.13974 .23318 L
.14109 .23544 L
.14237 .22877 L
.14356 .23068 L
.14585 .23436 L
.14697 .23617 L
.14801 .23783 L
.1492 .23053 L
.1505 .23253 L
.15275 .23602 L
.15392 .23783 L
.15518 .23976 L
.15636 .23193 L
.15744 .23353 L
.16012 .2375 L
.1613 .23925 L
.16259 .24117 L
.16383 .23289 L
.16515 .23476 L
.16793 .23871 L
.16919 .2405 L
.17054 .24242 L
.17182 .23362 L
.17299 .23521 L
.1755 .23862 L
.17787 .24184 L
.17918 .24363 L
.17992 .23351 L
.1806 .23439 L
.18308 .23761 L
.18543 .24067 L
.18764 .24353 L
.18875 .24497 L
.18994 .23477 L
.19126 .23641 L
.19246 .2379 L
.195 .24103 L
Mistroke
.19769 .24436 L
.19849 .24535 L
.19924 .24628 L
.19992 .23476 L
.20065 .23562 L
.20339 .23884 L
.20602 .24192 L
.2088 .24518 L
.20994 .24653 L
.21117 .24797 L
.21251 .23641 L
.21377 .23781 L
.21641 .24075 L
.21922 .24387 L
.22162 .24654 L
.22227 .24727 L
.22298 .24806 L
.22426 .23562 L
.22498 .23638 L
.22565 .23708 L
.22716 .23867 L
.23021 .24187 L
.23302 .24482 L
.23566 .2476 L
.23689 .24889 L
.23819 .25025 L
.23886 .2362 L
.23961 .23694 L
.24092 .23823 L
.24569 .24295 L
.24835 .24558 L
.25121 .24841 L
.2526 .24979 L
.25392 .25108 L
.25509 .23649 L
.25638 .23768 L
.26604 .24663 L
.26868 .24908 L
.27007 .25037 L
.27083 .25107 L
.27154 .25173 L
.27282 .23606 L
.2735 .23665 L
.27423 .23728 L
.2767 .23942 L
.28252 .24445 L
.28538 .24693 L
.28802 .24921 L
.29042 .25128 L
.29163 .25233 L
Mistroke
.29296 .23537 L
.29429 .23644 L
.29572 .2376 L
.29831 .23968 L
.30335 .24372 L
.30872 .24804 L
.31031 .24932 L
.31181 .25052 L
.31315 .2516 L
.31391 .25221 L
.31461 .23333 L
.31588 .23427 L
.31727 .2353 L
.32007 .23738 L
.32524 .24121 L
.33077 .24531 L
.33345 .2473 L
.33599 .24919 L
.33827 .25088 L
.33956 .25183 L
.34075 .23166 L
.34197 .23248 L
.34324 .23335 L
.34552 .2349 L
.35067 .2384 L
.35997 .24472 L
.36487 .24805 L
.36756 .24988 L
.36888 .25078 L
.3701 .25161 L
.3708 .22917 L
.37155 .22963 L
.37311 .23059 L
.37584 .23228 L
.38118 .23558 L
.3909 .24159 L
.39625 .2449 L
.39889 .24653 L
.40133 .24804 L
.40362 .24945 L
.40489 .25024 L
.40605 .22586 L
.40732 .22657 L
.4087 .22733 L
.41119 .22871 L
.42018 .23372 L
.43083 .23964 L
.44076 .24516 L
.44333 .24659 L
.44459 .24729 L
Mistroke
.44576 .24794 L
.4471 .22106 L
.44781 .22141 L
.44856 .22178 L
.45111 .22304 L
.46245 .22865 L
.47213 .23343 L
.48254 .23858 L
.48758 .24107 L
.49007 .2423 L
.49237 .24344 L
.49344 .24397 L
.49445 .24447 L
.49562 .21442 L
.49667 .21487 L
.50137 .2169 L
.52027 .22508 L
.531 .22972 L
.54103 .23406 L
.54611 .23626 L
.55092 .23834 L
.55221 .2389 L
.55358 .23949 L
.55429 .2398 L
.55508 .20584 L
.5558 .2061 L
.55647 .20635 L
.56153 .20823 L
.58321 .21626 L
.60221 .22331 L
.61298 .22731 L
.61823 .22925 L
.623 .23102 L
.6242 .23146 L
.62546 .23193 L
.62612 .23218 L
.62685 .19371 L
.62813 .1941 L
.63297 .1956 L
.64361 .19889 L
.66532 .2056 L
.687 .2123 L
.69728 .21547 L
.70682 .21842 L
.71156 .21989 L
.71293 .22031 L
.71422 .22071 L
.71537 .17685 L
.71662 .17716 L
.7273 .1798 L
Mistroke
.74676 .18461 L
.7669 .18959 L
.78899 .19505 L
.79915 .19756 L
.80474 .19894 L
.81004 .20025 L
.81496 .20147 L
.81631 .2018 L
.81774 .20216 L
.81896 .20246 L
.82031 .15209 L
.82152 .15232 L
.82263 .15252 L
.82514 .15299 L
.82966 .15383 L
.87048 .1614 L
.90973 .16867 L
.92013 .1706 L
.92524 .17155 L
.92748 .17196 L
.92994 .17242 L
.9306 .17254 L
.93131 .17267 L
.93258 .11527 L
.93333 .11537 L
.93404 .11545 L
.93537 .11562 L
.94125 .11634 L
.95151 .11761 L
.99 .12237 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool2
0004Ool20003Ool4000POol20004Ool20005Ool3000POol20004Ool20003Ool3000QOol20004Ool2
0004Ool2000WOol5000BOol004Eoo`04001oogoo0008Ool00`00Oomoo`0POol01000Oomoo`002goo
00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`0027oo00@007ooOol0
02Qoo`03001oogoo019oo`00AGoo00@007ooOol000Uoo`03001oogoo01moo`04001oogoo0008Ool5
000OOol01000Oomoo`0027oo00@007ooOol001moo`04001oogoo0008Ool01000Oomoo`00:7oo00<0
07ooOol04Woo0015Ool01000Oomoo`002Woo00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo
000POol01000Oomoo`0027oo0`0087oo00@007ooOol000Uoo`8002Uoo`03001oogoo019oo`00AGoo
00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`002Goo00<007oo000087oo00@007ooOol0
00Uoo`03001oogoo01moo`04001oogoo0008Ool01000Oomoo`00:7oo00<007ooOol04Woo0016Ool2
000:Ool2000QOol2000;Ool2000QOol2000:Ool3000POol2000:Ool2000XOol2000DOol00?moob5o
o`00ogoo8Goo003oOolQOol00?mooaAoo`<000Yoo`00ogoo5goo00<007ooOol01goo000NOoo^0007
Ool3000:Ool001ioo`03001oogoo02aoo`03001oogoo02aoo`03001oogoo02eoo`03001oogoo02ao
o`03001oogoo02eoo`03001oogoo00Eoo`@000Uoo`007Woo00<007ooOol0ogoo000NOol00`00Oomo
o`3oOol001ioo`03001oo`000?moo`007Woo00@007ooOol00?ioo`007Woo00@007ooOol00?ioo`00
7Woo00D007ooOomoo`000?eoo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03
001oogoo0?moo`007Woo00<007ooOol00goo00<007ooOol0nGoo000NOol00`00Oomoo`03Ool00`00
Oomoo`3iOol001ioo`03001oogoo00Aoo`03001oogoo0?Qoo`007Woo00<007ooOol017oo00<007oo
Ool0n7oo000NOol00`00Oomoo`05Ool00`00Oomoo`3gOol001ioo`03001oogoo0?moo`007Woo00<0
07ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo00Qoo`03001oogoo0?Aoo`007Woo
00<007ooOol027oo00<007ooOol0m7oo000NOol00`00Oomoo`09Ool00`00Oomoo`3cOol001ioo`03
001oogoo00Uoo`03001oogoo0?=oo`007Woo00<007ooOol02Woo00<007ooOol0lWoo000NOol00`00
Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000FOol40004Ool00`00Oomo
o`0<Ool00`00Oomoo`3;Ool5000POol001Ioo`03001oogoo00Eoo`03001oogoo00eoo`03001oogoo
0=9oo`<001Yoo`005goo00<007ooOol017oo0P003Woo00<007ooOol0bWoo3P005goo000HOol00`00
Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`39Ool00`00Oomoo`0ROol001Ioo`04001oogoo0004
Ool00`00Oomoo`0?Ool00`00Oomoo`38Ool00`00Oomoo`0ROol001Moo`8000Eoo`03001oogoo0=Uo
o`8002Aoo`007Woo00<007ooOol0fGoo0P0097oo000NOol00`00Oomoo`3IOol2000TOol001ioo`03
001oogoo015oo`03001oogoo0<Eoo`8002Aoo`007Woo00<007ooOol04Woo00<007ooOol0[7oo0P00
5Woo00<007ooOol08goo000NOol00`00Oomoo`0BOol00`00Oomoo`2^Ool3000COol00`00Oomoo`0S
Ool001ioo`03001oogoo01=oo`03001oogoo0:Uoo`03001oogoo00Qoo`<000aoo`03001oogoo02=o
o`007Woo00<007ooOol057oo00<007ooOol0Z7oo00<007ooOol02goo0`000goo00<007ooOol00goo
00<007ooOol08goo000NOol00`00Oomoo`2oOol00`00Oomoo`0BOol6000UOol001ioo`03001oogoo
0;moo`03001oogoo01Moo`03001oogoo02=oo`007Woo00<007ooOol0ZGoo0P0057oo00<007ooOol0
5goo00<007ooOol08goo000NOol00`00Oomoo`2VOol00`00Oomoo`02Ool2000BOolK000UOol001io
o`03001oogoo01Ioo`03001oogoo08eoo`03001oogoo00Moo`@000]oo`03001oogoo03eoo`007Woo
00<007ooOol05goo00<007ooOol0Mgoo00<007ooOol04Woo00<007ooOol02goo0P002Goo00<007oo
Ool0?Goo000NOol00`00Oomoo`0HOol00`00Oomoo`1fOol3000BOol00`00Oomoo`0AOol00`00Oomo
o`02Ool00`00Oomoo`0mOol001ioo`03001oogoo01Qoo`03001oogoo07Ioo`03001oogoo019oo`03
001oogoo019oo`D003moo`007Woo00<007ooOol067oo00<007ooOol0IGoo00<007ooOol03Woo00<0
07ooOol017oo0`002goo00<007ooOol05Woo00<007ooOol0?Goo000NOol00`00Oomoo`20Ool2000I
Ool2000ROol00`00Oomoo`0mOol001ioo`03001oogoo081oo`03001oogoo009oo`03001oogoo01Uo
o`03001oogoo01]oo`03001oogoo03eoo`007Woo00<007ooOol0LWoo0`002goo00<007ooOol00goo
0`006Goo0`006Woo00<007ooOol0?Goo000NOol00`00Oomoo`0KOol00`00Oomoo`1:Ool00`00Oomo
o`0:Ool30008Ool00`00Oomoo`06Ool2000JOol00`00Oomoo`0GOol00`00Oomoo`0mOol001ioo`03
001oogoo01]oo`80041oo`03001oogoo00Uoo`03001oogoo02Eoo`03001oogoo02]oo`03001oogoo
03eoo`007Woo00<007ooOol077oo1@00;7oo00<007ooOol03Goo0P002goo00<007ooOol03Woo00<0
07ooOol047oo1000;Goo00<007ooOol0?Goo000NOol00`00Oomoo`0MOol01@00Ool00000Ool00`00
0Woo00@007ooOol000Moo`03001oogoo019oo`8000Aoo`8000Qoo`03001oogoo00=oo`03001oogoo
00]oo`8000Eoo`03001oogoo00Moo`8001=oo`03001oogoo02]oo`03001oogoo03eoo`0067oo0`00
0goo00<007ooOol07goo0P0000Eoo`00000007oo00800003Ool00000009oo`03001oo`00009oo`03
001oogoo0080009oo`04001oogooOol20004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Ool0
0004Ool01@00Oomoogoo000017oo00<007ooOol00Woo0P000Woo00<007ooOol02Goo00<007ooOol0
2Goo0P00?goo00<007ooOol0?Goo000IOol00`00Oomoo`02Ool00`00Oomoo`0SOol01@00Oomoogoo
00000goo00d007oo001oo`00Ool007oo001oo`00Ool00002Ool20003Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool20002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Ool00009
Ool3001<Ool00`00Oomoo`0mOol001Ioo`D000=oo`8002aoo`03001oogoo00800003Ool007oo00Ao
o`8000=oo`07001oogooOol007oo00000Woo0P0017oo00<007ooOol01Goo0P001Goo0P002Goo0P00
?goo6P00?goo000FOol01000Oomoo`0017oo00<007ooOol0?7oo00<007ooOol00Woo0P000goo0P00
37oo00<007ooOol0Cgoo00<007ooOol0EWoo000GOol00`00Ool00004Ool00`00Oomoo`2VOol00`00
Oomoo`1FOol001Qoo`8000Aoo`03001oogoo0:Ioo`03001oogoo05Ioo`007Woo00<007ooOol0YWoo
00<007ooOol0EWoo000NOol00`00Oomoo`2VOol00`00Oomoo`1FOol001ioo`03001oogoo0:Ioo`03
001oogoo05Ioo`007Woo00<007ooOol0YWoo00<007ooOol0EWoo000NOol00`00Oomoo`2VOol00`00
Oomoo`1FOol001ioo`03001oogoo0:Ioo`03001oogoo05Ioo`007Woo00<007ooOol0YWoo00<007oo
Ool0EWoo000NOol00`00Oomoo`2VOol00`00Oomoo`1FOol001ioo`03001oogoo0:Ioo`03001oogoo
05Ioo`007Woo00<007ooOol0YWoo00<007ooOol0EWoo000NOol00`00Oomoo`2VOol00`00Oomoo`1F
Ool001ioo`03001oogoo095ooaH005Qoo`007Woo00<007ooOol0TGoo00<007ooOol0Jgoo000NOol0
0`00Oomoo`2AOol00`00Oomoo`1[Ool001ioo`03001oogoo095oo`03001oogoo06]oo`007Woo00<0
07ooOol0TGoo00<007ooOol0Jgoo000NOol00`00Oomoo`2AOol00`00Oomoo`1[Ool001ioo`03001o
ogoo095oo`03001oogoo06]oo`007Woo00<007ooOol0TGoo00<007ooOol0Jgoo000NOol00`00Oomo
o`2AOol00`00Oomoo`1[Ool001ioo`03001oogoo095oo`03001oogoo06]oo`007Woo00<007ooOol0
TGoo00<007ooOol0Jgoo000NOol00`00Oomoo`2AOol00`00Oomoo`1[Ool001Ioo`<000Eoo`03001o
ogoo095oo`03001oogoo06]oo`005Woo00@007ooOol000Aoo`03001oogoo095oo`03001oogoo06]o
o`005Woo00@007ooOol000Aoo`80085ooa8006eoo`005Woo0`001Goo00<007ooOol0P7oo00<007oo
Ool0O7oo000GOol00`00Oomoo`04Ool00`00Oomoo`20Ool00`00Oomoo`1lOol001Moo`<000Aoo`03
001oogoo081oo`03001oogoo07aoo`007Woo00<007ooOol0P7oo00<007ooOol0O7oo000NOol00`00
Oomoo`20Ool00`00Oomoo`1lOol001ioo`03001oogoo081oo`03001oogoo07aoo`007Woo00<007oo
Ool0P7oo00<007ooOol0O7oo000NOol00`00Oomoo`20Ool00`00Oomoo`1lOol001ioo`03001oogoo
081oo`03001oogoo07aoo`007Woo00<007ooOol0P7oo00<007ooOol0O7oo000NOol00`00Oomoo`20
Ool00`00Oomoo`1lOol001ioo`03001oogoo081oo`03001oogoo07aoo`007Woo00<007ooOol0P7oo
00<007ooOol0O7oo000NOol00`00Oomoo`20Ool00`00Oomoo`1lOol001ioo`03001oogoo079oo`l0
07ioo`007Woo00<007ooOol0LWoo00<007ooOol0RWoo000NOol00`00Oomoo`1bOol00`00Oomoo`2:
Ool001ioo`03001oogoo079oo`03001oogoo08Yoo`007Woo00<007ooOol0LWoo00<007ooOol0RWoo
000NOol00`00Oomoo`1bOol00`00Oomoo`2:Ool001ioo`03001oogoo079oo`03001oogoo08Yoo`00
7Woo00<007ooOol0LWoo00<007ooOol0RWoo000NOol00`00Oomoo`1bOol00`00Oomoo`2:Ool001io
o`03001oogoo079oo`03001oogoo08Yoo`007Woo00<007ooOol0LWoo00<007ooOol0RWoo000NOol0
0`00Oomoo`1bOol00`00Oomoo`2:Ool001ioo`03001oogoo079oo`03001oogoo08Yoo`005goo0P00
1Goo00<007ooOol0LWoo00<007ooOol0RWoo000FOol01000Oomoo`0017oo00<007ooOol0LWoo00<0
07ooOol0RWoo000FOol01000Oomoo`0017oo0P00J7oo3000S7oo000GOol20005Ool00`00Oomoo`1W
Ool00`00Oomoo`2EOol001Ioo`04001oogoo0004Ool00`00Oomoo`1WOol00`00Oomoo`2EOol001Mo
o`8000Eoo`03001oogoo06Moo`03001oogoo09Eoo`007Woo00<007ooOol0Igoo00<007ooOol0UGoo
000NOol00`00Oomoo`1WOol00`00Oomoo`2EOol001ioo`03001oogoo06Moo`03001oogoo09Eoo`00
7Woo00<007ooOol0IWoo00<007ooOol0UWoo000NOol00`00Oomoo`1VOol00`00Oomoo`2FOol001io
o`03001oogoo06Ioo`03001oogoo09Ioo`007Woo00<007ooOol0IWoo00<007ooOol0UWoo000NOol0
0`00Oomoo`1VOol00`00Oomoo`2FOol001ioo`03001oogoo06Ioo`03001oogoo09Ioo`007Woo00<0
07ooOol0IWoo00<007ooOol0UWoo000NOol00`00Oomoo`1MOol:002HOol001ioo`03001oogoo05eo
o`03001oogoo09moo`007Woo00<007ooOol0GGoo00<007ooOol0Wgoo000NOol00`00Oomoo`1MOol0
0`00Oomoo`2OOol001ioo`03001oogoo05eoo`03001oogoo09moo`007Woo00<007ooOol0GGoo00<0
07ooOol0Wgoo000NOol00`00Oomoo`1MOol00`00Oomoo`2OOol001ioo`03001oogoo05eoo`03001o
ogoo09moo`007Woo00<007ooOol0G7oo00<007ooOol0X7oo000NOol00`00Oomoo`1LOol00`00Oomo
o`2POol001ioo`03001oogoo05aoo`03001oogoo0:1oo`007Woo00<007ooOol0G7oo00<007ooOol0
X7oo000NOol00`00Oomoo`1LOol00`00Oomoo`2POol0011oo`D0009oo`8000Eoo`03001oogoo05ao
o`03001oogoo0:1oo`004Woo00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo05Aoo`03
001oogoo00Eoo`03001oogoo0:1oo`004Woo00D007ooOomoo`00009oo`03001oogoo009oo`8005Eo
o`T00:9oo`004Woo00D007ooOomoo`00009oo`03001oogoo0?moo`Eoo`004Woo00D007ooOomoo`00
009oo`03001oogoo0?moo`Eoo`004Goo0P0017oo0P00ogoo27oo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol000Qoo`<00005Ool00000001oo`020002
Ool30002Ool30004Ool400000goo000000020003Ool300000goo00000002Ool2003ZOol000Moo`03
001oogoo00=oo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000goo
00<007ooOol00Woo00<007ooOol00goo00@007ooOol00>]oo`001goo00<007ooOol00goo00@007oo
Ool000Aoo`03001oogoo009oo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool40002
Ool01000Oomoo`00jgoo0007Ool00`00Oomoo`03Ool30004Ool20004Ool00`00Oomoo`03Ool30002
Ool40003Ool20002Ool4003/Ool000Moo`04001oogoo0002Ool00`00Oomoo`0:Ool00`00Oomoo`05
Ool00`00Oomoo`3kOol000Qoo`<00003Ool0000000Moo`04001oogooOol20006Ool2003mOol00?mo
ob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.8167, \
0.00421906, 0.0682658}}],

Cell[BoxData[
    \(0.62200927734375`\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.0618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(10)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.01 .0618 m
.01478 .0618 L
.01707 .0618 L
.01924 .0618 L
.02046 .0618 L
.0218 .12361 L
.02301 .24721 L
.02412 .37082 L
.02533 .43262 L
.02666 .55623 L
.02733 .55623 L
.02805 .61803 L
s
.02805 .61803 m
.02805 .61803 L
s
.2237 .61803 m
.2237 .61803 L
.22476 .61803 L
.22709 .61803 L
.23205 .61803 L
.24241 .61803 L
.24809 .61803 L
.25344 .61803 L
.25594 .61803 L
.25731 .61803 L
.25858 .61803 L
.25925 .55623 L
.25996 .55623 L
.26148 .55623 L
.26414 .55623 L
.27384 .55623 L
.28367 .55623 L
.29276 .55623 L
.29785 .55623 L
.30041 .55623 L
.30111 .55623 L
.30187 .55623 L
.30259 .49443 L
.30324 .49443 L
.31463 .49443 L
.33534 .49443 L
.34477 .49443 L
.34995 .49443 L
.35249 .49443 L
.3536 .49443 L
.35483 .49443 L
.35618 .43262 L
.35692 .43262 L
.35761 .43262 L
.36062 .43262 L
.36587 .43262 L
.37614 .43262 L
.39527 .43262 L
.40536 .43262 L
.41611 .43262 L
.41917 .43262 L
.42067 .43262 L
.42205 .43262 L
.42331 .43262 L
.42463 .37082 L
.42597 .37082 L
.42743 .37082 L
.43791 .37082 L
.4586 .37082 L
.48042 .37082 L
Mistroke
.50027 .37082 L
.50507 .37082 L
.5077 .37082 L
.51016 .37082 L
.51144 .37082 L
.51215 .37082 L
.51281 .30902 L
.51353 .30902 L
.51431 .30902 L
.51574 .30902 L
.52089 .30902 L
.54038 .30902 L
.5822 .30902 L
.60153 .30902 L
.6117 .30902 L
.62245 .30902 L
.62791 .30902 L
.62941 .30902 L
.63102 .30902 L
.6318 .30902 L
.63253 .30902 L
.6332 .24721 L
.63392 .24721 L
.64447 .24721 L
.66522 .24721 L
.70717 .24721 L
.74757 .24721 L
.76782 .24721 L
.7864 .24721 L
.79609 .24721 L
.79845 .24721 L
.80097 .24721 L
.80171 .24721 L
.80241 .24721 L
.80373 .18541 L
.80496 .18541 L
.8063 .18541 L
.82776 .18541 L
.86985 .18541 L
.91038 .18541 L
.94936 .18541 L
.99 .18541 L
Mfstroke
[ .02 .02 ] 0 setdash
.01 .00062 m
.04976 .05228 L
.07045 .07402 L
.09311 .09207 L
.11443 .10609 L
.13383 .1158 L
.15397 .12371 L
.17552 .13017 L
.18589 .13786 L
.18841 .13973 L
.19112 .14174 L
.19191 .14233 L
.19267 .14289 L
.19335 .13145 L
.19409 .13195 L
.19688 .13385 L
.20722 .14088 L
.2166 .14726 L
.21906 .14892 L
.22035 .1498 L
.22171 .15073 L
.22291 .15154 L
.22422 .13857 L
.22541 .13931 L
.22652 .14 L
.2371 .14654 L
.24622 .15217 L
.25102 .15514 L
.25613 .1583 L
.25741 .15909 L
.25808 .1595 L
.25879 .15994 L
.25958 .14438 L
.2603 .14479 L
.26172 .14558 L
.26689 .14845 L
.27707 .15412 L
.28708 .15968 L
.29617 .16474 L
.29859 .16609 L
.29987 .1668 L
.30122 .16755 L
.3024 .14952 L
.3037 .15016 L
.30599 .15129 L
.31648 .15648 L
.33538 .16582 L
.34565 .1709 L
.3507 .1734 L
.35317 .17461 L
Mistroke
.35424 .17514 L
.35539 .17572 L
.35673 .15433 L
.358 .15488 L
.36077 .15608 L
.36663 .15861 L
.37689 .16305 L
.39705 .17177 L
.40771 .17639 L
.41358 .17893 L
.41647 .18018 L
.41914 .18133 L
.4217 .18244 L
.42299 .183 L
.42373 .18332 L
.42442 .15738 L
.42512 .15764 L
.42586 .15792 L
.42718 .15841 L
.43016 .15951 L
.44019 .16323 L
.45982 .17051 L
.48041 .17815 L
.49909 .18507 L
.50409 .18693 L
.50672 .1879 L
.5095 .18893 L
.51067 .18937 L
.51193 .18984 L
.51266 .1901 L
.51331 .15862 L
.51461 .15902 L
.51931 .16048 L
.54088 .16714 L
.58185 .1798 L
.60057 .18559 L
.61124 .18888 L
.62126 .19198 L
.62602 .19345 L
.62862 .19425 L
.63103 .195 L
.6323 .19539 L
.63366 .15665 L
.63443 .15684 L
.63516 .15702 L
.63653 .15736 L
.64158 .15861 L
.66319 .16395 L
.70274 .17373 L
.74481 .18413 L
Mistroke
.76573 .1893 L
.77597 .19183 L
.78532 .19414 L
.78993 .19528 L
.79495 .19652 L
.79724 .19709 L
.79969 .19769 L
.80088 .19799 L
.802 .19827 L
.80301 .14889 L
.80409 .14909 L
.82428 .15283 L
.86649 .16066 L
.90714 .16819 L
.94623 .17544 L
.98785 .18316 L
.99 .18356 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool2
0004Ool20003Ool4000POol20004Ool20005Ool3000POol20004Ool20003Ool3000QOol20004Ool2
0004Ool2000WOol5000BOol004Eoo`04001oogoo0008Ool00`00Oomoo`0POol01000Oomoo`002goo
00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`0027oo00@007ooOol0
02Qoo`03001oogoo019oo`00AGoo00@007ooOol000Uoo`03001oogoo01moo`04001oogoo0008Ool5
000OOol01000Oomoo`0027oo00@007ooOol001moo`04001oogoo0008Ool01000Oomoo`00:7oo00<0
07ooOol04Woo0015Ool01000Oomoo`002Woo00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo
000POol01000Oomoo`0027oo0`0087oo00@007ooOol000Uoo`8002Uoo`03001oogoo019oo`00AGoo
00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`002Goo00<007oo000087oo00@007ooOol0
00Uoo`03001oogoo01moo`04001oogoo0008Ool01000Oomoo`00:7oo00<007ooOol04Woo0016Ool2
000:Ool2000QOol2000;Ool2000QOol2000:Ool3000POol2000:Ool2000XOol2000DOol00?moob5o
o`00ogoo8Goo003oOolQOol00?mooaAoo`<000Yoo`00ogoo5goo00<007ooOol01goo000NOoo^0007
Ool3000:Ool001ioo`04001oogoo000[Ool00`00Oomoo`0/Ool00`00Oomoo`0]Ool00`00Oomoo`0/
Ool00`00Oomoo`0]Ool00`00Oomoo`05Ool40009Ool001ioo`04001oogoo003nOol001ioo`05001o
ogooOol0003mOol001ioo`03001oogoo009oo`03001oogoo0?Yoo`007Woo00<007ooOol0ogoo000N
Ool00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol01Goo00<007ooOol0mgoo
000NOol00`00Oomoo`06Ool00`00Oomoo`3fOol001ioo`03001oogoo00Ioo`03001oogoo0?Ioo`00
7Woo00<007ooOol01goo00<007ooOol0mGoo000NOol00`00Oomoo`08Ool00`00Oomoo`3dOol001io
o`03001oogoo0?moo`007Woo00<007oo00000P00oGoo000NOol01@00Oomoogoo00002Goo00<007oo
Ool0lGoo000NOol01@00Oomoogoo00002Woo00<007ooOol0l7oo000NOol01@00Oomoogoo00002goo
00<007ooOol0kgoo000NOol01@00Oomoogoo000037oo0P00kgoo000NOol01@00Oomoogoo0000oGoo
000NOol01@00Oomoogoo0000oGoo000NOol01@00Oomoogoo00004Goo00<007ooOol0jGoo000NOol0
0`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`3XOol001ioo`03001oogoo009oo`03001oogoo
011oo`03001oogoo0>Moo`007Woo00<007ooOol00Woo00<007ooOol04Goo00<007ooOol0iWoo000N
Ool00`00Oomoo`02Ool00`00Oomoo`3jOol001ioo`03001oogoo009oo`03001oogoo01Ioo`03001o
ogoo0>5oo`005Woo100017oo00<007ooOol00Woo00<007ooOol05goo0P00hGoo000FOol00`00Oomo
o`05Ool00`00Oomoo`02Ool00`00Oomoo`0IOol2003OOol001Moo`03001oogoo00Aoo`8000=oo`03
001oogoo0?Yoo`0067oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol07Woo1000f7oo000F
Ool01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol08Woo00<007ooOol00P00dgoo000GOol2
0005Ool00`00Oomoo`02Ool00`00Oomoo`0SOol01@00Ool007oo00001Goo00<007ooOol0bWoo000N
Ool00`00Oomoo`02Ool00`00Oomoo`0XOol00`00Oomoo`02Ool2003;Ool001ioo`03001oogoo009o
o`03001oogoo02aoo`03001oogoo0<]oo`007Woo00<007ooOol00Woo00<007ooOol0;7oo00<007oo
Ool027oo00<007ooOol01Goo0P00Mgoo0P00@7oo000NOol00`00Oomoo`02Ool00`00Oomoo`0bOol2
000017oo001oogoo0P001Goo00<007ooOol0N7oo1000?7oo000NOol00`00Oomoo`02Ool00`00Oomo
o`0dOol20004Ool20003Ool00`00Oomoo`0=Ool00`00Oomoo`0:Ool2000COol2000KOol2000VOol0
0`00Oomoo`08Ool2000gOol001ioo`03001oogoo009oo`03001oogoo03moo`03001oogoo009oo`80
00Ioo`04001oogooOol2000:Ool01000Ool000004Goo00<007oo00006Woo00<007ooOol00goo0`00
7goo00<007ooOol02Woo1000<goo000NOol00`00Oomoo`02Ool00`00Oomoo`0oOol00`00Oomoo`04
Ool20004Ool00`00Oomoo`03Ool2000MOol00`00Oomoo`04Ool00`00Oomoo`0COol00`00Oomoo`06
Ool2000MOol00`00Oomoo`0BOol5000ZOol001ioo`03001oogoo009oo`03001oogoo04Qoo`80009o
o`03001oogoo01Eoo`<000Yoo`03001oogoo00Eoo`8001=oo`03001oogoo00aoo`03001oogoo01Io
o`03001oogoo01Ioo`03001oogoo009oo`8002Aoo`007Woo00<007ooOol00Woo00<007ooOol0Bgoo
0P002goo00<007ooOol037oo0P004Woo0P008Goo0P005Woo00<007ooOol07Goo100087oo000NOol0
0`00Oomoo`02Ool00`00Oomoo`1IOol2000VOol2000MOol2000DOol00`00Oomoo`0TOol3000JOol0
01ioo`03001oogoo009oo`03001oogoo05]oo`80011oo`8001Aoo`<0021oo`@000aoobd001Moo`00
7Woo00<007ooOol00Woo00<007ooOol0Kgoo0`00>7oo0`002Goo00<007ooOol0@Goo000NOol00`00
Oomoo`02Ool00`00Oomoo`1aOol00`00Oomoo`0FOol4000SOol00`00Oomoo`02Ool00`00Oomoo`11
Ool001ioo`03001oogoo009oo`03001oogoo08eoo`03001oogoo029oo`D004=oo`007Woo00<007oo
Ool00Woo00<007ooOol0]Woo00<007ooOol0@Goo000NOol00`00Oomoo`02Ool00`00Oomoo`2fOol0
0`00Oomoo`11Ool001ioo`03001oogoo009oo`03001oogoo0;Ioo`03001oogoo045oo`007Woo00<0
07ooOol00Woo00<007ooOol0]Woo00<007ooOol0@Goo000NOol00`00Oomoo`02Ool00`00Oomoo`2f
Ool00`00Oomoo`11Ool001ioo`03001oogoo009oo`03001oogoo0;Ioo`03001oogoo045oo`007Woo
00<007ooOol00Woo00<007ooOol0]Woo00<007ooOol0@Goo000NOol00`00Oomoo`02Ool00`00Oomo
o`2fOol00`00Oomoo`11Ool001ioo`03001oogoo009oo`03001oogoo0;Ioo`03001oogoo045oo`00
67oo0`000goo00<007ooOol00Woo00<007ooOol0]Woo00<007ooOol0@Goo000IOol00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`2fOol00`00Oomoo`11Ool001Ioo`D000=oo`8000=oo`03001o
ogoo08ioobT004=oo`005Woo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo08ioo`03001o
ogoo06Uoo`005goo00<007oo000017oo00<007ooOol00Woo00<007ooOol0SWoo00<007ooOol0JGoo
000HOol20004Ool00`00Oomoo`02Ool00`00Oomoo`2>Ool00`00Oomoo`1YOol001ioo`03001oogoo
009oo`03001oogoo08ioo`03001oogoo06Uoo`007Woo00<007ooOol00Woo00<007ooOol0SWoo00<0
07ooOol0JGoo000NOol00`00Oomoo`02Ool00`00Oomoo`2>Ool00`00Oomoo`1YOol001ioo`03001o
ogoo009oo`03001oogoo08ioo`03001oogoo06Uoo`007Woo00<007ooOol00Woo00<007ooOol0SGoo
00<007ooOol0JWoo000NOol00`00Oomoo`02Ool00`00Oomoo`2=Ool00`00Oomoo`1ZOol001ioo`03
001oogoo009oo`03001oogoo08eoo`03001oogoo06Yoo`007Woo00<007ooOol00Woo00<007ooOol0
SGoo00<007ooOol0JWoo000NOol00`00Oomoo`02Ool00`00Oomoo`2=Ool00`00Oomoo`1ZOol001io
o`03001oogoo009oo`03001oogoo08eoo`03001oogoo06Yoo`007Woo00<007ooOol00Woo00<007oo
Ool0SGoo00<007ooOol0JWoo000NOol00`00Oomoo`02Ool00`00Oomoo`1aOolM001/Ool001ioo`03
001oogoo009oo`03001oogoo075oo`03001oogoo08Ioo`007Woo00<007ooOol00Woo00<007ooOol0
LGoo00<007ooOol0QWoo000NOol00`00Oomoo`02Ool00`00Oomoo`1aOol00`00Oomoo`26Ool001io
o`03001oogoo009oo`03001oogoo075oo`03001oogoo08Ioo`007Woo00<007ooOol00Woo00<007oo
Ool0LGoo00<007ooOol0QWoo000NOol00`00Oomoo`02Ool00`00Oomoo`1aOol00`00Oomoo`26Ool0
01ioo`03001oogoo009oo`03001oogoo075oo`03001oogoo08Ioo`007Woo00<007ooOol00Woo00<0
07ooOol0LGoo00<007ooOol0QWoo000NOol00`00Oomoo`02Ool00`00Oomoo`1aOol00`00Oomoo`26
Ool001ioo`03001oogoo009oo`03001oogoo075oo`03001oogoo08Ioo`007Woo00<007ooOol00Woo
00<007ooOol0LGoo00<007ooOol0QWoo000FOol30005Ool00`00Oomoo`02Ool00`00Oomoo`1aOol0
0`00Oomoo`26Ool001Ioo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`1aOol00`00Oomo
o`26Ool001Ioo`04001oogoo0004Ool20003Ool00`00Oomoo`1LOolF0028Ool001Ioo`<000Eoo`03
001oogoo009oo`03001oogoo05aoo`03001oogoo09]oo`005goo00<007ooOol017oo00<007ooOol0
0Woo00<007ooOol0G7oo00<007ooOol0Vgoo000GOol30004Ool00`00Oomoo`02Ool00`00Oomoo`1L
Ool00`00Oomoo`2KOol001ioo`03001oogoo009oo`03001oogoo05aoo`03001oogoo09]oo`007Woo
00<007ooOol00Woo00<007ooOol0G7oo00<007ooOol0Vgoo000NOol00`00Oomoo`02Ool00`00Oomo
o`1LOol00`00Oomoo`2KOol001ioo`03001oogoo009oo`03001oogoo05aoo`03001oogoo09]oo`00
7Woo00<007ooOol00goo00<007ooOol0Fgoo00<007ooOol0Vgoo000NOol00`00Oomoo`03Ool00`00
Oomoo`1KOol00`00Oomoo`2KOol001ioo`03001oogoo00=oo`03001oogoo05]oo`03001oogoo09]o
o`007Woo00<007ooOol00goo00<007ooOol0Fgoo00<007ooOol0Vgoo000NOol00`00Oomoo`03Ool0
0`00Oomoo`1KOol00`00Oomoo`2KOol001ioo`03001oogoo00=oo`03001oogoo05]oo`03001oogoo
09]oo`007Woo00<007ooOol00goo00<007ooOol0Fgoo00<007ooOol0Vgoo000NOol00`00Oomoo`03
Ool00`00Oomoo`1;OolA002MOol001ioo`03001oogoo00=oo`03001oogoo04]oo`03001oogoo0:]o
o`007Woo00<007ooOol00goo00<007ooOol0Bgoo00<007ooOol0Zgoo000NOol00`00Oomoo`03Ool0
0`00Oomoo`1;Ool00`00Oomoo`2[Ool001ioo`03001oogoo00=oo`03001oogoo04]oo`03001oogoo
0:]oo`007Woo00<007ooOol00goo00<007ooOol0Bgoo00<007ooOol0Zgoo000NOol00`00Oomoo`03
Ool00`00Oomoo`1;Ool00`00Oomoo`2[Ool001ioo`03001oogoo00=oo`03001oogoo04]oo`03001o
ogoo0:]oo`007Woo00<007ooOol00goo00<007ooOol0Bgoo00<007ooOol0Zgoo000NOol00`00Oomo
o`03Ool00`00Oomoo`1;Ool00`00Oomoo`2[Ool001ioo`03001oogoo00=oo`03001oogoo04]oo`03
001oogoo0:]oo`007Woo00<007ooOol00goo00<007ooOol0Bgoo00<007ooOol0Zgoo000NOol00`00
Oomoo`03Ool00`00Oomoo`1;Ool00`00Oomoo`2[Ool001Moo`8000Eoo`03001oogoo00=oo`03001o
ogoo04]oo`03001oogoo0:]oo`005Woo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo04]o
o`03001oogoo0:]oo`005Woo00@007ooOol000Aoo`8000Aoo`03001oogoo03ioo`h00:eoo`005goo
0P001Goo00<007ooOol00goo00<007ooOol0?Woo00<007ooOol0^7oo000FOol01000Oomoo`0017oo
00<007ooOol00goo00<007ooOol0?Woo00<007ooOol0^7oo000GOol20005Ool00`00Oomoo`03Ool0
0`00Oomoo`0nOol00`00Oomoo`2hOol001ioo`03001oogoo00=oo`03001oogoo03ioo`03001oogoo
0;Qoo`007Woo00<007ooOol00goo00<007ooOol0?Woo00<007ooOol0^7oo000NOol00`00Oomoo`03
Ool00`00Oomoo`0nOol00`00Oomoo`2hOol001ioo`03001oogoo00=oo`03001oogoo03ioo`03001o
ogoo0;Qoo`007Woo00<007ooOol00goo00<007ooOol0?Woo00<007ooOol0^7oo000NOol00`00Oomo
o`03Ool00`00Oomoo`0nOol00`00Oomoo`2hOol001ioo`03001oogoo00=oo`03001oogoo03ioo`03
001oogoo0;Qoo`007Woo00<007ooOol00goo00<007ooOol0?Woo00<007ooOol0^7oo000NOol00`00
Oomoo`03Ool00`00Oomoo`0nOol00`00Oomoo`2hOol001ioo`03001oogoo00=oo`03001oogoo03io
o`03001oogoo0;Qoo`007Woo00<007ooOol00goo00<007ooOol0=7oo2`00^Woo000NOol00`00Oomo
o`03Ool00`00Oomoo`0dOol00`00Oomoo`32Ool001ioo`03001oogoo00=oo`03001oogoo03Aoo`03
001oogoo0<9oo`007Woo00<007ooOol00goo00<007ooOol0=7oo00<007ooOol0`Woo000NOol00`00
Oomoo`03Ool00`00Oomoo`0dOol00`00Oomoo`32Ool001ioo`03001oogoo00=oo`03001oogoo03Ao
o`03001oogoo0<9oo`007Woo00<007ooOol00goo00<007ooOol0=7oo00<007ooOol0`Woo000NOol0
0`00Oomoo`03Ool00`00Oomoo`0dOol00`00Oomoo`32Ool001ioo`03001oogoo00=oo`03001oogoo
03Aoo`03001oogoo0<9oo`007Woo00<007ooOol00goo00<007ooOol0=7oo00<007ooOol0`Woo000N
Ool00`00Oomoo`03Ool00`00Oomoo`0dOol00`00Oomoo`32Ool001ioo`03001oogoo00=oo`03001o
ogoo03Aoo`03001oogoo0<9oo`007Woo00<007ooOol00goo00<007ooOol0=7oo00<007ooOol0`Woo
000@Ool50002Ool20005Ool00`00Oomoo`03Ool00`00Oomoo`0dOol00`00Oomoo`32Ool0019oo`05
001oogooOol00002Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0[Ool00`00Oomoo`06
Ool00`00Oomoo`32Ool0019oo`05001oogooOol00002Ool00`00Oomoo`02Ool20004Ool00`00Oomo
o`0/Ool90034Ool0019oo`05001oogooOol00002Ool00`00Oomoo`3oOol5Ool0019oo`05001oogoo
Ool00002Ool00`00Oomoo`3oOol5Ool0015oo`8000Aoo`800?moo`Qoo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0008Ool300001Goo00000000Ool0
0P000Woo0`000Woo0`0017oo100000=oo`0000000P000goo0`0000=oo`0000000Woo0P00jWoo0007
Ool00`00Oomoo`03Ool01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0
00=oo`03001oogoo009oo`03001oogoo00=oo`04001oogoo003[Ool000Moo`03001oogoo00=oo`04
001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000goo00<007ooOol00Woo
10000Woo00@007ooOol00>]oo`001goo00<007ooOol00goo0`0017oo0P0017oo00<007ooOol00goo
0`000Woo10000goo0P000Woo1000k7oo0007Ool01000Oomoo`000Woo00<007ooOol02Woo00<007oo
Ool01Goo00<007ooOol0ngoo0008Ool300000goo00000007Ool01000Oomoogoo0P001Woo0P00oGoo
003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.8167, \
0.00421906, 0.0682658}}],

Cell[BoxData[
    \(0.28125`\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.0618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(10)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.01 .0618 m
.02935 .0618 L
.03921 .0618 L
.04463 .0618 L
.04976 .0618 L
.05245 .0618 L
.05318 .0618 L
.05396 .0618 L
.05463 .0618 L
.05536 .12361 L
.05663 .12361 L
.05733 .12361 L
.058 .12361 L
.05929 .18541 L
.06047 .18541 L
.06167 .18541 L
.06294 .24721 L
.06415 .24721 L
.06524 .24721 L
.06653 .30902 L
.06725 .30902 L
.06792 .30902 L
.07045 .30902 L
.07176 .30902 L
.07249 .37082 L
.07317 .37082 L
.0757 .37082 L
.07712 .37082 L
.07787 .37082 L
.07866 .37082 L
.07936 .37082 L
.08012 .43262 L
.08147 .43262 L
.08436 .43262 L
.08747 .43262 L
.08891 .43262 L
.08969 .43262 L
.09042 .43262 L
.0917 .49443 L
.09238 .49443 L
.09311 .49443 L
.10365 .49443 L
.10654 .49443 L
.1096 .49443 L
.11085 .49443 L
.11221 .49443 L
.11298 .55623 L
.11369 .55623 L
.11508 .55623 L
.13581 .55623 L
Mistroke
.15704 .55623 L
.17673 .55623 L
.18655 .55623 L
.19579 .55623 L
.19828 .55623 L
.19964 .55623 L
.20091 .55623 L
.20157 .55623 L
.20228 .49443 L
.20307 .49443 L
.20379 .49443 L
.20644 .49443 L
.21608 .49443 L
.23742 .49443 L
.25714 .49443 L
.2763 .49443 L
.28096 .49443 L
.28597 .49443 L
.28737 .49443 L
.28813 .49443 L
.28884 .49443 L
.2901 .43262 L
.29076 .43262 L
.29147 .43262 L
.29663 .43262 L
.33939 .43262 L
.36083 .43262 L
.37024 .43262 L
.37523 .43262 L
.38058 .43262 L
.38325 .43262 L
.38457 .43262 L
.38579 .43262 L
.38689 .37082 L
.38806 .37082 L
.39054 .37082 L
.39985 .37082 L
.42022 .37082 L
.45903 .37082 L
.48058 .37082 L
.49003 .37082 L
.49502 .37082 L
.50036 .37082 L
.50307 .37082 L
.50562 .37082 L
.50791 .37082 L
.5092 .37082 L
.51039 .30902 L
.51151 .30902 L
.51255 .30902 L
Mistroke
.51493 .30902 L
.51973 .30902 L
.54014 .30902 L
.58006 .30902 L
.6225 .30902 L
.6437 .30902 L
.65402 .30902 L
.66338 .30902 L
.66809 .30902 L
.67318 .30902 L
.67552 .30902 L
.67799 .30902 L
.67901 .30902 L
.6801 .30902 L
.6813 .24721 L
.68242 .24721 L
.7027 .24721 L
.74528 .24721 L
.7863 .24721 L
.82576 .24721 L
.86775 .24721 L
.88861 .24721 L
.90817 .24721 L
.92688 .24721 L
.93201 .24721 L
.9374 .24721 L
.94201 .24721 L
.94327 .24721 L
.94461 .24721 L
.94589 .24721 L
.94704 .18541 L
.94827 .18541 L
.94942 .18541 L
.95204 .18541 L
.95732 .18541 L
.9668 .18541 L
.9882 .18541 L
.99 .18541 L
Mfstroke
[ .02 .02 ] 0 setdash
.01 .00062 m
.02935 .00181 L
.03921 .00242 L
.04463 .00276 L
.04976 .00308 L
.05245 .00324 L
.05318 .00329 L
.05396 .00334 L
.05463 .00338 L
.05536 .00684 L
.05663 .007 L
.05733 .00709 L
.058 .00717 L
.05929 .01099 L
.06047 .01121 L
.06167 .01143 L
.06294 .01556 L
.06415 .01586 L
.06524 .01613 L
.06653 .02056 L
.06725 .02078 L
.06792 .02099 L
.07045 .02177 L
.07176 .02217 L
.07249 .02688 L
.07317 .02713 L
.0757 .02807 L
.07712 .0286 L
.07787 .02888 L
.07866 .02917 L
.07936 .02943 L
.08012 .03466 L
.08147 .03525 L
.08436 .0365 L
.08747 .03784 L
.08891 .03846 L
.08969 .0388 L
.09042 .03912 L
.0917 .04534 L
.09238 .04568 L
.09311 .04604 L
.13581 .07554 L
.15722 .08745 L
.17696 .09843 L
.18689 .10395 L
.19618 .10912 L
.19858 .11046 L
.19976 .11111 L
.20085 .11172 L
.20211 .09993 L
Mistroke
.20277 .10026 L
.20348 .1006 L
.20587 .10179 L
.21654 .10706 L
.23713 .11724 L
.25938 .12824 L
.26985 .13342 L
.27556 .13625 L
.28089 .13888 L
.28545 .14113 L
.28676 .14178 L
.288 .14239 L
.28911 .14295 L
.29032 .1256 L
.29156 .12614 L
.29293 .12673 L
.2957 .12793 L
.30066 .13007 L
.34208 .14799 L
.36113 .15624 L
.37192 .1609 L
.37718 .16318 L
.38195 .16524 L
.38442 .16631 L
.38509 .1666 L
.38581 .16691 L
.38709 .14354 L
.38829 .14398 L
.3894 .1444 L
.39194 .14534 L
.40261 .1493 L
.42433 .15735 L
.46434 .17219 L
.4847 .17974 L
.49544 .18372 L
.50133 .1859 L
.50422 .18697 L
.50686 .18796 L
.50809 .18841 L
.50923 .18883 L
.51042 .15773 L
.51173 .15813 L
.51697 .15975 L
.52814 .1632 L
.54783 .16929 L
.58798 .18169 L
.63064 .19488 L
.65202 .20149 L
.66141 .20439 L
.6664 .20593 L
Mistroke
.67175 .20758 L
.67441 .2084 L
.67693 .20918 L
.6792 .20988 L
.68048 .21028 L
.68167 .16852 L
.68288 .16882 L
.68403 .1691 L
.68616 .16963 L
.69095 .17081 L
.7113 .17584 L
.75099 .18566 L
.7932 .19609 L
.83386 .20614 L
.87295 .21581 L
.89472 .22119 L
.91457 .22609 L
.92442 .22853 L
.93514 .23118 L
.94005 .23239 L
.94274 .23306 L
.94406 .23338 L
.94526 .23368 L
.94631 .23394 L
.94741 .17566 L
.94851 .17586 L
.94971 .17609 L
.95462 .177 L
.99 .18356 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool2
0004Ool20003Ool4000POol20004Ool20005Ool3000POol20004Ool20003Ool3000QOol20004Ool2
0004Ool2000WOol5000BOol004Eoo`04001oogoo0008Ool00`00Oomoo`0POol01000Oomoo`002goo
00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`0027oo00@007ooOol0
02Qoo`03001oogoo019oo`00AGoo00@007ooOol000Uoo`03001oogoo01moo`04001oogoo0008Ool5
000OOol01000Oomoo`0027oo00@007ooOol001moo`04001oogoo0008Ool01000Oomoo`00:7oo00<0
07ooOol04Woo0015Ool01000Oomoo`002Woo00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo
000POol01000Oomoo`0027oo0`0087oo00@007ooOol000Uoo`8002Uoo`03001oogoo019oo`00AGoo
00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`002Goo00<007oo000087oo00@007ooOol0
00Uoo`03001oogoo01moo`04001oogoo0008Ool01000Oomoo`00:7oo00<007ooOol04Woo0016Ool2
000:Ool2000QOol2000;Ool2000QOol2000:Ool3000POol2000:Ool2000XOol2000DOol00?moob5o
o`00ogoo8Goo003oOolQOol00?mooaAoo`<000Yoo`00ogoo5goo00<007ooOol01goo000NOoo^0007
Ool3000:Ool001ioo`03001oogoo00Yoo`03001oogoo01moo`03001oogoo02aoo`03001oogoo02eo
o`03001oogoo02aoo`03001oogoo02eoo`03001oogoo00Eoo`@000Uoo`007Woo00<007ooOol0ogoo
000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol03Goo0P00l7oo000N
Ool00`00Oomoo`0>Ool2003_Ool001ioo`03001oogoo00moo`03001oogoo0>eoo`007Woo00<007oo
Ool0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo019oo`800>]oo`007Woo00<007ooOol0
57oo00<007ooOol0j7oo000NOol00`00Oomoo`0EOol00`00Oomoo`3WOol001ioo`03001oogoo01Io
o`03001oogoo0>Ioo`007Woo00<007oo00002P00mGoo000NOol00`00Oomoo`09Ool00`00Oomoo`3c
Ool001ioo`03001oogoo00Uoo`03001oogoo00ioo`800>=oo`007Woo00<007ooOol02Goo00<007oo
Ool047oo0P00hGoo000NOol00`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`3NOol001ioo`03
001oogoo00Uoo`03001oogoo0?=oo`007Woo00<007ooOol02Goo00<007ooOol0lgoo000NOol00`00
Oomoo`09Ool00`00Oomoo`0FOol00`00Oomoo`3JOol001ioo`03001oogoo00Yoo`03001oogoo01Io
o`800=Yoo`007Woo00<007ooOol02Woo00<007ooOol067oo0`0017oo0P00dGoo000NOol00`00Oomo
o`0:Ool00`00Oomoo`0OOol2003AOol001ioo`03001oogoo00Yoo`03001oogoo01ioo`800=9oo`00
7Woo00<007ooOol02Woo00<007ooOol07goo00<007ooOol00Woo0P00c7oo000FOol40004Ool00`00
Oomoo`0:Ool00`00Oomoo`0VOol30039Ool001Ioo`03001oogoo00Eoo`03001oogoo00Yoo`03001o
ogoo02Uoo`03001oogoo0<Ioo`005goo00<007ooOol017oo0P002goo00<007ooOol0=7oo0P00_7oo
000HOol00`00Oomoo`03Ool00`00Oomoo`0:Ool00`00Oomoo`0]Ool00`00Oomoo`04Ool3002kOol0
01Ioo`04001oogoo0004Ool00`00Oomoo`0:Ool00`00Oomoo`0^Ool20004Ool00`00Oomoo`2kOol0
01Moo`8000Eoo`03001oogoo00Yoo`03001oogoo031oo`80009oo`03001oogoo00Aoo`03001oogoo
0;Aoo`007Woo00<007ooOol02Woo00<007ooOol0?7oo0P00]7oo000NOol00`00Oomoo`0:Ool00`00
Oomoo`0nOol2000;Ool2002UOol001ioo`03001oogoo00Yoo`03001oogoo04]oo`03001oogoo009o
o`03001oogoo09moo`007Woo00<007ooOol02Woo00<007ooOol0@goo00<007ooOol01Goo00<007oo
Ool00goo0P00Wgoo000NOol00`00Oomoo`0;Ool00`00Oomoo`13Ool30004Ool00`00Oomoo`05Ool3
000COol00`00Oomoo`26Ool001ioo`03001oogoo00]oo`03001oogoo04Ioo`80009oo`03001oogoo
01]oo`05001oogooOol00024Ool001ioo`03001oogoo00]oo`03001oogoo05Qoo`8000ioo`03001o
ogoo009oo`80089oo`007Woo00<007ooOol02goo00<007ooOol0FWoo0`002Woo00<007ooOol01Goo
0`0087oo0P00GGoo000NOol00`00Oomoo`0;Ool00`00Oomoo`1WOol00`00Oomoo`0;Ool2000MOol3
000hOol3000OOol001ioo`03001oogoo00]oo`03001oogoo065oo`8000Aoo`03001oogoo00eoo`80
01Moo`03001oogoo00Qoo`<0035oo`03001oogoo008001eoo`007Woo00<007ooOol02goo00<007oo
Ool0Hgoo0P0057oo0P005Goo00<007ooOol02goo0`00;Woo2`005goo000NOol00`00Oomoo`0;Ool0
0`00Oomoo`1UOol00`00Oomoo`0FOol3000?Ool00`00Oomoo`0AOol2000YOol00`00Oomoo`0OOol0
01ioo`03001oogoo00]oo`03001oogoo085oo`<000aoo`03001oogoo01=oo`8002Moo`03001oogoo
01moo`007Woo00<007ooOol02goo00<007ooOol0T7oo00<007ooOol05Goo0P009Goo00<007ooOol0
7goo000NOol00`00Oomoo`0;Ool00`00Oomoo`27Ool30006Ool00`00Oomoo`0JOol3000OOol00`00
Oomoo`0OOol001ioo`03001oogoo00]oo`03001oogoo08Yoo`<002=oo`<001aoo`03001oogoo01mo
o`007Woo00<007ooOol02goo00<007ooOol0SGoo00<007ooOol09goo0P005Woo00<007ooOol07goo
000NOol00`00Oomoo`0;Ool00`00Oomoo`2iOol3000COol00`00Oomoo`0OOol001ioo`03001oogoo
00]oo`03001oogoo0<1oo`8000eoo`03001oogoo01moo`007Woo00<007ooOol02goo00<007ooOol0
`Woo0`002Woo00<007ooOol07goo000NOol00`00Oomoo`0;Ool00`00Oomoo`3?Ool00`00Oomoo`0O
Ool001ioo`03001oogoo00]oo`03001oogoo0<Uoo`@0009oo`03001oogoo01moo`007Woo00<007oo
Ool02goo00<007ooOol0cGoo0`008Goo000HOol30003Ool00`00Oomoo`0;Ool00`00Oomoo`3?Ool0
0`00Oomoo`0OOol001Uoo`03001oogoo009oo`03001oogoo00]oo`03001oogoo0<moo`03001oogoo
01moo`005Woo1@000goo0P0037oo0P00TGoo@0008Goo000FOol01000Oomoo`0017oo00<007ooOol0
37oo00<007ooOol0Sgoo00<007ooOol0GWoo000GOol00`00Ool00004Ool00`00Oomoo`0<Ool00`00
Oomoo`2?Ool00`00Oomoo`1NOol001Qoo`8000Aoo`03001oogoo00aoo`03001oogoo08moo`03001o
ogoo05ioo`007Woo00<007ooOol037oo00<007ooOol0Sgoo00<007ooOol0GWoo000NOol00`00Oomo
o`0<Ool00`00Oomoo`2?Ool00`00Oomoo`1NOol001ioo`03001oogoo00aoo`03001oogoo08moo`03
001oogoo05ioo`007Woo00<007ooOol037oo00<007ooOol0Sgoo00<007ooOol0GWoo000NOol00`00
Oomoo`0<Ool00`00Oomoo`2?Ool00`00Oomoo`1NOol001ioo`03001oogoo00aoo`03001oogoo08mo
o`03001oogoo05ioo`007Woo00<007ooOol037oo00<007ooOol0Sgoo00<007ooOol0GWoo000NOol0
0`00Oomoo`0<Ool00`00Oomoo`2?Ool00`00Oomoo`1NOol001ioo`03001oogoo00aoo`03001oogoo
08moo`03001oogoo05ioo`007Woo00<007ooOol037oo00<007ooOol0Sgoo00<007ooOol0GWoo000N
Ool00`00Oomoo`0<Ool00`00Oomoo`2?Ool00`00Oomoo`1NOol001ioo`03001oogoo00aoo`<006Mo
obT0061oo`007Woo00<007ooOol03Woo00<007ooOol0IGoo00<007ooOol0QWoo000NOol00`00Oomo
o`0>Ool00`00Oomoo`1UOol00`00Oomoo`26Ool001ioo`03001oogoo00ioo`03001oogoo06Eoo`03
001oogoo08Ioo`007Woo00<007ooOol03Woo00<007ooOol0IGoo00<007ooOol0QWoo000NOol00`00
Oomoo`0>Ool00`00Oomoo`1UOol00`00Oomoo`26Ool001ioo`03001oogoo00ioo`03001oogoo06Eo
o`03001oogoo08Ioo`007Woo00<007ooOol03Woo00<007ooOol0I7oo00<007ooOol0Qgoo000NOol0
0`00Oomoo`0>Ool00`00Oomoo`1TOol00`00Oomoo`27Ool001ioo`03001oogoo00ioo`03001oogoo
06Aoo`03001oogoo08Moo`007Woo00<007ooOol03Woo00<007ooOol0I7oo00<007ooOol0Qgoo000N
Ool00`00Oomoo`0>Ool00`00Oomoo`1TOol00`00Oomoo`27Ool001Ioo`<000Eoo`03001oogoo00io
o`03001oogoo06Aoo`03001oogoo08Moo`005Woo00@007ooOol000Aoo`03001oogoo00ioo`03001o
ogoo06Aoo`03001oogoo08Moo`005Woo00@007ooOol000Aoo`8000moo`8004Qooah008Uoo`005Woo
0`001Goo00<007ooOol03goo00<007ooOol0AWoo00<007ooOol0Y7oo000GOol00`00Oomoo`04Ool0
0`00Oomoo`0?Ool00`00Oomoo`16Ool00`00Oomoo`2TOol001Moo`<000Aoo`03001oogoo00moo`03
001oogoo04Ioo`03001oogoo0:Aoo`007Woo00<007ooOol03goo00<007ooOol0AWoo00<007ooOol0
Y7oo000NOol00`00Oomoo`0?Ool00`00Oomoo`16Ool00`00Oomoo`2TOol001ioo`03001oogoo00mo
o`03001oogoo04Ioo`03001oogoo0:Aoo`007Woo00<007ooOol03goo00<007ooOol0AWoo00<007oo
Ool0Y7oo000NOol00`00Oomoo`0@Ool00`00Oomoo`15Ool00`00Oomoo`2TOol001ioo`03001oogoo
011oo`03001oogoo04Eoo`03001oogoo0:Aoo`007Woo00<007ooOol047oo00<007ooOol0AGoo00<0
07ooOol0Y7oo000NOol00`00Oomoo`0@Ool00`00Oomoo`15Ool00`00Oomoo`2TOol001ioo`03001o
ogoo011oo`03001oogoo04Eoo`03001oogoo0:Aoo`007Woo00<007ooOol047oo00<007ooOol0AGoo
00<007ooOol0Y7oo000NOol00`00Oomoo`0@Ool00`00Oomoo`15Ool00`00Oomoo`2TOol001ioo`03
001oogoo011oo`<002iooaP00:Ioo`007Woo00<007ooOol04Woo00<007ooOol0;7oo00<007ooOol0
^goo000NOol00`00Oomoo`0BOol00`00Oomoo`0/Ool00`00Oomoo`2kOol001ioo`03001oogoo019o
o`03001oogoo02aoo`03001oogoo0;]oo`007Woo00<007ooOol04Woo00<007ooOol0;7oo00<007oo
Ool0^goo000NOol00`00Oomoo`0BOol00`00Oomoo`0/Ool00`00Oomoo`2kOol001ioo`03001oogoo
019oo`03001oogoo02aoo`03001oogoo0;]oo`007Woo00<007ooOol04Woo00<007ooOol0;7oo00<0
07ooOol0^goo000NOol00`00Oomoo`0BOol00`00Oomoo`0/Ool00`00Oomoo`2kOol001ioo`03001o
ogoo019oo`03001oogoo02aoo`03001oogoo0;]oo`007Woo00<007ooOol04Woo00<007ooOol0;7oo
00<007ooOol0^goo000NOol00`00Oomoo`0BOol00`00Oomoo`0/Ool00`00Oomoo`2kOol001ioo`03
001oogoo019oo`03001oogoo02aoo`03001oogoo0;]oo`005goo0P001Goo00<007ooOol04Woo00<0
07ooOol0;7oo00<007ooOol0^goo000FOol01000Oomoo`0017oo00<007ooOol04Woo00<007ooOol0
;7oo00<007ooOol0^goo000FOol01000Oomoo`0017oo0P004goo1P0057oo5P00_Goo000GOol20005
Ool00`00Oomoo`0GOol00`00Oomoo`0BOol00`00Oomoo`3@Ool001Ioo`04001oogoo0004Ool00`00
Oomoo`0GOol00`00Oomoo`0BOol00`00Oomoo`3@Ool001Moo`8000Eoo`03001oogoo01Moo`03001o
ogoo019oo`03001oogoo0=1oo`007Woo00<007ooOol05goo00<007ooOol04Woo00<007ooOol0d7oo
000NOol00`00Oomoo`0GOol00`00Oomoo`0BOol00`00Oomoo`3@Ool001ioo`03001oogoo01Moo`03
001oogoo019oo`03001oogoo0=1oo`007Woo00<007ooOol05goo00<007ooOol04Woo00<007ooOol0
d7oo000NOol00`00Oomoo`0GOol00`00Oomoo`0BOol00`00Oomoo`3@Ool001ioo`03001oogoo01Mo
o`03001oogoo019oo`03001oogoo0=1oo`007Woo00<007ooOol05goo00<007ooOol04Woo00<007oo
Ool0d7oo000NOol00`00Oomoo`0GOol00`00Oomoo`0BOol00`00Oomoo`3@Ool001ioo`03001oogoo
01Moo`03001oogoo019oo`03001oogoo0=1oo`007Woo00<007ooOol05goo00<007ooOol04Woo00<0
07ooOol0d7oo000NOol00`00Oomoo`0GOolF003BOol001ioo`03001oogoo0?moo`007Woo00<007oo
Ool0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000N
Ool00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomo
o`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol0011o
o`D0009oo`8000Eoo`03001oogoo0?moo`004Woo00D007ooOomoo`00009oo`03001oogoo009oo`03
001oogoo0?moo`004Woo00D007ooOomoo`00009oo`03001oogoo009oo`800?moo`5oo`004Woo00D0
07ooOomoo`00009oo`03001oogoo0?moo`Eoo`004Woo00D007ooOomoo`00009oo`03001oogoo0?mo
o`Eoo`004Goo0P0017oo0P00ogoo27oo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol000Qoo`<00005Ool00000001oo`020002Ool30002Ool30004Ool4
00000goo000000020003Ool300000goo00000002Ool2003ZOol000Moo`03001oogoo00=oo`04001o
ogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000goo00<007ooOol00Woo00<0
07ooOol00goo00@007ooOol00>]oo`001goo00<007ooOol00goo00@007ooOol000Aoo`03001oogoo
009oo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool40002Ool01000Oomoo`00jgoo
0007Ool00`00Oomoo`03Ool30004Ool20004Ool00`00Oomoo`03Ool30002Ool40003Ool20002Ool4
003/Ool000Moo`04001oogoo0002Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`3kOol0
00Qoo`<00003Ool0000000Moo`04001oogooOol20006Ool2003mOol00?moob5oo`00ogoo8Goo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.8167, \
0.00421906, 0.0682658}}],

Cell[BoxData[
    \(0.140625`\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.0618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(10)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.01 .0618 m
.04976 .0618 L
.09311 .0618 L
.11419 .0618 L
.13383 .0618 L
.14356 .0618 L
.15275 .0618 L
.15522 .0618 L
.15783 .0618 L
.1592 .0618 L
.15998 .0618 L
.1607 .12361 L
.16198 .12361 L
.16335 .12361 L
.17299 .12361 L
.17802 .12361 L
.18079 .12361 L
.18214 .12361 L
.18339 .12361 L
.18411 .18541 L
.18487 .18541 L
.18648 .18541 L
.18928 .18541 L
.19474 .18541 L
.20472 .18541 L
.21021 .18541 L
.21541 .18541 L
.22047 .18541 L
.22186 .18541 L
.22262 .18541 L
.22334 .18541 L
.22459 .24721 L
.22526 .24721 L
.22598 .24721 L
.23562 .24721 L
.25448 .24721 L
.29682 .24721 L
.33759 .24721 L
.3768 .24721 L
.41854 .24721 L
.45872 .24721 L
.50142 .24721 L
.54256 .24721 L
.58214 .24721 L
.62425 .24721 L
.66479 .24721 L
.70378 .24721 L
.74529 .24721 L
.78524 .24721 L
.82771 .24721 L
Mistroke
.86863 .24721 L
.88928 .24721 L
.90798 .24721 L
.91301 .24721 L
.91565 .24721 L
.91709 .24721 L
.91843 .24721 L
.91961 .24721 L
.92088 .18541 L
.9216 .18541 L
.92228 .18541 L
.92356 .18541 L
.92827 .18541 L
.94986 .18541 L
.98936 .18541 L
.99 .18541 L
Mfstroke
[ .02 .02 ] 0 setdash
.01 .00062 m
.04976 .00308 L
.09311 .00575 L
.11419 .00706 L
.13383 .00827 L
.14356 .00887 L
.15275 .00944 L
.15522 .00959 L
.15783 .00975 L
.1592 .00984 L
.15998 .00989 L
.1607 .01986 L
.16198 .02002 L
.16335 .02019 L
.17299 .02138 L
.17802 .02201 L
.18079 .02235 L
.18214 .02251 L
.18339 .02267 L
.18411 .03414 L
.18487 .03428 L
.18648 .03457 L
.18928 .03509 L
.19474 .03611 L
.20472 .03796 L
.21021 .03897 L
.21541 .03994 L
.22047 .04088 L
.22186 .04114 L
.22262 .04128 L
.22334 .04141 L
.22459 .05552 L
.22526 .05569 L
.22598 .05587 L
.23562 .05825 L
.25448 .06291 L
.29682 .07338 L
.33759 .08346 L
.3768 .09315 L
.41854 .10347 L
.45872 .1134 L
.50142 .12396 L
.54256 .13413 L
.58214 .14391 L
.62425 .15432 L
.66479 .16435 L
.70378 .17398 L
.74529 .18425 L
.78524 .19412 L
.82771 .20462 L
Mistroke
.86863 .21474 L
.88928 .21984 L
.90798 .22447 L
.91301 .22571 L
.91565 .22636 L
.91709 .22672 L
.91843 .22705 L
.91961 .22734 L
.92088 .17074 L
.9216 .17087 L
.92228 .171 L
.92356 .17124 L
.92827 .17211 L
.94986 .17611 L
.98936 .18344 L
.99 .18356 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool2
0004Ool20003Ool4000POol20004Ool20005Ool3000POol20004Ool20003Ool3000QOol20004Ool2
0004Ool2000WOol5000BOol004Eoo`04001oogoo0008Ool00`00Oomoo`0POol01000Oomoo`002goo
00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`0027oo00@007ooOol0
02Qoo`03001oogoo019oo`00AGoo00@007ooOol000Uoo`03001oogoo01moo`04001oogoo0008Ool5
000OOol01000Oomoo`0027oo00@007ooOol001moo`04001oogoo0008Ool01000Oomoo`00:7oo00<0
07ooOol04Woo0015Ool01000Oomoo`002Woo00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo
000POol01000Oomoo`0027oo0`0087oo00@007ooOol000Uoo`8002Uoo`03001oogoo019oo`00AGoo
00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`002Goo00<007oo000087oo00@007ooOol0
00Uoo`03001oogoo01moo`04001oogoo0008Ool01000Oomoo`00:7oo00<007ooOol04Woo0016Ool2
000:Ool2000QOol2000;Ool2000QOol2000:Ool3000POol2000:Ool2000XOol2000DOol00?moob5o
o`00ogoo8Goo003oOolQOol00?mooaAoo`<000Yoo`00ogoo5goo00<007ooOol01goo000NOoo^0007
Ool3000:Ool001ioo`03001oogoo00eoo`<000Aoo`H0019oo`03001oogoo02aoo`03001oogoo02eo
o`03001oogoo02aoo`03001oogoo02eoo`03001oogoo00Eoo`@000Uoo`007Woo00<007ooOol07Woo
1@00g7oo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol09Goo1000
eWoo000NOol00`00Oomoo`0XOol00`00Oomoo`3DOol001ioo`03001oogoo02Qoo`03001oogoo0=Ao
o`007Woo00<007ooOol0;7oo00<007ooOol0d7oo000NOol00`00Oomoo`0]Ool4003>Ool001ioo`03
001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo039o
o`@00<Uoo`007Woo00<007oo00008`004goo0P00agoo000NOol00`00Oomoo`0ROol00`00Oomoo`0F
Ool30031Ool001ioo`03001oogoo029oo`03001oogoo01Uoo`<00;ioo`007Woo00<007ooOol08Woo
00<007ooOol07goo0`00^7oo000NOol00`00Oomoo`0ROol00`00Oomoo`0ROol3002eOol001ioo`03
001oogoo029oo`03001oogoo0=Yoo`007Woo00<007ooOol08Woo00<007ooOol0:Goo0P00[goo000N
Ool00`00Oomoo`0ROol00`00Oomoo`0[Ool3002/Ool001ioo`03001oogoo02=oo`03001oogoo035o
o`800:Ioo`007Woo00<007ooOol08goo00<007ooOol0<goo0`00Xgoo000NOol00`00Oomoo`0SOol0
0`00Oomoo`0jOol3002LOol001ioo`03001oogoo02=oo`03001oogoo03eoo`<009Uoo`007Woo00<0
07ooOol08goo00<007ooOol0@goo0P00U7oo000FOol40004Ool00`00Oomoo`0SOol00`00Oomoo`15
Ool2002BOol001Ioo`03001oogoo00Eoo`03001oogoo02=oo`03001oogoo04Moo`80091oo`005goo
00<007ooOol017oo0P0097oo1P00BGoo0`00RWoo000HOol00`00Oomoo`03Ool00`00Oomoo`0XOol0
0`00Oomoo`1:Ool30027Ool001Ioo`04001oogoo0004Ool00`00Oomoo`0XOol00`00Oomoo`1AOol3
0020Ool001Moo`8000Eoo`03001oogoo02Qoo`03001oogoo05Aoo`8007ioo`007Woo00<007ooOol0
:7oo00<007ooOol0FWoo00<007ooOol0Mgoo000NOol00`00Oomoo`0XOol00`00Oomoo`1KOol4001e
Ool001ioo`03001oogoo02Qoo`03001oogoo0=Aoo`007Woo00<007ooOol0:7oo00<007ooOol0Hgoo
1000KGoo000NOol00`00Oomoo`0XOol00`00Oomoo`1WOol2001[Ool001ioo`03001oogoo02Qoo`03
001oogoo06aoo`@006Aoo`007Woo00<007ooOol0:7oo00<007ooOol0L7oo0P00HWoo000NOol00`00
Oomoo`0XOol00`00Oomoo`1eOol2000eOol00`00Oomoo`0UOol001ioo`03001oogoo02Qoo`03001o
ogoo07Moo`@0035oo`04001oogooOol4000POol001ioo`03001oogoo02Qoo`03001oogoo07moo`80
02]oo`03001oogoo00Eoo`8001ioo`007Woo00<007ooOol0:7oo2P00NWoo0P00:Goo4@005goo000N
Ool00`00Oomoo`0aOol00`00Oomoo`1jOol00`00Oomoo`0VOol00`00Oomoo`0UOol001ioo`03001o
ogoo035oo`03001oogoo07moo`80029oo`03001oogoo02Eoo`007Woo00<007ooOol0<Goo00<007oo
Ool0PGoo10007Woo00<007ooOol09Goo000NOol00`00Oomoo`0aOol00`00Oomoo`28Ool3000HOol0
0`00Oomoo`0UOol001ioo`03001oogoo035oo`03001oogoo08]oo`<001Eoo`03001oogoo02Eoo`00
7Woo00<007ooOol0<Goo00<007ooOol0Sgoo0`004Goo00<007ooOol09Goo000NOol00`00Oomoo`0a
Ool00`00Oomoo`2BOol3000>Ool00`00Oomoo`0UOol001ioo`03001oogoo039oo`03001oogoo09Mo
o`8000Qoo`8002Moo`007Woo00<007ooOol0<Woo00<007ooOol0VGoo100017oo00<007ooOol09Woo
000NOol00`00Oomoo`0bOol00`00Oomoo`2POol2000XOol001ioo`03001oogoo039oo`03001oogoo
0:5oo`03001oogoo02Ioo`007Woo00<007ooOol0<Woo00<007ooOol0XGoo00<007ooOol09Woo000H
Ool30003Ool00`00Oomoo`0bOol00`00Oomoo`2QOol00`00Oomoo`0VOol001Uoo`03001oogoo009o
o`03001oogoo039oo`03001oogoo0:5oo`03001oogoo02Ioo`005Woo1@000goo0P00<gooY@00:7oo
000FOol01000Oomoo`0017oo00<007ooOol0ogoo000GOol00`00Ool00004Ool00`00Oomoo`3oOol0
01Qoo`8000Aoo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001io
o`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo
0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo
00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0
ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol0
0`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3o
Ool001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001Ioo`<0
00Eoo`03001oogoo0?moo`005Woo00@007ooOol000Aoo`03001oogoo0?moo`005Woo00@007ooOol0
00Aoo`800?moo`5oo`005Woo0`001Goo00<007ooOol0ogoo000GOol00`00Oomoo`04Ool00`00Oomo
o`3oOol001Moo`<000Aoo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3o
Ool001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03
001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?mo
o`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<0
07ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo
000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00
Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol0
01ioo`03001oogoo0?moo`005goo0P001Goo00<007ooOol0ogoo000FOol01000Oomoo`0017oo00<0
07ooOol0ogoo000FOol01000Oomoo`0017oo0P00ogoo0Goo000GOol20005Ool00`00Oomoo`3oOol0
01Ioo`04001oogoo0004Ool00`00Oomoo`3oOol001Moo`8000Eoo`03001oogoo0?moo`007Woo00<0
07ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo
000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00
Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol0
01ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001o
ogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`00
7Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007oo
Ool0ogoo000NOol00`00Oomoo`3oOol0011oo`D0009oo`8000Eoo`03001oogoo0?moo`004Woo00D0
07ooOomoo`00009oo`03001oogoo009oo`03001oogoo0?moo`004Woo00D007ooOomoo`00009oo`03
001oogoo009oo`800?moo`5oo`004Woo00D007ooOomoo`00009oo`03001oogoo0?moo`Eoo`004Woo
00D007ooOomoo`00009oo`03001oogoo0?moo`Eoo`004Goo0P0017oo0P00ogoo27oo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol000Qoo`<00005Ool0
0000001oo`020002Ool30002Ool30004Ool400000goo000000020003Ool300000goo00000002Ool2
003ZOol000Moo`03001oogoo00=oo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol00goo00@007ooOol00>]oo`001goo00<007oo
Ool00goo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo009oo`04001oogoo0003Ool00`00
Oomoo`02Ool40002Ool01000Oomoo`00jgoo0007Ool00`00Oomoo`03Ool30004Ool20004Ool00`00
Oomoo`03Ool30002Ool40003Ool20002Ool4003/Ool000Moo`04001oogoo0002Ool00`00Oomoo`0:
Ool00`00Oomoo`05Ool00`00Oomoo`3kOol000Qoo`<00003Ool0000000Moo`04001oogooOol20006
Ool2003mOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.8167, \
0.00421906, 0.0682658}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowSize->{1017, 668},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 52, 0, 115, "Title"],
Cell[1782, 54, 52, 1, 30, "Input"],
Cell[1837, 57, 37, 0, 33, "Text"],
Cell[1877, 59, 219, 3, 61, "Input"],
Cell[2099, 64, 158, 4, 51, "Input"],
Cell[2260, 70, 93, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[2378, 76, 454, 9, 150, "Input"],
Cell[2835, 87, 180, 3, 24, "Message"]
}, Open  ]],
Cell[3030, 93, 70, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[3125, 97, 665, 11, 110, "Input"],
Cell[3793, 110, 107, 2, 29, "Output"],
Cell[3903, 114, 85, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4025, 120, 2001, 34, 650, "Input"],
Cell[6029, 156, 181, 3, 24, "Message"],
Cell[6213, 161, 42, 1, 25, "Print"],
Cell[6258, 164, 18822, 717, 186, 9192, 594, "GraphicsData", "PostScript", \
"Graphics"],
Cell[25083, 883, 48, 1, 25, "Print"],
Cell[25134, 886, 18423, 695, 186, 8780, 571, "GraphicsData", "PostScript", \
"Graphics"],
Cell[43560, 1583, 49, 1, 25, "Print"],
Cell[43612, 1586, 17874, 658, 186, 8264, 535, "GraphicsData", "PostScript", \
"Graphics"],
Cell[61489, 2246, 52, 1, 25, "Print"],
Cell[61544, 2249, 14117, 518, 186, 6443, 419, "GraphicsData", "PostScript", \
"Graphics"],
Cell[75664, 2769, 43, 1, 25, "Print"],
Cell[75710, 2772, 18843, 720, 186, 9225, 597, "GraphicsData", "PostScript", \
"Graphics"],
Cell[94556, 3494, 49, 1, 25, "Print"],
Cell[94608, 3497, 18183, 686, 186, 8678, 564, "GraphicsData", "PostScript", \
"Graphics"],
Cell[112794, 4185, 51, 1, 25, "Print"],
Cell[112848, 4188, 18452, 657, 186, 8076, 524, "GraphicsData", "PostScript", \
"Graphics"],
Cell[131303, 4847, 52, 1, 25, "Print"],
Cell[131358, 4850, 13842, 502, 186, 6180, 403, "GraphicsData", "PostScript", \
"Graphics"],
Cell[145203, 5354, 44, 1, 25, "Print"],
Cell[145250, 5357, 18752, 720, 186, 9239, 598, "GraphicsData", "PostScript", \
"Graphics"],
Cell[164005, 6079, 48, 1, 25, "Print"],
Cell[164056, 6082, 19513, 693, 186, 8489, 552, "GraphicsData", "PostScript", \
"Graphics"],
Cell[183572, 6777, 52, 1, 25, "Print"],
Cell[183627, 6780, 18132, 649, 186, 7999, 519, "GraphicsData", "PostScript", \
"Graphics"],
Cell[201762, 7431, 42, 1, 25, "Print"],
Cell[201807, 7434, 13948, 511, 186, 6343, 413, "GraphicsData", "PostScript", \
"Graphics"],
Cell[215758, 7947, 44, 1, 25, "Print"],
Cell[215805, 7950, 18760, 722, 186, 9263, 600, "GraphicsData", "PostScript", \
"Graphics"],
Cell[234568, 8674, 50, 1, 25, "Print"],
Cell[234621, 8677, 18250, 628, 186, 7534, 491, "GraphicsData", "PostScript", \
"Graphics"],
Cell[252874, 9307, 41, 1, 25, "Print"],
Cell[252918, 9310, 18279, 663, 186, 8235, 534, "GraphicsData", "PostScript", \
"Graphics"],
Cell[271200, 9975, 42, 1, 25, "Print"],
Cell[271245, 9978, 13336, 491, 186, 6091, 397, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

