(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     76647,       1734]*)
(*NotebookOutlinePosition[     77293,       1756]*)
(*  CellTagsIndexPosition[     77249,       1752]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Mortality in the Barro-Becker Model", "Title"],

Cell["The utility function:", "Text"],

Cell[BoxData[
    \(u[N_] := \((w - N\ f - s\ N\ p)\)\^\(1 - \[Sigma]\)\/\(1 - \[Sigma]\) + \
\[Beta]\ \(\((s\ N)\)\^\(\(\ \)\(\[Epsilon]\)\)\) V\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(assu = {0 < \[Beta] < 1, 0 < \[Epsilon] < 1, 
        0 < \[Sigma] < 1}\)], "Input"],

Cell[BoxData[
    \({0 < \[Beta] < 1, 0 < \[Epsilon] < 1, 0 < \[Sigma] < 1}\)], "Output"]
}, Open  ]],

Cell["The first-order condition:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foc = FullSimplify[D[u[N], N]]\)], "Input"],

Cell[BoxData[
    \(\(-\((f + 
              p\ s)\)\)\ \((\(-N\)\ \((f + p\ s)\) + w)\)\^\(-\[Sigma]\) + \(\
\((N\ s)\)\^\[Epsilon]\ V\ \[Beta]\ \[Epsilon]\)\/N\)], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{\(computemax[sin_]\), ":=", 
      RowBox[{"Module", "[", 
        RowBox[{\({local}\), ",", "\[IndentingNewLine]", 
          
          RowBox[{\(par = Join[prepar, {s \[Rule] sin}]\), ";", 
            "\[IndentingNewLine]", \(Nmax = w/\((f + p)\) /. par\), ";", 
            "\[IndentingNewLine]", 
            RowBox[{"Nopt", "=", 
              RowBox[{"FindRoot", "[", 
                RowBox[{\({foc /. par}[\([1]\)] \[Equal] 0\), ",", 
                  RowBox[{"{", 
                    RowBox[{"N", 
                      StyleBox[",",
                        "MR"], ".1", 
                      StyleBox[",",
                        "MR"], "0", 
                      StyleBox[",",
                        "MR"], "Nmax"}], "}"}]}], "]"}]}]}]}], 
        "\[IndentingNewLine]", "]"}]}]], "Input"],

Cell["The following version finds actual steady state utility", "Text"],

Cell[BoxData[
    RowBox[{\(computemaxiter[sin_, Vstart_]\), ":=", 
      RowBox[{"Module", "[", 
        RowBox[{\({local}\), ",", "\[IndentingNewLine]", 
          
          RowBox[{\(Vin = Vstart\), ";", "\[IndentingNewLine]", \(crit = 1\), 
            ";", "\[IndentingNewLine]", 
            RowBox[{"While", "[", 
              RowBox[{\(crit > 0.0001\), ",", "\[IndentingNewLine]", 
                
                RowBox[{\(par = 
                    Join[prepariter, {s \[Rule] sin}, {V \[Rule] \ Vin}]\), 
                  ";", "\[IndentingNewLine]", \(Nmax = w/\((f + p)\) /. par\),
                   ";", "\[IndentingNewLine]", 
                  RowBox[{"Nopt", "=", 
                    RowBox[{"FindRoot", "[", 
                      RowBox[{\({foc /. par}[\([1]\)] \[Equal] 0\), ",", 
                        RowBox[{"{", 
                          RowBox[{"N", 
                            StyleBox[",",
                              "MR"], ".1", 
                            StyleBox[",",
                              "MR"], "0", 
                            StyleBox[",",
                              "MR"], "Nmax"}], "}"}]}], "]"}]}], ";", 
                  "\[IndentingNewLine]", \(Vnew = 
                    u[N /. computemax[sin]] /. par\), ";", 
                  "\[IndentingNewLine]", 
                  "\[IndentingNewLine]", \(crit = Abs[Vnew - Vin]\), ";", 
                  "\[IndentingNewLine]", \(Vin = Vnew\), ";"}]}], 
              "\[IndentingNewLine]", "]"}], ";", 
            "\[IndentingNewLine]", \(par = 
              Join[prepariter, {s \[Rule] sin}, {V \[Rule] \ Vin}]\), ";", 
            "\[IndentingNewLine]", \(Nmax = w/\((f + p)\) /. par\), ";", 
            "\[IndentingNewLine]", 
            RowBox[{"Nopt", "=", 
              RowBox[{"FindRoot", "[", 
                RowBox[{\({foc /. par}[\([1]\)] \[Equal] 0\), ",", 
                  RowBox[{"{", 
                    RowBox[{"N", 
                      StyleBox[",",
                        "MR"], ".1", 
                      StyleBox[",",
                        "MR"], "0", 
                      StyleBox[",",
                        "MR"], "Nmax"}], "}"}]}], "]"}]}], ";", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", "Nopt"}]}], 
        "\[IndentingNewLine]", "]"}]}]], "Input"],

Cell["Hitting the required fertility level of 5:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Vset =  .2;\)\), "\[IndentingNewLine]", 
    \(\(Vlo =  .1;\)\), "\[IndentingNewLine]", 
    \(\(Vhi = 1;\)\), "\[IndentingNewLine]", 
    \(\(NTarget = 5;\)\), "\[IndentingNewLine]", 
    \(\(it = 1;\)\), "\[IndentingNewLine]", 
    \(While[
      it < 30, \[IndentingNewLine]prepar = {\[Sigma] \[Rule]  .5, \[Epsilon] \
\[Rule]  .5, \[Beta] \[Rule] 1, f \[Rule] 1/12, p \[Rule] 5/12, 
          V \[Rule] Vset, 
          w \[Rule] 
            14}; \[IndentingNewLine]\[IndentingNewLine]If[\((N /. 
              computemax[ .73])\) > NTarget, Vhi = Vset; 
        Vset =  .5\ Vset\  + \  .5\ Vlo, Vlo = Vset; 
        Vset =  .5\ Vset\  + \  .5\ Vhi]; \[IndentingNewLine]\
\[IndentingNewLine]it = it + 1\[IndentingNewLine]]\), "\[IndentingNewLine]", 
    \(\(prepar = {\[Sigma] \[Rule]  .5, \[Epsilon] \[Rule]  .5, \[Beta] \
\[Rule] 1, f \[Rule] 1/12, p \[Rule] 5/12, V \[Rule] Vset, 
          w \[Rule] 14};\)\), "\[IndentingNewLine]", 
    \({N /. computemax[ .73],  .73\ N /. computemax[ .73], 
      u[N /. computemax[ .73]] /. par, \((V/u[N /. computemax[ .73]])\) /. 
        par}\), "\[IndentingNewLine]", 
    \({N /. computemax[ .965],  .965\ N /. computemax[ .965], 
      u[N /. computemax[ .965]] /. par, \((V/u[N /. computemax[ .965]])\) /. 
        par}\), "\[IndentingNewLine]", 
    \(\(bbplot = 
        Plot[{N /. computemax[s], s\ {N /. computemax[s]}}, {s, 0.01,  .99}, 
          PlotRange \[Rule] {{0, 1}, {0, 10}}, 
          AxesLabel \[Rule] {"\<s\>", "\<Children\>"}, 
          PlotStyle \[Rule] {{Thickness[ .008]}, {Dashing[{ .02,  .02}], 
                Thickness[ .008]}}];\)\)}], "Input"],

Cell[BoxData[
    \({5.000000001966851`, 3.6500000014358007`, 8.061936409504199`, 
      0.07243813220676829`}\)], "Output"],

Cell[BoxData[
    \({4.179985297764595`, 4.033685812342834`, 8.092707585421957`, 
      0.07216269824529616`}\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.0618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(10)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.01 .09542 m
.01924 .16707 L
.02935 .23106 L
.04976 .32567 L
.0606 .36195 L
.0722 .39276 L
.09311 .43242 L
.10363 .44646 L
.11504 .45828 L
.12581 .46674 L
.13576 .47261 L
.14055 .47487 L
.14571 .47693 L
.15503 .47977 L
.16071 .48101 L
.16351 .48149 L
.16611 .48187 L
.17096 .48241 L
.17352 .48261 L
.17482 .48269 L
.17625 .48277 L
.17764 .48282 L
.17893 .48286 L
.17965 .48288 L
.1803 .48289 L
.18105 .4829 L
.18176 .4829 L
.18303 .4829 L
.18419 .48289 L
.18547 .48286 L
.18612 .48285 L
.18684 .48283 L
.18968 .48271 L
.19128 .48262 L
.19274 .48252 L
.19828 .48204 L
.20311 .48149 L
.2084 .48074 L
.21904 .47885 L
.23922 .47409 L
.26078 .46775 L
.30348 .45287 L
.34462 .43711 L
.3842 .42162 L
.42631 .40535 L
.46685 .3902 L
.50584 .37626 L
.54735 .36215 L
.5873 .3493 L
.62977 .33642 L
Mistroke
.67069 .32475 L
.71004 .31416 L
.75192 .30354 L
.79224 .29391 L
.83508 .28427 L
.87636 .27552 L
.91608 .26757 L
.95833 .25956 L
.99 .25385 L
Mfstroke
[ .02 .02 ] 0 setdash
.01 .00095 m
.01478 .00198 L
.01924 .00321 L
.02935 .00678 L
.04976 .0162 L
.09311 .04026 L
.13324 .06279 L
.17588 .08491 L
.21697 .10398 L
.2565 .12032 L
.29855 .13575 L
.33904 .14894 L
.37798 .16028 L
.41943 .17112 L
.45933 .1805 L
.50175 .18951 L
.54261 .19736 L
.58191 .20425 L
.62373 .21095 L
.664 .21687 L
.70679 .22265 L
.74801 .22777 L
.78768 .23234 L
.82987 .23686 L
.87051 .2409 L
.90958 .24453 L
.95118 .24815 L
.99 .25131 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{359.375, 222.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005W0000gR000`400?l00000o`00003oo`3ooomX
0?ooo`00E@3oool2000000@0oooo0P0000030?ooo`@00000;@3oool2000000@0oooo0P0000050?oo
o`<00000;@3oool2000000@0oooo0P0000030?ooo`<00000;`3oool2000000@0oooo0P0000040?oo
o`800000=03oool5000001D0oooo001D0?ooo`040000003oool0oooo000000P0oooo00<000000?oo
o`3oool0;@3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo02/0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool00000=@3oool00`000000oooo0?ooo`0E0?ooo`00E03oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo02`0oooo00@000000?ooo`3oool00000203oool5
000002`0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000]0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool00000=@3oool00`000000oooo0?ooo`0E0?oo
o`00E03oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo02/0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo000000P0oooo
0`00000^0?ooo`040000003oool0oooo000000T0oooo0P00000f0?ooo`030000003oool0oooo01D0
oooo001D0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000;03oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0000002d0oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo0?ooo`0]0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000=@3oool00`000000oooo0?ooo`0E0?ooo`00E@3oool2000000X0oooo0P00000^0?ooo`800000
2`3oool2000002h0oooo0P00000:0?ooo`<00000;P3oool2000000X0oooo0P00000e0?ooo`800000
5`3oool00?l0ooooJ03oool00?l0ooooJ03oool00?l0ooooJ03oool00?l0ooooJ03oool00?l0oooo
J03oool00280oooo00<000000?ooo`3oool0o`3ooolf0?ooo`<000002P3oool001l0ooooo`00000b
000000d0oooo00<000000?ooo`3oool01`3oool001l0oooo00<000000?ooo`3oool01`0000050?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool3000000X0oooo000O0?ooo`03
0000003oool0oooo00P00000<P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03X0
oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00P0
oooo100000090?ooo`007`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo
?@3oool001l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooocL0oooo000O
0?ooo`030000003oool0oooo00X0oooo1000003o0?ooocP0oooo000O0?ooo`030000003oool0oooo
00X0oooo1P00003o0?ooocH0oooo000O0?ooo`030000003oool0oooo00d0oooo1000003o0?ooocD0
oooo000O0?ooo`030000003oool0oooo00l0oooo0`00003o0?oooc@0oooo000O0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0o`3ooolc0?ooo`007`3oool2000001L0oooo00<00000
0?ooo`3oool0o`3oool]0?ooo`007`3oool00`000000oooo0?ooo`0E0?ooo`D00000o`3oool/0?oo
o`007`3oool00`000000oooo0?ooo`0F0?ooo`D00000o`3oool[0?ooo`007`3oool00`000000oooo
0?ooo`0I0?ooo`<00000o`3ooolZ0?ooo`007`3oool00`000000oooo0?ooo`0J0?ooo`<00000o`3o
oolY0?ooo`007`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0?l0oooo:03oool0
01l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`3o0?ooob<0oooo000O0?ooo`03
0000003oool0oooo01l0oooo1000003o0?ooob<0oooo000O0?ooo`030000003oool0oooo0200oooo
1P00003o0?ooob00oooo000O0?ooo`8000008`3oool500000?l0oooo7`3oool001l0oooo00<00000
0?ooo`3oool09@3oool300000?l0oooo7P3oool001l0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo603oool001l0oooo00<000000?ooo`3o
ool0:P3oool400000?l0oooo603oool001l0oooo00<000000?ooo`3oool0:`3oool400000?l0oooo
5`3oool001l0oooo00<000000?ooo`3oool0;@3oool400000?l0oooo5@3oool001l0oooo00<00000
0?ooo`3oool0;P3oool400000?l0oooo503oool001l0oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`3o0?oooa<0oooo000O0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool0o`3oool=0?ooo`007`3oool2000003H0oooo1000003o0?ooo`d0oooo000O0?ooo`030000003o
ool0oooo00800000=03oool600000?l0oooo2P3oool001l0oooo00<000000?ooo`3oool00P00000f
0?ooo`D00000o`3oool90?ooo`007`3oool00`000000oooo0?ooo`02000003T0oooo00<000000?oo
o`3oool0o`3oool80?ooo`007`3oool00`000000oooo0?ooo`02000003l0oooo00<000000?ooo`3o
ool0o`3oool20?ooo`007`3oool00`000000oooo0?ooo`02000003h0oooo1@00003o0?ooo`40oooo
000O0?ooo`030000003oool0oooo00800000?`3oool700000?d0oooo000O0?ooo`030000003oool0
oooo00800000@P3oool500000?`0oooo000F0?ooo`@000001@3oool00`000000oooo0?ooo`020000
04D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3f0?ooo`005P3oool00`000000
oooo0?ooo`060?ooo`040000003oool0oooo0?ooo`800000B03oool400000?H0oooo000G0?ooo`03
0000003oool0oooo00D0oooo0`0000000`3oool00000000000190?ooo`D00000m03oool001P0oooo
00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool2000004/0oooo1@00003b0?ooo`00
5P3oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo0?ooo`800000C@3oool40000
0?40oooo000G0?ooo`8000001P3oool010000000oooo0?ooo`3oool2000004l0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`3Z0?ooo`007`3oool010000000oooo0?ooo`3oool20000
05@0oooo1@00003Y0?ooo`007`3oool010000000oooo0?ooo`3oool2000005D0oooo1`00003V0?oo
o`007`3oool00`000000oooo0?ooo`020?ooo`800000E`3oool5000000<0oooo00<000000?ooo`3o
ool0g`3oool001l0oooo00<000000?ooo`3oool00P3oool2000005X0oooo00@000000?ooo`3oool0
oooo0`00003P0?ooo`007`3oool00`000000oooo0?ooo`020?ooo`800000G`3oool700000=/0oooo
000O0?ooo`8000000`3oool200000600oooo1P00003K0?ooo`007`3oool00`000000oooo0?ooo`02
0?ooo`800000J`3oool00`000000oooo0?ooo`3C0?ooo`007`3oool00`000000oooo0?ooo`020?oo
o`800000JP3oool800000<l0oooo000O0?ooo`030000003oool0oooo0080oooo0P00001Z0?ooo`P0
0000c`3oool001l0oooo00<000000?ooo`3oool00P3oool2000007L0oooo00<000000?ooo`3oool0
a`3oool001l0oooo00<000000?ooo`3oool00`3oool2000007D0oooo200000330?ooo`007`3oool0
0`000000oooo0?ooo`030?ooo`800000M@3oool800000<<0oooo000O0?ooo`030000003oool0oooo
00<0oooo0P0000230?ooo`030000003oool0oooo0;X0oooo000O0?ooo`030000003oool0oooo00<0
oooo0P0000210?ooo`L00000^03oool001l0oooo00<000000?ooo`3oool00`3oool200000840oooo
200000050?ooo`030000003oool0oooo0:l0oooo000O0?ooo`800000103oool2000008P0oooo00<0
00000?ooo`3oool00P3oool400000:l0oooo000O0?ooo`030000003oool0oooo00@0oooo0P00002=
0?ooo`L00000Z`3oool001l0oooo00<000000?ooo`3oool0103oool2000008h0oooo1P0000080?oo
o`030000003oool0oooo0:00oooo000O0?ooo`030000003oool0oooo00@0oooo0P00002G0?ooo`P0
0000X03oool001l0oooo00<000000?ooo`3oool0103oool2000009L0oooo2@0000080?ooo`030000
003oool0oooo09@0oooo000O0?ooo`030000003oool0oooo00@0oooo0P00002N0?ooo`030000003o
ool0oooo0080oooo2000002D0?ooo`007`3oool00`000000oooo0?ooo`040?ooo`800000X`3oool9
000000T0oooo00<000000?ooo`3oool0Q`3oool001l0oooo00<000000?ooo`3oool0103oool20000
0:X0oooo00<000000?ooo`3oool00P3oool8000008P0oooo000O0?ooo`030000003oool0oooo00D0
oooo0P00002^0?ooo`T00000Q`3oool001l0oooo0P0000060?ooo`800000]@3oool00`000000oooo
0?ooo`030?ooo`P00000103oool00`000000oooo0?ooo`1d0?ooo`007`3oool00`000000oooo0?oo
o`050?ooo`800000^`3oool8000000@0oooo1`00001`0?ooo`007`3oool00`000000oooo0?ooo`05
0?ooo`800000b03oool7000000@0oooo00<000000?ooo`3oool0J03oool001l0oooo00<000000?oo
o`3oool01@3oool200000<`0oooo0`0000040?ooo`L000001@3oool00`000000oooo0?ooo`1L0?oo
o`007`3oool00`000000oooo0?ooo`050?ooo`800000e03oool7000000@0oooo1`00001H0?ooo`00
7`3oool00`000000oooo0?ooo`050?ooo`800000f03oool3000000D0oooo1`00001G0?ooo`007`3o
ool00`000000oooo0?ooo`060?ooo`800000h`3oool3000000@0oooo2000001;0?ooo`00603oool3
000000@0oooo00<000000?ooo`3oool01P3oool200000>X0oooo200000040?ooo`P00000103oool2
000003T0oooo000I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool20000
0?H0oooo200000040?ooo`L000001@3oool2000002d0oooo000F0?ooo`D00000103oool3000000H0
oooo0P00003o0?ooo`D0oooo1P0000040?ooo`L000001@3oool200000240oooo000F0?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`3oool01`3oool200000?l0oooo2@3oool00`000000
oooo0?ooo`040?ooo`H00000103oool7000001`0oooo000G0?ooo`030000003oool0000000D0oooo
00<000000?ooo`3oool01`3oool200000?l0oooo5@3oool00`000000oooo0?ooo`040?ooo`L00000
6P3oool001P0oooo0P0000050?ooo`030000003oool0oooo00L0oooo0P00003o0?oooaP0oooo2`00
000J0?ooo`007`3oool00`000000oooo0?ooo`070?ooo`800000o`3ooolD0?ooo`X000007`3oool0
01l0oooo00<000000?ooo`3oool01`3oool200000?l0oooo403oool8000002D0oooo000O0?ooo`03
0000003oool0oooo00P0oooo0P00003o0?ooo`/0oooo2000000Y0?ooo`007`3oool00`000000oooo
0?ooo`080?ooo`800000o`3oool50?ooo`X00000;@3oool001l0oooo00<000000?ooo`3oool0203o
ool200000?d0oooo3@00000a0?ooo`007`3oool00`000000oooo0?ooo`080?ooo`800000n@3oool;
000003L0oooo000O0?ooo`8000002@3oool200000?D0oooo2000000n0?ooo`007`3oool00`000000
oooo0?ooo`090?ooo`800000l03oool800000480oooo000O0?ooo`030000003oool0oooo00T0oooo
0P00003/0?ooo`P00000AP3oool001l0oooo00<000000?ooo`3oool02@3oool200000>P0oooo2000
001:0?ooo`007`3oool00`000000oooo0?ooo`090?ooo`800000h`3oool9000004h0oooo000O0?oo
o`030000003oool0oooo00X0oooo0P00003N0?ooo`T00000DP3oool001l0oooo00<000000?ooo`3o
ool02P3oool200000=X0oooo2000001G0?ooo`007`3oool00`000000oooo0?ooo`0:0?ooo`800000
eP3oool8000005/0oooo000O0?ooo`030000003oool0oooo00X0oooo0P00003B0?ooo`P00000G`3o
ool001l0oooo0P00000;0?ooo`800000cP3oool8000006<0oooo000O0?ooo`030000003oool0oooo
00/0oooo0P0000380?ooo`T00000I`3oool001l0oooo00<000000?ooo`3oool02`3oool200000<@0
oooo2@00001[0?ooo`007`3oool00`000000oooo0?ooo`0;0?ooo`800000`03oool800000700oooo
000O0?ooo`030000003oool0oooo00/0oooo0P00002l0?ooo`P00000M03oool001l0oooo00<00000
0?ooo`3oool02`3oool300000;P0oooo1`00001h0?ooo`007`3oool00`000000oooo0?ooo`0<0?oo
o`800000]@3oool6000007`0oooo000O0?ooo`030000003oool0oooo00`0oooo0P00002b0?ooo`H0
0000O`3oool001l0oooo00<000000?ooo`3oool0303oool200000:h0oooo1`0000220?ooo`007`3o
ool00`000000oooo0?ooo`0<0?ooo`<00000ZP3oool7000008D0oooo000O0?ooo`8000003P3oool2
00000:L0oooo1`0000280?ooo`007`3oool00`000000oooo0?ooo`0=0?ooo`800000Y03oool60000
08`0oooo000O0?ooo`030000003oool0oooo00d0oooo0`00002O0?ooo`L00000S`3oool001l0oooo
00<000000?ooo`3oool03P3oool2000009/0oooo2000002B0?ooo`007`3oool00`000000oooo0?oo
o`0>0?ooo`800000U`3oool8000009H0oooo000O0?ooo`030000003oool0oooo00h0oooo0P00002C
0?ooo`P00000VP3oool001l0oooo00<000000?ooo`3oool03P3oool300000900oooo1P00002N0?oo
o`005P3oool3000000H0oooo00<000000?ooo`3oool03`3oool2000008d0oooo1P00002Q0?ooo`00
5P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00l0oooo0P00002;0?ooo`H0
0000X`3oool001H0oooo00@000000?ooo`3oool000001@3oool3000000l0oooo0`0000270?ooo`H0
0000YP3oool001H0oooo0`0000060?ooo`030000003oool0oooo0100oooo0P0000250?ooo`H00000
Z03oool001L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`<00000P@3o
ool600000:/0oooo000G0?ooo`<000001@3oool00`000000oooo0?ooo`0A0?ooo`800000OP3oool7
00000:d0oooo000O0?ooo`030000003oool0oooo0140oooo0P00001k0?ooo`L00000/03oool001l0
oooo00<000000?ooo`3oool04P3oool2000007L0oooo1`00002c0?ooo`007`3oool00`000000oooo
0?ooo`0B0?ooo`800000M03oool700000;H0oooo000O0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0L03oool600000;T0oooo000O0?ooo`030000003oool0oooo01<0oooo0P00001^
0?ooo`H00000_03oool001l0oooo0P00000E0?ooo`030000003oool0oooo06X0oooo1P00002n0?oo
o`007`3oool00`000000oooo0?ooo`0D0?ooo`800000J03oool600000<40oooo000O0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool0I03oool600000<<0oooo000O0?ooo`030000003o
ool0oooo01D0oooo0P00001R0?ooo`H00000aP3oool001l0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`1N0?ooo`H00000b03oool001l0oooo00<000000?ooo`3oool05P3oool20000
05`0oooo1P00003;0?ooo`007`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo05P0
oooo1P00003=0?ooo`007`3oool00`000000oooo0?ooo`0G0?ooo`800000EP3oool600000=00oooo
000O0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0D@3oool700000=80oooo000O
0?ooo`030000003oool0oooo01P0oooo0P00001?0?ooo`L00000e@3oool001l0oooo0P00000J0?oo
o`030000003oool0oooo04X0oooo1`00003H0?ooo`007`3oool00`000000oooo0?ooo`0I0?ooo`80
0000B03oool700000=/0oooo000O0?ooo`030000003oool0oooo01X0oooo0P0000150?ooo`H00000
gP3oool001l0oooo00<000000?ooo`3oool06`3oool200000440oooo1P00003Q0?ooo`007`3oool0
0`000000oooo0?ooo`0L0?ooo`800000?P3oool600000><0oooo000O0?ooo`030000003oool0oooo
01`0oooo0`00000j0?ooo`H00000iP3oool001l0oooo00<000000?ooo`3oool07@3oool3000003H0
oooo1`00003X0?ooo`007`3oool00`000000oooo0?ooo`0N0?ooo`<00000<`3oool600000>/0oooo
000O0?ooo`030000003oool0oooo01l0oooo0`00000_0?ooo`H00000kP3oool001l0oooo0P00000Q
0?ooo`@00000:`3oool600000?00oooo000O0?ooo`030000003oool0oooo0240oooo1000000W0?oo
o`H00000l`3oool001l0oooo00<000000?ooo`3oool08`3oool400000280oooo1`00003e0?ooo`00
7`3oool00`000000oooo0?ooo`0T0?ooo`@000007@3oool700000?T0oooo000O0?ooo`030000003o
ool0oooo02H0oooo1`00000B0?ooo`X00000o03oool001l0oooo00<000000?ooo`3oool09`3oool8
000000d0oooo2@00003o0?ooo`40oooo000O0?ooo`030000003oool0oooo02`0oooo5000003o0?oo
o`H0oooo000O0?ooo`030000003oool0oooo02h0oooo3`00003o0?ooo`T0oooo000G0?ooo`800000
1P3oool00`000000oooo0?ooo`3o0?ooodH0oooo000F0?ooo`040000003oool0oooo000000D0oooo
00<000000?ooo`3oool0o`3ooom60?ooo`005P3oool010000000oooo0?ooo`0000050?ooo`<00000
o`3ooom60?ooo`005`3oool2000000H0oooo00<000000?ooo`3oool0o`3ooom60?ooo`005P3oool0
10000000oooo0?ooo`0000050?ooo`030000003oool0oooo0?l0ooooAP3oool001L0oooo0P000006
0?ooo`030000003oool0oooo0?l0ooooAP3oool001l0oooo00<000000?ooo`3oool0o`3ooom60?oo
o`007`3oool00`000000oooo0?ooo`3o0?ooodH0oooo000O0?ooo`030000003oool0oooo0?l0oooo
AP3oool001l0oooo00<000000?ooo`3oool0o`3ooom60?ooo`007`3oool00`000000oooo0?ooo`3o
0?ooodH0oooo000O0?ooo`800000o`3ooom70?ooo`007`3oool00`000000oooo0?ooo`3o0?ooodH0
oooo000O0?ooo`030000003oool0oooo0?l0ooooAP3oool001l0oooo00<000000?ooo`3oool0o`3o
oom60?ooo`007`3oool00`000000oooo0?ooo`3o0?ooodH0oooo000O0?ooo`030000003oool0oooo
0?l0ooooAP3oool001l0oooo00<000000?ooo`3oool0o`3ooom60?ooo`007`3oool00`000000oooo
0?ooo`3o0?ooodH0oooo000O0?ooo`030000003oool0oooo0?l0ooooAP3oool001l0oooo00<00000
0?ooo`3oool0o`3ooom60?ooo`007`3oool200000?l0ooooA`3oool001l0oooo00<000000?ooo`3o
ool0o`3ooom60?ooo`007`3oool00`000000oooo0?ooo`3o0?ooodH0oooo000O0?ooo`030000003o
ool0oooo0?l0ooooAP3oool001l0oooo00<000000?ooo`3oool0o`3ooom60?ooo`007`3oool00`00
0000oooo0?ooo`3o0?ooodH0oooo000O0?ooo`030000003oool0oooo0?l0ooooAP3oool001l0oooo
00<000000?ooo`3oool0o`3ooom60?ooo`007`3oool00`000000oooo0?ooo`3o0?ooodH0oooo000O
0?ooo`800000o`3ooom70?ooo`007`3oool00`000000oooo0?ooo`3o0?ooodH0oooo000O0?ooo`03
0000003oool0oooo0?l0ooooAP3oool001l0oooo00<000000?ooo`3oool0o`3ooom60?ooo`007`3o
ool00`000000oooo0?ooo`3o0?ooodH0oooo000O0?ooo`030000003oool0oooo0?l0ooooAP3oool0
01l0oooo00<000000?ooo`3oool0o`3ooom60?ooo`00403oool500000080oooo0P0000060?ooo`03
0000003oool0oooo0?l0ooooAP3oool00180oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooom60?ooo`004P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool00`3oool300000?l0ooooAP3oool00180oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0?l0ooooC03oool00180oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0?l0ooooC03oool00140oooo
0P0000040?ooo`800000o`3ooom?0?ooo`00o`3ooomX0?ooo`00o`3ooomX0?ooo`00o`3ooomX0?oo
o`00o`3ooomX0?ooo`00o`3ooomX0?ooo`00o`3ooomX0?ooo`00o`3ooomX0?ooo`00o`3ooomX0?oo
o`00o`3ooomX0?ooo`002@3oool3000000050?ooo`00000000000000003oool00P0000020?ooo`<0
00000P3oool3000000@0oooo100000000`3oool0000000000002000000<0oooo0`0000000`3oool0
0000000000020?ooo`800000o`3ooola0?ooo`00203oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000?l0oooo<P3oool000P0oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo100000020?ooo`040000003o
ool0oooo00000?l0oooo<P3oool000P0oooo00<000000?ooo`3oool00`3oool3000000@0oooo0P00
00040?ooo`030000003oool0oooo00<0oooo0`0000020?ooo`@000000`3oool200000080oooo1000
003o0?oooc<0oooo00080?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo@P3oool000T0oooo0`000000
0`3oool00000000000070?ooo`040000003oool0oooo0?ooo`8000001P3oool200000?l0ooooA03o
ool00?l0ooooJ03oool00?l0ooooJ03oool00001\
\>"],
  ImageRangeCache->{{{0, 358.375}, {221.125, 0}} -> {-0.102386, -0.68066, \
0.00328487, 0.0531503}}]
}, Open  ]],

Cell[BoxData[{
    \(\(SetDirectory["\<c:/temp\>"];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<bbplot.eps\>", bbplot, "\<EPS\>"];\)\)}], "Input"],

Cell["\<\
Below, I do the case where utility adjusts to the new (higher) steady state. \
That is a more complicated problem. Before I did not actually solve the \
fixed-point problem, because beta could be adjusted arbitrarily.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ By\ now\ we\ have\ the\ correct\ Vset\ *) \[IndentingNewLine] (*\ 
      Compute\ the\ corresponding\ utility\ and\ beta\ *) \[IndentingNewLine]\
\(prepar = {\[Sigma] \[Rule]  .5, \[Epsilon] \[Rule]  .5, \[Beta] \[Rule] 1, 
          f \[Rule] 1/12, p \[Rule] 5/12, V \[Rule] Vset, 
          w \[Rule] 14};\)\), "\[IndentingNewLine]", 
    \(\(par = Join[prepar, {s \[Rule]  .73}];\)\), "\[IndentingNewLine]", 
    \(\(Vact = 
        u[N /. computemax[ .73]] /. 
          par;\)\[IndentingNewLine]\[IndentingNewLine] (*\ 
      Want : \ Vact = Vset/trubeta\ *) \[IndentingNewLine] (*\ 
      The\ correct\ beta\ is\ below\ *) \), "\[IndentingNewLine]", 
    \(trubeta = Vset/Vact\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[
    \(0.07243813220676829`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ 
      Now\ we\ plug\ in\ the\ correct\ beta\ and\ do\ everything\ again\ with\
\ adjusting\ V\ *) \[IndentingNewLine] (*\ 
      The\ point\ is\ to\ adjust\ utility\ for\ the\ positive\ effect\ of\ \
lower\ mortality\ *) \[IndentingNewLine] (*\ 
      prepar\ iter\ does\ not\ contain\ a\ value\ for\ utility\ *) \ \
\[IndentingNewLine]\(prepar = {\[Sigma] \[Rule]  .5, \[Epsilon] \[Rule]  .5, \
\[Beta] \[Rule] 1, f \[Rule] 1/12, p \[Rule] 5/12, V \[Rule] Vset, 
          w \[Rule] 14};\)\), "\[IndentingNewLine]", 
    \(\(prepariter = {\[Sigma] \[Rule]  .5, \[Epsilon] \[Rule]  .5, \[Beta] \
\[Rule] trubeta, f \[Rule] 1/12, p \[Rule] 5/12, 
          w \[Rule] 14};\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(bbplot = 
        Plot[{N /. computemax[s], s\ {N /. computemax[s]}, 
            N /. computemaxiter[s, Vact], 
            s\ {N /. computemaxiter[s, Vact]}}, {s, 0.01,  .99}, 
          PlotRange \[Rule] {{0, 1}, {0, 10}}, 
          AxesLabel \[Rule] {"\<s\>", "\<Children\>"}, 
          PlotStyle \[Rule] {{Thickness[ .001]}, {Dashing[{ .02,  .02}], 
                Thickness[ .001]}}];\)\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.0618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(10)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
.01 .09542 m
.01924 .16707 L
.02935 .23106 L
.04976 .32567 L
.0606 .36195 L
.0722 .39276 L
.09311 .43242 L
.10363 .44646 L
.11504 .45828 L
.12581 .46674 L
.13576 .47261 L
.14055 .47487 L
.14571 .47693 L
.15503 .47977 L
.16071 .48101 L
.16351 .48149 L
.16611 .48187 L
.17096 .48241 L
.17352 .48261 L
.17482 .48269 L
.17625 .48277 L
.17764 .48282 L
.17893 .48286 L
.17965 .48288 L
.1803 .48289 L
.18105 .4829 L
.18176 .4829 L
.18303 .4829 L
.18419 .48289 L
.18547 .48286 L
.18612 .48285 L
.18684 .48283 L
.18968 .48271 L
.19128 .48262 L
.19274 .48252 L
.19828 .48204 L
.20311 .48149 L
.2084 .48074 L
.21904 .47885 L
.23922 .47409 L
.26078 .46775 L
.30348 .45287 L
.34462 .43711 L
.3842 .42162 L
.42631 .40535 L
.46685 .3902 L
.50584 .37626 L
.54735 .36215 L
.5873 .3493 L
.62977 .33642 L
Mistroke
.67069 .32475 L
.71004 .31416 L
.75192 .30354 L
.79224 .29391 L
.83508 .28427 L
.87636 .27552 L
.91608 .26757 L
.95833 .25956 L
.99 .25385 L
Mfstroke
[ .02 .02 ] 0 setdash
.01 .00095 m
.01478 .00198 L
.01924 .00321 L
.02935 .00678 L
.04976 .0162 L
.09311 .04026 L
.13324 .06279 L
.17588 .08491 L
.21697 .10398 L
.2565 .12032 L
.29855 .13575 L
.33904 .14894 L
.37798 .16028 L
.41943 .17112 L
.45933 .1805 L
.50175 .18951 L
.54261 .19736 L
.58191 .20425 L
.62373 .21095 L
.664 .21687 L
.70679 .22265 L
.74801 .22777 L
.78768 .23234 L
.82987 .23686 L
.87051 .2409 L
.90958 .24453 L
.95118 .24815 L
.99 .25131 L
s
[ ] 0 setdash
.01 .08312 m
.01924 .14685 L
.02935 .20491 L
.04976 .29322 L
.0606 .32815 L
.0722 .35846 L
.09311 .3988 L
.10363 .41365 L
.11504 .42656 L
.1249 .43544 L
.13576 .44317 L
.1463 .44893 L
.15617 .453 L
.1666 .45611 L
.17245 .4574 L
.17781 .4583 L
.18272 .45893 L
.18541 .4592 L
.18794 .4594 L
.19031 .45956 L
.19156 .45962 L
.19288 .45968 L
.19399 .45972 L
.1952 .45975 L
.19631 .45977 L
.19735 .45979 L
.19867 .4598 L
.19942 .4598 L
.20011 .4598 L
.20138 .45978 L
.20273 .45976 L
.20393 .45973 L
.20506 .4597 L
.20764 .4596 L
.21041 .45945 L
.21295 .45928 L
.21867 .45879 L
.22876 .45759 L
.23814 .45613 L
.25945 .45181 L
.29962 .44103 L
.34232 .42746 L
.38347 .41351 L
.42305 .39991 L
.46515 .38566 L
.5057 .37235 L
.54468 .36005 L
.58619 .34754 L
.62614 .3361 L
.66862 .32457 L
Mistroke
.70953 .31406 L
.74889 .30449 L
.79076 .29484 L
.83108 .28606 L
.87392 .27723 L
.91521 .26918 L
.95493 .26183 L
.99 .25565 L
Mfstroke
[ .02 .02 ] 0 setdash
.01 .00083 m
.01478 .00174 L
.01924 .00282 L
.02935 .00601 L
.04976 .01459 L
.09311 .03713 L
.13324 .05883 L
.17588 .08056 L
.21697 .09958 L
.2565 .11606 L
.29855 .13177 L
.33904 .1453 L
.37798 .15701 L
.41943 .16825 L
.45933 .17804 L
.50175 .18746 L
.54261 .19571 L
.58191 .20297 L
.62373 .21006 L
.664 .21632 L
.70679 .22246 L
.74801 .22791 L
.78768 .23279 L
.82987 .23761 L
.87051 .24193 L
.90958 .24581 L
.95118 .24969 L
.99 .25309 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{683.063, 422.188},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:[0001YR000`400?l00000o`00003oo`3ooooo
0?ooojd0oooo002G0?ooo`800000103oool2000000<0oooo1000001[0?ooo`800000103oool20000
00D0oooo0`00001Z0?ooo`800000103oool2000000<0oooo0`00001/0?ooo`800000103oool20000
00@0oooo0P00001a0?ooo`D000008P3oool009H0oooo00@000000?ooo`3oool00000203oool00`00
0000oooo0?ooo`1[0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0J03oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo000006X0oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`00001b0?ooo`030000003oool0oooo0280oooo002F0?ooo`04
0000003oool0oooo000000T0oooo00<000000?ooo`3oool0JP3oool010000000oooo0?ooo`000008
0?ooo`D00000J@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000006X0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00001b0?ooo`030000003oool0oooo
0280oooo002F0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0J@3oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo000006X0oooo00@000000?ooo`3oool00000
203oool3000006/0oooo00@000000?ooo`3oool000002@3oool2000007<0oooo00<000000?ooo`3o
ool08P3oool009H0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00001Z0?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`000000JP3oool010000000oooo0?ooo`00
00090?ooo`030000003oool0oooo06X0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00001b0?ooo`030000003oool0oooo0280oooo002G0?ooo`8000002P3oool2000006`0oooo
0P00000;0?ooo`800000J`3oool2000000X0oooo0`00001[0?ooo`8000002P3oool200000780oooo
0P00000T0?ooo`00o`3ooooo0?ooojd0oooo003o0?ooool0oooo[@3oool00?l0ooooo`3ooon]0?oo
o`00o`3ooooo0?ooojd0oooo003o0?ooool0oooo[@3oool00?l0ooooo`3ooon]0?ooo`00o`3ooooo
0?ooojd0oooo003o0?ooool0oooo[@3oool00?l0ooooo`3ooonJ0?ooo`<00000403oool00?l0oooo
o`3ooonM0?ooo`030000003oool0oooo00d0oooo000T0?ooool00000o`00001U00000140oooo0`00
000@0?ooo`00903oool00`000000oooo0?ooo`030?ooo`D00000503oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo00l0oooo1000000?0?ooo`00903oool00`000000oooo0?ooo`080?oo
o`<000004@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0280oooo000T0?ooo`03
0000003oool0oooo00/0oooo0`00001Y0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3o
ool0M`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3o
ool08P3oool002@0oooo00<000000?ooo`3oool03P3oool2000006L0oooo00<000000?ooo`3oool0
M`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0
M`3oool00`000000oooo0?ooo`0R0?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0ooooQP3o
ool002@0oooo00<000000?ooo`3oool0o`3ooooo0?ooohH0oooo000T0?ooo`030000003oool0oooo
0?l0ooooo`3ooon60?ooo`00903oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0?l0
ooooo`3ooomY0?ooo`00903oool00`000000oooo0?ooo`0J0?ooo`800000o`3ooooo0?ooofX0oooo
000T0?ooo`030000003oool0oooo01/0oooo0`00003o0?ooool0ooooJ03oool002@0oooo00<00000
0?ooo`3oool0703oool400000?l0ooooo`3ooomV0?ooo`00903oool00`000000oooo0?ooo`0N0?oo
o`@00000o`3ooooo0?ooof@0oooo000T0?ooo`030000003oool0oooo0200oooo1000003o0?ooool0
ooooHP3oool002@0oooo00<000000?ooo`3oool08P3oool400000?l0ooooo`3ooomP0?ooo`00903o
ool00`000000oooo0?ooo`0T0?ooo`800000o`3ooooo0?ooof00oooo000T0?ooo`030000003oool0
oooo0?l0ooooo`3ooon60?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0ooooQP3oool002@0
oooo00<000000?ooo`3oool0o`3ooooo0?ooohH0oooo000T0?ooo`<00000o`3ooooo0?ooohH0oooo
000T0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0o`3ooooo0?oooe<0oooo000T
0?ooo`030000003oool0oooo02l0oooo1000003o0?ooool0ooooD`3oool002@0oooo00<000000?oo
o`3oool0<@3oool400000?l0ooooo`3ooomA0?ooo`00903oool00`000000oooo0?ooo`0c0?ooo`D0
0000o`3ooooo0?ooodh0oooo000T0?ooo`030000003oool0oooo03D0oooo0P0000000`3oool00000
0000003o0?ooool0ooooC03oool002@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`0200000?l0ooooo`3ooom:0?ooo`00903oool00`000000oooo0?ooo`0h0?ooo`800000o`3ooooo
0?oood`0oooo000T0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0o`3ooooo0?oo
odT0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3ooon60?ooo`00903oool00`000000oooo
0?ooo`3o0?ooool0ooooQP3oool002@0oooo00<000000?ooo`3oool0o`3ooooo0?ooohH0oooo000T
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0o`3ooooo0?oooch0oooo000T0?oo
o`030000003oool0oooo04H0oooo0P00003o0?ooool0oooo?P3oool002@0oooo00<000000?ooo`3o
ool0A@3oool00`000000oooo0?ooo`0200000?l0ooooo`3oooll0?ooo`00903oool00`000000oooo
0?ooo`160?ooo`8000000P3oool200000?l0ooooo`3ooolj0?ooo`00903oool00`000000oooo0?oo
o`180?ooo`8000000P3oool200000?l0ooooo`3ooolh0?ooo`00903oool00`000000oooo0?ooo`1:
0?ooo`8000000P3oool00`000000oooo0?ooo`3o0?ooool0oooo=@3oool002@0oooo00<000000?oo
o`3oool0C03oool2000000030?ooo`00000000000?l0ooooo`3ooole0?ooo`00903oool3000004h0
oooo00<000000?ooo`3oool0o`3ooooo0?ooocD0oooo000T0?ooo`030000003oool0oooo04l0oooo
00<000000?ooo`3oool0o`3ooooo0?oooc@0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3o
oon60?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0ooooQP3oool002@0oooo00<000000?oo
o`3oool0F`3oool00`000000oooo0?ooo`3o0?ooool0oooo:03oool002@0oooo00<000000?ooo`3o
ool0G03oool200000?l0ooooo`3ooolX0?ooo`00903oool00`000000oooo0?ooo`1J0?ooo`040000
003oool0oooo0?ooo`800000o`3ooooo0?ooobH0oooo000T0?ooo`030000003oool0oooo05/0oooo
0P0000030?ooo`800000o`3ooooo0?ooob@0oooo000T0?ooo`030000003oool0oooo05d0oooo0P00
00030?ooo`800000o`3ooooo0?ooob80oooo000T0?ooo`030000003oool0oooo05l0oooo0P000003
0?ooo`800000o`3ooooo0?ooob00oooo000T0?ooo`030000003oool0oooo0640oooo0P0000030?oo
o`030000003oool0oooo0?l0ooooo`3ooolM0?ooo`00903oool00`000000oooo0?ooo`1S0?ooo`80
0000o`3ooooo0?ooob40oooo000T0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0
o`3ooooo0?oooah0oooo000T0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3o
oooo0?oooh00oooo000T0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooooo
0?oooh00oooo000T0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0J`3oool20000
0?l0ooooo`3ooolC0?ooo`00903oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo06d0
oooo0P00003o0?ooool0oooo4@3oool002@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`1Y0?ooo`8000000`3oool200000?l0ooooo`3oool?0?ooo`00903oool3000000@0oooo00<0
00000?ooo`3oool0J`3oool2000000<0oooo0P00003o0?ooool0oooo3@3oool002@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`1]0?ooo`8000000`3oool200000?l0ooooo`3oool;
0?ooo`00903oool00`000000oooo0?ooo`030?ooo`800000L@3oool2000000<0oooo0P00003o0?oo
ool0oooo2@3oool002@0oooo00<000000?ooo`3oool00`3oool2000007<0oooo0P00003o0?ooool0
oooo303oool002@0oooo00<000000?ooo`3oool00`3oool2000007D0oooo0P00003o0?ooool0oooo
2P3oool002@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000003o0?ooool0ooooP03o
ool002@0oooo00<000000?ooo`3oool0103oool200000?l0ooooo`3ooon00?ooo`00903oool00`00
0000oooo0?ooo`040?ooo`800000P@3oool200000?l0ooooo03oool002@0oooo00<000000?ooo`3o
ool0103oool2000008<0oooo0P00003o0?ooooX0oooo000T0?ooo`030000003oool0oooo00@0oooo
0P0000200?ooo`8000000`3oool200000?l0oooon03oool002@0oooo00<000000?ooo`3oool0103o
ool200000880oooo0P0000030?ooo`800000o`3oooof0?ooo`00903oool00`000000oooo0?ooo`04
0?ooo`030000003oool0000008<0oooo0P0000030?ooo`800000o`3ooood0?ooo`00903oool00`00
0000oooo0?ooo`040?ooo`030000003oool0000008D0oooo0P0000030?ooo`800000o`3oooob0?oo
o`00903oool00`000000oooo0?ooo`050?ooo`800000Q`3oool200000?l0oooom@3oool002@0oooo
00<000000?ooo`3oool01@3oool2000008T0oooo0P00003o0?oooo<0oooo000T0?ooo`030000003o
ool0oooo00D0oooo0P00003o0?ooool0ooooO`3oool002@0oooo00<000000?ooo`3oool01@3oool2
000009L0oooo0P00003o0?ooonD0oooo000G0?ooo`@000002@3oool00`000000oooo0?ooo`050?oo
o`800000V@3oool200000?l0ooooh`3oool001L0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0000009D0oooo0P0000030?ooo`800000o`3ooooQ0?ooo`00
603oool00`000000oooo0?ooo`090?ooo`D000000`3oool00`000000oooo0000002G0?ooo`800000
0`3oool200000?l0oooog`3oool001T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`050?ooo`030000003oool0000009T0oooo0P0000030?ooo`800000o`3ooooM0?ooo`005`3oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo00H0oooo0P00002K0?ooo`8000000`3o
ool200000?l0oooof`3oool001P0oooo0P00000:0?ooo`030000003oool0oooo00H0oooo0P00002M
0?ooo`800000o`3ooooN0?ooo`00903oool00`000000oooo0?ooo`060?ooo`800000W`3oool20000
0?l0oooog03oool002@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000003o0?ooool0
ooooO@3oool002@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000002/0?ooo`800000
o`3oooo>0?ooo`00903oool00`000000oooo0?ooo`060?ooo`030000003oool000000:h0oooo0`00
003o0?oool/0oooo000T0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`000000Z`3oool2
000000@0oooo0P00003o0?ooolT0oooo000T0?ooo`030000003oool0oooo00L0oooo0P00002]0?oo
o`<000000`3oool300000?l0ooooaP3oool002@0oooo00<000000?ooo`3oool01`3oool200000;00
oooo0P0000040?ooo`800000o`3oooo40?ooo`00903oool00`000000oooo0?ooo`070?ooo`030000
003oool000000;40oooo0`00003o0?ooolL0oooo000T0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`000000]03oool200000?l0ooooa@3oool002@0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0000003o0?ooool0ooooO03oool002@0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo000000320?ooo`800000o`3ooong0?ooo`00903oool00`000000oooo0?ooo`070?ooo`03
0000003oool000000<40oooo00<000000?ooo`3oool01000003o0?oook<0oooo000T0?ooo`030000
003oool0oooo00P0oooo0P0000320?ooo`800000103oool400000?l0oooo[`3oool002@0oooo00<0
00000?ooo`3oool0203oool00`000000oooo000000330?ooo`<000001@3oool200000?l0oooo[@3o
ool002@0oooo00<000000?ooo`3oool0203oool00`000000oooo000000360?ooo`@00000o`3ooon`
0?ooo`00903oool3000000P0oooo00<000000?ooo`000000bP3oool200000?l0oooo[P3oool002@0
oooo00<000000?ooo`3oool0203oool00`000000oooo0000003o0?ooool0ooooN`3oool002@0oooo
00<000000?ooo`3oool0203oool00`000000oooo0000003H0?ooo`<00000o`3ooonO0?ooo`00903o
ool00`000000oooo0?ooo`080?ooo`030000003oool000000=L0oooo00@000000?ooo`3oool0oooo
1000003o0?oooi/0oooo000T0?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool00000
e`3oool4000000<0oooo1000003o0?oooiL0oooo000T0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`000000f`3oool500000080oooo0P00003o0?oooiD0oooo000T0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`000000h03oool300000?l0ooooUP3oool002@0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0000003o0?ooool0ooooNP3oool002@0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0000003_0?ooo`030000003oool0oooo0?l0ooooQ`3oool002@0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0000003`0?ooo`@00000o`3ooon50?ooo`00903o
ool00`000000oooo0?ooo`090?ooo`040000003oool0oooo00000>d0oooo2P00003o0?oooh40oooo
000T0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000l`3oool700000?l0oooo
OP3oool002@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0000003g0?ooo`<00000o`3o
oomn0?ooo`00903oool00`000000oooo0?ooo`0:0?ooo`030000003oool000000?l0ooooo`3ooomi
0?ooo`00903oool00`000000oooo0?ooo`0:0?ooo`030000003oool000000?l0oooo1P3oool50000
0?l0ooooKP3oool002@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0000003o0?ooo`D0
oooo0P0000040?ooo`<00000o`3ooom[0?ooo`00903oool00`000000oooo0?ooo`0:0?ooo`040000
003oool0oooo00000?l0oooo1P3oool4000000<0oooo0`00003o0?ooofP0oooo000T0?ooo`030000
003oool0oooo00X0oooo00@000000?ooo`3oool00000o`3oool:0?ooo`@000000P3oool200000?l0
ooooIP3oool002@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0000003o0?ooo`h0oooo
0`00003o0?ooofL0oooo000T0?ooo`<000002`3oool00`000000oooo0000003o0?oooad0oooo0`00
003o0?oooeP0oooo000T0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`000000o`3ooolL
0?ooo`<0000000<0oooo0000000000000P00003o0?oooe@0oooo000T0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`000000o`3ooolO0?ooo`T00000o`3ooom@0?ooo`00903oool00`000000
oooo0?ooo`0;0?ooo`040000003oool0oooo00000?l0oooo8`3oool3000000030?ooo`0000000000
0?l0ooooCP3oool002@0oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`00003o0?oo
obH0oooo0P00003o0?ooodl0oooo000T0?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3o
ool00000o`3ooold0?ooo`<00000o`3ooom00?ooo`00903oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool000000?l0oooo<`3oool:00000?l0oooo>P3oool002@0oooo00<000000?ooo`3oool0
303oool00`000000oooo0000003o0?ooocL0oooo2P00003o0?ooocH0oooo000T0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`000000o`3ooolm0?ooo`<00000o`3ooolg0?ooo`00903oool0
0`000000oooo0?ooo`0<0?ooo`040000003oool0oooo00000?l0ooooo`3ooomf0?ooo`00903oool0
0`000000oooo0?ooo`0<0?ooo`040000003oool0oooo00000?l0ooooBP3oool400000?l0oooo:03o
ool002@0oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`00003o0?ooodh0oooo1P00
003o0?ooob80oooo000T0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`000000o`3ooomD
0?ooo`@00000o`3ooolN0?ooo`00903oool00`000000oooo0?ooo`0=0?ooo`030000003oool00000
0?l0ooooo`3ooomf0?ooo`00903oool00`000000oooo0?ooo`0=0?ooo`030000003oool000000?l0
ooooHP3oool500000?l0oooo3`3oool002@0oooo00<000000?ooo`3oool03@3oool010000000oooo
0?ooo`00003o0?ooof<0oooo2@00003o0?ooo`T0oooo000T0?ooo`030000003oool0oooo00d0oooo
00@000000?ooo`3oool00000o`3ooomW0?ooo`P00000o`3oool60?ooo`00903oool00`000000oooo
0?ooo`0=0?ooo`040000003oool0oooo00000?l0ooooo`3ooome0?ooo`00903oool00`000000oooo
0?ooo`0=0?ooo`040000003oool0oooo00000?l0ooooN@3oool500000?H0oooo000T0?ooo`<00000
3P3oool010000000oooo0?ooo`00003o0?ooogd0oooo2@00003]0?ooo`00903oool00`000000oooo
0?ooo`0>0?ooo`040000003oool0oooo00000?l0ooooP`3oool200000>h0oooo000T0?ooo`030000
003oool0oooo00h0oooo00@000000?ooo`3oool00000o`3ooonA0?ooo`<00000g`3oool002@0oooo
00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00003o0?oooi@0oooo1@00003J0?ooo`00
903oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo00000?l0ooooV@3oool500000=D0
oooo000T0?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000003o0?ooojP0
oooo0`0000370?ooo`00903oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo00000?l0
ooooZ`3oool600000<40oooo000T0?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3oool0
0000o`3ooona0?ooo`@00000_@3oool002@0oooo00<000000?ooo`3oool03`3oool010000000oooo
0?ooo`00003o0?oool00oooo0`00002_0?ooo`00903oool00`000000oooo0?ooo`0?0?ooo`050000
003oool0oooo0?ooo`000000o`3ooono0?ooo`T00000Z@3oool002@0oooo00<000000?ooo`3oool0
3`3oool01@000000oooo0?ooo`3oool000000?l0ooooa@3oool800000:@0oooo000T0?ooo`030000
003oool0oooo00l0oooo00D000000?ooo`3oool0oooo0000003o0?ooomL0oooo1P00002D0?ooo`00
903oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo00000?l0oooof`3oool9000008d0
oooo000T0?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool00000o`3ooooQ0?ooo`@0
00002P3oool4000007h0oooo000T0?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0
oooo0000003o0?ooonl0oooo2@00001h0?ooo`00903oool00`000000oooo0?ooo`0@0?ooo`050000
003oool0oooo0?ooo`000000o`3ooooe0?ooo`L00000M03oool002@0oooo00<000000?ooo`3oool0
403oool01@000000oooo0?ooo`3oool000000?l0ooooo`3oool80?ooo`H00000H`3oool001T0oooo
0`0000080?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool00000o`3ooooo0?ooo`P0
oooo3@00001L0?ooo`006P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo
00D000000?ooo`3oool0oooo0000003o0?ooool0oooo3@3oool7000000/0oooo1P00001;0?ooo`00
5`3oool5000000P0oooo1@00000?0?ooo`050000003oool0oooo0?ooo`000000o`3ooooo0?oooal0
oooo3@0000140?ooo`005`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0140
oooo00D000000?ooo`3oool0oooo0000003o0?ooool0oooo9P3oool7000000X0oooo1P00000c0?oo
o`00603oool00`000000oooo000000090?ooo`030000003oool0oooo0180oooo00@000000?ooo`3o
ool00000o`3ooooo0?ooocP0oooo3000000/0?ooo`006@3oool2000000T0oooo00<000000?ooo`3o
ool04P3oool010000000oooo0?ooo`00003o0?ooool0oooo?P3oool7000002/0oooo000T0?ooo`03
0000003oool0oooo0180oooo00D000000?ooo`3oool0oooo0000003o0?ooool0oooo@@3oool40000
02X0oooo000T0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo0000003o0?oo
ool0oooo>`3oool6000000040?ooo`0000000000000002X0oooo000T0?ooo`030000003oool0oooo
0180oooo00D000000?ooo`3oool0oooo0000003o0?ooool0oooo=03oool7000000030?ooo`000000
000000@00000;@3oool002@0oooo00<000000?ooo`3oool04`3oool010000000oooo0?ooo`00003o
0?ooool0oooo;P3oool6000000<0oooo1@00000c0?ooo`00903oool00`000000oooo0?ooo`0C0?oo
o`050000003oool0oooo0?ooo`000000o`3ooooo0?ooobP0oooo1@0000030?ooo`H00000>03oool0
02@0oooo00<000000?ooo`3oool04`3oool01@000000oooo0?ooo`3oool000000?l0ooooo`3ooolS
0?ooo`D000000`3oool5000003h0oooo000T0?ooo`030000003oool0oooo01<0oooo00D000000?oo
o`3oool0oooo0000003o0?ooool0oooo7P3oool500000080oooo1P0000130?ooo`00903oool00`00
0000oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`000000o`3ooooo0?oooaT0oooo1@000000
0`3oool0000000000004000004T0oooo000T0?ooo`030000003oool0oooo01@0oooo00@000000?oo
o`3oool00000o`3ooooo0?oooa@0oooo2`00001?0?ooo`00903oool00`000000oooo0?ooo`0D0?oo
o`050000003oool0oooo0?ooo`000000o`3ooooo0?ooo`h0oooo2P00001E0?ooo`00903oool00`00
0000oooo0?ooo`0D0?ooo`050000003oool0oooo0?ooo`000000o`3ooooo0?ooo`T0oooo2@00001K
0?ooo`00903oool00`000000oooo0?ooo`0D0?ooo`050000003oool0oooo0?ooo`000000o`3ooooo
0?ooo`@0oooo2@00001P0?ooo`00903oool00`000000oooo0?ooo`0D0?ooo`050000003oool0oooo
0?ooo`000000o`3oooon0?ooo`T00000I@3oool002@0oooo00<000000?ooo`3oool05@3oool01@00
0000oooo0?ooo`3oool000000?l0oooon03oool9000006X0oooo000T0?ooo`<000005@3oool01@00
0000oooo0?ooo`3oool000000?l0ooool`3oool9000006l0oooo000T0?ooo`030000003oool0oooo
01D0oooo00D000000?ooo`3oool0oooo0000003o0?ooonh0oooo2@00001d0?ooo`00903oool00`00
0000oooo0?ooo`0E0?ooo`050000003oool0oooo0?ooo`000000o`3ooooY0?ooo`T00000N@3oool0
02@0oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`00003o0?ooon@0oooo2@00001n
0?ooo`00903oool00`000000oooo0?ooo`0F0?ooo`050000003oool0oooo0?ooo`000000o`3ooooN
0?ooo`P00000Q03oool002@0oooo00<000000?ooo`3oool05P3oool01@000000oooo0?ooo`3oool0
00000?l0oooofP3oool7000008T0oooo000T0?ooo`030000003oool0oooo01H0oooo00D000000?oo
o`3oool0oooo0000003o0?ooomH0oooo1P00002>0?ooo`00903oool00`000000oooo0?ooo`0F0?oo
o`050000003oool0oooo0?ooo`000000o`3ooooA0?ooo`L00000TP3oool002@0oooo00<000000?oo
o`3oool05`3oool01@000000oooo0?ooo`3oool000000?l0ooooc03oool7000009H0oooo000T0?oo
o`030000003oool0oooo01L0oooo00D000000?ooo`3oool0oooo0000003o0?ooolP0oooo1`00002J
0?ooo`00903oool00`000000oooo0?ooo`0G0?ooo`050000003oool0oooo0?ooo`000000o`3oooo3
0?ooo`P00000WP3oool002@0oooo00<000000?ooo`3oool05`3oool01@000000oooo0?ooo`3oool0
00000?l0oooo_`3oool800000:80oooo000T0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`3o0?oookP0oooo1`00002W0?ooo`00903oool00`000000
oooo0?ooo`0H0?ooo`050000003oool0oooo0?ooo`000000o`3ooonf0?ooo`L00000Z`3oool002@0
oooo00<000000?ooo`3oool0603oool01@000000oooo0?ooo`3oool000000?l0oooo/P3oool70000
0:l0oooo000T0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`3o0?oooj/0oooo1`00002c0?ooo`00903oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooonV0?ooo`P00000]`3oool002@0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0ooooXP3o
ool800000;/0oooo000T0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`3o0?oooid0oooo1`0000300?ooo`00903oool3000001T0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`3o0?oooiT0oooo1P0000350?ooo`00903oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooonE0?ooo`H0
0000b@3oool002@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0?l0ooooT03oool500000<h0oooo000T0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?oooh`0oooo1000003C0?ooo`00903oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooon8
0?ooo`@00000e`3oool002@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0?l0ooooQ03oool300000=/0oooo000T0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?oooh00oooo1000003N0?ooo`00
903oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
o`3oooml0?ooo`D00000h@3oool002@0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0?l0ooooN03oool400000>D0oooo000T0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooog@0oooo1@00003X
0?ooo`00903oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0o`3oooma0?ooo`@00000k03oool002@0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooK03oool500000>l0oooo000T0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooofP0oooo
1@00003c0?ooo`00903oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0o`3ooomU0?ooo`D00000mP3oool002@0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooH03oool500000?X0oooo000T0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?oo
oe`0oooo1@00003n0?ooo`00903oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0o`3ooomG0?ooo`H00000o`3oool20?ooo`00903oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooomD0?ooo`D00000
o`3oool60?ooo`00903oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0o`3ooom@0?ooo`H00000o`3oool90?ooo`00903oool3000001h0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oood`0oooo1P00003o0?ooo``0oooo000T0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oo
odP0oooo1P00003o0?oooa00oooo000T0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`3o0?oood<0oooo1`00003o0?oooa<0oooo000T0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oood00oooo
0`000000103oool0000000000000003o0?oooaH0oooo000T0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooc`0oooo2000003o0?oooaT0oooo
000T0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`3o0?ooocP0oooo0`000000103oool0000000000000003o0?oooad0oooo000T0?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooc@0oooo1000
0000103oool0000000000000003o0?ooob00oooo000T0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooc40oooo0`0000020?ooo`<00000o`3o
oolS0?ooo`00903oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0o`3oool/0?ooo`@000000P3oool300000?l0oooo9P3oool002@0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo:03oool40000
00<0oooo0`00003o0?ooobT0oooo000T0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`3o0?ooob@0oooo0`0000040?ooo`<00000o`3oool/0?ooo`00
903oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
o`3ooolP0?ooo`@00000103oool300000?l0oooo;`3oool002@0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo703oool3000000D0oooo0`00
003o0?oooc80oooo000T0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`3o0?oooaT0oooo0`0000050?ooo`<00000o`3ooole0?ooo`00903oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooolE0?oo
o`<000001@3oool300000?l0oooo>03oool002@0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo4P3oool3000000D0oooo0`00003o0?oooc/0
oooo000T0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`3o0?ooo`h0oooo0`0000040?ooo`@00000o`3oooln0?ooo`005`3oool3000000X0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo2`3o
ool3000000@0oooo0`00003o0?oood80oooo000G0?ooo`040000003oool0oooo000000T0oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo1`3o
ool3000000@0oooo0`00003o0?ooodD0oooo000G0?ooo`040000003oool0oooo000000T0oooo1@00
000R0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3oool40?ooo`<00000103o
ool300000?l0ooooB03oool001L0oooo0`00000:0?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooo`<000000`3oool400000?l0ooooB`3oool0
01P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0o03oool3000000<0oooo0`00003o0?ooodl0oooo000H0?ooo`<0
00002@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0n03oool3000000<0oooo0`00003o0?oooe80oooo000T0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3e0?ooo`<00000103oool200000?l0oooo
E@3oool002@0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0?40oooo0`0000040?ooo`<00000o`3ooomG0?ooo`00903oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0kP3oool3000000D0oooo0P00003o
0?oooeX0oooo000T0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`3Z0?ooo`<000001@3oool300000?l0ooooG03oool002@0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0>L0oooo0`0000050?ooo`<0
0000o`3ooomO0?ooo`00903oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0h`3oool3000000H0oooo0P00003o0?ooof80oooo000T0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3P0?ooo`<000001P3o
ool300000?l0ooooI03oool002@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0=`0oooo0`0000070?ooo`800000o`3ooomW0?ooo`00903oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0f@3oool30000
00L0oooo0`00003o0?ooofT0oooo000T0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`3F0?ooo`8000001`3oool300000?l0ooooK03oool002@0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0=<0oooo
0`0000070?ooo`800000o`3ooom_0?ooo`00903oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0c`3oool3000000L0oooo0`00003o0?ooog40oooo000T
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3<
0?ooo`<000001`3oool300000?l0ooooM03oool002@0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0<P0oooo0`0000070?ooo`<00000o`3ooomg0?oo
o`00903oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0a03oool3000000L0oooo0`00003o0?ooogX0oooo000T0?ooo`<00000;03oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0<40oooo0`0000080?ooo`800000o`3ooomm0?ooo`00903o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0_@3o
ool3000000P0oooo0`00003o0?ooogl0oooo000T0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`2i0?ooo`<00000203oool300000?l0ooooPP3oool0
02@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0;H0oooo0`0000090?ooo`800000o`3ooon50?ooo`00903oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0/P3oool3000000T0oooo0`00003o0?ooohL0
oooo000T0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`2^0?ooo`<000002@3oool300000?l0ooooRP3oool002@0oooo00<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0:/0oooo0`00000:0?ooo`800000o`3o
oon=0?ooo`00903oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0Y`3oool3000000X0oooo0`00003o0?ooohl0oooo000T0?ooo`030000003oool0oooo
0300oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2S0?ooo`<000002`3oool20000
0?l0ooooTP3oool002@0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0:00oooo0P00000;0?ooo`<00000o`3ooonD0?ooo`00903oool00`000000oooo
0?ooo`0a0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0W03oool3000000X0oooo
0`00003o0?oooiL0oooo000T0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`2H0?ooo`<000002`3oool200000?l0ooooVP3oool002@0oooo00<00000
0?ooo`3oool0<P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo09D0oooo0`00000;
0?ooo`<00000o`3ooonL0?ooo`00903oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0T@3oool3000000`0oooo0P00003o0?oooil0oooo000T0?ooo`03
0000003oool0oooo03<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2>0?ooo`80
0000303oool300000?l0ooooX@3oool002@0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo08X0oooo0`00000;0?ooo`<00000o`3ooonT0?ooo`00903o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0QP3o
ool3000000`0oooo0P00003o0?ooojL0oooo000T0?ooo`030000003oool0oooo03D0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`220?ooo`<00000303oool300000?l0ooooZ@3oool0
02@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0>0?ooo`800000OP3oool40000
00`0oooo0`00003o0?oooj`0oooo000T0?ooo`<00000=P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo07P0oooo0`00000>0?ooo`800000o`3ooon_0?ooo`00903oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0M03oool3000000h0oooo
0`00003o0?oook40oooo000T0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool03`3o
ool200000740oooo0`00000>0?ooo`<00000o`3ooond0?ooo`00903oool00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0JP3oool4000000l0oooo0P00003o
0?oookL0oooo000T0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`1V0?ooo`<00000403oool300000?l0oooo^@3oool002@0oooo00<000000?ooo`3o
ool0>P3oool00`000000oooo0?ooo`0A0?ooo`800000HP3oool400000140oooo0P00003o0?oook`0
oooo000T0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`1K0?ooo`@000004P3oool300000?l0oooo_P3oool002@0oooo00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`0C0?ooo`800000E`3oool4000001@0oooo0P00003o0?oool40oooo000T
0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1@
0?ooo`@000005@3oool300000?l0oooo``3oool002@0oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`0D0?ooo`800000C03oool4000001L0oooo0P00003o0?ooolH0oooo000T0?ooo`03
0000003oool0oooo03h0oooo00<000000?ooo`3oool05@3oool2000004H0oooo1000000H0?ooo`<0
0000o`3oooo80?ooo`00903oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo01H0oooo
0`00000n0?ooo`D000006P3oool200000?l0oooob`3oool002@0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`0H0?ooo`<00000=`3oool4000001`0oooo0`00003o0?ooold0oooo000T
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool06P3oool4000002l0oooo1000000M
0?ooo`<00000o`3oooo@0?ooo`00903oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
01d0oooo0`00000W0?ooo`D000007P3oool300000?l0ooood`3oool002@0oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo0?ooo`0O0?ooo`H000006`3oool600000200oooo0`00003o0?ooomH0
oooo000T0?ooo`030000003oool0oooo04@0oooo0P00000U0?oooa/00000903oool200000?l0oooo
f@3oool002@0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`1N0?ooo`<00000o`3o
oooK0?ooo`00903oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo05X0oooo0`00003o
0?ooomh0oooo000T0?ooo`<00000B03oool2000005L0oooo0`00003o0?ooon40oooo000T0?ooo`03
0000003oool0oooo04X0oooo00<000000?ooo`3oool0D@3oool300000?l0ooooi03oool002@0oooo
00<000000?ooo`3oool0B`3oool2000004h0oooo0`00003o0?ooonL0oooo000T0?ooo`030000003o
ool0oooo04d0oooo00<000000?ooo`3oool0B03oool300000?l0oooojP3oool002@0oooo00<00000
0?ooo`3oool0CP3oool2000004@0oooo1000003o0?ooond0oooo000T0?ooo`030000003oool0oooo
0500oooo0P00000o0?ooo`<00000o`3ooooa0?ooo`00903oool00`000000oooo0?ooo`1B0?ooo`80
0000>P3oool300000?l0oooom03oool002@0oooo00<000000?ooo`3oool0E03oool2000003@0oooo
1000003o0?ooooL0oooo000T0?ooo`030000003oool0oooo05H0oooo0`00000]0?ooo`@00000o`3o
oook0?ooo`00903oool00`000000oooo0?ooo`1I0?ooo`D000008P3oool600000?l0ooooo`3oool0
02@0oooo00<000000?ooo`3oool0GP3oool4000001H0oooo2000003o0?ooool0oooo1P3oool002@0
oooo00<000000?ooo`3oool0HP3ooolF00000?l0ooooo`3oool>0?ooo`00903oool00`000000oooo
0?ooo`3o0?ooool0ooooQP3oool002@0oooo00<000000?ooo`3oool0o`3ooooo0?ooohH0oooo000T
0?ooo`030000003oool0oooo0?l0ooooo`3ooon60?ooo`00903oool00`000000oooo0?ooo`3o0?oo
ool0ooooQP3oool001P0oooo0P00000:0?ooo`030000003oool0oooo0?l0ooooo`3ooon60?ooo`00
5`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0?l0ooooo`3ooon60?ooo`00
5`3oool010000000oooo0?ooo`0000090?ooo`D00000o`3ooooo0?oooh@0oooo000H0?ooo`800000
2P3oool00`000000oooo0?ooo`3o0?ooool0ooooQP3oool001L0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0?ooo`3o0?ooool0ooooQP3oool001P0oooo0P00000:0?ooo`030000003o
ool0oooo0?l0ooooo`3ooon60?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0ooooQP3oool0
02@0oooo00<000000?ooo`3oool0o`3ooooo0?ooohH0oooo000T0?ooo`030000003oool0oooo0?l0
ooooo`3ooon60?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0ooooQP3oool002@0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooohH0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3ooon6
0?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0ooooQP3oool002@0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooohH0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3ooon60?ooo`00903o
ool00`000000oooo0?ooo`3o0?ooool0ooooQP3oool002@0oooo00<000000?ooo`3oool0o`3ooooo
0?ooohH0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3ooon60?ooo`00903oool00`000000
oooo0?ooo`3o0?ooool0ooooQP3oool002@0oooo00<000000?ooo`3oool0o`3ooooo0?ooohH0oooo
000T0?ooo`030000003oool0oooo0?l0ooooo`3ooon60?ooo`00903oool300000?l0ooooo`3ooon6
0?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0ooooQP3oool002@0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooohH0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3ooon60?ooo`00903o
ool00`000000oooo0?ooo`3o0?ooool0ooooQP3oool002@0oooo00<000000?ooo`3oool0o`3ooooo
0?ooohH0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3ooon60?ooo`00903oool00`000000
oooo0?ooo`3o0?ooool0ooooQP3oool002@0oooo00<000000?ooo`3oool0o`3ooooo0?ooohH0oooo
000T0?ooo`030000003oool0oooo0?l0ooooo`3ooon60?ooo`00903oool00`000000oooo0?ooo`3o
0?ooool0ooooQP3oool002@0oooo00<000000?ooo`3oool0o`3ooooo0?ooohH0oooo000T0?ooo`03
0000003oool0oooo0?l0ooooo`3ooon60?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0oooo
QP3oool002@0oooo00<000000?ooo`3oool0o`3ooooo0?ooohH0oooo000T0?ooo`030000003oool0
oooo0?l0ooooo`3ooon60?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0ooooQP3oool002@0
oooo00<000000?ooo`3oool0o`3ooooo0?ooohH0oooo000T0?ooo`030000003oool0oooo0?l0oooo
o`3ooon60?ooo`00903oool300000?l0ooooo`3ooon60?ooo`00903oool00`000000oooo0?ooo`3o
0?ooool0ooooQP3oool002@0oooo00<000000?ooo`3oool0o`3ooooo0?ooohH0oooo000T0?ooo`03
0000003oool0oooo0?l0ooooo`3ooon60?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0oooo
QP3oool002@0oooo00<000000?ooo`3oool0o`3ooooo0?ooohH0oooo000T0?ooo`030000003oool0
oooo0?l0ooooo`3ooon60?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0ooooQP3oool002@0
oooo00<000000?ooo`3oool0o`3ooooo0?ooohH0oooo000T0?ooo`030000003oool0oooo0?l0oooo
o`3ooon60?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0ooooQP3oool002@0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooohH0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3ooon60?oo
o`00903oool00`000000oooo0?ooo`3o0?ooool0ooooQP3oool002@0oooo00<000000?ooo`3oool0
o`3ooooo0?ooohH0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3ooon60?ooo`00903oool0
0`000000oooo0?ooo`3o0?ooool0ooooQP3oool002@0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ohH0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3ooon60?ooo`00903oool300000?l0oooo
o`3ooon60?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0ooooQP3oool002@0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooohH0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3ooon60?oo
o`00903oool00`000000oooo0?ooo`3o0?ooool0ooooQP3oool002@0oooo00<000000?ooo`3oool0
o`3ooooo0?ooohH0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3ooon60?ooo`00903oool0
0`000000oooo0?ooo`3o0?ooool0ooooQP3oool002@0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ohH0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3ooon60?ooo`00903oool00`000000oooo
0?ooo`3o0?ooool0ooooQP3oool002@0oooo00<000000?ooo`3oool0o`3ooooo0?ooohH0oooo000T
0?ooo`030000003oool0oooo0?l0ooooo`3ooon60?ooo`00903oool00`000000oooo0?ooo`3o0?oo
ool0ooooQP3oool002@0oooo00<000000?ooo`3oool0o`3ooooo0?ooohH0oooo000T0?ooo`030000
003oool0oooo0?l0ooooo`3ooon60?ooo`00903oool00`000000oooo0?ooo`3o0?ooool0ooooQP3o
ool00140oooo1@0000020?ooo`8000002P3oool00`000000oooo0?ooo`3o0?ooool0ooooQP3oool0
01<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooohH0oooo000C0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`070?ooo`D00000o`3ooooo0?oooh@0oooo000C0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`3o0?ooool0ooooT03oool001<0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo0?l0ooooo`3ooon@0?ooo`004P3oool20000
00@0oooo0P00003o0?ooool0ooooT`3oool00?l0ooooo`3ooon]0?ooo`00o`3ooooo0?ooojd0oooo
003o0?ooool0oooo[@3oool00?l0ooooo`3ooon]0?ooo`00o`3ooooo0?ooojd0oooo003o0?ooool0
oooo[@3oool00?l0ooooo`3ooon]0?ooo`00o`3ooooo0?ooojd0oooo003o0?ooool0oooo[@3oool0
0?l0ooooo`3ooon]0?ooo`00o`3ooooo0?ooojd0oooo003o0?ooool0oooo[@3oool00?l0ooooo`3o
oon]0?ooo`00o`3ooooo0?ooojd0oooo003o0?ooool0oooo[@3oool00?l0ooooo`3ooon]0?ooo`00
3P3oool3000000050?ooo`00000000000000003oool00P0000020?ooo`<000000P3oool3000000@0
oooo100000000`3oool0000000000002000000<0oooo0`0000000`3oool00000000000020?ooo`80
0000o`3ooooo0?ooog40oooo000=0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool00000o`3ooooo0?ooog80oooo000=0?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`@000000P3oool010000000oooo0?oo
o`00003o0?ooool0ooooLP3oool000d0oooo00<000000?ooo`3oool00`3oool3000000@0oooo0P00
00040?ooo`030000003oool0oooo00<0oooo0`0000020?ooo`@000000`3oool200000080oooo1000
003o0?ooool0ooooL`3oool000d0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooooo0?oooh80oooo000>
0?ooo`<0000000<0oooo0000000000001`3oool010000000oooo0?ooo`3oool2000000H0oooo0P00
003o0?ooool0ooooQ03oool00?l0ooooo`3ooon]0?ooo`00o`3ooooo0?ooojd0oooo0000\
\>"],
  ImageRangeCache->{{{0, 682.063}, {421.188, 0}} -> {-0.0600436, -0.441184, \
0.00164038, 0.0265419}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowSize->{892, 633},
WindowMargins->{{38, Automatic}, {-14, Automatic}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 52, 0, 115, "Title"],
Cell[1782, 54, 37, 0, 33, "Text"],
Cell[1822, 56, 158, 2, 45, "Input"],

Cell[CellGroupData[{
Cell[2005, 62, 104, 2, 30, "Input"],
Cell[2112, 66, 89, 1, 29, "Output"]
}, Open  ]],
Cell[2216, 70, 42, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[2283, 74, 63, 1, 30, "Input"],
Cell[2349, 77, 175, 3, 44, "Output"]
}, Open  ]],
Cell[2539, 83, 833, 19, 110, "Input"],
Cell[3375, 104, 71, 0, 33, "Text"],
Cell[3449, 106, 2319, 47, 370, "Input"],
Cell[5771, 155, 58, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[5854, 159, 1649, 30, 370, "Input"],
Cell[7506, 191, 124, 2, 29, "Output"],
Cell[7633, 195, 123, 2, 29, "Output"],
Cell[7759, 199, 21690, 557, 231, 5360, 351, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[29464, 759, 149, 2, 50, "Input"],
Cell[29616, 763, 241, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[29882, 771, 756, 13, 210, "Input"],
Cell[30641, 786, 54, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30732, 792, 1218, 22, 230, "Input"],
Cell[31953, 816, 44666, 914, 431, 6756, 442, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

