(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     93435,       3001]*)
(*NotebookOutlinePosition[     94113,       3024]*)
(*  CellTagsIndexPosition[     94069,       3020]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Mortality in the Barro-Becker Model", "Title"],

Cell[BoxData[
    \(<< Graphics`MultipleListPlot`\)], "Input"],

Cell["\<\
This is the version with education investment which is done as an extension\
\>", "Text"],

Cell["\<\
Model parameters; \[Beta] and A are set in the program to match statistics.\
\>", "Text"],

Cell[BoxData[{
    \(\(\[Sigma] = 0.5;\)\), "\[IndentingNewLine]", 
    \(\(eps = 0.5;\)\), "\[IndentingNewLine]", 
    \(\(wu = 9.3;\)\), "\[IndentingNewLine]", 
    \(\(w = 9.3;\)\), "\[IndentingNewLine]", 
    \(\(p = 1/168;\)\), "\[IndentingNewLine]", 
    \(\(q = 5/168;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(ntarget = 5;\)\), "\[IndentingNewLine]", 
    \(\(ntargetlo = 2.1;\)\), "\[IndentingNewLine]", 
    \(\(htarget = 0.5;\)\)}], "Input"],

Cell["Technical parameters", "Text"],

Cell[BoxData[{
    \(\(ngrid = 20;\)\), "\[IndentingNewLine]", 
    \(\(hgrid = 20;\)\), "\[IndentingNewLine]", 
    \(\(hmax =  .8;\)\), "\[IndentingNewLine]", 
    \(\(hstep = hmax/\((hgrid - 1)\);\)\), "\[IndentingNewLine]", 
    \(\(Do[
        Value[i] = 0, {i, 
          hgrid}];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(itertol = 0.0001;\)\), "\[IndentingNewLine]", 
    \(\(maxiter = 30;\)\), "\[IndentingNewLine]", 
    \(\(betaiter = 10;\)\), "\[IndentingNewLine]", 
    \(\(Aiter = 10;\)\)}], "Input"],

Cell["Iterate to match initial steady state", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(s = 0.73;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(betalo =  .07;\)\), "\[IndentingNewLine]", 
    \(\(betahi =  .12;\)\), "\[IndentingNewLine]", 
    \(\(\[Beta] = 0.09;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(betacount = 1;\)\), "\[IndentingNewLine]", 
    \(\(While[
        betacount < betaiter, \[IndentingNewLine]\[IndentingNewLine]Alo = 
          5; \[IndentingNewLine]A = 6; \[IndentingNewLine]Ahi = 
          8; \[IndentingNewLine]\[IndentingNewLine]Acount = 
          1; \[IndentingNewLine]While[
          Acount < Aiter, \[IndentingNewLine]\[IndentingNewLine] (*\ 
            feasible\ human\ capital\ values\ *) \[IndentingNewLine]Do[
            hval[i] = hstep*\((i - 1)\), {i, 
              hgrid}]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
            Implied\ feasible\ education\ values\ *) \[IndentingNewLine]Do[
            eval[i] = \((\(hstep*\((i - 1)\)\)\/A)\)\^2, {i, 
              hgrid}]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
            Implied\ feasible\ fertility\ values\ *) \[IndentingNewLine]Nmax \
= Min[{6, Floor[1\/\(p\/s + q\)]}]; \[IndentingNewLine]Do[
            nval[i] = \(Nmax\/\(ngrid - 1\)\) \((i - 1)\), {i, 
              ngrid}]; \[IndentingNewLine]\[IndentingNewLine]itercrit = 
            1; \[IndentingNewLine]itercount = 
            1; \[IndentingNewLine]While[\((\((itercount < 
                    maxiter)\) && \((itercrit > 
                    itertol)\))\), \
\[IndentingNewLine]\[IndentingNewLine]hcount = 1; \[IndentingNewLine]While[
              hcount \[LessEqual] 
                hgrid, \[IndentingNewLine]\[IndentingNewLine] (*\ 
                Set\ the\ interim\ utilities\ to\ zero\ \
*) \[IndentingNewLine]prevalues = 
                Table[0, {i, 1, ngrid}, {j, 1, 
                    hgrid}]; \[IndentingNewLine]\[IndentingNewLine]ncount = 
                1; \[IndentingNewLine]While[
                ncount \[LessEqual] 
                  ngrid, \[IndentingNewLine]\[IndentingNewLine]ecount = 
                  1; \[IndentingNewLine]While[
                  ecount \[LessEqual] 
                    hgrid, \[IndentingNewLine]\[IndentingNewLine] (*\ 
                    Need\ to\ check\ whether\ consumption\ is\ positive\ \
*) \[IndentingNewLine]worktime = 
                    1 - p\ nval[ncount]\/s - \((q + eval[ecount])\)\ nval[
                          ncount]; \[IndentingNewLine]\[IndentingNewLine]If[
                    worktime < 
                      0, \[IndentingNewLine]prevalues[\([ncount, 
                          ecount]\)] = \(-1\), \
\[IndentingNewLine]prevalues[\([ncount, 
                          ecount]\)] = \((\((wu + w\ hval[hcount])\)\ \
worktime)\)\^\(1 - \[Sigma]\)\/\(1 - \[Sigma]\) + \[Beta]\ \ \(\((nval[
                                  ncount])\)\^eps\) 
                          Value[ecount]\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine]ecount = 
                    ecount + 
                      1;\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]ncount = 
                  ncount + 
                    1;\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]NewValue[hcount] = 
                Max[prevalues]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
                The\ following\ extracts\ the\ maximizing\ index\ \
*) \[IndentingNewLine]MaxIndN[hcount] = 
                Ordering[prevalues, \(-1\)]; \[IndentingNewLine]MaxIndE[
                  hcount] = 
                Ordering[\(prevalues[\([Ordering[
                          prevalues, \(-1\)]]\)]\)[\([1]\)], \(-1\)]; \
\[IndentingNewLine]\[IndentingNewLine]hcount = 
                hcount + 
                  1;\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]deviation = 
              Table[Value[i] - NewValue[i], {i, 
                  hgrid}]; \[IndentingNewLine]\[IndentingNewLine]itercrit = 
              Max[Abs[deviation]]; \[IndentingNewLine]\[IndentingNewLine]Do[
              Value[i] = NewValue[i], {i, 
                hgrid}]; \[IndentingNewLine]\[IndentingNewLine]itercount = 
              itercount + 
                1;\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine]EDev = 
            Table[MaxIndE[i] - i, {i, 
                hgrid}]; \[IndentingNewLine]Eoptind = \(Ordering[Abs[EDev], 
                1]\)[\([1]\)]; \[IndentingNewLine]Noptind = \(MaxIndN[
                Eoptind]\)[\([1]\)]; \[IndentingNewLine]\[IndentingNewLine] \
(*\ Print[A\ \@eval[Eoptind]]; \[IndentingNewLine]Print[
              nval[\ Noptind]];\ \ \
*) \[IndentingNewLine]\[IndentingNewLine]If[A\ \@eval[Eoptind] > htarget, 
            Ahi = A; A = 0.5\ A + 0.5\ Alo, \ Alo = A; 
            A = 0.5\ A + 
                0.5\ Ahi]; \[IndentingNewLine]\[IndentingNewLine]Print[
            A]; \[IndentingNewLine]Acount = 
            Acount + 
              1;\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine]If[nval[\ Noptind] > 0.73\ ntarget, 
          betahi = \[Beta]; \[Beta] = 0.5\ \[Beta] + 0.5\ betalo, \ 
          betalo = \[Beta]; \[Beta] = 
            0.5\ \[Beta] + 
              0.5\ betahi]; \[IndentingNewLine]\[IndentingNewLine]Print[\
\[Beta]]; \[IndentingNewLine]Print[{}]; \[IndentingNewLine]Print[
          A\ \@eval[Eoptind]]; \[IndentingNewLine]Print[
          nval[\ Noptind]]; \ \ \[IndentingNewLine]Print[{}]; \
\[IndentingNewLine]\[IndentingNewLine]betacount = 
          betacount + 1;\[IndentingNewLine]];\)\)}], "Input"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(eval\)\" is similar to \
existing symbol \"\!\(hval\)\"."\)], "Message"],

Cell[BoxData[
    \(General::"spell" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(nval\)\" is similar to \
existing symbols \!\({eval, hval}\)."\)], "Message"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(ncount\)\" is similar \
to existing symbol \"\!\(hcount\)\"."\)], "Message"],

Cell[BoxData[
    \(General::"spell" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(ecount\)\" is similar \
to existing symbols \!\({hcount, ncount}\)."\)], "Message"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(MaxIndE\)\" is similar \
to existing symbol \"\!\(MaxIndN\)\"."\)], "Message"],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(General :: \"spell1\"\) will be suppressed \
during this calculation."\)], "Message"],

Cell[BoxData[
    \(7.`\)], "Print"],

Cell[BoxData[
    \(6.5`\)], "Print"],

Cell[BoxData[
    \(6.25`\)], "Print"],

Cell[BoxData[
    \(6.375`\)], "Print"],

Cell[BoxData[
    \(6.4375`\)], "Print"],

Cell[BoxData[
    \(6.40625`\)], "Print"],

Cell[BoxData[
    \(6.390625`\)], "Print"],

Cell[BoxData[
    \(6.3984375`\)], "Print"],

Cell[BoxData[
    \(6.40234375`\)], "Print"],

Cell[BoxData[
    \(0.08`\)], "Print"],

Cell[BoxData[
    \({}\)], "Print"],

Cell[BoxData[
    \(0.4634406529143371`\)], "Print"],

Cell[BoxData[
    \(84\/19\)], "Print"],

Cell[BoxData[
    \({}\)], "Print"],

Cell[BoxData[
    \(7.`\)], "Print"],

Cell[BoxData[
    \(6.5`\)], "Print"],

Cell[BoxData[
    \(6.25`\)], "Print"],

Cell[BoxData[
    \(6.125`\)], "Print"],

Cell[BoxData[
    \(6.1875`\)], "Print"],

Cell[BoxData[
    \(6.21875`\)], "Print"],

Cell[BoxData[
    \(6.234375`\)], "Print"],

Cell[BoxData[
    \(6.2421875`\)], "Print"],

Cell[BoxData[
    \(6.23828125`\)], "Print"],

Cell[BoxData[
    \(0.08499999999999999`\)], "Print"],

Cell[BoxData[
    \({}\)], "Print"],

Cell[BoxData[
    \(0.5049469731901719`\)], "Print"],

Cell[BoxData[
    \(60\/19\)], "Print"],

Cell[BoxData[
    \({}\)], "Print"],

Cell[BoxData[
    \(7.`\)], "Print"],

Cell[BoxData[
    \(6.5`\)], "Print"],

Cell[BoxData[
    \(6.25`\)], "Print"],

Cell[BoxData[
    \(6.375`\)], "Print"],

Cell[BoxData[
    \(6.3125`\)], "Print"],

Cell[BoxData[
    \(6.28125`\)], "Print"],

Cell[BoxData[
    \(6.296875`\)], "Print"],

Cell[BoxData[
    \(6.3046875`\)], "Print"],

Cell[BoxData[
    \(6.30859375`\)], "Print"],

Cell[BoxData[
    \(0.08249999999999999`\)], "Print"],

Cell[BoxData[
    \({}\)], "Print"],

Cell[BoxData[
    \(0.4634448574969021`\)], "Print"],

Cell[BoxData[
    \(72\/19\)], "Print"],

Cell[BoxData[
    \({}\)], "Print"],

Cell[BoxData[
    \(7.`\)], "Print"],

Cell[BoxData[
    \(6.5`\)], "Print"],

Cell[BoxData[
    \(6.25`\)], "Print"],

Cell[BoxData[
    \(6.125`\)], "Print"],

Cell[BoxData[
    \(6.1875`\)], "Print"],

Cell[BoxData[
    \(6.21875`\)], "Print"],

Cell[BoxData[
    \(6.203125`\)], "Print"],

Cell[BoxData[
    \(6.2109375`\)], "Print"],

Cell[BoxData[
    \(6.21484375`\)], "Print"],

Cell[BoxData[
    \(0.08124999999999999`\)], "Print"],

Cell[BoxData[
    \({}\)], "Print"],

Cell[BoxData[
    \(0.42131744455478315`\)], "Print"],

Cell[BoxData[
    \(72\/19\)], "Print"],

Cell[BoxData[
    \({}\)], "Print"],

Cell[BoxData[
    \(7.`\)], "Print"],

Cell[BoxData[
    \(6.5`\)], "Print"],

Cell[BoxData[
    \(6.25`\)], "Print"],

Cell[BoxData[
    \(6.375`\)], "Print"],

Cell[BoxData[
    \(6.3125`\)], "Print"],

Cell[BoxData[
    \(6.28125`\)], "Print"],

Cell[BoxData[
    \(6.265625`\)], "Print"],

Cell[BoxData[
    \(6.2578125`\)], "Print"],

Cell[BoxData[
    \(6.26171875`\)], "Print"],

Cell[BoxData[
    \(0.08187499999999999`\)], "Print"],

Cell[BoxData[
    \({}\)], "Print"],

Cell[BoxData[
    \(0.4634470070306853`\)], "Print"],

Cell[BoxData[
    \(66\/19\)], "Print"],

Cell[BoxData[
    \({}\)], "Print"],

Cell[BoxData[
    \(7.`\)], "Print"],

Cell[BoxData[
    \(6.5`\)], "Print"],

Cell[BoxData[
    \(6.25`\)], "Print"],

Cell[BoxData[
    \(6.125`\)], "Print"],

Cell[BoxData[
    \(6.1875`\)], "Print"],

Cell[BoxData[
    \(6.21875`\)], "Print"],

Cell[BoxData[
    \(6.234375`\)], "Print"],

Cell[BoxData[
    \(6.2421875`\)], "Print"],

Cell[BoxData[
    \(6.23828125`\)], "Print"],

Cell[BoxData[
    \(0.0821875`\)], "Print"],

Cell[BoxData[
    \({}\)], "Print"],

Cell[BoxData[
    \(0.5049469731901719`\)], "Print"],

Cell[BoxData[
    \(66\/19\)], "Print"],

Cell[BoxData[
    \({}\)], "Print"],

Cell[BoxData[
    \(7.`\)], "Print"],

Cell[BoxData[
    \(6.5`\)], "Print"],

Cell[BoxData[
    \(6.25`\)], "Print"],

Cell[BoxData[
    \(6.125`\)], "Print"],

Cell[BoxData[
    \(6.1875`\)], "Print"],

Cell[BoxData[
    \(6.21875`\)], "Print"],

Cell[BoxData[
    \(6.234375`\)], "Print"],

Cell[BoxData[
    \(6.2265625`\)], "Print"],

Cell[BoxData[
    \(6.23046875`\)], "Print"],

Cell[BoxData[
    \(0.08234375`\)], "Print"],

Cell[BoxData[
    \({}\)], "Print"],

Cell[BoxData[
    \(0.46344845803341467`\)], "Print"],

Cell[BoxData[
    \(66\/19\)], "Print"],

Cell[BoxData[
    \({}\)], "Print"],

Cell[BoxData[
    \(7.`\)], "Print"],

Cell[BoxData[
    \(6.5`\)], "Print"],

Cell[BoxData[
    \(6.25`\)], "Print"],

Cell[BoxData[
    \(6.125`\)], "Print"],

Cell[BoxData[
    \(6.1875`\)], "Print"],

Cell[BoxData[
    \(6.21875`\)], "Print"],

Cell[BoxData[
    \(6.234375`\)], "Print"],

Cell[BoxData[
    \(6.2265625`\)], "Print"],

Cell[BoxData[
    \(6.22265625`\)], "Print"],

Cell[BoxData[
    \(0.08242187499999999`\)], "Print"],

Cell[BoxData[
    \({}\)], "Print"],

Cell[BoxData[
    \(0.5049461797530211`\)], "Print"],

Cell[BoxData[
    \(66\/19\)], "Print"],

Cell[BoxData[
    \({}\)], "Print"],

Cell[BoxData[
    \(7.`\)], "Print"],

Cell[BoxData[
    \(6.5`\)], "Print"],

Cell[BoxData[
    \(6.25`\)], "Print"],

Cell[BoxData[
    \(6.125`\)], "Print"],

Cell[BoxData[
    \(6.1875`\)], "Print"],

Cell[BoxData[
    \(6.21875`\)], "Print"],

Cell[BoxData[
    \(6.234375`\)], "Print"],

Cell[BoxData[
    \(6.2265625`\)], "Print"],

Cell[BoxData[
    \(6.22265625`\)], "Print"],

Cell[BoxData[
    \(0.0824609375`\)], "Print"],

Cell[BoxData[
    \({}\)], "Print"],

Cell[BoxData[
    \(0.5049461797530211`\)], "Print"],

Cell[BoxData[
    \(66\/19\)], "Print"],

Cell[BoxData[
    \({}\)], "Print"]
}, Open  ]],

Cell["Current values:Trying it with a finer grid", "Text"],

Cell[BoxData[{
    \(\(ngrid = 60;\)\), "\[IndentingNewLine]", 
    \(\(hgrid = 60;\)\), "\[IndentingNewLine]", 
    \(\(hmax = 2;\)\), "\[IndentingNewLine]", 
    \(\(hstep = hmax/\((hgrid - 1)\);\)\), "\[IndentingNewLine]", 
    \(\(Do[
        Value[i] = 0, {i, 
          hgrid}];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(itertol = 0.0001;\)\), "\[IndentingNewLine]", 
    \(\(maxiter = 30;\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(s = 0.73;\)\), "\[IndentingNewLine]", 
    \(\(A = 6.22;\)\), "\[IndentingNewLine]", 
    \(\(\[Beta] = 
        0.0825;\)\[IndentingNewLine]\[IndentingNewLine]\[IndentingNewLine] \
(*\ feasible\ human\ capital\ values\ *) \), "\[IndentingNewLine]", 
    \(\(Do[
        hval[i] = hstep*\((i - 1)\), {i, 
          hgrid}];\)\[IndentingNewLine]\[IndentingNewLine] (*\ 
      Implied\ feasible\ education\ values\ *) \), "\[IndentingNewLine]", 
    \(\(Do[
        eval[i] = \((\(hstep*\((i - 1)\)\)\/A)\)\^2, {i, 
          hgrid}];\)\[IndentingNewLine]\[IndentingNewLine] (*\ 
      Implied\ feasible\ fertility\ values\ *) \), "\[IndentingNewLine]", 
    \(\(Nmax = Min[{5, Floor[1\/\(p\/s + q\)]}];\)\), "\[IndentingNewLine]", 
    \(\(Do[
        nval[i] = \(Nmax\/\(ngrid - 1\)\) \((i - 1)\), {i, 
          ngrid}];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(itercrit = 1;\)\), "\[IndentingNewLine]", 
    \(\(itercount = 1;\)\), "\[IndentingNewLine]", 
    \(\(While[\((\((itercount < maxiter)\) && \((itercrit > 
                itertol)\))\), \[IndentingNewLine]\[IndentingNewLine]hcount = 
          1; \[IndentingNewLine]While[
          hcount \[LessEqual] 
            hgrid, \[IndentingNewLine]\[IndentingNewLine] (*\ 
            Set\ the\ interim\ utilities\ to\ zero\ \
*) \[IndentingNewLine]prevalues = 
            Table[0, {i, 1, ngrid}, {j, 1, 
                hgrid}]; \[IndentingNewLine]\[IndentingNewLine]ncount = 
            1; \[IndentingNewLine]While[
            ncount \[LessEqual] 
              ngrid, \[IndentingNewLine]\[IndentingNewLine]ecount = 
              1; \[IndentingNewLine]While[
              ecount \[LessEqual] 
                hgrid, \[IndentingNewLine]\[IndentingNewLine] (*\ 
                Need\ to\ check\ whether\ consumption\ is\ positive\ \
*) \[IndentingNewLine]worktime = 
                1 - p\ nval[ncount]\/s - \((q + eval[ecount])\)\ nval[
                      ncount]; \[IndentingNewLine]\[IndentingNewLine]If[
                worktime < 
                  0, \[IndentingNewLine]prevalues[\([ncount, 
                      ecount]\)] = \(-1\), \
\[IndentingNewLine]prevalues[\([ncount, 
                      ecount]\)] = \((\((wu + w\ hval[hcount])\)\ worktime)\)\
\^\(1 - \[Sigma]\)\/\(1 - \[Sigma]\) + \[Beta]\ \ \(\((nval[ncount])\)\^eps\) 
                      Value[ecount]\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]ecount = 
                ecount + 
                  1;\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]ncount = 
              ncount + 
                1;\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine]NewValue[hcount] = 
            Max[prevalues]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
            The\ following\ extracts\ the\ maximizing\ index\ \
*) \[IndentingNewLine]MaxIndN[hcount] = 
            Ordering[prevalues, \(-1\)]; \[IndentingNewLine]MaxIndE[hcount] = 
            Ordering[\(prevalues[\([Ordering[
                      prevalues, \(-1\)]]\)]\)[\([1]\)], \(-1\)]; \
\[IndentingNewLine]\[IndentingNewLine]hcount = 
            hcount + 
              1;\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine]deviation = 
          Table[Value[i] - NewValue[i], {i, 
              hgrid}]; \[IndentingNewLine]\[IndentingNewLine]itercrit = 
          Max[Abs[deviation]]; \[IndentingNewLine]\[IndentingNewLine]Do[
          Value[i] = NewValue[i], {i, 
            hgrid}]; \[IndentingNewLine]\[IndentingNewLine]itercount = 
          itercount + 
            1;\[IndentingNewLine]];\)\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(EDev = 
        Table[MaxIndE[i] - i, {i, hgrid}];\)\), "\[IndentingNewLine]", 
    \(\(Eoptind = \(Ordering[Abs[EDev], 
            1]\)[\([1]\)];\)\), "\[IndentingNewLine]", 
    \(\(Noptind = \(MaxIndN[
            Eoptind]\)[\([1]\)];\)\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(Print[A\ \@eval[Eoptind]];\)\), "\[IndentingNewLine]", 
    \(\(Print[nval[\ Noptind]];\)\ \)}], "Input"],

Cell[BoxData[
    \(0.4745762711864407`\)], "Print"],

Cell[BoxData[
    \(210\/59\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(N[210/59]\), "\[IndentingNewLine]", 
    \(N[210/\((s\ 59)\)]\)}], "Input"],

Cell[BoxData[
    \(3.559322033898305`\)], "Output"],

Cell[BoxData[
    \(4.87578360807987`\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(Now\ use\ the\ first\ calibrated\ value\ \((beta)\)\ and\ the\ 1951\ \
mortality\ rate\ to\ match\ fertility\ in\ 1951. \)], "Input"],

Cell[BoxData[{
    \(\(ngrid = 40;\)\), "\[IndentingNewLine]", 
    \(\(hgrid = 40;\)\), "\[IndentingNewLine]", 
    \(\(hmax = 8;\)\), "\[IndentingNewLine]", 
    \(\(hstep = hmax/\((hgrid - 1)\);\)\), "\[IndentingNewLine]", 
    \(\(Do[
        Value[i] = 0, {i, 
          hgrid}];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(itertol = 0.0001;\)\), "\[IndentingNewLine]", 
    \(\(maxiter = 30;\)\), "\[IndentingNewLine]", 
    \(\(Aiter = 20;\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(s = 0.965;\)\), "\[IndentingNewLine]", 
    \(\(\[Beta] = 0.0825;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(Alo = 10;\)\), "\[IndentingNewLine]", 
    \(\(A = 30;\)\), "\[IndentingNewLine]", 
    \(\(Ahi = 50;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(Acount = 1;\)\), "\[IndentingNewLine]", 
    \(\(While[
        Acount < Aiter, \[IndentingNewLine]\[IndentingNewLine] (*\ 
          feasible\ human\ capital\ values\ *) \[IndentingNewLine]Do[
          hval[i] = hstep*\((i - 1)\), {i, 
            hgrid}]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
          Implied\ feasible\ education\ values\ *) \[IndentingNewLine]Do[
          eval[i] = \((\(hstep*\((i - 1)\)\)\/A)\)\^2, {i, 
            hgrid}]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
          Implied\ feasible\ fertility\ values\ *) \[IndentingNewLine]Nmax = 
          Min[{2.5, Floor[1\/\(p\/s + q\)]}]; \[IndentingNewLine]Do[
          nval[i] = \(Nmax\/\(ngrid - 1\)\) \((i - 1)\), {i, 
            ngrid}]; \[IndentingNewLine]\[IndentingNewLine]itercrit = 
          1; \[IndentingNewLine]itercount = 
          1; \[IndentingNewLine]While[\((\((itercount < 
                  maxiter)\) && \((itercrit > 
                  itertol)\))\), \[IndentingNewLine]\[IndentingNewLine]hcount \
= 1; \[IndentingNewLine]While[
            hcount \[LessEqual] 
              hgrid, \[IndentingNewLine]\[IndentingNewLine] (*\ 
              Set\ the\ interim\ utilities\ to\ zero\ \
*) \[IndentingNewLine]prevalues = 
              Table[0, {i, 1, ngrid}, {j, 1, 
                  hgrid}]; \[IndentingNewLine]\[IndentingNewLine]ncount = 
              1; \[IndentingNewLine]While[
              ncount \[LessEqual] 
                ngrid, \[IndentingNewLine]\[IndentingNewLine]ecount = 
                1; \[IndentingNewLine]While[
                ecount \[LessEqual] 
                  hgrid, \[IndentingNewLine]\[IndentingNewLine] (*\ 
                  Need\ to\ check\ whether\ consumption\ is\ positive\ \
*) \[IndentingNewLine]worktime = 
                  1 - p\ nval[ncount]\/s - \((q + eval[ecount])\)\ nval[
                        ncount]; \[IndentingNewLine]\[IndentingNewLine]If[
                  worktime < 
                    0, \[IndentingNewLine]prevalues[\([ncount, 
                        ecount]\)] = \(-1\), \
\[IndentingNewLine]prevalues[\([ncount, 
                        ecount]\)] = \((\((wu + w\ hval[hcount])\)\ worktime)\
\)\^\(1 - \[Sigma]\)\/\(1 - \[Sigma]\) + \[Beta]\ \ \(\((nval[
                                ncount])\)\^eps\) 
                        Value[ecount]\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine]ecount = 
                  ecount + 
                    1;\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]ncount = 
                ncount + 
                  1;\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]NewValue[hcount] = 
              Max[prevalues]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
              The\ following\ extracts\ the\ maximizing\ index\ \
*) \[IndentingNewLine]MaxIndN[hcount] = 
              Ordering[prevalues, \(-1\)]; \[IndentingNewLine]MaxIndE[
                hcount] = 
              Ordering[\(prevalues[\([Ordering[
                        prevalues, \(-1\)]]\)]\)[\([1]\)], \(-1\)]; \
\[IndentingNewLine]\[IndentingNewLine]hcount = 
              hcount + 
                1;\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine]deviation = 
            Table[Value[i] - NewValue[i], {i, 
                hgrid}]; \[IndentingNewLine]\[IndentingNewLine]itercrit = 
            Max[Abs[deviation]]; \[IndentingNewLine]\[IndentingNewLine]Do[
            Value[i] = NewValue[i], {i, 
              hgrid}]; \[IndentingNewLine]\[IndentingNewLine]itercount = 
            itercount + 
              1;\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine]EDev = 
          Table[MaxIndE[i] - i, {i, 
              hgrid}]; \[IndentingNewLine]Eoptind = \(Ordering[Abs[EDev], 
              1]\)[\([1]\)]; \[IndentingNewLine]Noptind = \(MaxIndN[
              Eoptind]\)[\([1]\)]; \[IndentingNewLine]\[IndentingNewLine]If[
          nval[\ Noptind] <  .965\ ntargetlo, Ahi = A; 
          A = 0.5\ A + 0.5\ Alo, \ Alo = A; 
          A = 0.5\ A + 
              0.5\ Ahi]; \[IndentingNewLine]\[IndentingNewLine]\
\[IndentingNewLine]Print[A]; \[IndentingNewLine]Print[
          A\ \@eval[Eoptind]]; \[IndentingNewLine]Print[
          nval[\ Noptind]]; \ \[IndentingNewLine]\[IndentingNewLine]Acount = 
          Acount + 1;\[IndentingNewLine]];\)\)}], "Input"],

Cell[BoxData[
    \(20.`\)], "Print"],

Cell[BoxData[
    \(3.282051282051282`\)], "Print"],

Cell[BoxData[
    \(1.346153846153846`\)], "Print"],

Cell[BoxData[
    \(15.`\)], "Print"],

Cell[BoxData[
    \(2.1538461538461537`\)], "Print"],

Cell[BoxData[
    \(1.8589743589743588`\)], "Print"],

Cell[BoxData[
    \(17.5`\)], "Print"],

Cell[BoxData[
    \(2.153846153846154`\)], "Print"],

Cell[BoxData[
    \(2.3717948717948714`\)], "Print"],

Cell[BoxData[
    \(18.75`\)], "Print"],

Cell[BoxData[
    \(2.4175824175824174`\)], "Print"],

Cell[BoxData[
    \(2.115384615384615`\)], "Print"],

Cell[BoxData[
    \(19.375`\)], "Print"],

Cell[BoxData[
    \(2.5435897435897434`\)], "Print"],

Cell[BoxData[
    \(2.051282051282051`\)], "Print"],

Cell[BoxData[
    \(19.0625`\)], "Print"],

Cell[BoxData[
    \(2.6236559139784945`\)], "Print"],

Cell[BoxData[
    \(1.923076923076923`\)], "Print"],

Cell[BoxData[
    \(18.90625`\)], "Print"],

Cell[BoxData[
    \(2.6448087431693987`\)], "Print"],

Cell[BoxData[
    \(1.923076923076923`\)], "Print"],

Cell[BoxData[
    \(18.828125`\)], "Print"],

Cell[BoxData[
    \(2.65564738292011`\)], "Print"],

Cell[BoxData[
    \(1.923076923076923`\)], "Print"],

Cell[BoxData[
    \(18.8671875`\)], "Print"],

Cell[BoxData[
    \(2.466645387807213`\)], "Print"],

Cell[BoxData[
    \(2.051282051282051`\)], "Print"],

Cell[BoxData[
    \(18.84765625`\)], "Print"],

Cell[BoxData[
    \($Aborted\)], "Output"]
}, Open  ]],

Cell["\<\
Using the parameter values found, reevaluate with a finer grid.\
\>", "Text"],

Cell[BoxData[{
    \(\(ngrid = 60;\)\), "\[IndentingNewLine]", 
    \(\(hgrid = 60;\)\), "\[IndentingNewLine]", 
    \(\(hmax = 8;\)\), "\[IndentingNewLine]", 
    \(\(hstep = hmax/\((hgrid - 1)\);\)\), "\[IndentingNewLine]", 
    \(\(Do[
        Value[i] = 0, {i, 
          hgrid}];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(itertol = 0.0001;\)\), "\[IndentingNewLine]", 
    \(\(maxiter = 30;\)\), "\[IndentingNewLine]", 
    \(\(Aiter = 20;\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(s = 0.965;\)\), "\[IndentingNewLine]", 
    \(\(\[Beta] = 0.0825;\)\), "\[IndentingNewLine]", 
    \(\(A = 
        18.9;\)\[IndentingNewLine]\[IndentingNewLine]\[IndentingNewLine] (*\ 
      feasible\ human\ capital\ values\ *) \), "\[IndentingNewLine]", 
    \(\(Do[
        hval[i] = hstep*\((i - 1)\), {i, 
          hgrid}];\)\[IndentingNewLine]\[IndentingNewLine] (*\ 
      Implied\ feasible\ education\ values\ *) \), "\[IndentingNewLine]", 
    \(\(Do[
        eval[i] = \((\(hstep*\((i - 1)\)\)\/A)\)\^2, {i, 
          hgrid}];\)\[IndentingNewLine]\[IndentingNewLine] (*\ 
      Implied\ feasible\ fertility\ values\ *) \), "\[IndentingNewLine]", 
    \(\(Nmax = Min[{4, Floor[1\/\(p\/s + q\)]}];\)\), "\[IndentingNewLine]", 
    \(\(Do[
        nval[i] = \(Nmax\/\(ngrid - 1\)\) \((i - 1)\), {i, 
          ngrid}];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(itercrit = 1;\)\), "\[IndentingNewLine]", 
    \(\(itercount = 1;\)\), "\[IndentingNewLine]", 
    \(\(While[\((\((itercount < maxiter)\) && \((itercrit > 
                itertol)\))\), \[IndentingNewLine]\[IndentingNewLine]hcount = 
          1; \[IndentingNewLine]While[
          hcount \[LessEqual] 
            hgrid, \[IndentingNewLine]\[IndentingNewLine] (*\ 
            Set\ the\ interim\ utilities\ to\ zero\ \
*) \[IndentingNewLine]prevalues = 
            Table[0, {i, 1, ngrid}, {j, 1, 
                hgrid}]; \[IndentingNewLine]\[IndentingNewLine]ncount = 
            1; \[IndentingNewLine]While[
            ncount \[LessEqual] 
              ngrid, \[IndentingNewLine]\[IndentingNewLine]ecount = 
              1; \[IndentingNewLine]While[
              ecount \[LessEqual] 
                hgrid, \[IndentingNewLine]\[IndentingNewLine] (*\ 
                Need\ to\ check\ whether\ consumption\ is\ positive\ \
*) \[IndentingNewLine]worktime = 
                1 - p\ nval[ncount]\/s - \((q + eval[ecount])\)\ nval[
                      ncount]; \[IndentingNewLine]\[IndentingNewLine]If[
                worktime < 
                  0, \[IndentingNewLine]prevalues[\([ncount, 
                      ecount]\)] = \(-1\), \
\[IndentingNewLine]prevalues[\([ncount, 
                      ecount]\)] = \((\((wu + w\ hval[hcount])\)\ worktime)\)\
\^\(1 - \[Sigma]\)\/\(1 - \[Sigma]\) + \[Beta]\ \ \(\((nval[ncount])\)\^eps\) 
                      Value[ecount]\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]ecount = 
                ecount + 
                  1;\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]ncount = 
              ncount + 
                1;\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine]NewValue[hcount] = 
            Max[prevalues]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
            The\ following\ extracts\ the\ maximizing\ index\ \
*) \[IndentingNewLine]MaxIndN[hcount] = 
            Ordering[prevalues, \(-1\)]; \[IndentingNewLine]MaxIndE[hcount] = 
            Ordering[\(prevalues[\([Ordering[
                      prevalues, \(-1\)]]\)]\)[\([1]\)], \(-1\)]; \
\[IndentingNewLine]\[IndentingNewLine]hcount = 
            hcount + 
              1;\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine]deviation = 
          Table[Value[i] - NewValue[i], {i, 
              hgrid}]; \[IndentingNewLine]\[IndentingNewLine]itercrit = 
          Max[Abs[deviation]]; \[IndentingNewLine]\[IndentingNewLine]Do[
          Value[i] = NewValue[i], {i, 
            hgrid}]; \[IndentingNewLine]\[IndentingNewLine]itercount = 
          itercount + 
            1;\[IndentingNewLine]];\)\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(EDev = 
        Table[MaxIndE[i] - i, {i, hgrid}];\)\), "\[IndentingNewLine]", 
    \(\(Eoptind = \(Ordering[Abs[EDev], 
            1]\)[\([1]\)];\)\), "\[IndentingNewLine]", 
    \(\(Noptind = \(MaxIndN[
            Eoptind]\)[\([1]\)];\)\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(Print[A\ \@eval[Eoptind]];\)\), "\[IndentingNewLine]", 
    \(\(Print[nval[\ Noptind]];\)\ \)}], "Input"],

Cell[BoxData[
    \(2.5762711864406778`\)], "Print"],

Cell[BoxData[
    \(120\/59\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[120/\((s\ 59)\)]\)], "Input"],

Cell[BoxData[
    \(2.107666637393519`\)], "Output"]
}, Open  ]],

Cell["Perfect. Now trying the same thing with higher mortality.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(s = 0.73;\)\), "\[IndentingNewLine]", 
    \(\(\[Beta] = 0.0825;\)\), "\[IndentingNewLine]", 
    \(\(A = 
        18.9;\)\[IndentingNewLine]\[IndentingNewLine]\[IndentingNewLine] (*\ 
      feasible\ human\ capital\ values\ *) \), "\[IndentingNewLine]", 
    \(\(Do[
        hval[i] = hstep*\((i - 1)\), {i, 
          hgrid}];\)\[IndentingNewLine]\[IndentingNewLine] (*\ 
      Implied\ feasible\ education\ values\ *) \), "\[IndentingNewLine]", 
    \(\(Do[
        eval[i] = \((\(hstep*\((i - 1)\)\)\/A)\)\^2, {i, 
          hgrid}];\)\[IndentingNewLine]\[IndentingNewLine] (*\ 
      Implied\ feasible\ fertility\ values\ *) \), "\[IndentingNewLine]", 
    \(\(Nmax = Min[{4, Floor[1\/\(p\/s + q\)]}];\)\), "\[IndentingNewLine]", 
    \(\(Do[
        nval[i] = \(Nmax\/\(ngrid - 1\)\) \((i - 1)\), {i, 
          ngrid}];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(itercrit = 1;\)\), "\[IndentingNewLine]", 
    \(\(itercount = 1;\)\), "\[IndentingNewLine]", 
    \(\(While[\((\((itercount < maxiter)\) && \((itercrit > 
                itertol)\))\), \[IndentingNewLine]\[IndentingNewLine]hcount = 
          1; \[IndentingNewLine]While[
          hcount \[LessEqual] 
            hgrid, \[IndentingNewLine]\[IndentingNewLine] (*\ 
            Set\ the\ interim\ utilities\ to\ zero\ \
*) \[IndentingNewLine]prevalues = 
            Table[0, {i, 1, ngrid}, {j, 1, 
                hgrid}]; \[IndentingNewLine]\[IndentingNewLine]ncount = 
            1; \[IndentingNewLine]While[
            ncount \[LessEqual] 
              ngrid, \[IndentingNewLine]\[IndentingNewLine]ecount = 
              1; \[IndentingNewLine]While[
              ecount \[LessEqual] 
                hgrid, \[IndentingNewLine]\[IndentingNewLine] (*\ 
                Need\ to\ check\ whether\ consumption\ is\ positive\ \
*) \[IndentingNewLine]worktime = 
                1 - p\ nval[ncount]\/s - \((q + eval[ecount])\)\ nval[
                      ncount]; \[IndentingNewLine]\[IndentingNewLine]If[
                worktime < 
                  0, \[IndentingNewLine]prevalues[\([ncount, 
                      ecount]\)] = \(-1\), \
\[IndentingNewLine]prevalues[\([ncount, 
                      ecount]\)] = \((\((wu + w\ hval[hcount])\)\ worktime)\)\
\^\(1 - \[Sigma]\)\/\(1 - \[Sigma]\) + \[Beta]\ \ \(\((nval[ncount])\)\^eps\) 
                      Value[ecount]\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]ecount = 
                ecount + 
                  1;\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]ncount = 
              ncount + 
                1;\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine]NewValue[hcount] = 
            Max[prevalues]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
            The\ following\ extracts\ the\ maximizing\ index\ \
*) \[IndentingNewLine]MaxIndN[hcount] = 
            Ordering[prevalues, \(-1\)]; \[IndentingNewLine]MaxIndE[hcount] = 
            Ordering[\(prevalues[\([Ordering[
                      prevalues, \(-1\)]]\)]\)[\([1]\)], \(-1\)]; \
\[IndentingNewLine]\[IndentingNewLine]hcount = 
            hcount + 
              1;\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine]deviation = 
          Table[Value[i] - NewValue[i], {i, 
              hgrid}]; \[IndentingNewLine]\[IndentingNewLine]itercrit = 
          Max[Abs[deviation]]; \[IndentingNewLine]\[IndentingNewLine]Do[
          Value[i] = NewValue[i], {i, 
            hgrid}]; \[IndentingNewLine]\[IndentingNewLine]itercount = 
          itercount + 
            1;\[IndentingNewLine]];\)\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(EDev = 
        Table[MaxIndE[i] - i, {i, hgrid}];\)\), "\[IndentingNewLine]", 
    \(\(Eoptind = \(Ordering[Abs[EDev], 
            1]\)[\([1]\)];\)\), "\[IndentingNewLine]", 
    \(\(Noptind = \(MaxIndN[
            Eoptind]\)[\([1]\)];\)\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(Print[A\ \@eval[Eoptind]];\)\), "\[IndentingNewLine]", 
    \(\(Print[nval[\ Noptind]];\)\ \ \)}], "Input"],

Cell[BoxData[
    \(2.711864406779661`\)], "Print"],

Cell[BoxData[
    \(104\/59\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(N[104/59]/0.73\), "\[IndentingNewLine]", 
    \(N[104/59]\)}], "Input"],

Cell[BoxData[
    \(2.414673786858602`\)], "Output"],

Cell[BoxData[
    \(1.7627118644067796`\)], "Output"]
}, Open  ]],

Cell["\<\
This answers all the important questions. Now we only need to do a Table with \
complete results. Do the initial case with low A first.Upper bound for net \
fertility is set to 5.\
\>", "Text"],

Cell[BoxData[{
    \(\(ngrid = 80;\)\), "\[IndentingNewLine]", 
    \(\(hgrid = 80;\)\), "\[IndentingNewLine]", 
    \(\(hmax = 1;\)\), "\[IndentingNewLine]", 
    \(\(hstep = hmax/\((hgrid - 1)\);\)\), "\[IndentingNewLine]", 
    \(\(Do[
        Value[i] = 0, {i, 
          hgrid}];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(itertol = 0.0001;\)\), "\[IndentingNewLine]", 
    \(\(maxiter = 30;\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(TFR1 = Table[0, {i, 20}];\)\), "\[IndentingNewLine]", 
    \(\(NTFR1 = 
        Table[0, {i, 20}];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(mortcount = 1;\)\), "\[IndentingNewLine]", 
    \(\(While[
        mortcount \[LessEqual] 
          20, \[IndentingNewLine]\[IndentingNewLine]s = \((mortcount -  \
.9)\)/\((20 -  .9)\); \[IndentingNewLine]A = 
          6.22; \[IndentingNewLine]\[Beta] = 
          0.0825; \[IndentingNewLine]\[IndentingNewLine]\[IndentingNewLine] \
(*\ feasible\ human\ capital\ values\ *) \[IndentingNewLine]Do[
          hval[i] = hstep*\((i - 1)\), {i, 
            hgrid}]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
          Implied\ feasible\ education\ values\ *) \[IndentingNewLine]Do[
          eval[i] = \((\(hstep*\((i - 1)\)\)\/A)\)\^2, {i, 
            hgrid}]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
          Implied\ feasible\ fertility\ values\ *) \[IndentingNewLine]Nmax = 
          Min[{5, Floor[1\/\(p\/s + q\)]}]; \[IndentingNewLine]Do[
          nval[i] = \(Nmax\/\(ngrid - 1\)\) \((i - 1)\), {i, 
            ngrid}]; \[IndentingNewLine]\[IndentingNewLine]itercrit = 
          1; \[IndentingNewLine]itercount = 
          1; \[IndentingNewLine]While[\((\((itercount < 
                  maxiter)\) && \((itercrit > 
                  itertol)\))\), \[IndentingNewLine]\[IndentingNewLine]hcount \
= 1; \[IndentingNewLine]While[
            hcount \[LessEqual] 
              hgrid, \[IndentingNewLine]\[IndentingNewLine] (*\ 
              Set\ the\ interim\ utilities\ to\ zero\ \
*) \[IndentingNewLine]prevalues = 
              Table[0, {i, 1, ngrid}, {j, 1, 
                  hgrid}]; \[IndentingNewLine]\[IndentingNewLine]ncount = 
              1; \[IndentingNewLine]While[
              ncount \[LessEqual] 
                ngrid, \[IndentingNewLine]\[IndentingNewLine]ecount = 
                1; \[IndentingNewLine]While[
                ecount \[LessEqual] 
                  hgrid, \[IndentingNewLine]\[IndentingNewLine] (*\ 
                  Need\ to\ check\ whether\ consumption\ is\ positive\ \
*) \[IndentingNewLine]worktime = 
                  1 - p\ nval[ncount]\/s - \((q + eval[ecount])\)\ nval[
                        ncount]; \[IndentingNewLine]\[IndentingNewLine]If[
                  worktime < 
                    0, \[IndentingNewLine]prevalues[\([ncount, 
                        
                        ecount]\)] = \(-1\), \
\[IndentingNewLine]prevalues[\([ncount, 
                        ecount]\)] = \((\((wu + w\ hval[hcount])\)\ worktime)\
\)\^\(1 - \[Sigma]\)\/\(1 - \[Sigma]\) + \[Beta]\ \ \(\((nval[
                                ncount])\)\^eps\) 
                        Value[ecount]\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine]ecount = 
                  ecount + 
                    1;\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]ncount = 
                ncount + 
                  1;\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]NewValue[hcount] = 
              Max[prevalues]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
              The\ following\ extracts\ the\ maximizing\ index\ \
*) \[IndentingNewLine]MaxIndN[hcount] = 
              Ordering[prevalues, \(-1\)]; \[IndentingNewLine]MaxIndE[
                hcount] = 
              Ordering[\(prevalues[\([Ordering[
                        prevalues, \(-1\)]]\)]\)[\([1]\)], \(-1\)]; \
\[IndentingNewLine]\[IndentingNewLine]hcount = 
              hcount + 
                1;\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine]deviation = 
            Table[Value[i] - NewValue[i], {i, 
                hgrid}]; \[IndentingNewLine]\[IndentingNewLine]itercrit = 
            Max[Abs[deviation]]; \[IndentingNewLine]\[IndentingNewLine]Do[
            Value[i] = NewValue[i], {i, 
              hgrid}]; \[IndentingNewLine]\[IndentingNewLine]itercount = 
            itercount + 
              1;\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine]EDev = 
          Table[MaxIndE[i] - i, {i, 
              hgrid}]; \[IndentingNewLine]Eoptind = \(Ordering[Abs[EDev], 
              1]\)[\([1]\)]; \[IndentingNewLine]Noptind = \(MaxIndN[
              Eoptind]\)[\([1]\)]; \
\[IndentingNewLine]\[IndentingNewLine]Print[
          A\ \@eval[Eoptind]]; \[IndentingNewLine]Print[
          nval[\ Noptind]]; \ \
\[IndentingNewLine]\[IndentingNewLine]NTFR1[\([mortcount]\)] = 
          nval[\ Noptind]; \[IndentingNewLine]TFR1[\([mortcount]\)] = 
          nval[\ Noptind]/s; \[IndentingNewLine]mortcount = 
          mortcount + 1;\[IndentingNewLine]];\)\)}], "Input"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(NTFR1\)\" is similar to \
existing symbol \"\!\(TFR1\)\"."\)], "Message"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(eval\)\" is similar to \
existing symbol \"\!\(hval\)\"."\)], "Message"],

Cell[BoxData[
    \(General::"spell" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(nval\)\" is similar to \
existing symbols \!\({eval, hval}\)."\)], "Message"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(ncount\)\" is similar \
to existing symbol \"\!\(hcount\)\"."\)], "Message"],

Cell[BoxData[
    \(General::"spell" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(ecount\)\" is similar \
to existing symbols \!\({hcount, ncount}\)."\)], "Message"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(MaxIndE\)\" is similar \
to existing symbol \"\!\(MaxIndN\)\"."\)], "Message"],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(General :: \"spell1\"\) will be suppressed \
during this calculation."\)], "Message"],

Cell[BoxData[
    \(1.`\)], "Print"],

Cell[BoxData[
    \(10\/79\)], "Print"],

Cell[BoxData[
    \(1.`\)], "Print"],

Cell[BoxData[
    \(35\/79\)], "Print"],

Cell[BoxData[
    \(0.8734177215189873`\)], "Print"],

Cell[BoxData[
    \(65\/79\)], "Print"],

Cell[BoxData[
    \(0.7594936708860759`\)], "Print"],

Cell[BoxData[
    \(95\/79\)], "Print"],

Cell[BoxData[
    \(0.6835443037974683`\)], "Print"],

Cell[BoxData[
    \(120\/79\)], "Print"],

Cell[BoxData[
    \(0.6329113924050633`\)], "Print"],

Cell[BoxData[
    \(145\/79\)], "Print"],

Cell[BoxData[
    \(0.5949367088607594`\)], "Print"],

Cell[BoxData[
    \(170\/79\)], "Print"],

Cell[BoxData[
    \(0.569620253164557`\)], "Print"],

Cell[BoxData[
    \(190\/79\)], "Print"],

Cell[BoxData[
    \(0.5569620253164558`\)], "Print"],

Cell[BoxData[
    \(205\/79\)], "Print"],

Cell[BoxData[
    \(0.5316455696202531`\)], "Print"],

Cell[BoxData[
    \(220\/79\)], "Print"],

Cell[BoxData[
    \(0.5189873417721519`\)], "Print"],

Cell[BoxData[
    \(235\/79\)], "Print"],

Cell[BoxData[
    \(0.5063291139240507`\)], "Print"],

Cell[BoxData[
    \(250\/79\)], "Print"],

Cell[BoxData[
    \(0.4936708860759494`\)], "Print"],

Cell[BoxData[
    \(260\/79\)], "Print"],

Cell[BoxData[
    \(0.4936708860759494`\)], "Print"],

Cell[BoxData[
    \(270\/79\)], "Print"],

Cell[BoxData[
    \(0.48101265822784806`\)], "Print"],

Cell[BoxData[
    \(280\/79\)], "Print"],

Cell[BoxData[
    \(0.45569620253164556`\)], "Print"],

Cell[BoxData[
    \(295\/79\)], "Print"],

Cell[BoxData[
    \(0.46835443037974683`\)], "Print"],

Cell[BoxData[
    \(300\/79\)], "Print"],

Cell[BoxData[
    \(0.45569620253164556`\)], "Print"],

Cell[BoxData[
    \(310\/79\)], "Print"],

Cell[BoxData[
    \(0.45569620253164556`\)], "Print"],

Cell[BoxData[
    \(315\/79\)], "Print"],

Cell[BoxData[
    \(0.45569620253164556`\)], "Print"],

Cell[BoxData[
    \(320\/79\)], "Print"]
}, Open  ]],

Cell[BoxData[{
    \(\(NTFRList = 
        Table[{\((i -  .9)\)/\((20 -  .9)\), NTFR1[\([i]\)]}, {i, 
            20}];\)\), "\[IndentingNewLine]", 
    \(\(TFRList = 
        Table[{\((i -  .9)\)/\((20 -  .9)\), TFR1[\([i]\)]}, {i, 
            20}];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(plot1 = 
      MultipleListPlot[TFRList, NTFRList, 
        SymbolShape \[Rule] {PlotSymbol[Box, 0], PlotSymbol[Box, 0]}, 
        PlotJoined \[Rule] True, PlotRange \[Rule] {{0, 1}, {0, 10}}, 
        AxesLabel \[Rule] {"\<s\>", "\<Children\>"}, 
        PlotStyle \[Rule] {{Thickness[ .008]}, {Dashing[{ .02,  .02}], 
              Thickness[ .008]}}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.0618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(10)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.0481 .16266 m
.0982 .27884 L
.1483 .3429 L
.1984 .37461 L
.2485 .37779 L
.2986 .3799 L
.3487 .3814 L
.3988 .37272 L
.4489 .35727 L
.499 .34491 L
.5491 .33481 L
.5992 .3264 L
.6493 .31327 L
.6994 .30201 L
.7495 .29226 L
.7996 .28863 L
.8497 .27621 L
.8998 .26953 L
.9499 .25943 L
1 .25034 L
s
.0001 w
.0481 .16266 m
.0481 .16266 L
.0481 .16266 L
.0481 .16266 L
.0481 .16266 L closepath F
.0982 .27884 m
.0982 .27884 L
.0982 .27884 L
.0982 .27884 L
.0982 .27884 L closepath F
.1483 .3429 m
.1483 .3429 L
.1483 .3429 L
.1483 .3429 L
.1483 .3429 L closepath F
.1984 .37461 m
.1984 .37461 L
.1984 .37461 L
.1984 .37461 L
.1984 .37461 L closepath F
.2485 .37779 m
.2485 .37779 L
.2485 .37779 L
.2485 .37779 L
.2485 .37779 L closepath F
.2986 .3799 m
.2986 .3799 L
.2986 .3799 L
.2986 .3799 L
.2986 .3799 L closepath F
.3487 .3814 m
.3487 .3814 L
.3487 .3814 L
.3487 .3814 L
.3487 .3814 L closepath F
.3988 .37272 m
.3988 .37272 L
.3988 .37272 L
.3988 .37272 L
.3988 .37272 L closepath F
.4489 .35727 m
.4489 .35727 L
.4489 .35727 L
.4489 .35727 L
.4489 .35727 L closepath F
.499 .34491 m
.499 .34491 L
.499 .34491 L
.499 .34491 L
.499 .34491 L closepath F
.5491 .33481 m
.5491 .33481 L
.5491 .33481 L
.5491 .33481 L
.5491 .33481 L closepath F
.5992 .3264 m
.5992 .3264 L
.5992 .3264 L
.5992 .3264 L
.5992 .3264 L closepath F
.6493 .31327 m
.6493 .31327 L
.6493 .31327 L
.6493 .31327 L
.6493 .31327 L closepath F
.6994 .30201 m
.6994 .30201 L
.6994 .30201 L
.6994 .30201 L
.6994 .30201 L closepath F
.7495 .29226 m
.7495 .29226 L
.7495 .29226 L
.7495 .29226 L
.7495 .29226 L closepath F
.7996 .28863 m
.7996 .28863 L
.7996 .28863 L
.7996 .28863 L
.7996 .28863 L closepath F
.8497 .27621 m
.8497 .27621 L
.8497 .27621 L
.8497 .27621 L
.8497 .27621 L closepath F
.8998 .26953 m
.8998 .26953 L
.8998 .26953 L
.8998 .26953 L
.8998 .26953 L closepath F
.9499 .25943 m
.9499 .25943 L
.9499 .25943 L
.9499 .25943 L
.9499 .25943 L closepath F
1 .25034 m
1 .25034 L
1 .25034 L
1 .25034 L
1 .25034 L closepath F
.008 w
[ .02 .02 ] 0 setdash
.0481 .00782 m
.0982 .02738 L
.1483 .05085 L
.1984 .07432 L
.2485 .09388 L
.2986 .11344 L
.3487 .13299 L
.3988 .14864 L
.4489 .16038 L
.499 .17211 L
.5491 .18385 L
.5992 .19558 L
.6493 .2034 L
.6994 .21123 L
.7495 .21905 L
.7996 .23078 L
.8497 .2347 L
.8998 .24252 L
.9499 .24643 L
1 .25034 L
s
.0001 w
[ ] 0 setdash
.0481 .00782 m
.0481 .00782 L
.0481 .00782 L
.0481 .00782 L
.0481 .00782 L closepath F
.0982 .02738 m
.0982 .02738 L
.0982 .02738 L
.0982 .02738 L
.0982 .02738 L closepath F
.1483 .05085 m
.1483 .05085 L
.1483 .05085 L
.1483 .05085 L
.1483 .05085 L closepath F
.1984 .07432 m
.1984 .07432 L
.1984 .07432 L
.1984 .07432 L
.1984 .07432 L closepath F
.2485 .09388 m
.2485 .09388 L
.2485 .09388 L
.2485 .09388 L
.2485 .09388 L closepath F
.2986 .11344 m
.2986 .11344 L
.2986 .11344 L
.2986 .11344 L
.2986 .11344 L closepath F
.3487 .13299 m
.3487 .13299 L
.3487 .13299 L
.3487 .13299 L
.3487 .13299 L closepath F
.3988 .14864 m
.3988 .14864 L
.3988 .14864 L
.3988 .14864 L
.3988 .14864 L closepath F
.4489 .16038 m
.4489 .16038 L
.4489 .16038 L
.4489 .16038 L
.4489 .16038 L closepath F
.499 .17211 m
.499 .17211 L
.499 .17211 L
.499 .17211 L
.499 .17211 L closepath F
.5491 .18385 m
.5491 .18385 L
.5491 .18385 L
.5491 .18385 L
.5491 .18385 L closepath F
.5992 .19558 m
.5992 .19558 L
.5992 .19558 L
.5992 .19558 L
.5992 .19558 L closepath F
.6493 .2034 m
.6493 .2034 L
.6493 .2034 L
.6493 .2034 L
.6493 .2034 L closepath F
.6994 .21123 m
.6994 .21123 L
.6994 .21123 L
.6994 .21123 L
.6994 .21123 L closepath F
.7495 .21905 m
.7495 .21905 L
.7495 .21905 L
.7495 .21905 L
.7495 .21905 L closepath F
.7996 .23078 m
.7996 .23078 L
.7996 .23078 L
.7996 .23078 L
.7996 .23078 L closepath F
.8497 .2347 m
.8497 .2347 L
.8497 .2347 L
.8497 .2347 L
.8497 .2347 L closepath F
.8998 .24252 m
.8998 .24252 L
.8998 .24252 L
.8998 .24252 L
.8998 .24252 L closepath F
.9499 .24643 m
.9499 .24643 L
.9499 .24643 L
.9499 .24643 L
.9499 .24643 L closepath F
1 .25034 m
1 .25034 L
1 .25034 L
1 .25034 L
1 .25034 L closepath F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{563.625, 348.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008c0001G1000`40O003h00Oogooogoo=Goo001n
Ool20004Ool20003Ool4001EOol20004Ool20005Ool3001COol20004Ool20003Ool3001FOol20004
Ool20004Ool2001JOol5000MOol007eoo`04001oogoo0008Ool00`00Oomoo`1EOol01000Oomoo`00
2goo00<007ooOol0DGoo00@007ooOol000Qoo`04001oogoo001DOol01000Oomoo`0027oo00@007oo
Ool005]oo`03001oogoo01eoo`00OGoo00@007ooOol000Uoo`03001oogoo05Aoo`04001oogoo0008
Ool5001BOol01000Oomoo`0027oo00@007ooOol005Aoo`04001oogoo0008Ool01000Oomoo`00Fgoo
00<007ooOol07Goo001mOol01000Oomoo`002Woo00<007ooOol0Dgoo00@007ooOol000Qoo`04001o
ogoo001COol01000Oomoo`0027oo0`00EGoo00@007ooOol000Uoo`8005aoo`03001oogoo01eoo`00
OGoo00@007ooOol000Qoo`04001oogoo001DOol01000Oomoo`002Goo00<007oo0000Dgoo00@007oo
Ool000Uoo`03001oogoo05Aoo`04001oogoo0008Ool01000Oomoo`00Fgoo00<007ooOol07Goo001n
Ool2000:Ool2001FOol2000;Ool2001DOol2000:Ool3001EOol2000:Ool2001KOol2000OOol00?mo
oomoocEoo`00ogooogoo=Goo003oOoooOoleOol00?mooomoocEoo`00ogooogoo=Goo003oOoooOole
Ool00?mooomoocEoo`00ogooogoo9Goo0`003Goo000ROooo003c000BOol00`00Oomoo`0:Ool0029o
o`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo01Eoo`03001oogoo01Io
o`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo01Io
o`03001oogoo01Eoo`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo01Io
o`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo01Eoo`03001oogoo01Ioo`03001oogoo01Io
o`03001oogoo00eoo`<000eoo`008Woo00<007ooOol05Woo00<007ooOol05Woo00<007ooOol05Woo
00<007ooOol05Goo00<007ooOol05Woo00<007ooOol05Woo00<007ooOol05Woo00<007ooOol05Woo
00<007ooOol05Woo00<007ooOol05Woo00<007ooOol05Goo00<007ooOol05Woo00<007ooOol05Woo
00<007ooOol05Woo00<007ooOol05Woo00<007ooOol05Woo00<007ooOol05Woo00<007ooOol05Goo
00<007ooOol05Woo00<007ooOol05Woo00<007ooOol03Goo100037oo000ROol00`00Oomoo`0DOol3
0019Ool00`00Oomoo`1QOol00`00Oomoo`1POol00`00Oomoo`1QOol00`00Oomoo`1POol00`00Oomo
o`0MOol0029oo`03001oogoo01Aoo`D00?moooIoo`008Woo00<007ooOol057oo2000ogoolgoo000R
Ool00`00Oomoo`0FOol8003oOooaOol0029oo`03001oogoo01Qoo`P00?moonmoo`008Woo00<007oo
Ool06goo1@00ogookgoo000ROol00`00Oomoo`0MOol3003oOoo_Ool0029oo`03001oogoo02Ioo`<0
0?moonIoo`008Woo00<007ooOol09Woo1@00ogooi7oo000ROol00`00Oomoo`0VOol8003oOooQOol0
029oo`03001oogoo02Qoo`P00?moommoo`008Woo00<007ooOol0:Woo2@00ogoog7oo000ROol00`00
Oomoo`0]Ool6003oOooLOol0029oo`<002moo`@00?moomaoo`008Woo00<007ooOol0ogooogoo47oo
000ROol00`00Oomoo`0iOol3003oOooCOol0029oo`03001oogoo03Uoo`D00?moom5oo`008Woo00<0
07ooOol0>Goo1P00ogood7oo000ROol00`00Oomoo`0kOol6003oOoo>Ool0029oo`03001oogoo03eo
o`H00?moolaoo`008Woo00<007ooOol0?Woo1`00ogoobWoo000ROol00`00Oomoo`10Ool5003oOoo:
Ool0029oo`03001oogoo049oo`<00?moolYoo`008Woo00<007ooOol0Agoo00<007ooOol0ogooaGoo
000ROol00`00Oomoo`1;Ool3003oOoo1Ool0029oo`03001oogoo04]oo`D00?mookmoo`008Woo00<0
07ooOol0Bgoo2000ogoo_7oo000ROol00`00Oomoo`1=Ool8003oOonjOol0029oo`<004moo`P00?mo
okQoo`008Woo00<007ooOol0DWoo1@00ogoo^7oo000ROol00`00Oomoo`1DOol3003oOonhOol0029o
o`03001oogoo0?mooomooa1oo`008Woo00<007ooOol0GGoo0`00ogoo[goo000ROol00`00Oomoo`1M
Ool5003oOon]Ool0029oo`03001oogoo05eoo`L00?mooj]oo`008Woo00<007ooOol0Ggoo2000ogoo
Z7oo000ROol00`00Oomoo`1QOol8003oOonVOol0029oo`03001oogoo06=oo`H00?moojIoo`008Woo
00<007ooOol0IWoo0`00ogooYWoo000ROol00`00Oomoo`3oOoooOol@Ool0029oo`03001oogoo06mo
o`@00?mooiaoo`008Woo00<007ooOol0Kgoo1P00ogooVWoo000ROol00`00Oomoo`1_Ool9003oOonG
Ool0029oo`<0079oo`T00?mooiAoo`008Woo00<007ooOol0M7oo1`00ogooU7oo000ROol00`00Oomo
o`1gOol4003oOonDOol0029oo`03001oogoo0?mooomooa1oo`008Woo00<007ooOol0PWoo0`00ogoo
RWoo000ROol00`00Oomoo`22Ool5003oOon8Ool0029oo`03001oogoo089oo`P00?moohEoo`008Woo
00<007ooOol0Q7oo2000ogooPgoo000ROol00`00Oomoo`26Ool8003oOon1Ool0029oo`03001oogoo
08Uoo`D00?mooh5oo`008Woo00<007ooOol0Rgoo0`00ogooPGoo000ROol00`00Oomoo`2BOol00`00
Ool00002003oOomhOol0029oo`03001oogoo09Aoo`D00?moogIoo`008Woo00<007ooOol0U7oo2000
ogooLgoo000GOol40007Ool00`00Oomoo`2FOol8003oOomaOol001Moo`03001oogoo00Qoo`03001o
ogoo09Qoo`P00?moofmoo`0067oo00<007ooOol01goo1000VWoo1@00ogooKgoo000IOol00`00Oomo
o`06Ool00`00Oomoo`2MOol3003oOom_Ool001Moo`04001oogoo0007Ool00`00Oomoo`2WOol3003o
OomUOol001Qoo`8000Qoo`03001oogoo0:Moo`D00?moof=oo`008Woo00<007ooOol0Ygoo1`00ogoo
HGoo000ROol00`00Oomoo`2YOol8003oOomNOol0029oo`03001oogoo0:]oo`P00?mooeaoo`008Woo
00<007ooOol0[Goo1P00ogooG7oo000ROol00`00Oomoo`2`Ool3003oOomLOol0029oo`03001oogoo
0;Yoo`@00?mooe5oo`008Woo00<007ooOol0^Woo1`00ogooCWoo000ROol00`00Oomoo`2jOol<003o
Oom9Ool0029oo`03001oogoo0;ioo`P00?moodUoo`008Woo00<007ooOol0`Goo1@00ogooBGoo000R
Ool00`00Oomoo`3=Ool4003oOolnOol0029oo`<00<eoo`P00?moocYoo`008Woo00<007ooOol0cGoo
3000ogoo=Woo000ROol00`00Oomoo`3AOol8003oOolfOol0029oo`03001oogoo01Aoo`<00;ioo`@0
00=oo`04001oogooOol4003oOol[Ool0029oo`03001oogoo01Aoo`<00<Uoo`L00?moobQoo`008Woo
00<007ooOol057oo1000b7oo2P00ogoo9Goo000ROol00`00Oomoo`0EOol3003;Ool:003oOolROol0
029oo`03001oogoo01Eoo`@00<eoo`L00?moob9oo`008Woo00<007ooOol05Woo0`00d7oo10001Woo
1@00ogoo5goo000ROol00`00Oomoo`0FOol3003JOol9003oOolCOol0029oo`03001oogoo01Ioo`@0
0=Uoo`d00?moo`moo`008Woo00<007ooOol05goo0`00gWoo2000ogoo3goo000ROol00`00Oomoo`0G
Ool4003QOol40007Ool4003oOol4Ool0029oo`03001oogoo01Qoo`<00>aoo`H00?moo`9oo`008Woo
00<007ooOol067oo1000jgoo2@00oWoo000ROol3000IOol3003^Ool:003jOol0029oo`03001oogoo
01Uoo`<00?1oo`P00?Yoo`008Woo00<007ooOol06Goo1000lgoo10001Woo1000l7oo000ROol00`00
Oomoo`0JOol3003mOol9003[Ool0029oo`03001oogoo01Yoo`@00?aoo`d00>Moo`008Woo00<007oo
Ool06goo0`00ogoo0Goo2@00igoo000ROol00`00Oomoo`0KOol4003oOol5Ool50006Ool6003JOol0
029oo`03001oogoo01aoo`<00?mooa1oo``00=Aoo`008Woo00<007ooOol077oo0`00ogoo47oo3000
e7oo000ROol00`00Oomoo`0LOol4003oOolEOol60006Ool70037Ool0029oo`03001oogoo01eoo`<0
0?moob9oo`d00<1oo`008Woo00<007ooOol07Goo1000ogoo8Goo3@00`7oo000ROol00`00Oomoo`0N
Ool3003oOolWOol70007Ool8002aOol0029oo`03001oogoo01ioo`@00?moocAoo`d00:aoo`008Woo
00<007ooOol07goo0`00ogoo=7oo3@00[7oo000ROol00`00Oomoo`0OOol3003oOollOol50007Ool5
002POol0029oo`<001moo`@00?moodMoo`/009Yoo`008Woo00<007ooOol087oo0`00ogooAgoo2`00
VWoo000ROol00`00Oomoo`0POol4003oOom;Ool7002IOol0029oo`03001oogoo025oo`<00?moodmo
o`<000Moo`@008ioo`008Woo00<007ooOol08Goo1000ogooCgoo00<007ooOol01Woo2@00RGoo000R
Ool00`00Oomoo`0ROol3003oOomHOol=0025Ool0029oo`03001oogoo029oo`<00?mooeaoo`T008Eo
o`008Woo00<007ooOol08Woo1000ogooH7oo10000Woo00<007ooOol00Woo3000LWoo000ROol00`00
Oomoo`0SOol3003oOom[Ool<0007Ool4001WOol0029oo`03001oogoo02=oo`@00?moofYoo``000Mo
o`T0069oo`008Woo00<007ooOol097oo0`00ogooOGoo3@00GWoo000ROol00`00Oomoo`0TOol4003o
Oon0Ool90007Ool3001DOol0029oo`03001oogoo02Eoo`<00?moohEoo`@000Moo`d004Yoo`006Goo
0`001Woo00<007ooOol09Goo0`00ogooT7oo3@001goo1P00?Goo000JOol00`00Oomoo`05Ool00`00
Oomoo`0UOol4003oOonBOol:0007Ool=000fOol001Moo`D000Ioo`@002Eoo`<00?mooj=oo`d000Mo
o`d0029oo`005goo00@007ooOol000Moo`03001oogoo02Ioo`@00?moojQoo`L000Mooa4001ioo`00
67oo00<007oo00001goo00<007ooOol09goo0`00ogoo]Woo4@007Woo000IOol20007Ool00`00Oomo
o`0WOol4003oOoneOolA000NOol0029oo`03001oogoo02Qoo`<00?moojmooa8002=oo`008Woo00<0
07ooOol0:7oo0`00ogooZGoo4P00:Goo000ROol00`00Oomoo`0XOol4003oOonSOolA000_Ool0029o
o`03001oogoo02Uoo`<00?mooiiooa0003Eoo`008Woo00<007ooOol0:Goo1000ogooV7oo3`00>goo
000ROol00`00Oomoo`0ZOol3003oOonCOol?0010Ool0029oo`03001oogoo02Yoo`@00?moohaooa00
04Eoo`008Woo00<007ooOol0:goo0`00ogooQWoo4@00BWoo000ROol00`00Oomoo`0[Ool3003oOon0
OolB001?Ool0029oo`03001oogoo02]oo`@00?moogUooa8005Eoo`008Woo00<007ooOol0;7oo0`00
ogooLgoo4P00Fgoo000ROol00`00Oomoo`0/Ool4003oOom^Ool@001QOol0029oo`<002eoo`<00?mo
ofYoo`h006Moo`008Woo00<007ooOol0;Goo1000ogooIGoo3000KGoo000ROol00`00Oomoo`0^Ool4
003oOomPOol<001aOol0029oo`03001oogoo02moo`@00?mooe]oo``007Eoo`008Woo00<007ooOol0
<7oo0`00ogooDgoo4000NGoo000ROol00`00Oomoo`0aOol3003oOom6OolH001mOol0029oo`03001o
ogoo035oo`@00?mooc]ooah0085oo`008Woo00<007ooOol0<Woo1000ogoo=7oo7000RGoo000ROol0
0`00Oomoo`0cOol4003oOol]OolF002EOol0029oo`03001oogoo03Aoo`<00?moobMooa8009moo`00
8Woo00<007ooOol0=Goo0`00ogoo87oo4P00YGoo000ROol00`00Oomoo`0eOol4003oOolKOol@002[
Ool0029oo`03001oogoo03Ioo`@00?mooaIoo`h00;5oo`008Woo00<007ooOol0=goo0`00ogoo4Woo
3000]goo000ROol00`00Oomoo`0hOol3003oOol=Ool<002kOol0029oo`<003Qoo`@00?moo`Qoo``0
0;moo`008Woo00<007ooOol0>Goo1000ogoo0goo3000`goo000ROol00`00Oomoo`0jOol4003mOol<
0037Ool0029oo`03001oogoo03]oo`<00?Yoo`/00<]oo`008Woo00<007ooOol0?7oo0`00mGoo2`00
cgoo000ROol00`00Oomoo`0lOol4003`Ool;003COol0029oo`03001oogoo03eoo`@00>aoo`/00=Io
o`008Woo00<007ooOol0?Woo0`00j7oo2`00fWoo000ROol00`00Oomoo`0oOol3003ROol<003NOol0
029oo`03001oogoo03moo`@00=]oo`l00>5oo`008Woo00<007ooOol0@7oo1000e7oo4@00iGoo000R
Ool00`00Oomoo`11Ool4003=OolB003ZOol0029oo`03001oogoo049oo`<00<Mooa800?1oo`008Woo
00<007ooOol0@goo0`00`Goo4@00mWoo000ROol00`00Oomoo`13Ool4002kOol@003lOol0029oo`<0
04Aoo`@00;Eoo`l00?moo`=oo`008Woo00<007ooOol0AGoo1000[goo3`00ogoo27oo000ROol00`00
Oomoo`16Ool4002YOol?003oOol=Ool0029oo`03001oogoo04Ioo`H00:=oo`h00?mooa9oo`008Woo
00<007ooOol0B7oo1@00WWoo3@00ogoo5goo000ROol00`00Oomoo`19Ool6002HOol<003oOolLOol0
029oo`03001oogoo04]oo`H0099oo``00?moob1oo`008Woo00<007ooOol0C7oo1P00SGoo3000ogoo
97oo000ROol00`00Oomoo`1>Ool60026Ool=003oOolXOol0029oo`03001oogoo051oo`D0089oo``0
0?moobaoo`008Woo00<007ooOol0DGoo1P00OGoo2`00ogoo<7oo000ROol00`00Oomoo`1COol5001i
Ool:003oOoldOol0029oo`03001oogoo05Aoo`H007Aoo`X00?moocMoo`008Woo00<007ooOol0EWoo
1P00Kgoo2P00ogoo>Woo000GOol30008Ool00`00Oomoo`1GOol6001[Ool:003oOolmOol001Moo`04
001oogoo0007Ool00`00Oomoo`1IOol6001VOol:003oOom0Ool001Moo`04001oogoo0007Ool4001J
Ool5001POol<003oOom3Ool001Moo`<000Qoo`03001oogoo05aooa4004eoo`l00?moodIoo`0067oo
00<007ooOol01goo00<007ooOol0GWoo:000;Woo4P00ogooBGoo000HOol30007Ool00`00Oomoo`1O
Oolo000@OolB003oOom?Ool0029oo`03001oogoo06eoodd00?mooeEoo`008Woo00<007ooOol0QWoo
;P00ogooFgoo000ROol00`00Oomoo`2NOol@003oOomQOol0029oo`03001oogoo0?mooomooa1oo`00
8Woo00<007ooOol0ogooogoo47oo000ROol00`00Oomoo`3oOoooOol@Ool0029oo`03001oogoo0?mo
oomooa1oo`008Woo00<007ooOol0ogooogoo47oo000ROol00`00Oomoo`3oOoooOol@Ool0029oo`03
001oogoo0?mooomooa1oo`008Woo00<007ooOol0ogooogoo47oo000ROol3003oOoooOol@Ool0029o
o`03001oogoo0?mooomooa1oo`008Woo00<007ooOol0ogooogoo47oo000ROol00`00Oomoo`3oOooo
Ool@Ool0029oo`03001oogoo0?mooomooa1oo`008Woo00<007ooOol0ogooogoo47oo000ROol00`00
Oomoo`3oOoooOol@Ool0029oo`03001oogoo0?mooomooa1oo`008Woo00<007ooOol0ogooogoo47oo
000ROol00`00Oomoo`3oOoooOol@Ool0029oo`03001oogoo0?mooomooa1oo`008Woo00<007ooOol0
ogooogoo47oo000ROol00`00Oomoo`3oOoooOol@Ool0029oo`03001oogoo0?mooomooa1oo`008Woo
00<007ooOol0ogooogoo47oo000ROol3003oOoooOol@Ool0029oo`03001oogoo0?mooomooa1oo`00
8Woo00<007ooOol0ogooogoo47oo000ROol00`00Oomoo`3oOoooOol@Ool0029oo`03001oogoo0?mo
oomooa1oo`008Woo00<007ooOol0ogooogoo47oo000ROol00`00Oomoo`3oOoooOol@Ool0029oo`03
001oogoo0?mooomooa1oo`008Woo00<007ooOol0ogooogoo47oo000ROol00`00Oomoo`3oOoooOol@
Ool0029oo`03001oogoo0?mooomooa1oo`008Woo00<007ooOol0ogooogoo47oo000ROol00`00Oomo
o`3oOoooOol@Ool0029oo`03001oogoo0?mooomooa1oo`008Woo00<007ooOol0ogooogoo47oo000R
Ool00`00Oomoo`3oOoooOol@Ool0029oo`<00?mooomooa1oo`008Woo00<007ooOol0ogooogoo47oo
000ROol00`00Oomoo`3oOoooOol@Ool0029oo`03001oogoo0?mooomooa1oo`008Woo00<007ooOol0
ogooogoo47oo000ROol00`00Oomoo`3oOoooOol@Ool0029oo`03001oogoo0?mooomooa1oo`008Woo
00<007ooOol0ogooogoo47oo000ROol00`00Oomoo`3oOoooOol@Ool0029oo`03001oogoo0?mooomo
oa1oo`008Woo00<007ooOol0ogooogoo47oo000ROol00`00Oomoo`3oOoooOol@Ool0029oo`03001o
ogoo0?mooomooa1oo`0067oo0P0027oo00<007ooOol0ogooogoo47oo000GOol01000Oomoo`001goo
00<007ooOol0ogooogoo47oo000GOol01000Oomoo`001goo1000ogooogoo3goo000HOol20008Ool0
0`00Oomoo`3oOoooOol@Ool001Moo`04001oogoo0007Ool00`00Oomoo`3oOoooOol@Ool001Qoo`80
00Qoo`03001oogoo0?mooomooa1oo`008Woo00<007ooOol0ogooogoo47oo000ROol00`00Oomoo`3o
OoooOol@Ool0029oo`03001oogoo0?mooomooa1oo`008Woo00<007ooOol0ogooogoo47oo000ROol0
0`00Oomoo`3oOoooOol@Ool0029oo`03001oogoo0?mooomooa1oo`008Woo00<007ooOol0ogooogoo
47oo000ROol00`00Oomoo`3oOoooOol@Ool0029oo`03001oogoo0?mooomooa1oo`008Woo00<007oo
Ool0ogooogoo47oo000ROol00`00Oomoo`3oOoooOol@Ool0029oo`<00?mooomooa1oo`008Woo00<0
07ooOol0ogooogoo47oo000ROol00`00Oomoo`3oOoooOol@Ool0029oo`03001oogoo0?mooomooa1o
o`008Woo00<007ooOol0ogooogoo47oo000ROol00`00Oomoo`3oOoooOol@Ool0029oo`03001oogoo
0?mooomooa1oo`008Woo00<007ooOol0ogooogoo47oo000ROol00`00Oomoo`3oOoooOol@Ool0029o
o`03001oogoo0?mooomooa1oo`008Woo00<007ooOol0ogooogoo47oo000ROol00`00Oomoo`3oOooo
Ool@Ool0029oo`03001oogoo0?mooomooa1oo`008Woo00<007ooOol0ogooogoo47oo000ROol00`00
Oomoo`3oOoooOol@Ool0029oo`03001oogoo0?mooomooa1oo`008Woo0`00ogooogoo47oo000ROol0
0`00Oomoo`3oOoooOol@Ool0029oo`03001oogoo0?mooomooa1oo`008Woo00<007ooOol0ogooogoo
47oo000ROol00`00Oomoo`3oOoooOol@Ool0029oo`03001oogoo0?mooomooa1oo`008Woo00<007oo
Ool0ogooogoo47oo000ROol00`00Oomoo`3oOoooOol@Ool0029oo`03001oogoo0?mooomooa1oo`00
8Woo00<007ooOol0ogooogoo47oo000ROol00`00Oomoo`3oOoooOol@Ool0029oo`03001oogoo0?mo
oomooa1oo`008Woo00<007ooOol0ogooogoo47oo000ROol00`00Oomoo`3oOoooOol@Ool0029oo`03
001oogoo0?mooomooa1oo`008Woo0`00ogooogoo47oo000ROol00`00Oomoo`3oOoooOol@Ool0029o
o`03001oogoo0?mooomooa1oo`008Woo00<007ooOol0ogooogoo47oo000ROol00`00Oomoo`3oOooo
Ool@Ool0029oo`03001oogoo0?mooomooa1oo`008Woo00<007ooOol0ogooogoo47oo000ROol00`00
Oomoo`3oOoooOol@Ool0029oo`03001oogoo0?mooomooa1oo`008Woo00<007ooOol0ogooogoo47oo
000ROol00`00Oomoo`3oOoooOol@Ool0029oo`03001oogoo0?mooomooa1oo`008Woo00<007ooOol0
ogooogoo47oo000ROol00`00Oomoo`3oOoooOol@Ool0015oo`D0009oo`8000Qoo`03001oogoo0?mo
oomooa1oo`004goo00D007ooOomoo`00009oo`03001oogoo00Eoo`03001oogoo0?mooomooa1oo`00
4goo00D007ooOomoo`00009oo`03001oogoo00Eoo`@00?mooomoo`moo`004goo00D007ooOomoo`00
009oo`03001oogoo0?mooomooaQoo`004goo00D007ooOomoo`00009oo`03001oogoo0?mooomooaQo
o`004Woo0P0017oo0P00ogooogoo6goo003oOoooOoleOol00?mooomoocEoo`00ogooogoo=Goo003o
OoooOoleOol00?mooomoocEoo`00ogooogoo=Goo003oOoooOoleOol00?mooomoocEoo`00ogooogoo
=Goo003oOoooOoleOol00?mooomoocEoo`00ogooogoo=Goo003oOoooOoleOol000aoo`<00005Ool0
0000001oo`020002Ool30002Ool30004Ool400000goo000000020003Ool300000goo00000002Ool2
003oOoojOol000]oo`03001oogoo00=oo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol00goo00@007ooOol00?mooo]oo`002goo
00<007ooOol00goo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo009oo`04001oogoo0003
Ool00`00Oomoo`02Ool40002Ool01000Oomoo`00ogoongoo000;Ool00`00Oomoo`03Ool30004Ool2
0004Ool00`00Oomoo`03Ool30002Ool40003Ool20002Ool4003oOoolOol000]oo`04001oogoo0002
Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`3oOoooOol<Ool000aoo`<00003Ool00000
00Moo`04001oogooOol20006Ool2003oOoooOol>Ool00?mooomoocEoo`00ogooogoo=Goo0000\
\>"],
  ImageRangeCache->{{{0, 562.625}, {347.375, 0}} -> {-0.0695984, -0.495302, \
0.00201201, 0.0325549}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(SetDirectory["\<c:/temp\>"];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<bellman1.eps\>", plot1, "\<EPS\>"];\)\)}], "Input"],

Cell["Now do the one with high A", "Text"],

Cell[BoxData[{
    \(\(ngrid = 80;\)\), "\[IndentingNewLine]", 
    \(\(hgrid = 80;\)\), "\[IndentingNewLine]", 
    \(\(hmax = 8;\)\), "\[IndentingNewLine]", 
    \(\(hstep = hmax/\((hgrid - 1)\);\)\), "\[IndentingNewLine]", 
    \(\(Do[
        Value[i] = 0, {i, 
          hgrid}];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(itertol = 0.0001;\)\), "\[IndentingNewLine]", 
    \(\(maxiter = 30;\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(TFR2 = Table[0, {i, 20}];\)\), "\[IndentingNewLine]", 
    \(\(NTFR2 = 
        Table[0, {i, 20}];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(mortcount = 1;\)\), "\[IndentingNewLine]", 
    \(\(While[
        mortcount \[LessEqual] 
          20, \[IndentingNewLine]\[IndentingNewLine]s = \((mortcount -  \
.9)\)/\((20 -  .9)\); \[IndentingNewLine]A = 
          18.9; \[IndentingNewLine]\[Beta] = 
          0.0825; \[IndentingNewLine]\[IndentingNewLine]\[IndentingNewLine] \
(*\ feasible\ human\ capital\ values\ *) \[IndentingNewLine]Do[
          hval[i] = hstep*\((i - 1)\), {i, 
            hgrid}]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
          Implied\ feasible\ education\ values\ *) \[IndentingNewLine]Do[
          eval[i] = \((\(hstep*\((i - 1)\)\)\/A)\)\^2, {i, 
            hgrid}]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
          Implied\ feasible\ fertility\ values\ *) \[IndentingNewLine]Nmax = 
          Min[{4, Floor[1\/\(p\/s + q\)]}]; \[IndentingNewLine]Do[
          nval[i] = \(Nmax\/\(ngrid - 1\)\) \((i - 1)\), {i, 
            ngrid}]; \[IndentingNewLine]\[IndentingNewLine]itercrit = 
          1; \[IndentingNewLine]itercount = 
          1; \[IndentingNewLine]While[\((\((itercount < 
                  maxiter)\) && \((itercrit > 
                  itertol)\))\), \[IndentingNewLine]\[IndentingNewLine]hcount \
= 1; \[IndentingNewLine]While[
            hcount \[LessEqual] 
              hgrid, \[IndentingNewLine]\[IndentingNewLine] (*\ 
              Set\ the\ interim\ utilities\ to\ zero\ \
*) \[IndentingNewLine]prevalues = 
              Table[0, {i, 1, ngrid}, {j, 1, 
                  hgrid}]; \[IndentingNewLine]\[IndentingNewLine]ncount = 
              1; \[IndentingNewLine]While[
              ncount \[LessEqual] 
                ngrid, \[IndentingNewLine]\[IndentingNewLine]ecount = 
                1; \[IndentingNewLine]While[
                ecount \[LessEqual] 
                  hgrid, \[IndentingNewLine]\[IndentingNewLine] (*\ 
                  Need\ to\ check\ whether\ consumption\ is\ positive\ \
*) \[IndentingNewLine]worktime = 
                  1 - p\ nval[ncount]\/s - \((q + eval[ecount])\)\ nval[
                        ncount]; \[IndentingNewLine]\[IndentingNewLine]If[
                  worktime < 
                    0, \[IndentingNewLine]prevalues[\([ncount, 
                        
                        ecount]\)] = \(-1\), \
\[IndentingNewLine]prevalues[\([ncount, 
                        ecount]\)] = \((\((wu + w\ hval[hcount])\)\ worktime)\
\)\^\(1 - \[Sigma]\)\/\(1 - \[Sigma]\) + \[Beta]\ \ \(\((nval[
                                ncount])\)\^eps\) 
                        Value[ecount]\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine]ecount = 
                  ecount + 
                    1;\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]ncount = 
                ncount + 
                  1;\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]NewValue[hcount] = 
              Max[prevalues]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
              The\ following\ extracts\ the\ maximizing\ index\ \
*) \[IndentingNewLine]MaxIndN[hcount] = 
              Ordering[prevalues, \(-1\)]; \[IndentingNewLine]MaxIndE[
                hcount] = 
              Ordering[\(prevalues[\([Ordering[
                        prevalues, \(-1\)]]\)]\)[\([1]\)], \(-1\)]; \
\[IndentingNewLine]\[IndentingNewLine]hcount = 
              hcount + 
                1;\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine]deviation = 
            Table[Value[i] - NewValue[i], {i, 
                hgrid}]; \[IndentingNewLine]\[IndentingNewLine]itercrit = 
            Max[Abs[deviation]]; \[IndentingNewLine]\[IndentingNewLine]Do[
            Value[i] = NewValue[i], {i, 
              hgrid}]; \[IndentingNewLine]\[IndentingNewLine]itercount = 
            itercount + 
              1;\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine]EDev = 
          Table[MaxIndE[i] - i, {i, 
              hgrid}]; \[IndentingNewLine]Eoptind = \(Ordering[Abs[EDev], 
              1]\)[\([1]\)]; \[IndentingNewLine]Noptind = \(MaxIndN[
              Eoptind]\)[\([1]\)]; \
\[IndentingNewLine]\[IndentingNewLine]Print[
          A\ \@eval[Eoptind]]; \[IndentingNewLine]Print[
          nval[\ Noptind]]; \ \
\[IndentingNewLine]\[IndentingNewLine]NTFR2[\([mortcount]\)] = 
          nval[\ Noptind]; \[IndentingNewLine]TFR2[\([mortcount]\)] = 
          nval[\ Noptind]/s; \[IndentingNewLine]mortcount = 
          mortcount + 1;\[IndentingNewLine]];\)\)}], "Input"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(NTFR2\)\" is similar to \
existing symbol \"\!\(TFR2\)\"."\)], "Message"],

Cell[BoxData[
    \(7.493670886075949`\)], "Print"],

Cell[BoxData[
    \(4\/79\)], "Print"],

Cell[BoxData[
    \(5.5696202531645564`\)], "Print"],

Cell[BoxData[
    \(12\/79\)], "Print"],

Cell[BoxData[
    \(4.3544303797468356`\)], "Print"],

Cell[BoxData[
    \(28\/79\)], "Print"],

Cell[BoxData[
    \(3.9493670886075947`\)], "Print"],

Cell[BoxData[
    \(40\/79\)], "Print"],

Cell[BoxData[
    \(3.5443037974683542`\)], "Print"],

Cell[BoxData[
    \(56\/79\)], "Print"],

Cell[BoxData[
    \(3.3417721518987342`\)], "Print"],

Cell[BoxData[
    \(68\/79\)], "Print"],

Cell[BoxData[
    \(3.1392405063291138`\)], "Print"],

Cell[BoxData[
    \(80\/79\)], "Print"],

Cell[BoxData[
    \(3.0379746835443036`\)], "Print"],

Cell[BoxData[
    \(92\/79\)], "Print"],

Cell[BoxData[
    \(2.8354430379746836`\)], "Print"],

Cell[BoxData[
    \(104\/79\)], "Print"],

Cell[BoxData[
    \(2.9367088607594938`\)], "Print"],

Cell[BoxData[
    \(108\/79\)], "Print"],

Cell[BoxData[
    \(2.8354430379746836`\)], "Print"],

Cell[BoxData[
    \(116\/79\)], "Print"],

Cell[BoxData[
    \(2.7341772151898733`\)], "Print"],

Cell[BoxData[
    \(124\/79\)], "Print"],

Cell[BoxData[
    \(2.7341772151898733`\)], "Print"],

Cell[BoxData[
    \(132\/79\)], "Print"],

Cell[BoxData[
    \(2.7341772151898733`\)], "Print"],

Cell[BoxData[
    \(136\/79\)], "Print"],

Cell[BoxData[
    \(2.632911392405063`\)], "Print"],

Cell[BoxData[
    \(144\/79\)], "Print"],

Cell[BoxData[
    \(2.632911392405063`\)], "Print"],

Cell[BoxData[
    \(148\/79\)], "Print"],

Cell[BoxData[
    \(2.632911392405063`\)], "Print"],

Cell[BoxData[
    \(152\/79\)], "Print"],

Cell[BoxData[
    \(2.5316455696202533`\)], "Print"],

Cell[BoxData[
    \(160\/79\)], "Print"],

Cell[BoxData[
    \(2.5316455696202533`\)], "Print"],

Cell[BoxData[
    \(160\/79\)], "Print"],

Cell[BoxData[
    \(2.5316455696202533`\)], "Print"],

Cell[BoxData[
    \(164\/79\)], "Print"]
}, Open  ]],

Cell[BoxData[{
    \(\(NTFRList2 = 
        Table[{\((i -  .9)\)/\((20 -  .9)\), NTFR2[\([i]\)]}, {i, 
            20}];\)\), "\[IndentingNewLine]", 
    \(\(TFRList2 = 
        Table[{\((i -  .9)\)/\((20 -  .9)\), TFR2[\([i]\)]}, {i, 
            20}];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(plot2 = 
      MultipleListPlot[TFRList2, NTFRList2, 
        SymbolShape \[Rule] {PlotSymbol[Box, 0], PlotSymbol[Box, 0]}, 
        PlotJoined \[Rule] True, PlotRange \[Rule] {{0, 1}, {0, 10}}, 
        AxesLabel \[Rule] {"\<s\>", "\<Children\>"}, 
        PlotStyle \[Rule] {{Thickness[ .008]}, {Dashing[{ .02,  .02}], 
              Thickness[ .008]}}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.0618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(10)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.0481 .06506 m
.0982 .0956 L
.1483 .14771 L
.1984 .15773 L
.2485 .1763 L
.2986 .17816 L
.3487 .17948 L
.3988 .18048 L
.4489 .18125 L
.499 .16932 L
.5491 .16527 L
.5992 .1619 L
.6493 .15904 L
.6994 .15212 L
.7495 .15031 L
.7996 .1448 L
.8497 .13995 L
.8998 .13911 L
.9499 .13177 L
1 .1283 L
s
.0001 w
.0481 .06506 m
.0481 .06506 L
.0481 .06506 L
.0481 .06506 L
.0481 .06506 L closepath F
.0982 .0956 m
.0982 .0956 L
.0982 .0956 L
.0982 .0956 L
.0982 .0956 L closepath F
.1483 .14771 m
.1483 .14771 L
.1483 .14771 L
.1483 .14771 L
.1483 .14771 L closepath F
.1984 .15773 m
.1984 .15773 L
.1984 .15773 L
.1984 .15773 L
.1984 .15773 L closepath F
.2485 .1763 m
.2485 .1763 L
.2485 .1763 L
.2485 .1763 L
.2485 .1763 L closepath F
.2986 .17816 m
.2986 .17816 L
.2986 .17816 L
.2986 .17816 L
.2986 .17816 L closepath F
.3487 .17948 m
.3487 .17948 L
.3487 .17948 L
.3487 .17948 L
.3487 .17948 L closepath F
.3988 .18048 m
.3988 .18048 L
.3988 .18048 L
.3988 .18048 L
.3988 .18048 L closepath F
.4489 .18125 m
.4489 .18125 L
.4489 .18125 L
.4489 .18125 L
.4489 .18125 L closepath F
.499 .16932 m
.499 .16932 L
.499 .16932 L
.499 .16932 L
.499 .16932 L closepath F
.5491 .16527 m
.5491 .16527 L
.5491 .16527 L
.5491 .16527 L
.5491 .16527 L closepath F
.5992 .1619 m
.5992 .1619 L
.5992 .1619 L
.5992 .1619 L
.5992 .1619 L closepath F
.6493 .15904 m
.6493 .15904 L
.6493 .15904 L
.6493 .15904 L
.6493 .15904 L closepath F
.6994 .15212 m
.6994 .15212 L
.6994 .15212 L
.6994 .15212 L
.6994 .15212 L closepath F
.7495 .15031 m
.7495 .15031 L
.7495 .15031 L
.7495 .15031 L
.7495 .15031 L closepath F
.7996 .1448 m
.7996 .1448 L
.7996 .1448 L
.7996 .1448 L
.7996 .1448 L closepath F
.8497 .13995 m
.8497 .13995 L
.8497 .13995 L
.8497 .13995 L
.8497 .13995 L closepath F
.8998 .13911 m
.8998 .13911 L
.8998 .13911 L
.8998 .13911 L
.8998 .13911 L closepath F
.9499 .13177 m
.9499 .13177 L
.9499 .13177 L
.9499 .13177 L
.9499 .13177 L closepath F
1 .1283 m
1 .1283 L
1 .1283 L
1 .1283 L
1 .1283 L closepath F
.008 w
[ .02 .02 ] 0 setdash
.0481 .00313 m
.0982 .00939 L
.1483 .02191 L
.1984 .03129 L
.2485 .04381 L
.2986 .0532 L
.3487 .06259 L
.3988 .07197 L
.4489 .08136 L
.499 .08449 L
.5491 .09075 L
.5992 .09701 L
.6493 .10327 L
.6994 .1064 L
.7495 .11265 L
.7996 .11578 L
.8497 .11891 L
.8998 .12517 L
.9499 .12517 L
1 .1283 L
s
.0001 w
[ ] 0 setdash
.0481 .00313 m
.0481 .00313 L
.0481 .00313 L
.0481 .00313 L
.0481 .00313 L closepath F
.0982 .00939 m
.0982 .00939 L
.0982 .00939 L
.0982 .00939 L
.0982 .00939 L closepath F
.1483 .02191 m
.1483 .02191 L
.1483 .02191 L
.1483 .02191 L
.1483 .02191 L closepath F
.1984 .03129 m
.1984 .03129 L
.1984 .03129 L
.1984 .03129 L
.1984 .03129 L closepath F
.2485 .04381 m
.2485 .04381 L
.2485 .04381 L
.2485 .04381 L
.2485 .04381 L closepath F
.2986 .0532 m
.2986 .0532 L
.2986 .0532 L
.2986 .0532 L
.2986 .0532 L closepath F
.3487 .06259 m
.3487 .06259 L
.3487 .06259 L
.3487 .06259 L
.3487 .06259 L closepath F
.3988 .07197 m
.3988 .07197 L
.3988 .07197 L
.3988 .07197 L
.3988 .07197 L closepath F
.4489 .08136 m
.4489 .08136 L
.4489 .08136 L
.4489 .08136 L
.4489 .08136 L closepath F
.499 .08449 m
.499 .08449 L
.499 .08449 L
.499 .08449 L
.499 .08449 L closepath F
.5491 .09075 m
.5491 .09075 L
.5491 .09075 L
.5491 .09075 L
.5491 .09075 L closepath F
.5992 .09701 m
.5992 .09701 L
.5992 .09701 L
.5992 .09701 L
.5992 .09701 L closepath F
.6493 .10327 m
.6493 .10327 L
.6493 .10327 L
.6493 .10327 L
.6493 .10327 L closepath F
.6994 .1064 m
.6994 .1064 L
.6994 .1064 L
.6994 .1064 L
.6994 .1064 L closepath F
.7495 .11265 m
.7495 .11265 L
.7495 .11265 L
.7495 .11265 L
.7495 .11265 L closepath F
.7996 .11578 m
.7996 .11578 L
.7996 .11578 L
.7996 .11578 L
.7996 .11578 L closepath F
.8497 .11891 m
.8497 .11891 L
.8497 .11891 L
.8497 .11891 L
.8497 .11891 L closepath F
.8998 .12517 m
.8998 .12517 L
.8998 .12517 L
.8998 .12517 L
.8998 .12517 L closepath F
.9499 .12517 m
.9499 .12517 L
.9499 .12517 L
.9499 .12517 L
.9499 .12517 L closepath F
1 .1283 m
1 .1283 L
1 .1283 L
1 .1283 L
1 .1283 L closepath F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{345.813, 213.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005I0000eA000`40O003h00OogooFWoo001BOol2
0004Ool20003Ool4000[Ool20004Ool20005Ool3000ZOol20004Ool20003Ool3000]Ool20004Ool2
0004Ool2000aOol5000DOol0055oo`04001oogoo0008Ool00`00Oomoo`0[Ool01000Oomoo`002goo
00<007ooOol0:7oo00@007ooOol000Qoo`04001oogoo000[Ool01000Oomoo`0027oo00@007ooOol0
039oo`03001oogoo01Aoo`00DGoo00@007ooOol000Uoo`03001oogoo02Yoo`04001oogoo0008Ool5
000YOol01000Oomoo`0027oo00@007ooOol002]oo`04001oogoo0008Ool01000Oomoo`00<Woo00<0
07ooOol057oo001AOol01000Oomoo`002Woo00<007ooOol0:Goo00@007ooOol000Qoo`04001oogoo
000ZOol01000Oomoo`0027oo0`00;7oo00@007ooOol000Uoo`8003=oo`03001oogoo01Aoo`00DGoo
00@007ooOol000Qoo`04001oogoo000ZOol01000Oomoo`002Goo00<007oo0000:Woo00@007ooOol0
00Uoo`03001oogoo02]oo`04001oogoo0008Ool01000Oomoo`00<Woo00<007ooOol057oo001BOol2
000:Ool2000/Ool2000;Ool2000[Ool2000:Ool3000/Ool2000:Ool2000bOol2000FOol00?mooeYo
o`00ogooFWoo003oOomJOol00?mooeYoo`00ogooCGoo0`002Woo000NOooo000V000<Ool00`00Oomo
o`07Ool001ioo`03001oogoo00Yoo`L000Yoo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo
00]oo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo
00]oo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo
00]oo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo
00]oo`03001oogoo00Moo`<000Yoo`007Woo00<007ooOol037oo1P0027oo00<007ooOol06goo00<0
07ooOol0=goo00<007ooOol0=goo00<007ooOol0>7oo00<007ooOol0=goo00<007ooOol01goo1000
2Goo000NOol00`00Oomoo`0AOol00`00Oomoo`02Ool8003oOolKOol001ioo`03001oogoo01Ioo`T0
00=oo`03001oogoo0?mooaAoo`007Woo00<007ooOol07Goo00@007ooOomoo`D00?mooa=oo`007Woo
00<007ooOol08Woo1`00ogoo47oo000NOol00`00Oomoo`0UOol50003Ool2003oOol:Ool001ioo`03
001oogoo02Qoo`03001oogoo009oo`L00?moo`Eoo`007Woo0`00;goo1P000goo0P00oWoo000NOol0
0`00Oomoo`0dOol00`00Oomoo`08003iOol001ioo`03001oogoo03Yoo`H00?Qoo`007Woo00<007oo
Ool0?goo00<007ooOol00goo00<007ooOol0l7oo000NOol00`00Oomoo`14Ool6003^Ool001ioo`03
001oogoo04Aoo`L000Aoo`03001oogoo0>Ioo`007Woo00<007ooOol0BWoo00<007ooOol00Woo1`00
hWoo000NOol00`00Oomoo`1@Ool70003Ool2003LOol001ioo`03001oogoo05Aoo`<000=oo`L00=Mo
o`007Woo0`002goo00<007ooOol0CWoo1P0017oo0P00d7oo000NOol00`00Oomoo`0:Ool4001COol0
0`00Ool00002Ool7003;Ool001ioo`03001oogoo00]oo`@005Uoo`H00<Yoo`007Woo00<007ooOol0
3Goo1000G7oo00@007ooOomoo`800<Eoo`007Woo00<007ooOol03Woo1@00GWoo1`00`7oo000NOol0
0`00Oomoo`0@Ool4001OOol6002oOol001ioo`03001oogoo019oo`@0069oo`03001oogoo009oo`P0
0;=oo`007Woo00<007ooOol04goo1@00IGoo20000goo200017oo0P00XWoo000NOol00`00Oomoo`0E
Ool4001_Ool80004Ool70005Ool00`00Oomoo`2EOol001ioo`<001Moo`@007]oo`H0009oo`03001o
o`0000H0095oo`007Woo00<007ooOol067oo1000Ogoo00<007ooOol00goo1P00TGoo000NOol00`00
Oomoo`0JOol3002>Ool80005Ool00`00Oomoo`1mOol001ioo`03001oogoo01]oo`<008eoo`P000Ao
o`D007aoo`007Woo00<007ooOol077oo0`00VGoo1`000goo200017oo0P00J7oo000NOol00`00Oomo
o`0MOol3002JOol50003Ool80004Ool70005Ool00`00Oomoo`1KOol001ioo`03001oogoo01ioo`<0
0:moo`H0009oo`03001oo`0000H000Eoo`03001oogoo04moo`005Woo100017oo00<007ooOol07goo
0`00/goo00<007ooOol00goo1P0017oo2000Bgoo000FOol00`00Oomoo`05Ool00`00Oomoo`0POol3
0032Ool80004Ool80004Ool00`00Oomoo`0hOol001Moo`03001oogoo00Aoo`<0025oo`<00<eoo`P0
00Aoo`L003Aoo`0067oo00<007ooOol00goo00<007ooOol08Woo0`00fGoo1`000goo20000Woo00<0
07oo00001`0077oo000FOol01000Oomoo`0017oo00<007ooOol08goo0`00hWoo20000Woo40005Woo
000GOol20005Ool00`00Oomoo`0TOol3003TOolG000FOol001ioo`03001oogoo02Eoo`<00=aoo`h0
02Ioo`007Woo00<007ooOol09Woo0`00aGoo7@00;Goo000NOol00`00Oomoo`0WOol3002mOolM000d
Ool001ioo`03001oogoo02Qoo`H00:YooaH004Yoo`007Woo00<007ooOol0:Goo2P00UWoo7P00DGoo
000NOol3000^Ool9002;OolF001POol001ioo`03001oogoo03=oo`L0085oo`h006moo`007Woo00<0
07ooOol0=goo1P00Kgoo5P00MWoo000NOol00`00Oomoo`0iOol6001OOolM001mOol001ioo`03001o
ogoo03aoo`H004eooad008aoo`007Woo00<007ooOol0?Woo1P00AWoo5000VWoo000NOol00`00Oomo
o`11Ool6000nOol:002YOol001ioo`03001oogoo04=oob0001eoo`X00:ioo`007Woo00<007ooOol0
AWoo?`00/goo000NOol3001SOolM002hOol001ioo`03001oogoo0?moocUoo`007Woo00<007ooOol0
ogoo>Goo000NOol00`00Oomoo`3oOoliOol001ioo`03001oogoo0?moocUoo`007Woo00<007ooOol0
ogoo>Goo000NOol00`00Oomoo`3oOoliOol001ioo`03001oogoo0?moocUoo`007Woo00<007ooOol0
ogoo>Goo000NOol3003oOoliOol001ioo`03001oogoo0?moocUoo`007Woo00<007ooOol0ogoo>Goo
000NOol00`00Oomoo`3oOoliOol001ioo`03001oogoo0?moocUoo`007Woo00<007ooOol0ogoo>Goo
000NOol00`00Oomoo`3oOoliOol001Qoo`<000=oo`03001oogoo0?moocUoo`006Goo00<007ooOol0
0Woo00<007ooOol0ogoo>Goo000FOol50003Ool3003oOoliOol001Ioo`04001oogoo0004Ool00`00
Oomoo`3oOoliOol001Moo`03001oo`0000Aoo`03001oogoo0?moocUoo`0067oo0P0017oo00<007oo
Ool0ogoo>Goo000NOol00`00Oomoo`3oOoliOol001ioo`03001oogoo0?moocUoo`007Woo00<007oo
Ool0ogoo>Goo000NOol00`00Oomoo`3oOoliOol001ioo`03001oogoo0?moocUoo`007Woo00<007oo
Ool0ogoo>Goo000NOol3003oOoliOol001ioo`03001oogoo0?moocUoo`007Woo00<007ooOol0ogoo
>Goo000NOol00`00Oomoo`3oOoliOol001ioo`03001oogoo0?moocUoo`007Woo00<007ooOol0ogoo
>Goo000NOol00`00Oomoo`3oOoliOol001ioo`03001oogoo0?moocUoo`007Woo00<007ooOol0ogoo
>Goo000NOol3003oOoliOol001ioo`03001oogoo0?moocUoo`007Woo00<007ooOol0ogoo>Goo000N
Ool00`00Oomoo`3oOoliOol001ioo`03001oogoo0?moocUoo`007Woo00<007ooOol0ogoo>Goo000N
Ool00`00Oomoo`3oOoliOol001ioo`03001oogoo0?moocUoo`007Woo00<007ooOol0ogoo>Goo000N
Ool3003oOoliOol001ioo`03001oogoo0?moocUoo`007Woo00<007ooOol0ogoo>Goo000NOol00`00
Oomoo`3oOoliOol001ioo`03001oogoo0?moocUoo`007Woo00<007ooOol0ogoo>Goo000NOol00`00
Oomoo`3oOoliOol001Ioo`<000Eoo`03001oogoo0?moocUoo`005Woo00@007ooOol000Aoo`03001o
ogoo0?moocUoo`005Woo00@007ooOol000Aoo`<00?moocUoo`005Woo0`001Goo00<007ooOol0ogoo
>Goo000GOol00`00Oomoo`04Ool00`00Oomoo`3oOoliOol001Moo`<000Aoo`03001oogoo0?moocUo
o`007Woo00<007ooOol0ogoo>Goo000NOol00`00Oomoo`3oOoliOol001ioo`03001oogoo0?moocUo
o`007Woo00<007ooOol0ogoo>Goo000NOol00`00Oomoo`3oOoliOol001ioo`<00?moocUoo`007Woo
00<007ooOol0ogoo>Goo000NOol00`00Oomoo`3oOoliOol001ioo`03001oogoo0?moocUoo`007Woo
00<007ooOol0ogoo>Goo000NOol00`00Oomoo`3oOoliOol001ioo`03001oogoo0?moocUoo`007Woo
00<007ooOol0ogoo>Goo000NOol00`00Oomoo`3oOoliOol001ioo`<00?moocUoo`007Woo00<007oo
Ool0ogoo>Goo000NOol00`00Oomoo`3oOoliOol001ioo`03001oogoo0?moocUoo`007Woo00<007oo
Ool0ogoo>Goo000NOol00`00Oomoo`3oOoliOol001ioo`03001oogoo0?moocUoo`007Woo00<007oo
Ool0ogoo>Goo000NOol00`00Oomoo`3oOoliOol001ioo`<00?moocUoo`007Woo00<007ooOol0ogoo
>Goo000NOol00`00Oomoo`3oOoliOol001ioo`03001oogoo0?moocUoo`007Woo00<007ooOol0ogoo
>Goo000NOol00`00Oomoo`3oOoliOol001ioo`03001oogoo0?moocUoo`005goo0P001Goo00<007oo
Ool0ogoo>Goo000FOol01000Oomoo`0017oo00<007ooOol0ogoo>Goo000FOol01000Oomoo`0017oo
0`00ogoo>Goo000GOol20005Ool00`00Oomoo`3oOoliOol001Ioo`04001oogoo0004Ool00`00Oomo
o`3oOoliOol001Moo`8000Eoo`03001oogoo0?moocUoo`007Woo00<007ooOol0ogoo>Goo000NOol0
0`00Oomoo`3oOoliOol001ioo`03001oogoo0?moocUoo`007Woo00<007ooOol0ogoo>Goo000NOol0
0`00Oomoo`3oOoliOol001ioo`<00?moocUoo`007Woo00<007ooOol0ogoo>Goo000NOol00`00Oomo
o`3oOoliOol001ioo`03001oogoo0?moocUoo`007Woo00<007ooOol0ogoo>Goo000NOol00`00Oomo
o`3oOoliOol001ioo`03001oogoo0?moocUoo`007Woo00<007ooOol0ogoo>Goo000NOol00`00Oomo
o`3oOoliOol001ioo`<00?moocUoo`007Woo00<007ooOol0ogoo>Goo000NOol00`00Oomoo`3oOoli
Ool001ioo`03001oogoo0?moocUoo`007Woo00<007ooOol0ogoo>Goo000NOol00`00Oomoo`3oOoli
Ool001ioo`03001oogoo0?moocUoo`007Woo00<007ooOol0ogoo>Goo000NOol00`00Oomoo`3oOoli
Ool001ioo`<00?moocUoo`007Woo00<007ooOol0ogoo>Goo000NOol00`00Oomoo`3oOoliOol001io
o`03001oogoo0?moocUoo`007Woo00<007ooOol0ogoo>Goo000NOol00`00Oomoo`3oOoliOol001io
o`03001oogoo0?moocUoo`0047oo1@000Woo0P001Goo00<007ooOol0ogoo>Goo000BOol01@00Oomo
ogoo00000Woo00<007ooOol00Woo00<007ooOol0ogoo>Goo000BOol01@00Oomoogoo00000Woo00<0
07ooOol00Woo0`00ogoo>Goo000BOol01@00Oomoogoo00000Woo00<007ooOol0ogoo?Woo000BOol0
1@00Oomoogoo00000Woo00<007ooOol0ogoo?Woo000AOol20004Ool2003oOom1Ool00?mooeYoo`00
ogooFWoo003oOomJOol00?mooeYoo`00ogooFWoo003oOomJOol00?mooeYoo`00ogooFWoo0008Ool3
00001Goo00000000Ool00P000Woo0`000Woo0`0017oo100000=oo`0000000P000goo0`0000=oo`00
00000Woo0P00ogoo97oo0007Ool00`00Oomoo`03Ool01000Oomoo`0017oo00<007ooOol00Woo00<0
07ooOol00Woo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00=oo`04001oogoo003oOolU
Ool000Moo`03001oogoo00=oo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000
Oomoo`000goo00<007ooOol00Woo10000Woo00@007ooOol00?moobEoo`001goo00<007ooOol00goo
0`0017oo0P0017oo00<007ooOol00goo0`000Woo10000goo0P000Woo1000ogoo9Woo0007Ool01000
Oomoo`000Woo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol0ogoo=Goo0008Ool300000goo
00000007Ool01000Oomoogoo0P001Woo0P00ogoo=goo003oOomJOol00?mooeYoo`00\
\>"],
  ImageRangeCache->{{{0, 344.813}, {212.75, 0}} -> {-0.10607, -0.701614, \
0.00342876, 0.0554785}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(SetDirectory["\<c:/temp\>"];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<bellman2.eps\>", plot2, "\<EPS\>"];\)\)}], "Input"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
ScreenStyleEnvironment->"Working",
WindowSize->{892, 633},
WindowMargins->{{0, Automatic}, {Automatic, 5}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 52, 0, 115, "Title"],
Cell[1782, 54, 62, 1, 30, "Input"],
Cell[1847, 57, 99, 2, 33, "Text"],
Cell[1949, 61, 99, 2, 33, "Text"],
Cell[2051, 65, 466, 9, 210, "Input"],
Cell[2520, 76, 36, 0, 33, "Text"],
Cell[2559, 78, 528, 11, 210, "Input"],
Cell[3090, 91, 53, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[3168, 95, 5521, 100, 2059, "Input"],
Cell[8692, 197, 181, 3, 24, "Message"],
Cell[8876, 202, 185, 3, 24, "Message"],
Cell[9064, 207, 185, 3, 24, "Message"],
Cell[9252, 212, 191, 3, 24, "Message"],
Cell[9446, 217, 187, 3, 24, "Message"],
Cell[9636, 222, 167, 3, 24, "Message"],
Cell[9806, 227, 36, 1, 25, "Print"],
Cell[9845, 230, 37, 1, 25, "Print"],
Cell[9885, 233, 38, 1, 25, "Print"],
Cell[9926, 236, 39, 1, 25, "Print"],
Cell[9968, 239, 40, 1, 25, "Print"],
Cell[10011, 242, 41, 1, 25, "Print"],
Cell[10055, 245, 42, 1, 25, "Print"],
Cell[10100, 248, 43, 1, 25, "Print"],
Cell[10146, 251, 44, 1, 25, "Print"],
Cell[10193, 254, 38, 1, 25, "Print"],
Cell[10234, 257, 35, 1, 25, "Print"],
Cell[10272, 260, 52, 1, 25, "Print"],
Cell[10327, 263, 39, 1, 38, "Print"],
Cell[10369, 266, 35, 1, 25, "Print"],
Cell[10407, 269, 36, 1, 25, "Print"],
Cell[10446, 272, 37, 1, 25, "Print"],
Cell[10486, 275, 38, 1, 25, "Print"],
Cell[10527, 278, 39, 1, 25, "Print"],
Cell[10569, 281, 40, 1, 25, "Print"],
Cell[10612, 284, 41, 1, 25, "Print"],
Cell[10656, 287, 42, 1, 25, "Print"],
Cell[10701, 290, 43, 1, 25, "Print"],
Cell[10747, 293, 44, 1, 25, "Print"],
Cell[10794, 296, 53, 1, 25, "Print"],
Cell[10850, 299, 35, 1, 25, "Print"],
Cell[10888, 302, 52, 1, 25, "Print"],
Cell[10943, 305, 39, 1, 38, "Print"],
Cell[10985, 308, 35, 1, 25, "Print"],
Cell[11023, 311, 36, 1, 25, "Print"],
Cell[11062, 314, 37, 1, 25, "Print"],
Cell[11102, 317, 38, 1, 25, "Print"],
Cell[11143, 320, 39, 1, 25, "Print"],
Cell[11185, 323, 40, 1, 25, "Print"],
Cell[11228, 326, 41, 1, 25, "Print"],
Cell[11272, 329, 42, 1, 25, "Print"],
Cell[11317, 332, 43, 1, 25, "Print"],
Cell[11363, 335, 44, 1, 25, "Print"],
Cell[11410, 338, 53, 1, 25, "Print"],
Cell[11466, 341, 35, 1, 25, "Print"],
Cell[11504, 344, 52, 1, 25, "Print"],
Cell[11559, 347, 39, 1, 38, "Print"],
Cell[11601, 350, 35, 1, 25, "Print"],
Cell[11639, 353, 36, 1, 25, "Print"],
Cell[11678, 356, 37, 1, 25, "Print"],
Cell[11718, 359, 38, 1, 25, "Print"],
Cell[11759, 362, 39, 1, 25, "Print"],
Cell[11801, 365, 40, 1, 25, "Print"],
Cell[11844, 368, 41, 1, 25, "Print"],
Cell[11888, 371, 42, 1, 25, "Print"],
Cell[11933, 374, 43, 1, 25, "Print"],
Cell[11979, 377, 44, 1, 25, "Print"],
Cell[12026, 380, 53, 1, 25, "Print"],
Cell[12082, 383, 35, 1, 25, "Print"],
Cell[12120, 386, 53, 1, 25, "Print"],
Cell[12176, 389, 39, 1, 38, "Print"],
Cell[12218, 392, 35, 1, 25, "Print"],
Cell[12256, 395, 36, 1, 25, "Print"],
Cell[12295, 398, 37, 1, 25, "Print"],
Cell[12335, 401, 38, 1, 25, "Print"],
Cell[12376, 404, 39, 1, 25, "Print"],
Cell[12418, 407, 40, 1, 25, "Print"],
Cell[12461, 410, 41, 1, 25, "Print"],
Cell[12505, 413, 42, 1, 25, "Print"],
Cell[12550, 416, 43, 1, 25, "Print"],
Cell[12596, 419, 44, 1, 25, "Print"],
Cell[12643, 422, 53, 1, 25, "Print"],
Cell[12699, 425, 35, 1, 25, "Print"],
Cell[12737, 428, 52, 1, 25, "Print"],
Cell[12792, 431, 39, 1, 38, "Print"],
Cell[12834, 434, 35, 1, 25, "Print"],
Cell[12872, 437, 36, 1, 25, "Print"],
Cell[12911, 440, 37, 1, 25, "Print"],
Cell[12951, 443, 38, 1, 25, "Print"],
Cell[12992, 446, 39, 1, 25, "Print"],
Cell[13034, 449, 40, 1, 25, "Print"],
Cell[13077, 452, 41, 1, 25, "Print"],
Cell[13121, 455, 42, 1, 25, "Print"],
Cell[13166, 458, 43, 1, 25, "Print"],
Cell[13212, 461, 44, 1, 25, "Print"],
Cell[13259, 464, 43, 1, 25, "Print"],
Cell[13305, 467, 35, 1, 25, "Print"],
Cell[13343, 470, 52, 1, 25, "Print"],
Cell[13398, 473, 39, 1, 38, "Print"],
Cell[13440, 476, 35, 1, 25, "Print"],
Cell[13478, 479, 36, 1, 25, "Print"],
Cell[13517, 482, 37, 1, 25, "Print"],
Cell[13557, 485, 38, 1, 25, "Print"],
Cell[13598, 488, 39, 1, 25, "Print"],
Cell[13640, 491, 40, 1, 25, "Print"],
Cell[13683, 494, 41, 1, 25, "Print"],
Cell[13727, 497, 42, 1, 25, "Print"],
Cell[13772, 500, 43, 1, 25, "Print"],
Cell[13818, 503, 44, 1, 25, "Print"],
Cell[13865, 506, 44, 1, 25, "Print"],
Cell[13912, 509, 35, 1, 25, "Print"],
Cell[13950, 512, 53, 1, 25, "Print"],
Cell[14006, 515, 39, 1, 38, "Print"],
Cell[14048, 518, 35, 1, 25, "Print"],
Cell[14086, 521, 36, 1, 25, "Print"],
Cell[14125, 524, 37, 1, 25, "Print"],
Cell[14165, 527, 38, 1, 25, "Print"],
Cell[14206, 530, 39, 1, 25, "Print"],
Cell[14248, 533, 40, 1, 25, "Print"],
Cell[14291, 536, 41, 1, 25, "Print"],
Cell[14335, 539, 42, 1, 25, "Print"],
Cell[14380, 542, 43, 1, 25, "Print"],
Cell[14426, 545, 44, 1, 25, "Print"],
Cell[14473, 548, 53, 1, 25, "Print"],
Cell[14529, 551, 35, 1, 25, "Print"],
Cell[14567, 554, 52, 1, 25, "Print"],
Cell[14622, 557, 39, 1, 38, "Print"],
Cell[14664, 560, 35, 1, 25, "Print"],
Cell[14702, 563, 36, 1, 25, "Print"],
Cell[14741, 566, 37, 1, 25, "Print"],
Cell[14781, 569, 38, 1, 25, "Print"],
Cell[14822, 572, 39, 1, 25, "Print"],
Cell[14864, 575, 40, 1, 25, "Print"],
Cell[14907, 578, 41, 1, 25, "Print"],
Cell[14951, 581, 42, 1, 25, "Print"],
Cell[14996, 584, 43, 1, 25, "Print"],
Cell[15042, 587, 44, 1, 25, "Print"],
Cell[15089, 590, 46, 1, 25, "Print"],
Cell[15138, 593, 35, 1, 25, "Print"],
Cell[15176, 596, 52, 1, 25, "Print"],
Cell[15231, 599, 39, 1, 38, "Print"],
Cell[15273, 602, 35, 1, 25, "Print"]
}, Open  ]],
Cell[15323, 606, 58, 0, 33, "Text"],
Cell[15384, 608, 425, 9, 170, "Input"],

Cell[CellGroupData[{
Cell[15834, 621, 4047, 79, 1489, "Input"],
Cell[19884, 702, 52, 1, 25, "Print"],
Cell[19939, 705, 40, 1, 38, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20016, 711, 96, 2, 50, "Input"],
Cell[20115, 715, 52, 1, 29, "Output"],
Cell[20170, 718, 51, 1, 29, "Output"]
}, Open  ]],
Cell[20236, 722, 153, 2, 30, "Input"],
Cell[20392, 726, 474, 10, 190, "Input"],

Cell[CellGroupData[{
Cell[20891, 740, 4625, 85, 1731, "Input"],
Cell[25519, 827, 37, 1, 25, "Print"],
Cell[25559, 830, 51, 1, 25, "Print"],
Cell[25613, 833, 51, 1, 25, "Print"],
Cell[25667, 836, 37, 1, 25, "Print"],
Cell[25707, 839, 52, 1, 25, "Print"],
Cell[25762, 842, 52, 1, 25, "Print"],
Cell[25817, 845, 38, 1, 25, "Print"],
Cell[25858, 848, 51, 1, 25, "Print"],
Cell[25912, 851, 52, 1, 25, "Print"],
Cell[25967, 854, 39, 1, 25, "Print"],
Cell[26009, 857, 52, 1, 25, "Print"],
Cell[26064, 860, 51, 1, 25, "Print"],
Cell[26118, 863, 40, 1, 25, "Print"],
Cell[26161, 866, 52, 1, 25, "Print"],
Cell[26216, 869, 51, 1, 25, "Print"],
Cell[26270, 872, 41, 1, 25, "Print"],
Cell[26314, 875, 52, 1, 25, "Print"],
Cell[26369, 878, 51, 1, 25, "Print"],
Cell[26423, 881, 42, 1, 25, "Print"],
Cell[26468, 884, 52, 1, 25, "Print"],
Cell[26523, 887, 51, 1, 25, "Print"],
Cell[26577, 890, 43, 1, 25, "Print"],
Cell[26623, 893, 50, 1, 25, "Print"],
Cell[26676, 896, 51, 1, 25, "Print"],
Cell[26730, 899, 44, 1, 25, "Print"],
Cell[26777, 902, 51, 1, 25, "Print"],
Cell[26831, 905, 51, 1, 25, "Print"],
Cell[26885, 908, 45, 1, 25, "Print"],
Cell[26933, 911, 42, 1, 29, "Output"]
}, Open  ]],
Cell[26990, 915, 87, 2, 33, "Text"],
Cell[27080, 919, 474, 10, 190, "Input"],

Cell[CellGroupData[{
Cell[27579, 933, 4053, 79, 1489, "Input"],
Cell[31635, 1014, 52, 1, 25, "Print"],
Cell[31690, 1017, 40, 1, 38, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31767, 1023, 51, 1, 30, "Input"],
Cell[31821, 1026, 52, 1, 29, "Output"]
}, Open  ]],
Cell[31888, 1030, 73, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[31986, 1034, 4054, 79, 1489, "Input"],
Cell[36043, 1115, 51, 1, 25, "Print"],
Cell[36097, 1118, 40, 1, 38, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36174, 1124, 92, 2, 50, "Input"],
Cell[36269, 1128, 52, 1, 29, "Output"],
Cell[36324, 1131, 53, 1, 29, "Output"]
}, Open  ]],
Cell[36392, 1135, 203, 4, 33, "Text"],
Cell[36598, 1141, 425, 9, 170, "Input"],

Cell[CellGroupData[{
Cell[37048, 1154, 4641, 87, 1711, "Input"],
Cell[41692, 1243, 182, 3, 24, "Message"],
Cell[41877, 1248, 181, 3, 24, "Message"],
Cell[42061, 1253, 185, 3, 24, "Message"],
Cell[42249, 1258, 185, 3, 24, "Message"],
Cell[42437, 1263, 191, 3, 24, "Message"],
Cell[42631, 1268, 187, 3, 24, "Message"],
Cell[42821, 1273, 167, 3, 24, "Message"],
Cell[42991, 1278, 36, 1, 25, "Print"],
Cell[43030, 1281, 39, 1, 38, "Print"],
Cell[43072, 1284, 36, 1, 25, "Print"],
Cell[43111, 1287, 39, 1, 38, "Print"],
Cell[43153, 1290, 52, 1, 25, "Print"],
Cell[43208, 1293, 39, 1, 38, "Print"],
Cell[43250, 1296, 52, 1, 25, "Print"],
Cell[43305, 1299, 39, 1, 38, "Print"],
Cell[43347, 1302, 52, 1, 25, "Print"],
Cell[43402, 1305, 40, 1, 38, "Print"],
Cell[43445, 1308, 52, 1, 25, "Print"],
Cell[43500, 1311, 40, 1, 38, "Print"],
Cell[43543, 1314, 52, 1, 25, "Print"],
Cell[43598, 1317, 40, 1, 38, "Print"],
Cell[43641, 1320, 51, 1, 25, "Print"],
Cell[43695, 1323, 40, 1, 38, "Print"],
Cell[43738, 1326, 52, 1, 25, "Print"],
Cell[43793, 1329, 40, 1, 38, "Print"],
Cell[43836, 1332, 52, 1, 25, "Print"],
Cell[43891, 1335, 40, 1, 38, "Print"],
Cell[43934, 1338, 52, 1, 25, "Print"],
Cell[43989, 1341, 40, 1, 38, "Print"],
Cell[44032, 1344, 52, 1, 25, "Print"],
Cell[44087, 1347, 40, 1, 38, "Print"],
Cell[44130, 1350, 52, 1, 25, "Print"],
Cell[44185, 1353, 40, 1, 38, "Print"],
Cell[44228, 1356, 52, 1, 25, "Print"],
Cell[44283, 1359, 40, 1, 38, "Print"],
Cell[44326, 1362, 53, 1, 25, "Print"],
Cell[44382, 1365, 40, 1, 38, "Print"],
Cell[44425, 1368, 53, 1, 25, "Print"],
Cell[44481, 1371, 40, 1, 38, "Print"],
Cell[44524, 1374, 53, 1, 25, "Print"],
Cell[44580, 1377, 40, 1, 38, "Print"],
Cell[44623, 1380, 53, 1, 25, "Print"],
Cell[44679, 1383, 40, 1, 38, "Print"],
Cell[44722, 1386, 53, 1, 25, "Print"],
Cell[44778, 1389, 40, 1, 38, "Print"],
Cell[44821, 1392, 53, 1, 25, "Print"],
Cell[44877, 1395, 40, 1, 38, "Print"]
}, Open  ]],
Cell[44932, 1399, 267, 6, 50, "Input"],

Cell[CellGroupData[{
Cell[45224, 1409, 386, 7, 70, "Input"],
Cell[45613, 1418, 22588, 691, 357, 8002, 507, "GraphicsData", "PostScript", \
"Graphics"],
Cell[68204, 2111, 130, 3, 29, "Output"]
}, Open  ]],
Cell[68349, 2117, 150, 2, 50, "Input"],
Cell[68502, 2121, 42, 0, 33, "Text"],
Cell[68547, 2123, 425, 9, 170, "Input"],

Cell[CellGroupData[{
Cell[68997, 2136, 4641, 87, 1711, "Input"],
Cell[73641, 2225, 182, 3, 24, "Message"],
Cell[73826, 2230, 51, 1, 25, "Print"],
Cell[73880, 2233, 38, 1, 38, "Print"],
Cell[73921, 2236, 52, 1, 25, "Print"],
Cell[73976, 2239, 39, 1, 38, "Print"],
Cell[74018, 2242, 52, 1, 25, "Print"],
Cell[74073, 2245, 39, 1, 38, "Print"],
Cell[74115, 2248, 52, 1, 25, "Print"],
Cell[74170, 2251, 39, 1, 38, "Print"],
Cell[74212, 2254, 52, 1, 25, "Print"],
Cell[74267, 2257, 39, 1, 38, "Print"],
Cell[74309, 2260, 52, 1, 25, "Print"],
Cell[74364, 2263, 39, 1, 38, "Print"],
Cell[74406, 2266, 52, 1, 25, "Print"],
Cell[74461, 2269, 39, 1, 38, "Print"],
Cell[74503, 2272, 52, 1, 25, "Print"],
Cell[74558, 2275, 39, 1, 38, "Print"],
Cell[74600, 2278, 52, 1, 25, "Print"],
Cell[74655, 2281, 40, 1, 38, "Print"],
Cell[74698, 2284, 52, 1, 25, "Print"],
Cell[74753, 2287, 40, 1, 38, "Print"],
Cell[74796, 2290, 52, 1, 25, "Print"],
Cell[74851, 2293, 40, 1, 38, "Print"],
Cell[74894, 2296, 52, 1, 25, "Print"],
Cell[74949, 2299, 40, 1, 38, "Print"],
Cell[74992, 2302, 52, 1, 25, "Print"],
Cell[75047, 2305, 40, 1, 38, "Print"],
Cell[75090, 2308, 52, 1, 25, "Print"],
Cell[75145, 2311, 40, 1, 38, "Print"],
Cell[75188, 2314, 51, 1, 25, "Print"],
Cell[75242, 2317, 40, 1, 38, "Print"],
Cell[75285, 2320, 51, 1, 25, "Print"],
Cell[75339, 2323, 40, 1, 38, "Print"],
Cell[75382, 2326, 51, 1, 25, "Print"],
Cell[75436, 2329, 40, 1, 38, "Print"],
Cell[75479, 2332, 52, 1, 25, "Print"],
Cell[75534, 2335, 40, 1, 38, "Print"],
Cell[75577, 2338, 52, 1, 25, "Print"],
Cell[75632, 2341, 40, 1, 38, "Print"],
Cell[75675, 2344, 52, 1, 25, "Print"],
Cell[75730, 2347, 40, 1, 38, "Print"]
}, Open  ]],
Cell[75785, 2351, 269, 6, 50, "Input"],

Cell[CellGroupData[{
Cell[76079, 2361, 388, 7, 70, "Input"],
Cell[76470, 2370, 16651, 618, 222, 7990, 507, "GraphicsData", "PostScript", \
"Graphics"],
Cell[93124, 2990, 130, 3, 29, "Output"]
}, Open  ]],
Cell[93269, 2996, 150, 2, 50, "Input"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

