(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     36703,       1078]*)
(*NotebookOutlinePosition[     37347,       1100]*)
(*  CellTagsIndexPosition[     37303,       1096]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Mortality in the Barro-Becker Model", "Title"],

Cell["\<\
This is the sequential choice model that is used in the paper. This one \
changes K.\
\>", "Subsubtitle"],

Cell[CellGroupData[{

Cell["Setup", "Section"],

Cell["\<\
Setting up some fixed parameters. Notice that T-K has to be at least equal to \
two; otherwise people have births until the last period and their are \
children left who did not have a chance to die yet.prob\
\>", "Text"],

Cell[BoxData[{
    \(\(T = 14;\)\), "\[IndentingNewLine]", 
    \(\(K = 8;\)\)}], "Input"],

Cell["The utility function:", "Text"],

Cell[BoxData[
    \(\(u[c_] := c\^\(1 - \[Sigma]\)\/\(1 - \[Sigma]\);\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computing the Optimum", "Section"],

Cell["The prodedure for computing the optimal solution:", "Text"],

Cell[BoxData[
    \(computemax[sin_, scin_] := 
      Module[{local}, \[IndentingNewLine]par = 
          Join[prepar, {si \[Rule] sin, 
              sc \[Rule] scin}]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
          Here\ nmax\ is\ K\ because\ old\ children\ cause\ no\ cost\ \
*) \[IndentingNewLine]\[IndentingNewLine]nmax = 
          K; \[IndentingNewLine]\[IndentingNewLine]For[n = 0, 
          n \[LessEqual] nmax, \(n++\), 
          Util[T, n, 0] = \[Beta]\ n\^\[Epsilon]\ V /. 
              par]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
          The\ following\ loop\ performs\ the\ backward\ induction\ \
*) \[IndentingNewLine] (*\ First\ the\ non - fecund, \ 
          than\ the\ fecund\ period\ *) \[IndentingNewLine] (*\ 
          Order\ of\ \(indeces : \ Period\), \ old\ children, \ 
          young\ children\ *) \[IndentingNewLine]\[IndentingNewLine]For[
          j = 1, j < T - K, \(j++\), \[IndentingNewLine]For[n = 0, 
            n < nmax, \(n++\), \[IndentingNewLine]Util[T - j, n, 0] = 
              u[w] + \[Gamma]\ \ Util[T - j + 1, n, 0] /. 
                par; \[IndentingNewLine]Util[T - j, n, 1] = 
              u[w - p\ ] + \[Gamma]\ \((sc\ Util[T - j + 1, n + 1, 
                            0] + \((1 - sc)\) Util[T - j + 1, n, 0])\) /. 
                par;\[IndentingNewLine]]; \[IndentingNewLine]Util[T - j, 
              nmax, 0] = 
            u[w] + \[Gamma]\ \ Util[T - j + 1, nmax, 0] /. 
              par;\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine] (*\ In\ the\ fecund\ period, \ 
          fertility\ choice\ only\ if\ n\ is\ less\ than\ max\ \
*) \[IndentingNewLine]\[IndentingNewLine]For[j = T - K, 
          j \[LessEqual] T, \(j++\), \[IndentingNewLine]For[n = 0, 
            n < nmax - 
                1, \(n++\), \[IndentingNewLine]\[IndentingNewLine]Ubirthchild \
= u[w - q - p] + \[Gamma]\ \((sc\ si\ Util[T - j + 1, n + 1, 
                            1] + \((1 - sc)\) si\ Util[T - j + 1, n, 1] + 
                        sc \((1 - si)\)\ Util[T - j + 1, n + 1, 
                            0] + \((1 - sc)\) \((1 - si)\) 
                          Util[T - j + 1, n, 0])\) /. 
                par; \[IndentingNewLine]\[IndentingNewLine]Unobirthchild = 
              u[w - p\ ] + \[Gamma]\ \((sc\ Util[T - j + 1, n + 1, 
                            0] + \((1 - sc)\) Util[T - j + 1, n, 0])\) /. 
                par; \[IndentingNewLine]\[IndentingNewLine]Ubirthnochild = 
              u[w - q] + \[Gamma]\ \((si\ Util[T - j + 1, n, 
                            1] + \((1 - si)\) Util[T - j + 1, n, 0])\) /. 
                par; \[IndentingNewLine]\[IndentingNewLine]Unobirthnochild = 
              u[w] + \[Gamma]\ \ Util[T - j + 1, n, 0] /. 
                par; \[IndentingNewLine]\[IndentingNewLine]If[
              Ubirthchild > Unobirthchild, Birth[T - j, n, 1] = 1, 
              Birth[T - j, n, 1] = 0]; \[IndentingNewLine]If[
              Ubirthnochild > Unobirthnochild, Birth[T - j, n, 0] = 1, 
              Birth[T - j, n, 0] = 
                0]; \[IndentingNewLine]\[IndentingNewLine]Util[T - j, n, 0] = 
              Max[Ubirthnochild, Unobirthnochild]; \[IndentingNewLine]Util[
                T - j, n, 1] = 
              Max[Ubirthchild, 
                Unobirthchild];\[IndentingNewLine]\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine] (*\ 
            nmax - 1\ and\ nmax\ are\ done\ separately, \ 
            because\ a\ birth\ may\ not\ be\ possible\ *) \[IndentingNewLine]\
\[IndentingNewLine]Unobirthchild = 
            u[w - p\ ] + \[Gamma]\ \((sc\ Util[T - j + 1, nmax, 
                          0] + \((1 - sc)\) Util[T - j + 1, nmax - 1, 0])\) /. 
              par; \[IndentingNewLine]\[IndentingNewLine]Ubirthnochild = 
            u[w - q] + \[Gamma]\ \((si\ Util[T - j + 1, nmax - 1, 
                          1] + \((1 - si)\) Util[T - j + 1, nmax - 1, 0])\) /. 
              par; \[IndentingNewLine]\[IndentingNewLine]Unobirthnochild = 
            u[w] + \[Gamma]\ \ Util[T - j + 1, nmax - 1, 0] /. 
              par; \[IndentingNewLine]\[IndentingNewLine]If[
            Ubirthnochild > Unobirthnochild, Birth[T - j, nmax - 1, 0] = 1, 
            Birth[T - j, nmax - 1, 0] = 
              0]; \[IndentingNewLine]\[IndentingNewLine]Birth[T - j, 
              nmax - 1, 1] = 
            0; \[IndentingNewLine]\[IndentingNewLine]Util[T - j, nmax - 1, 
              0] = Max[Ubirthnochild, 
              Unobirthnochild]; \[IndentingNewLine]Util[T - j, nmax - 1, 1] = 
            Unobirthchild; \[IndentingNewLine]\[IndentingNewLine]Birth[T - j, 
              nmax, 0] = 0; \[IndentingNewLine]Birth[T - j, nmax, 1] = 
            0; \[IndentingNewLine]\[IndentingNewLine]Util[T - j, nmax, 0] = 
            u[w] + \[Gamma]\ \ Util[T - j + 1, nmax, 0] /. 
              par;\[IndentingNewLine]];\[IndentingNewLine]]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computing Fertility and Reproduction Rates", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ComputeFertility[sin_, scin_] := 
      Module[{local}, \[IndentingNewLine]par = 
          Join[prepar, {si \[Rule] sin, 
              sc \[Rule] scin}]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
          In\ the\ initial\ period, \ 
          zero\ children\ for\ sure\ \
*) \[IndentingNewLine]\[IndentingNewLine]ageatfirstchild = 
          0; \[IndentingNewLine]\[IndentingNewLine]prob[0, 0, 0] = 
          1; \[IndentingNewLine]For[n = 1, n \[LessEqual] nmax, \(n++\), 
          prob[0, n, 0] = 0]; \[IndentingNewLine]For[n = 0, 
          n \[LessEqual] nmax, \(n++\), 
          prob[0, n, 1] = 0]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
          The\ following\ loops\ moves\ forward\ in\ time\ \
*) \[IndentingNewLine] (*\ First\ the\ fecund, \ 
          than\ the\ non - fecund\ period\ *) \[IndentingNewLine] (*\ 
          Order\ of\ \(indeces : \ Period\), \ old\ children, \ 
          young\ children\ *) \[IndentingNewLine] (*\ 
          n = 0\ \((at\ least)\)\ will\ have\ to\ be\ done\ separately\ \
*) \[IndentingNewLine]\[IndentingNewLine]For[j = 0, 
          j \[LessEqual] 
            K, \(j++\), \[IndentingNewLine]\[IndentingNewLine] (*\ 
            Age\ at\ first\ birth\ \
*) \[IndentingNewLine]If[\((ageatfirstchild \[Equal] 
                    0)\) && \((Birth[j, 0, 0] == 1)\), 
              ageatfirstchild = j]\[IndentingNewLine]\[IndentingNewLine] (*\ 
              Expected\ number\ of\ children\ \((born\ previously)\)\ and\ \
expected\ number\ of\ births\ *) \[IndentingNewLine]\[IndentingNewLine]\(FR[
                j] = \[Sum]\+\(n = 0\)\%nmax\((prob[j, n, 0] Birth[j, n, 0] + 
                    prob[j, n, 1] 
                      Birth[j, n, 1])\)\); \[IndentingNewLine]Eofn[
              j] = \[Sum]\+\(n = 0\)\%nmax\((n\ prob[j, n, 0] + \((n + 1)\) 
                    prob[j, n, 1])\); \[IndentingNewLine] (*\ 
            First\ the\ n = 0\ case, \ 
            the\ loop\ below\ does\ the\ rest\ *) \[IndentingNewLine]\
\[IndentingNewLine]prob[j + 1, 0, 
              0] = \((1 - si\ Birth[j, 0, 0])\) 
                  prob[j, 0, 0] + \((1 - si\ Birth[j, 0, 1])\) \((1 - sc)\) 
                  prob[j, 0, 1] /. 
              par; \[IndentingNewLine]\[IndentingNewLine]prob[j + 1, 0, 1] = 
            si\ Birth[j, 0, 0] prob[j, 0, 0] + 
                si\ Birth[j, 0, 1] \((1 - sc)\) prob[j, 0, 1] /. 
              
              par; \[IndentingNewLine]\[IndentingNewLine]\[IndentingNewLine]\
For[n = 1, 
            n \[LessEqual] 
              nmax, \(n++\), \[IndentingNewLine]\[IndentingNewLine]prob[
                j + 1, n, 
                0] = \((1 - si\ Birth[j, n, 0])\) 
                    prob[j, n, 0] + \((1 - si\ Birth[j, n, 1])\) \((1 - sc)\) 
                    prob[j, n, 1] + \((1 - si\ Birth[j, n - 1, 1])\) 
                    sc\ prob[j, n - 1, 1] /. 
                par; \[IndentingNewLine]\[IndentingNewLine]prob[j + 1, n, 
                1] = si\ Birth[j, n, 0] prob[j, n, 0] + 
                  si\ Birth[j, n, 1] \((1 - sc)\) prob[j, n, 1] + 
                  si\ Birth[j, n - 1, 1] sc\ prob[j, n - 1, 1] /. 
                par;\[IndentingNewLine]];\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine]For[j = K + 1, 
          j \[LessEqual] 
            T, \(j++\), \[IndentingNewLine]\[IndentingNewLine] (*\ 
            Fertility\ Rates\ and\ Expected\ number\ of\ children\ \((born\ \
previously)\)\ *) \[IndentingNewLine]\[IndentingNewLine]FR[j] = 
            0; \[IndentingNewLine]Eofn[
              j] = \[Sum]\+\(n = 0\)\%nmax\((n\ prob[j, n, 0] + \((n + 1)\) 
                    prob[j, n, 
                      1])\); \[IndentingNewLine]\[IndentingNewLine] (*\ 
            First\ the\ n = 0\ case, \ 
            the\ loop\ below\ does\ the\ rest\ *) \[IndentingNewLine]\
\[IndentingNewLine]prob[j + 1, 0, 0] = 
            prob[j, 0, 0] + \((1 - sc)\) prob[j, 0, 1] /. 
              par; \[IndentingNewLine]\[IndentingNewLine]prob[j + 1, 0, 1] = 
            0 /. par; \[IndentingNewLine]\[IndentingNewLine]For[n = 1, 
            n \[LessEqual] 
              nmax, \(n++\), \[IndentingNewLine]\[IndentingNewLine]prob[
                j + 1, n, 0] = 
              prob[j, n, 0] + \((1 - sc)\) prob[j, n, 1] + 
                  sc\ prob[j, n - 1, 1] /. 
                par; \[IndentingNewLine]\[IndentingNewLine]prob[j + 1, n, 
                1] = 0 /. 
                par;\[IndentingNewLine]];\[IndentingNewLine]\
\[IndentingNewLine]];\[IndentingNewLine]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"prob\" is similar to \
existing symbol \"prob\"."\)], "Message",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computing TFR and NFR", "Section"],

Cell[BoxData[
    \(TFRNFRAge[sin_, scin_] := 
      Module[{local}, \[IndentingNewLine]computemax[sin, 
          scin]; \[IndentingNewLine]ComputeFertility[sin, 
          scin]; \[IndentingNewLine]{\[Sum]\+\(j = 0\)\%T FR[j], Eofn[T], 
          ageatfirstchild}\[IndentingNewLine]]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Actual Computation", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(NTarget = 5;\)\), "\[IndentingNewLine]", 
    \(\(sigmaset =  .5;\)\), "\[IndentingNewLine]", 
    \(\(epsset =  .5;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(Vlo = 0;\)\), "\[IndentingNewLine]", 
    \(\(Vset = 0.5;\)\), "\[IndentingNewLine]", 
    \(\(Vhi = 1000;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(it = 1;\)\), "\[IndentingNewLine]", 
    \(While[
      it < 30, \[IndentingNewLine]Clear[Util, Birth, prob, 
        FR]; \[IndentingNewLine]prepar = {\[Sigma] \[Rule] 
            sigmaset, \[Epsilon] \[Rule] epsset, \[Beta] \[Rule] 
            1, \[Gamma] \[Rule]  .95, p \[Rule] 5/12, q \[Rule] 1/12, 
          V \[Rule] Vset, 
          w \[Rule] 
            1}; \[IndentingNewLine]\[IndentingNewLine]If[\(TFRNFRAge[ .73, 
              1]\)[\([1]\)] > NTarget, Vhi = Vset; 
        Vset =  .5\ Vset\  + \  .5\ Vlo, Vlo = Vset; 
        Vset =  .5\ Vset\  + \  .5\ Vhi]; \[IndentingNewLine]\
\[IndentingNewLine]it = 
        it + 1;\[IndentingNewLine]]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(Print[Vset];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(prepar = {\[Sigma] \[Rule] sigmaset, \[Epsilon] \[Rule] 
            epsset, \[Beta] \[Rule] 1, \[Gamma] \[Rule]  .95, p \[Rule] 5/12, 
          q \[Rule] 1/12, V \[Rule] Vset, 
          w \[Rule] 1};\)\), "\[IndentingNewLine]", 
    \(\(Print[{\(TFRNFRAge[ .73, 1]\)[\([1]\)], \(TFRNFRAge[ .73, 
              1]\)[\([2]\)], \(TFRNFRAge[ .73, 
              1]\)[\([3]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(Print[{\(TFRNFRAge[ .965, 1]\)[\([1]\)], \(TFRNFRAge[ .965, 
              1]\)[\([2]\)], \(TFRNFRAge[ .965, 
              1]\)[\([3]\)]}];\)\[IndentingNewLine]\), "\[IndentingNewLine]", \

    \(\(Plot[{\(TFRNFRAge[s, 1]\)[\([1]\)], \(TFRNFRAge[s, 
              1]\)[\([2]\)]}, {s, 0.06,  .99}, 
        PlotRange \[Rule] {{0, 1}, {0, 11}}, 
        AxesLabel \[Rule] {"\<s\>", "\<Children\>"}, 
        PlotStyle \[Rule] {{Thickness[ .008]}, {Dashing[{ .02,  .02}], 
              Thickness[ .008]}}];\)\)}], "Input"],

Cell[BoxData[
    \(3.7348301680758595`\)], "Print"],

Cell[BoxData[
    \({4.539999999999999`, 3.3141999999999996`, 3}\)], "Print"],

Cell[BoxData[
    \({4.035`, 3.893775`, 4}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 1.38778e-017 0.0561849 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .11237 -6 -4.5 ]
[-0.0125 .11237 0 4.5 ]
[-0.0125 .22474 -6 -4.5 ]
[-0.0125 .22474 0 4.5 ]
[-0.0125 .33711 -6 -4.5 ]
[-0.0125 .33711 0 4.5 ]
[-0.0125 .44948 -6 -4.5 ]
[-0.0125 .44948 0 4.5 ]
[-0.0125 .56185 -12 -4.5 ]
[-0.0125 .56185 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11237 m
.00625 .11237 L
s
[(2)] -0.0125 .11237 1 0 Mshowa
0 .22474 m
.00625 .22474 L
s
[(4)] -0.0125 .22474 1 0 Mshowa
0 .33711 m
.00625 .33711 L
s
[(6)] -0.0125 .33711 1 0 Mshowa
0 .44948 m
.00625 .44948 L
s
[(8)] -0.0125 .44948 1 0 Mshowa
0 .56185 m
.00625 .56185 L
s
[(10)] -0.0125 .56185 1 0 Mshowa
.125 Mabswid
0 .02809 m
.00375 .02809 L
s
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .14046 m
.00375 .14046 L
s
0 .16855 m
.00375 .16855 L
s
0 .19665 m
.00375 .19665 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .47757 m
.00375 .47757 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .58994 m
.00375 .58994 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.06 .32917 m
.09773 .34707 L
.10721 .3352 L
.11736 .32308 L
.12036 .31961 L
.12183 .31793 L
.12248 .31719 L
.12319 .31638 L
.12443 .349 L
.1251 .34836 L
.12574 .34776 L
.1285 .34517 L
.1335 .34055 L
.13494 .33924 L
.13565 .33859 L
.1363 .338 L
.13753 .36541 L
.13818 .36489 L
.13887 .36435 L
.14389 .36042 L
.14931 .35626 L
.1518 .35437 L
.15316 .35334 L
.15443 .35239 L
.15551 .37444 L
.15667 .37363 L
.15914 .37192 L
.16153 .37027 L
.16269 .36947 L
.16377 .36874 L
.16489 .37059 L
.1661 .36976 L
.16868 .36799 L
.17751 .36202 L
.18235 .35879 L
.18479 .35718 L
.18545 .35674 L
.18617 .35628 L
.18745 .37244 L
.18818 .37196 L
.18885 .37152 L
.19036 .37054 L
.19167 .36968 L
.19236 .36923 L
.19311 .36875 L
.1944 .37032 L
.19561 .36953 L
.19826 .3678 L
.19948 .367 L
.20015 .36656 L
Mistroke
.20077 .36615 L
.20152 .37868 L
.2022 .37831 L
.20352 .37758 L
.20852 .37485 L
.2179 .3698 L
.22285 .36717 L
.22746 .36473 L
.22979 .36352 L
.23046 .36317 L
.23109 .36284 L
.23227 .36876 L
.23291 .36845 L
.23359 .36813 L
.2348 .36754 L
.23624 .36686 L
.23686 .36656 L
.23755 .36623 L
.23859 .36854 L
.23968 .36801 L
.24198 .3669 L
.24613 .36491 L
.24736 .36433 L
.24851 .36378 L
.24915 .36348 L
.24984 .38256 L
.25104 .38201 L
.2556 .37992 L
.26007 .37788 L
.26253 .37676 L
.26487 .37571 L
.26618 .37511 L
.26693 .37478 L
.26762 .38099 L
.26883 .38046 L
.27013 .37989 L
.27505 .37772 L
.29561 .36879 L
.29681 .36827 L
.29795 .37644 L
.29858 .3762 L
.29926 .37594 L
.30045 .37548 L
.30159 .37504 L
.3028 .37458 L
.30383 .35585 L
.30496 .3555 L
.30966 .35408 L
.31481 .35252 L
.3192 .3512 L
Mistroke
.32162 .35048 L
.32392 .34979 L
.32605 .34915 L
.32725 .34879 L
.32837 .35221 L
.3294 .35189 L
.33034 .3516 L
.33244 .35095 L
.34151 .34816 L
.35131 .34516 L
.35397 .34435 L
.35542 .34391 L
.35612 .34369 L
.35677 .34349 L
.35793 .34907 L
.35917 .34869 L
.36179 .34788 L
.37167 .34486 L
.38071 .3421 L
.38567 .34059 L
.39032 .33918 L
.39273 .33845 L
.39339 .33825 L
.39408 .33804 L
.39533 .35017 L
.39599 .35001 L
.39669 .34983 L
.39797 .34952 L
.40085 .3488 L
.40559 .34763 L
.40817 .34699 L
.41059 .34639 L
.41179 .34609 L
.41308 .32836 L
.41381 .32823 L
.4145 .3281 L
.4158 .32787 L
.42061 .327 L
.43145 .32503 L
.45114 .32144 L
.4885 .31463 L
.52826 .30737 L
.54667 .30401 L
.55634 .30225 L
.56162 .30129 L
.56654 .30039 L
.56784 .30016 L
.56906 .29993 L
.56974 .29981 L
.57047 .27892 L
Mistroke
.57176 .27875 L
.57747 .27801 L
.58751 .27671 L
.60722 .27414 L
.64711 .26892 L
.66694 .26632 L
.67665 .26505 L
.68553 .26389 L
.68989 .26331 L
.69219 .26301 L
.69465 .26269 L
.69586 .26253 L
.697 .26238 L
.69803 .25867 L
.69914 .25855 L
.70332 .25808 L
.71322 .25697 L
.72246 .25593 L
.72694 .25542 L
.72823 .25528 L
.72945 .25514 L
.73054 .285 L
.73174 .28497 L
.74192 .28467 L
.7517 .28439 L
.75689 .28425 L
.75962 .28417 L
.7611 .28413 L
.76183 .28411 L
.76249 .28409 L
.76369 .23802 L
.76497 .23794 L
.76768 .23779 L
.77244 .23752 L
.78179 .237 L
.8023 .23585 L
.84133 .23365 L
.87888 .23154 L
.91883 .2293 L
.95729 .22714 L
.99 .22474 L
Mfstroke
[ .02 .02 ] 0 setdash
.06 .01975 m
.09773 .03392 L
.13887 .0506 L
.17751 .06426 L
.21468 .07976 L
.21978 .08105 L
.22532 .08244 L
.22786 .08306 L
.22925 .0834 L
.22993 .08357 L
.23056 .08372 L
.23166 .0855 L
.23286 .0858 L
.23539 .08645 L
.23654 .08674 L
.23762 .08702 L
.23887 .088 L
.24001 .08829 L
.24262 .08894 L
.24505 .08955 L
.24617 .08982 L
.24735 .09012 L
.24835 .09036 L
.24946 .09548 L
.25065 .0958 L
.25193 .09614 L
.25423 .09675 L
.27247 .10323 L
.28209 .10568 L
.28736 .107 L
.29231 .10822 L
.29477 .10882 L
.29545 .10898 L
.29616 .10915 L
.29743 .11203 L
.29811 .1122 L
.29883 .11239 L
.30013 .11273 L
.30155 .1131 L
.30229 .11329 L
.30308 .1135 L
.30375 .1081 L
.30448 .10829 L
.30577 .10863 L
.30831 .10929 L
.31305 .11052 L
.3327 .11673 L
.37209 .12827 L
.38088 .13028 L
.3857 .13136 L
Mistroke
.39023 .13237 L
.39282 .13294 L
.39353 .1331 L
.39427 .13326 L
.39491 .1334 L
.39561 .1385 L
.39683 .13881 L
.39814 .13914 L
.40049 .13973 L
.40505 .14086 L
.40745 .14145 L
.41 .14208 L
.41066 .14224 L
.41138 .14242 L
.41216 .13541 L
.41289 .13559 L
.41556 .13627 L
.42082 .13759 L
.43068 .14004 L
.45031 .14482 L
.49053 .15415 L
.52928 .16259 L
.54881 .16663 L
.55733 .16835 L
.5618 .16925 L
.56654 .17019 L
.56899 .17067 L
.56966 .1708 L
.57038 .17094 L
.57106 .15924 L
.57168 .15936 L
.57642 .16033 L
.58573 .16221 L
.6062 .16626 L
.64508 .17365 L
.66285 .17689 L
.67297 .17869 L
.68247 .18037 L
.69175 .18198 L
.69429 .18242 L
.69568 .18265 L
.69697 .18288 L
.69808 .18057 L
.69926 .18078 L
.70176 .18123 L
.71243 .18313 L
.72227 .18486 L
.72711 .18571 L
.72829 .18591 L
.72956 .18613 L
Mistroke
.73029 .20814 L
.73095 .20831 L
.73225 .20866 L
.74309 .21151 L
.75329 .21419 L
.75826 .2155 L
.7606 .21612 L
.76163 .21639 L
.76276 .21669 L
.76384 .1818 L
.76498 .18202 L
.76738 .18249 L
.77174 .18334 L
.78131 .18519 L
.80155 .18908 L
.84105 .19653 L
.87906 .20353 L
.91947 .2108 L
.9584 .21763 L
.99 .22249 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00AP3oool2000000@0oooo0P0000030?ooo`@00000803oool2000000@0oooo0P0000050?oo
o`<00000803oool2000000@0oooo0P0000030?ooo`<000008@3oool2000000@0oooo0P0000040?oo
o`8000009`3oool500000180oooo00150?ooo`040000003oool0oooo000000P0oooo00<000000?oo
o`3oool0803oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo01h0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000O0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool00000:03oool00`000000oooo0?ooo`0B0?ooo`00A@3oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo01l0oooo00@000000?ooo`3oool00000203oool5
000001l0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000O0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool00000:03oool00`000000oooo0?ooo`0B0?oo
o`00A@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo01h0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`00000P0?ooo`040000003oool0oooo000000P0oooo
0`00000P0?ooo`040000003oool0oooo000000T0oooo0P00000Y0?ooo`030000003oool0oooo0180
oooo00150?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000007`3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool000000200oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo0?ooo`0O0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000:03oool00`000000oooo0?ooo`0B0?ooo`00AP3oool2000000X0oooo0P00000Q0?ooo`800000
2`3oool200000240oooo0P00000:0?ooo`<00000803oool2000000X0oooo0P00000X0?ooo`800000
503oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo503oool3000000X0
oooo003o0?oooaL0oooo00<000000?ooo`3oool01`3oool001h0ooookP0000070?ooo`<000002P3o
ool001h0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo00D0oooo100000090?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool00`000000
oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?oo
o`0<0?ooo`800000l@3oool001h0oooo00<000000?ooo`3oool03P3oool300000>h0oooo000N0?oo
o`030000003oool0oooo0?l0oooo000N0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0i`3oool001h0oooo00<000000?ooo`3oool05P3oool200000>L0oooo000N0?ooo`030000003o
ool0oooo01P0oooo0P00003U0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool00`00
0000oooo0?ooo`0M0?ooo`<00000g`3oool001h0oooo00<000000?ooo`3oool0803oool300000=`0
oooo000N0?ooo`030000003oool0oooo0?l0oooo000N0?ooo`030000003oool0oooo02H0oooo0P00
003G0?ooo`007P3oool00`000000oooo0?ooo`0X0?ooo`800000e@3oool001h0oooo00<000000?oo
o`3oool0:P3oool200000=<0oooo000N0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3o
ool0c@3oool001h0oooo00<000000?ooo`3oool0<03oool400000</0oooo000N0?ooo`030000003o
ool0oooo03<0oooo00<000000?ooo`3oool0b@3oool001h0oooo00<000000?ooo`3oool0o`3oool0
01h0oooo00<000000?ooo`3oool0>03oool300000<@0oooo000N0?ooo`030000003oool0oooo03/0
oooo0P0000320?ooo`005P3oool4000000@0oooo00<000000?ooo`3oool0o`3oool001H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`100?ooo`@00000^`3oool001L0oooo00<00000
0?ooo`3oool0103oool2000004@0oooo0P0000030?ooo`800000]@3oool001P0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`1:0?ooo`800000/`3oool001H0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0;00oooo000G0?ooo`80
00001@3oool00`000000oooo0?ooo`1A0?ooo`800000[03oool001h0oooo00<000000?ooo`3oool0
D`3oool300000:T0oooo000N0?ooo`030000003oool0oooo05P0oooo0`00002T0?ooo`007P3oool0
0`000000oooo0?ooo`1N0?ooo`@00000W@3oool001h0oooo00<000000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo09H0oooo000N0?ooo`030000003oool0oooo06L0
oooo0P00002F0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`800000U03oool001h0oooo00<0
00000?ooo`3oool0K`3oool3000008d0oooo000N0?ooo`030000003oool0oooo0780oooo0P00002;
0?ooo`007P3oool00`000000oooo0?ooo`1h0?ooo`@00000203oool010000000oooo0?ooo`3oool2
000007D0oooo000N0?ooo`030000003oool0oooo07`0oooo0P0000060?ooo`030000003oool0oooo
00<0oooo1000001a0?ooo`007P3oool00`000000oooo0?ooo`210?ooo`@00000303oool2000006`0
oooo000N0?ooo`030000003oool0oooo09<0oooo1000001X0?ooo`007P3oool00`000000oooo0?oo
o`2K0?ooo`@00000H03oool001h0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`02
0?ooo`D000002@3oool00`000000oooo0?ooo`1:0?ooo`007P3oool00`000000oooo0?ooo`2X0?oo
o`800000203oool010000000oooo0?ooo`3oool6000004<0oooo000N0?ooo`030000003oool0oooo
0:T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`<00000?@3oool001h0
oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0
oooo0`00000j0?ooo`007P3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01D0oooo
0P00000d0?ooo`007P3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01L0oooo0`00
000a0?ooo`007P3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo02@0oooo1@00000X
0?ooo`007P3oool00`000000oooo0?ooo`2/0?ooo`@000009`3oool010000000oooo0?ooo`3oool3
00000240oooo000H0?ooo`<000000`3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo
02/0oooo0`00000N0?ooo`006@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0>D0
oooo0`00000G0?ooo`005P3oool5000000<0oooo0P00003L0?ooo`d000005`3oool001H0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`390?oooa800000903oool001L0oooo00<0
00000?ooo`000000103oool00`000000oooo0?ooo`2i0?oooa000000=P3oool001P0oooo0P000004
0?ooo`030000003oool0oooo0;80oooo1`0000160?ooo`007P3oool00`000000oooo0?ooo`2b0?oo
o`030000003oool0oooo04X0oooo000N0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3o
ool0BP3oool001h0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`1:0?ooo`007P3o
ool00`000000oooo0?ooo`2U0?ooo`D00000203oool00`000000oooo0?ooo`1:0?ooo`007P3oool0
0`000000oooo0?ooo`2R0?ooo`<00000103oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo04X0oooo000N0?ooo`030000003oool0oooo09d0oooo1P0000060?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0B`3oool001h0oooo00<000000?ooo`3oool0U03oool9000000`0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1;0?ooo`007P3oool00`000000oooo
0?ooo`2?0?ooo`D000005P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04/0oooo
000N0?ooo`030000003oool0oooo08D0oooo2P00000K0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0B`3oool001h0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0B`3oool001h0oooo00<000000?oo
o`3oool0Q03oool00`000000oooo0?ooo`0S0?ooo`P00000C@3oool001h0oooo00<000000?ooo`3o
ool0Q03oool00`000000oooo0?ooo`1h0?ooo`007P3oool00`000000oooo0?ooo`240?ooo`030000
003oool0oooo07P0oooo000N0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0N03o
ool001h0oooo00<000000?ooo`3oool0P03oool5000007X0oooo000N0?ooo`030000003oool0oooo
07P0oooo2000001o0?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`D00000Q`3oool001h0oooo
00<000000?ooo`3oool0KP3oool5000008`0oooo000N0?ooo`030000003oool0oooo01T0oooo0P00
001?0?ooo`@00000T@3oool001h0oooo00<000000?ooo`3oool0603oool00`000000oooo0000001;
0?ooo`@00000U@3oool001H0oooo0`0000050?ooo`030000003oool0oooo01L0oooo00@000000?oo
o`3oool00000@`3oool8000009T0oooo000F0?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool02`3oool2000000X0oooo00@000000?ooo`3oool00000@`3oool00`000000oooo0?oo
o`2N0?ooo`005P3oool010000000oooo0?ooo`0000040?ooo`8000003P3oool2000000L0oooo00D0
00000?ooo`3oool0oooo000000130?ooo`030000003oool0oooo09h0oooo000F0?ooo`<000001@3o
ool00`000000oooo0?ooo`0?0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`040000003o
ool00000000003X0oooo0`0000030?ooo`030000003oool0oooo09h0oooo000G0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool04@3oool200000080oooo00<000000?ooo`3oool00P3o
ool2000000030?ooo`000000oooo0300oooo0`0000020?ooo`@000000P3oool01@000000oooo0?oo
o`3oool000000:00oooo000G0?ooo`<00000103oool00`000000oooo0?ooo`0C0?ooo`8000001@3o
ool010000000oooo0?ooo`00000[0?ooo`8000000P3oool200000080oooo0`0000060?ooo`D00000
X03oool001h0oooo00<000000?ooo`3oool07@3oool01@000000oooo0?ooo`3oool0000002@0oooo
1`00000=0?ooo`030000003oool0oooo0:80oooo000N0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool00P0000060?ooo`8000006`3oool00`000000oooo0?ooo`2g0?ooo`007P3oool0
0`000000oooo0?ooo`0M0?ooo`050000003oool000000?ooo`0000001@3oool3000001/0oooo00<0
00000?ooo`3oool0]`3oool001h0oooo00<000000?ooo`3oool07@3oool200000080oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo0P00
00000`3oool0000000000002000000/0oooo00<000000?ooo`3oool0^03oool001h0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo00000002000000<0oooo100000030?ooo`8000000P3oool2
00000080oooo00<000000?ooo`3oool01`3oool300000;X0oooo000N0?ooo`030000003oool0oooo
0240oooo0P0000060?ooo`050000003oool0oooo0000003oool00P0000080?ooo`050000003oool0
oooo0?ooo`0000000`3oool2000000030?ooo`00000000000;X0oooo000N0?ooo`030000003oool0
oooo02`0oooo0P00000:0?ooo`030000003oool000000080000000<0oooo0000000000000`3oool2
00000;X0oooo000N0?ooo`030000003oool0oooo03P0oooo0P0000020?ooo`800000`@3oool001h0
oooo00<000000?ooo`3oool0o`3oool001h0oooo00<000000?ooo`3oool0o`3oool001h0oooo00<0
00000?ooo`3oool0o`3oool001h0oooo00<000000?ooo`3oool0o`3oool001h0oooo00<000000?oo
o`3oool0o`3oool001h0oooo00<000000?ooo`3oool0o`3oool001h0oooo00<000000?ooo`3oool0
o`3oool001h0oooo00<000000?ooo`3oool0o`3oool001h0oooo00<000000?ooo`3oool0o`3oool0
01h0oooo00<000000?ooo`3oool0o`3oool001h0oooo00<000000?ooo`3oool0o`3oool001h0oooo
00<000000?ooo`3oool0o`3oool001h0oooo00<000000?ooo`3oool0o`3oool001L0oooo0P000005
0?ooo`030000003oool0oooo0?l0oooo000F0?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0o`3oool001H0oooo00@000000?ooo`3oool00000103oool200000?l0oooo0@3oool0
01L0oooo0P0000050?ooo`030000003oool0oooo0?l0oooo000F0?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0o`3oool001L0oooo0P0000050?ooo`030000003oool0oooo0?l0
oooo000N0?ooo`030000003oool0oooo0?l0oooo000N0?ooo`030000003oool0oooo0?l0oooo000N
0?ooo`030000003oool0oooo0?l0oooo000N0?ooo`030000003oool0oooo0?l0oooo000N0?ooo`03
0000003oool0oooo0?l0oooo000N0?ooo`030000003oool0oooo0?l0oooo000N0?ooo`030000003o
ool0oooo0?l0oooo000N0?ooo`030000003oool0oooo0?l0oooo000N0?ooo`030000003oool0oooo
0?l0oooo000N0?ooo`030000003oool0oooo0?l0oooo000N0?ooo`030000003oool0oooo0?l0oooo
000N0?ooo`030000003oool0oooo0?l0oooo000N0?ooo`030000003oool0oooo0?l0oooo000N0?oo
o`030000003oool0oooo0?l0oooo000N0?ooo`030000003oool0oooo0?l0oooo000N0?ooo`030000
003oool0oooo0?l0oooo000N0?ooo`030000003oool0oooo0?l0oooo000N0?ooo`030000003oool0
oooo0?l0oooo000N0?ooo`030000003oool0oooo0?l0oooo000N0?ooo`030000003oool0oooo0?l0
oooo000N0?ooo`030000003oool0oooo0?l0oooo000@0?ooo`D000000P3oool2000000D0oooo00<0
00000?ooo`3oool0o`3oool00180oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0o`3oool00180oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0080oooo0P00003o0?ooo`40oooo000B0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo000B
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0?l0oooo000A0?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0o`3oool0
01h0oooo00<000000?ooo`3oool0o`3oool001h0oooo00<000000?ooo`3oool0o`3oool001h0oooo
00<000000?ooo`3oool0o`3oool001h0oooo00<000000?ooo`3oool0o`3oool001h0oooo00<00000
0?ooo`3oool0o`3oool001h0oooo00<000000?ooo`3oool0o`3oool001h0oooo00<000000?ooo`3o
ool0o`3oool001h0oooo00<000000?ooo`3oool0o`3oool001h0oooo00<000000?ooo`3oool0o`3o
ool001h0oooo00<000000?ooo`3oool0o`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool000P0oooo0`0000001@3oool00000000000000000
oooo008000000P3oool300000080oooo0`0000040?ooo`@0000000<0oooo0000000000000P000003
0?ooo`<0000000<0oooo0000000000000P3oool200000>X0oooo00070?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool00000j`3oool000L0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo100000020?ooo`04
0000003oool0oooo00000>/0oooo00070?ooo`030000003oool0oooo00<0oooo0`0000040?ooo`80
0000103oool00`000000oooo0?ooo`030?ooo`<000000P3oool4000000<0oooo0P0000020?ooo`@0
0000k03oool000L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0n`3oool000P0oooo0`0000000`3oool00000
000000070?ooo`040000003oool0oooo0?ooo`8000001P3oool200000?d0oooo003o0?ooob40oooo
003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.89837, \
0.00421906, 0.0750924}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowSize->{1016, 668},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 52, 0, 115, "Title"],
Cell[1782, 54, 115, 3, 53, "Subsubtitle"],

Cell[CellGroupData[{
Cell[1922, 61, 24, 0, 59, "Section"],
Cell[1949, 63, 231, 4, 52, "Text"],
Cell[2183, 69, 90, 2, 50, "Input"],
Cell[2276, 73, 37, 0, 33, "Text"],
Cell[2316, 75, 84, 1, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2437, 81, 40, 0, 59, "Section"],
Cell[2480, 83, 65, 0, 33, "Text"],
Cell[2548, 85, 4894, 78, 1310, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7479, 168, 61, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[7565, 172, 4557, 80, 1385, "Input"],
Cell[12125, 254, 221, 5, 24, "Message"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12395, 265, 40, 0, 59, "Section"],
Cell[12438, 267, 298, 5, 140, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12773, 277, 41, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[12839, 281, 2081, 39, 530, "Input"],
Cell[14923, 322, 52, 1, 25, "Print"],
Cell[14978, 325, 77, 1, 25, "Print"],
Cell[15058, 328, 55, 1, 25, "Print"],
Cell[15116, 331, 21547, 742, 186, 8971, 582, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

