(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     88355,       2861]*)
(*NotebookOutlinePosition[     88999,       2883]*)
(*  CellTagsIndexPosition[     88955,       2879]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Mortality in the Barro-Becker Model", "Title"],

Cell["\<\
This is the sequential choice model that is used in the paper. This one \
changes the cost per birth.\
\>", "Subsubtitle"],

Cell[CellGroupData[{

Cell["Setup", "Section"],

Cell["\<\
Setting up some fixed parameters. Notice that T-K has to be at least equal to \
two; otherwise people have births until the last period and their are \
children left who did not have a chance to die yet.prob\
\>", "Text"],

Cell[BoxData[{
    \(\(T = 14;\)\), "\[IndentingNewLine]", 
    \(\(K = 12;\)\)}], "Input"],

Cell["The utility function:", "Text"],

Cell[BoxData[
    \(\(u[c_] := c\^\(1 - \[Sigma]\)\/\(1 - \[Sigma]\);\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computing the Optimum", "Section"],

Cell["The prodedure for computing the optimal solution:", "Text"],

Cell[BoxData[
    \(computemax[sin_, scin_] := 
      Module[{local}, \[IndentingNewLine]par = 
          Join[prepar, {si \[Rule] sin, 
              sc \[Rule] scin}]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
          Here\ nmax\ is\ K\ because\ old\ children\ cause\ no\ cost\ \
*) \[IndentingNewLine]\[IndentingNewLine]nmax = 
          K; \[IndentingNewLine]\[IndentingNewLine]For[n = 0, 
          n \[LessEqual] nmax, \(n++\), 
          Util[T, n, 0] = \[Beta]\ n\^\[Epsilon]\ V /. 
              par]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
          The\ following\ loop\ performs\ the\ backward\ induction\ \
*) \[IndentingNewLine] (*\ First\ the\ non - fecund, \ 
          than\ the\ fecund\ period\ *) \[IndentingNewLine] (*\ 
          Order\ of\ \(indeces : \ Period\), \ old\ children, \ 
          young\ children\ *) \[IndentingNewLine]\[IndentingNewLine]For[
          j = 1, j < T - K, \(j++\), \[IndentingNewLine]For[n = 0, 
            n < nmax, \(n++\), \[IndentingNewLine]Util[T - j, n, 0] = 
              u[w] + \[Gamma]\ \ Util[T - j + 1, n, 0] /. 
                par; \[IndentingNewLine]Util[T - j, n, 1] = 
              u[w - p\ ] + \[Gamma]\ \((sc\ Util[T - j + 1, n + 1, 
                            0] + \((1 - sc)\) Util[T - j + 1, n, 0])\) /. 
                par;\[IndentingNewLine]]; \[IndentingNewLine]Util[T - j, 
              nmax, 0] = 
            u[w] + \[Gamma]\ \ Util[T - j + 1, nmax, 0] /. 
              par;\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine] (*\ In\ the\ fecund\ period, \ 
          fertility\ choice\ only\ if\ n\ is\ less\ than\ max\ \
*) \[IndentingNewLine]\[IndentingNewLine]For[j = T - K, 
          j \[LessEqual] T, \(j++\), \[IndentingNewLine]For[n = 0, 
            n < nmax - 
                1, \(n++\), \[IndentingNewLine]\[IndentingNewLine]Ubirthchild \
= u[w - q - p] + \[Gamma]\ \((sc\ si\ Util[T - j + 1, n + 1, 
                            1] + \((1 - sc)\) si\ Util[T - j + 1, n, 1] + 
                        sc \((1 - si)\)\ Util[T - j + 1, n + 1, 
                            0] + \((1 - sc)\) \((1 - si)\) 
                          Util[T - j + 1, n, 0])\) /. 
                par; \[IndentingNewLine]\[IndentingNewLine]Unobirthchild = 
              u[w - p\ ] + \[Gamma]\ \((sc\ Util[T - j + 1, n + 1, 
                            0] + \((1 - sc)\) Util[T - j + 1, n, 0])\) /. 
                par; \[IndentingNewLine]\[IndentingNewLine]Ubirthnochild = 
              u[w - q] + \[Gamma]\ \((si\ Util[T - j + 1, n, 
                            1] + \((1 - si)\) Util[T - j + 1, n, 0])\) /. 
                par; \[IndentingNewLine]\[IndentingNewLine]Unobirthnochild = 
              u[w] + \[Gamma]\ \ Util[T - j + 1, n, 0] /. 
                par; \[IndentingNewLine]\[IndentingNewLine]If[
              Ubirthchild > Unobirthchild, Birth[T - j, n, 1] = 1, 
              Birth[T - j, n, 1] = 0]; \[IndentingNewLine]If[
              Ubirthnochild > Unobirthnochild, Birth[T - j, n, 0] = 1, 
              Birth[T - j, n, 0] = 
                0]; \[IndentingNewLine]\[IndentingNewLine]Util[T - j, n, 0] = 
              Max[Ubirthnochild, Unobirthnochild]; \[IndentingNewLine]Util[
                T - j, n, 1] = 
              Max[Ubirthchild, 
                Unobirthchild];\[IndentingNewLine]\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine] (*\ 
            nmax - 1\ and\ nmax\ are\ done\ separately, \ 
            because\ a\ birth\ may\ not\ be\ possible\ *) \[IndentingNewLine]\
\[IndentingNewLine]Unobirthchild = 
            u[w - p\ ] + \[Gamma]\ \((sc\ Util[T - j + 1, nmax, 
                          0] + \((1 - sc)\) Util[T - j + 1, nmax - 1, 0])\) /. 
              par; \[IndentingNewLine]\[IndentingNewLine]Ubirthnochild = 
            u[w - q] + \[Gamma]\ \((si\ Util[T - j + 1, nmax - 1, 
                          1] + \((1 - si)\) Util[T - j + 1, nmax - 1, 0])\) /. 
              par; \[IndentingNewLine]\[IndentingNewLine]Unobirthnochild = 
            u[w] + \[Gamma]\ \ Util[T - j + 1, nmax - 1, 0] /. 
              par; \[IndentingNewLine]\[IndentingNewLine]If[
            Ubirthnochild > Unobirthnochild, Birth[T - j, nmax - 1, 0] = 1, 
            Birth[T - j, nmax - 1, 0] = 
              0]; \[IndentingNewLine]\[IndentingNewLine]Birth[T - j, 
              nmax - 1, 1] = 
            0; \[IndentingNewLine]\[IndentingNewLine]Util[T - j, nmax - 1, 
              0] = Max[Ubirthnochild, 
              Unobirthnochild]; \[IndentingNewLine]Util[T - j, nmax - 1, 1] = 
            Unobirthchild; \[IndentingNewLine]\[IndentingNewLine]Birth[T - j, 
              nmax, 0] = 0; \[IndentingNewLine]Birth[T - j, nmax, 1] = 
            0; \[IndentingNewLine]\[IndentingNewLine]Util[T - j, nmax, 0] = 
            u[w] + \[Gamma]\ \ Util[T - j + 1, nmax, 0] /. 
              par;\[IndentingNewLine]];\[IndentingNewLine]]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computing Fertility and Reproduction Rates", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ComputeFertility[sin_, scin_] := 
      Module[{local}, \[IndentingNewLine]par = 
          Join[prepar, {si \[Rule] sin, 
              sc \[Rule] scin}]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
          In\ the\ initial\ period, \ 
          zero\ children\ for\ sure\ \
*) \[IndentingNewLine]\[IndentingNewLine]ageatfirstchild = 
          0; \[IndentingNewLine]\[IndentingNewLine]prob[0, 0, 0] = 
          1; \[IndentingNewLine]For[n = 1, n \[LessEqual] nmax, \(n++\), 
          prob[0, n, 0] = 0]; \[IndentingNewLine]For[n = 0, 
          n \[LessEqual] nmax, \(n++\), 
          prob[0, n, 1] = 0]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
          The\ following\ loops\ moves\ forward\ in\ time\ \
*) \[IndentingNewLine] (*\ First\ the\ fecund, \ 
          than\ the\ non - fecund\ period\ *) \[IndentingNewLine] (*\ 
          Order\ of\ \(indeces : \ Period\), \ old\ children, \ 
          young\ children\ *) \[IndentingNewLine] (*\ 
          n = 0\ \((at\ least)\)\ will\ have\ to\ be\ done\ separately\ \
*) \[IndentingNewLine]\[IndentingNewLine]For[j = 0, 
          j \[LessEqual] 
            K, \(j++\), \[IndentingNewLine]\[IndentingNewLine] (*\ 
            Age\ at\ first\ birth\ \
*) \[IndentingNewLine]If[\((ageatfirstchild \[Equal] 
                    0)\) && \((Birth[j, 0, 0] == 1)\), 
              ageatfirstchild = j]\[IndentingNewLine]\[IndentingNewLine] (*\ 
              Expected\ number\ of\ children\ \((born\ previously)\)\ and\ \
expected\ number\ of\ births\ *) \[IndentingNewLine]\[IndentingNewLine]\(FR[
                j] = \[Sum]\+\(n = 0\)\%nmax\((prob[j, n, 0] Birth[j, n, 0] + 
                    prob[j, n, 1] 
                      Birth[j, n, 1])\)\); \[IndentingNewLine]Eofn[
              j] = \[Sum]\+\(n = 0\)\%nmax\((n\ prob[j, n, 0] + \((n + 1)\) 
                    prob[j, n, 1])\); \[IndentingNewLine] (*\ 
            First\ the\ n = 0\ case, \ 
            the\ loop\ below\ does\ the\ rest\ *) \[IndentingNewLine]\
\[IndentingNewLine]prob[j + 1, 0, 
              0] = \((1 - si\ Birth[j, 0, 0])\) 
                  prob[j, 0, 0] + \((1 - si\ Birth[j, 0, 1])\) \((1 - sc)\) 
                  prob[j, 0, 1] /. 
              par; \[IndentingNewLine]\[IndentingNewLine]prob[j + 1, 0, 1] = 
            si\ Birth[j, 0, 0] prob[j, 0, 0] + 
                si\ Birth[j, 0, 1] \((1 - sc)\) prob[j, 0, 1] /. 
              
              par; \[IndentingNewLine]\[IndentingNewLine]\[IndentingNewLine]\
For[n = 1, 
            n \[LessEqual] 
              nmax, \(n++\), \[IndentingNewLine]\[IndentingNewLine]prob[
                j + 1, n, 
                0] = \((1 - si\ Birth[j, n, 0])\) 
                    prob[j, n, 0] + \((1 - si\ Birth[j, n, 1])\) \((1 - sc)\) 
                    prob[j, n, 1] + \((1 - si\ Birth[j, n - 1, 1])\) 
                    sc\ prob[j, n - 1, 1] /. 
                par; \[IndentingNewLine]\[IndentingNewLine]prob[j + 1, n, 
                1] = si\ Birth[j, n, 0] prob[j, n, 0] + 
                  si\ Birth[j, n, 1] \((1 - sc)\) prob[j, n, 1] + 
                  si\ Birth[j, n - 1, 1] sc\ prob[j, n - 1, 1] /. 
                par;\[IndentingNewLine]];\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine]For[j = K + 1, 
          j \[LessEqual] 
            T, \(j++\), \[IndentingNewLine]\[IndentingNewLine] (*\ 
            Fertility\ Rates\ and\ Expected\ number\ of\ children\ \((born\ \
previously)\)\ *) \[IndentingNewLine]\[IndentingNewLine]FR[j] = 
            0; \[IndentingNewLine]Eofn[
              j] = \[Sum]\+\(n = 0\)\%nmax\((n\ prob[j, n, 0] + \((n + 1)\) 
                    prob[j, n, 
                      1])\); \[IndentingNewLine]\[IndentingNewLine] (*\ 
            First\ the\ n = 0\ case, \ 
            the\ loop\ below\ does\ the\ rest\ *) \[IndentingNewLine]\
\[IndentingNewLine]prob[j + 1, 0, 0] = 
            prob[j, 0, 0] + \((1 - sc)\) prob[j, 0, 1] /. 
              par; \[IndentingNewLine]\[IndentingNewLine]prob[j + 1, 0, 1] = 
            0 /. par; \[IndentingNewLine]\[IndentingNewLine]For[n = 1, 
            n \[LessEqual] 
              nmax, \(n++\), \[IndentingNewLine]\[IndentingNewLine]prob[
                j + 1, n, 0] = 
              prob[j, n, 0] + \((1 - sc)\) prob[j, n, 1] + 
                  sc\ prob[j, n - 1, 1] /. 
                par; \[IndentingNewLine]\[IndentingNewLine]prob[j + 1, n, 
                1] = 0 /. 
                par;\[IndentingNewLine]];\[IndentingNewLine]\
\[IndentingNewLine]];\[IndentingNewLine]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"prob\" is similar to \
existing symbol \"prob\"."\)], "Message",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computing TFR and NFR", "Section"],

Cell[BoxData[
    \(TFRNFRAge[sin_, scin_] := 
      Module[{local}, \[IndentingNewLine]computemax[sin, 
          scin]; \[IndentingNewLine]ComputeFertility[sin, 
          scin]; \[IndentingNewLine]{\[Sum]\+\(j = 0\)\%T FR[j], Eofn[T], 
          ageatfirstchild}\[IndentingNewLine]]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Actual Computation", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(NTarget = 5;\)\), "\[IndentingNewLine]", 
    \(\(sigmaset =  .01;\)\), "\[IndentingNewLine]", 
    \(\(epsset =  .01;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(Vlo = 0;\)\), "\[IndentingNewLine]", 
    \(\(Vset = 0.5;\)\), "\[IndentingNewLine]", 
    \(\(Vhi = 1000;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(it = 1;\)\), "\[IndentingNewLine]", 
    \(While[
      it < 30, \[IndentingNewLine]Clear[Util, Birth, prob, 
        FR]; \[IndentingNewLine]prepar = {\[Sigma] \[Rule] 
            sigmaset, \[Epsilon] \[Rule] epsset, \[Beta] \[Rule] 
            1, \[Gamma] \[Rule]  .95, p \[Rule] 5/12, q \[Rule] 0/12, 
          V \[Rule] Vset, 
          w \[Rule] 
            1}; \[IndentingNewLine]\[IndentingNewLine]If[\(TFRNFRAge[ .73, 
              1]\)[\([1]\)] > NTarget, Vhi = Vset; 
        Vset =  .5\ Vset\  + \  .5\ Vlo, Vlo = Vset; 
        Vset =  .5\ Vset\  + \  .5\ Vhi]; \[IndentingNewLine]\
\[IndentingNewLine]it = 
        it + 1;\[IndentingNewLine]]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(Print[Vset];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(prepar = {\[Sigma] \[Rule] sigmaset, \[Epsilon] \[Rule] 
            epsset, \[Beta] \[Rule] 1, \[Gamma] \[Rule]  .95, p \[Rule] 5/12, 
          q \[Rule] 0/12, V \[Rule] Vset, 
          w \[Rule] 1};\)\), "\[IndentingNewLine]", 
    \(\(Print[{\(TFRNFRAge[ .73, 1]\)[\([1]\)], \(TFRNFRAge[ .73, 
              1]\)[\([2]\)], \(TFRNFRAge[ .73, 
              1]\)[\([3]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(Print[{\(TFRNFRAge[ .965, 1]\)[\([1]\)], \(TFRNFRAge[ .965, 
              1]\)[\([2]\)], \(TFRNFRAge[ .965, 
              1]\)[\([3]\)]}];\)\[IndentingNewLine]\), "\[IndentingNewLine]", \

    \(\(Plot[{\(TFRNFRAge[s, 1]\)[\([1]\)], \(TFRNFRAge[s, 
              1]\)[\([2]\)]}, {s, 0.06,  .99}, 
        PlotRange \[Rule] {{0, 1}, {0, 11}}, 
        AxesLabel \[Rule] {"\<s\>", "\<Children\>"}, 
        PlotStyle \[Rule] {{Thickness[ .008]}, {Dashing[{ .02,  .02}], 
              Thickness[ .008]}}];\)\)}], "Input"],

Cell[BoxData[
    \(194.10730040352792`\)], "Print"],

Cell[BoxData[
    \({4.961540021611`, 3.6219242157760303`, 6}\)], "Print"],

Cell[BoxData[
    \({4.`, 3.86`, 9}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 1.38778e-017 0.0561849 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .11237 -6 -4.5 ]
[-0.0125 .11237 0 4.5 ]
[-0.0125 .22474 -6 -4.5 ]
[-0.0125 .22474 0 4.5 ]
[-0.0125 .33711 -6 -4.5 ]
[-0.0125 .33711 0 4.5 ]
[-0.0125 .44948 -6 -4.5 ]
[-0.0125 .44948 0 4.5 ]
[-0.0125 .56185 -12 -4.5 ]
[-0.0125 .56185 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11237 m
.00625 .11237 L
s
[(2)] -0.0125 .11237 1 0 Mshowa
0 .22474 m
.00625 .22474 L
s
[(4)] -0.0125 .22474 1 0 Mshowa
0 .33711 m
.00625 .33711 L
s
[(6)] -0.0125 .33711 1 0 Mshowa
0 .44948 m
.00625 .44948 L
s
[(8)] -0.0125 .44948 1 0 Mshowa
0 .56185 m
.00625 .56185 L
s
[(10)] -0.0125 .56185 1 0 Mshowa
.125 Mabswid
0 .02809 m
.00375 .02809 L
s
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .14046 m
.00375 .14046 L
s
0 .16855 m
.00375 .16855 L
s
0 .19665 m
.00375 .19665 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .47757 m
.00375 .47757 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .58994 m
.00375 .58994 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.23874 .61803 m
.2389 .61792 L
.24105 .61636 L
.24218 .61553 L
.24339 .61465 L
.24444 .61388 L
.2456 .60231 L
.24665 .60157 L
.24764 .60088 L
.257 .59427 L
.27508 .58134 L
.28531 .57392 L
.2903 .5703 L
.29266 .56858 L
.29483 .567 L
.29597 .56616 L
.29717 .55091 L
.29838 .5501 L
.29971 .5492 L
.30431 .54608 L
.30684 .54437 L
.30954 .54254 L
.31086 .54165 L
.3121 .5408 L
.31322 .54005 L
.31443 .52983 L
.3157 .52898 L
.3169 .52818 L
.31962 .52636 L
.32514 .52267 L
.33505 .51608 L
.34463 .50974 L
.34986 .50629 L
.35473 .50309 L
.3589 .50036 L
.3601 .49957 L
.36123 .49883 L
.36225 .48362 L
.36336 .48297 L
.3728 .47745 L
.3918 .46647 L
.41272 .45458 L
.42229 .44921 L
.42757 .44628 L
.43016 .44483 L
.43143 .44413 L
.43258 .4435 L
.43374 .44286 L
.43483 .42965 L
.43598 .42905 L
Mistroke
.43722 .4284 L
.43851 .42774 L
.43921 .42737 L
.43986 .42703 L
.44102 .41332 L
.44229 .41274 L
.45117 .40874 L
.48918 .38628 L
.50854 .3783 L
.51875 .37342 L
.52959 .36918 L
.53921 .36546 L
.54184 .36444 L
.54468 .36335 L
.54599 .36285 L
.5467 .36258 L
.54736 .36232 L
.54853 .34818 L
.54982 .34778 L
.56852 .34135 L
.58683 .33583 L
.59647 .33295 L
.59709 .33276 L
.59777 .33256 L
.59901 .33127 L
.59975 .33106 L
.60043 .33086 L
.60174 .33049 L
.60667 .32908 L
.60917 .32836 L
.60989 .32815 L
.61057 .32796 L
.61184 .31944 L
.61253 .31925 L
.61326 .31906 L
.61457 .31871 L
.61752 .31793 L
.62753 .3153 L
.64721 .31015 L
.64832 .30875 L
.6495 .30846 L
.65079 .30814 L
.65198 .30785 L
.6565 .30673 L
.6617 .30545 L
.66644 .30428 L
.67496 .30218 L
.6773 .3016 L
.67981 .30099 L
.68103 .30069 L
Mistroke
.68219 .3004 L
.68322 .28841 L
.68436 .28819 L
.72404 .27983 L
.76223 .27291 L
.76345 .27269 L
.7646 .27043 L
.76523 .27033 L
.76593 .27021 L
.76714 .27002 L
.77171 .26927 L
.77649 .26849 L
.78173 .26763 L
.79272 .26579 L
.80283 .26406 L
.80791 .26318 L
.81267 .26235 L
.81384 .26215 L
.81507 .26193 L
.81571 .26182 L
.81641 .25505 L
.81765 .25486 L
.82314 .25398 L
.82556 .2536 L
.82675 .25341 L
.82785 .25323 L
.82911 .2453 L
.82978 .24522 L
.83048 .24217 L
.83162 .24207 L
.83288 .24195 L
.83513 .24174 L
.83638 .24162 L
.83756 .24151 L
.83865 .24141 L
.83985 .23374 L
.84093 .23368 L
.84194 .23362 L
.88019 .23147 L
.89025 .23091 L
.89554 .23061 L
.89843 .23045 L
.90113 .23029 L
.90349 .23016 L
.90417 .23012 L
.90482 .23009 L
.90602 .22474 L
.90667 .22474 L
.90736 .22474 L
.9086 .22474 L
Mistroke
.9114 .22474 L
.92083 .22474 L
.95774 .22474 L
.99 .22474 L
Mfstroke
[ .02 .02 ] 0 setdash
.06 .04374 m
.09773 .0706 L
.13887 .09827 L
.17751 .12067 L
.19697 .13165 L
.21468 .1393 L
.23379 .14533 L
.25423 .15158 L
.27451 .15969 L
.28341 .16305 L
.28814 .16478 L
.29075 .16572 L
.29322 .1666 L
.29436 .167 L
.29557 .16743 L
.29627 .16767 L
.2969 .16362 L
.29813 .16405 L
.30263 .1656 L
.30721 .16716 L
.30922 .16783 L
.31143 .16856 L
.31263 .16896 L
.31375 .16638 L
.31494 .16676 L
.31621 .16716 L
.32137 .16878 L
.33074 .17163 L
.34067 .17454 L
.34591 .17603 L
.35148 .17758 L
.35633 .17889 L
.35766 .17925 L
.35909 .17963 L
.35975 .1798 L
.36044 .17999 L
.36168 .17504 L
.36281 .17535 L
.36402 .17567 L
.36619 .17625 L
.37112 .17756 L
.39057 .18246 L
.41165 .18738 L
.42151 .18953 L
.42691 .19068 L
.42955 .19122 L
.43196 .19172 L
.43302 .19194 L
.43417 .19217 L
.43525 .18691 L
Mistroke
.43626 .18711 L
.4385 .18756 L
.43975 .18781 L
.44088 .18225 L
.44215 .18252 L
.44331 .18277 L
.44593 .18332 L
.45069 .18431 L
.45529 .18526 L
.45662 .18553 L
.45787 .18578 L
.459 .18358 L
.46022 .18382 L
.46911 .18554 L
.4893 .18898 L
.50827 .19233 L
.51834 .19364 L
.52917 .19545 L
.53422 .19626 L
.53952 .19711 L
.54405 .19781 L
.54529 .198 L
.54597 .19811 L
.54661 .19821 L
.54786 .19087 L
.54899 .19107 L
.56757 .1939 L
.58549 .19686 L
.5904 .19764 L
.59311 .19807 L
.59444 .19828 L
.59567 .19847 L
.59683 .19865 L
.59805 .19828 L
.59928 .19848 L
.60064 .1987 L
.60518 .19941 L
.60753 .19977 L
.60881 .19997 L
.61001 .20016 L
.61063 .20025 L
.6113 .19536 L
.61204 .19548 L
.61272 .19558 L
.61521 .19597 L
.62463 .19742 L
.64519 .20045 L
.6639 .20243 L
.66903 .20315 L
.67446 .20389 L
Mistroke
.6791 .20452 L
.68037 .20469 L
.68107 .20478 L
.68173 .20487 L
.68302 .19702 L
.6842 .1972 L
.72152 .20223 L
.74235 .20529 L
.75218 .20666 L
.7565 .20725 L
.75894 .20758 L
.76123 .20789 L
.76237 .20804 L
.76345 .20818 L
.76469 .20678 L
.76583 .20695 L
.77069 .20766 L
.78092 .2091 L
.79946 .21157 L
.80889 .21275 L
.81119 .21303 L
.81366 .21332 L
.81435 .21341 L
.81507 .21349 L
.81569 .21357 L
.81637 .20822 L
.81701 .2083 L
.81769 .20839 L
.81891 .20854 L
.82124 .20883 L
.82376 .20914 L
.82492 .20928 L
.82615 .20943 L
.82719 .20956 L
.82834 .20328 L
.82946 .20343 L
.83048 .20112 L
.83165 .20131 L
.83277 .2015 L
.8369 .20217 L
.83813 .20237 L
.83877 .20248 L
.83945 .20259 L
.84069 .19646 L
.84184 .19667 L
.8463 .19751 L
.8563 .19936 L
.87427 .20266 L
.88356 .20435 L
.8935 .20615 L
Mistroke
.89832 .20702 L
.90069 .20745 L
.90288 .20784 L
.90391 .20802 L
.90487 .2082 L
.90587 .20359 L
.90698 .20383 L
.91142 .20483 L
.94927 .21334 L
.98951 .22238 L
.99 .22249 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00AP3oool2000000@0oooo0P0000030?ooo`@00000803oool2000000@0oooo0P0000050?oo
o`<00000803oool2000000@0oooo0P0000030?ooo`<000008@3oool2000000@0oooo0P0000040?oo
o`8000009`3oool500000180oooo00150?ooo`040000003oool0oooo000000P0oooo00<000000?oo
o`3oool0803oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo01h0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000O0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool00000:03oool00`000000oooo0?ooo`0B0?ooo`00A@3oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo01l0oooo00@000000?ooo`3oool00000203oool5
000001l0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000O0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool00000:03oool00`000000oooo0?ooo`0B0?oo
o`00A@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo01h0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`00000P0?ooo`040000003oool0oooo000000P0oooo
0`00000P0?ooo`040000003oool0oooo000000T0oooo0P00000Y0?ooo`030000003oool0oooo0180
oooo00150?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000007`3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool000000200oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo0?ooo`0O0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000:03oool00`000000oooo0?ooo`0B0?ooo`00AP3oool2000000X0oooo0P00000Q0?ooo`800000
2`3oool200000240oooo0P00000:0?ooo`<00000803oool2000000X0oooo0P00000X0?ooo`800000
503oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo503oool3000000X0
oooo003o0?oooaL0oooo00<000000?ooo`3oool01`3oool001h0ooookP0000070?ooo`<000002P3o
ool001h0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo00D0oooo100000090?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool00`000000
oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?oo
o`3o0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?ooo`3o0?oo
o`007P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`007P3o
ool00`000000oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0>l0oooo000N0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0kP3oool001h0oooo00<000000?ooo`3oool03`3oool200000>h0oooo
000N0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0j`3oool001h0oooo00<00000
0?ooo`3oool0o`3oool001h0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`3W0?oo
o`007P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0>H0oooo000N0?ooo`030000
003oool0oooo01L0oooo0P00003V0?ooo`007P3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo0><0oooo000N0?ooo`030000003oool0oooo0?l0oooo000N0?ooo`030000003oool0oooo
0?l0oooo000N0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0g`3oool001H0oooo
100000040?ooo`030000003oool0oooo01h0oooo0P00003O0?ooo`005P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0200oooo0P00003M0?ooo`005`3oool00`000000oooo0?ooo`04
0?ooo`800000o`3oool10?ooo`00603oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool0e`3oool001H0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`0V0?ooo`800000e`3oool001L0oooo0P0000050?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool0e03oool001h0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`3C0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo0<h0oooo000N0?ooo`030000003oool0oooo02l0oooo1000003<0?oo
o`007P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?ooo`0g0?ooo`<00000
a@3oool001h0oooo00<000000?ooo`3oool0>P3oool200000<<0oooo000N0?ooo`030000003oool0
oooo0?l0oooo000N0?ooo`030000003oool0oooo0400oooo00@000000?ooo`3oool00000^`3oool0
01h0oooo00<000000?ooo`3oool0@@3oool3000000<0oooo00<000000?ooo`3oool0]@3oool001h0
oooo00<000000?ooo`3oool0B03oool400000;<0oooo000N0?ooo`030000003oool0oooo04`0oooo
00<000000?ooo`3oool00`3oool200000:/0oooo000N0?ooo`030000003oool0oooo0500oooo0`00
00000`3oool000000?ooo`2Y0?ooo`007P3oool00`000000oooo0?ooo`1I0?ooo`8000002P3oool2
000000@0oooo00<000000?ooo`3oool0T@3oool001h0oooo00<000000?ooo`3oool0F`3oool30000
00H0oooo0P0000060?ooo`@00000S`3oool001h0oooo00<000000?ooo`3oool0HP3oool200000100
oooo100000060?ooo`@00000O@3oool001h0oooo00<000000?ooo`3oool0N03oool2000000<0oooo
0P0000060?ooo`H000000`3oool400000380oooo0P00000i0?ooo`007P3oool00`000000oooo0?oo
o`1n0?ooo`030000003oool0oooo00P0oooo0P0000070?ooo`030000003oool0oooo0080oooo0P00
00050?ooo`040000003oool0oooo0?ooo`H000007P3oool3000003H0oooo000N0?ooo`030000003o
ool0oooo09T0oooo1P00000<0?ooo`<000004`3oool00`000000oooo0?ooo`090?ooo`@0000000<0
oooo0000003oool0:`3oool001h0oooo00<000000?ooo`3oool0[P3oool3000000@0oooo0`000006
0?ooo`@000003`3oool3000000<0oooo0P00000V0?ooo`007P3oool00`000000oooo0?ooo`2h0?oo
o`800000103oool00`000000oooo0?ooo`0H0?ooo`<000008`3oool001P0oooo0`0000030?ooo`03
0000003oool0oooo0>00oooo0P00000M0?ooo`006@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0>80oooo0`00000J0?ooo`005P3oool5000000<0oooo0P00003D0?oooaD000005`3o
ool001H0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`390?ooo`/00000:`3o
ool001L0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`340?ooo`D00000=P3oool0
01P0oooo0P0000040?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0>@3oool001h0
oooo00<000000?ooo`3oool0`@3oool3000003/0oooo000N0?ooo`030000003oool0oooo0<40oooo
00<000000?ooo`3oool0>`3oool001h0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?oo
o`0k0?ooo`007P3oool00`000000oooo0?ooo`2n0?ooo`@00000?@3oool001h0oooo00<000000?oo
o`3oool0_P3oool00`000000oooo0?ooo`0n0?ooo`007P3oool00`000000oooo0?ooo`2j0?ooo`D0
0000@03oool001h0oooo00<000000?ooo`3oool0/`3oool7000004D0oooo000N0?ooo`030000003o
ool0oooo0:l0oooo1000001<0?ooo`007P3oool00`000000oooo0?ooo`2[0?ooo`@00000D03oool0
01h0oooo00<000000?ooo`3oool0YP3oool5000005@0oooo000N0?ooo`030000003oool0oooo0:80
oooo1000001I0?ooo`007P3oool00`000000oooo0?ooo`2N0?ooo`@00000G@3oool001h0oooo00<0
00000?ooo`3oool0WP3oool00`000000oooo0?ooo`1N0?ooo`007P3oool00`000000oooo0?ooo`2N
0?ooo`030000003oool0oooo05h0oooo000N0?ooo`030000003oool0oooo09`0oooo0`00001P0?oo
o`007P3oool00`000000oooo0?ooo`2G0?ooo`D00000H`3oool001h0oooo00<000000?ooo`3oool0
U03oool4000006L0oooo000N0?ooo`030000003oool0oooo0940oooo0`00001[0?ooo`007P3oool0
0`000000oooo0?ooo`2>0?ooo`<00000KP3oool001h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`1_0?ooo`005P3oool3000000D0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`1_0?ooo`005P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo08X0
oooo0`00001b0?ooo`005P3oool010000000oooo0?ooo`0000040?ooo`800000Q`3oool4000007D0
oooo000F0?ooo`<000001@3oool00`000000oooo0?ooo`230?ooo`<00000N@3oool001L0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`210?ooo`800000O03oool001L0oooo0`000004
0?ooo`030000003oool0oooo07l0oooo0P00001n0?ooo`007P3oool00`000000oooo0?ooo`1o0?oo
o`030000003oool0oooo07d0oooo000N0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3o
ool0OP3oool001h0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`1n0?ooo`007P3o
ool00`000000oooo0?ooo`1l0?ooo`<00000P03oool001h0oooo00<000000?ooo`3oool0N@3oool3
000008<0oooo000N0?ooo`030000003oool0oooo07L0oooo0P0000260?ooo`007P3oool00`000000
oooo0?ooo`1d0?ooo`<00000R03oool001h0oooo00<000000?ooo`3oool0LP3oool2000008/0oooo
000N0?ooo`030000003oool0oooo0700oooo0P00002=0?ooo`007P3oool00`000000oooo0?ooo`1^
0?ooo`800000S`3oool001h0oooo00<000000?ooo`3oool0K03oool200000940oooo000N0?ooo`03
0000003oool0oooo06X0oooo0P00002C0?ooo`007P3oool00`000000oooo0?ooo`1X0?ooo`800000
U@3oool001h0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`2E0?ooo`007P3oool0
0`000000oooo0?ooo`1U0?ooo`800000V03oool001h0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`2G0?ooo`007P3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo09L0
oooo000N0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0U`3oool001h0oooo00<0
00000?ooo`3oool0I03oool2000009T0oooo000N0?ooo`030000003oool0oooo06@0oooo00<00000
0?ooo`3oool0V03oool001h0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`2I0?oo
o`005`3oool2000000D0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`2I0?ooo`00
5P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0680oooo0P00002K0?ooo`00
5P3oool010000000oooo0?ooo`0000040?ooo`800000H@3oool2000009d0oooo000G0?ooo`800000
1@3oool00`000000oooo0?ooo`1N0?ooo`800000W`3oool001H0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`1L0?ooo`800000X@3oool001L0oooo0P0000050?ooo`030000003o
ool0oooo05X0oooo0P00002S0?ooo`007P3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0
oooo0:<0oooo000N0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0Y03oool001h0
oooo00<000000?ooo`3oool0EP3oool200000:L0oooo000N0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0Y`3oool001h0oooo00<000000?ooo`3oool0DP3oool300000:X0oooo000N
0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0ZP3oool001h0oooo00<000000?oo
o`3oool0DP3oool00`000000oooo0?ooo`2Z0?ooo`007P3oool00`000000oooo0?ooo`1B0?ooo`03
0000003oool0oooo0:X0oooo000N0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0
ZP3oool001h0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`2[0?ooo`007P3oool0
0`000000oooo0?ooo`1>0?ooo`<00000[P3oool001h0oooo00<000000?ooo`3oool0C@3oool00`00
0000oooo0?ooo`2_0?ooo`007P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0;00
oooo000N0?ooo`030000003oool0oooo04X0oooo0P00002c0?ooo`007P3oool00`000000oooo0?oo
o`180?ooo`800000]@3oool001h0oooo00<000000?ooo`3oool0A`3oool200000;H0oooo000N0?oo
o`030000003oool0oooo04L0oooo00<000000?ooo`3oool0]@3oool001h0oooo00<000000?ooo`3o
ool0A`3oool00`000000oooo0?ooo`2e0?ooo`007P3oool00`000000oooo0?ooo`160?ooo`800000
]`3oool001h0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`2g0?ooo`007P3oool0
0`000000oooo0?ooo`130?ooo`800000^P3oool00100oooo1@0000020?ooo`8000001@3oool00`00
0000oooo0?ooo`130?ooo`030000003oool0oooo0;T0oooo000B0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04<0oooo00<000000?oo
o`3oool0^@3oool00180oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
0080oooo0P0000140?ooo`030000003oool0oooo0;T0oooo000B0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0480oooo0P00002k0?oo
o`004P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo0;/0oooo000A0?ooo`800000103oool2000000D0
oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2l0?ooo`007P3oool00`000000oooo
0?ooo`0n0?ooo`800000_`3oool001h0oooo00<000000?ooo`3oool0?03oool200000<40oooo000N
0?ooo`030000003oool0oooo03X0oooo0P0000330?ooo`007P3oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo0<<0oooo000N0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3o
ool0a03oool001h0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`350?ooo`007P3o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0<D0oooo000N0?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool0aP3oool001h0oooo00<000000?ooo`3oool0=P3oool00`00
0000oooo0?ooo`360?ooo`007P3oool00`000000oooo0?ooo`0e0?ooo`800000b03oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool000P0oooo
0`0000001@3oool00000000000000000oooo008000000P3oool300000080oooo0`0000040?ooo`@0
000000<0oooo0000000000000P0000030?ooo`<0000000<0oooo0000000000000P3oool200000>X0
oooo00070?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000j`3oool0
00L0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo0080oooo100000020?ooo`040000003oool0oooo00000>/0oooo00070?ooo`030000003o
ool0oooo00<0oooo0`0000040?ooo`800000103oool00`000000oooo0?ooo`030?ooo`<000000P3o
ool4000000<0oooo0P0000020?ooo`@00000k03oool000L0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0n`3o
ool000P0oooo0`0000000`3oool00000000000070?ooo`040000003oool0oooo0?ooo`8000001P3o
ool200000?d0oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.89837, \
0.00421906, 0.0750924}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(NTarget = 5;\)\), "\[IndentingNewLine]", 
    \(\(sigmaset =  .05;\)\), "\[IndentingNewLine]", 
    \(\(epsset =  .05;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(Vlo = 0;\)\), "\[IndentingNewLine]", 
    \(\(Vset = 0.5;\)\), "\[IndentingNewLine]", 
    \(\(Vhi = 1000;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(it = 1;\)\), "\[IndentingNewLine]", 
    \(While[
      it < 30, \[IndentingNewLine]Clear[Util, Birth, prob, 
        FR]; \[IndentingNewLine]prepar = {\[Sigma] \[Rule] 
            sigmaset, \[Epsilon] \[Rule] epsset, \[Beta] \[Rule] 
            1, \[Gamma] \[Rule]  .95, p \[Rule] 5/24, q \[Rule] 1/24, 
          V \[Rule] Vset, 
          w \[Rule] 
            1}; \[IndentingNewLine]\[IndentingNewLine]If[\(TFRNFRAge[ .73, 
              1]\)[\([1]\)] > NTarget, Vhi = Vset; 
        Vset =  .5\ Vset\  + \  .5\ Vlo, Vlo = Vset; 
        Vset =  .5\ Vset\  + \  .5\ Vhi]; \[IndentingNewLine]\
\[IndentingNewLine]it = 
        it + 1;\[IndentingNewLine]]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(Print[Vset];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(prepar = {\[Sigma] \[Rule] sigmaset, \[Epsilon] \[Rule] 
            epsset, \[Beta] \[Rule] 1, \[Gamma] \[Rule]  .95, p \[Rule] 5/24, 
          q \[Rule] 1/24, V \[Rule] Vset, 
          w \[Rule] 1};\)\), "\[IndentingNewLine]", 
    \(\(Print[{\(TFRNFRAge[ .73, 1]\)[\([1]\)], \(TFRNFRAge[ .73, 
              1]\)[\([2]\)], \(TFRNFRAge[ .73, 
              1]\)[\([3]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(Print[{\(TFRNFRAge[ .965, 1]\)[\([1]\)], \(TFRNFRAge[ .965, 
              1]\)[\([2]\)], \(TFRNFRAge[ .965, 
              1]\)[\([3]\)]}];\)\[IndentingNewLine]\), "\[IndentingNewLine]", \

    \(\(Plot[{\(TFRNFRAge[s, 1]\)[\([1]\)], \(TFRNFRAge[s, 
              1]\)[\([2]\)]}, {s, 0.06,  .99}, 
        PlotRange \[Rule] {{0, 1}, {0, 11}}, 
        AxesLabel \[Rule] {"\<s\>", "\<Children\>"}, 
        PlotStyle \[Rule] {{Thickness[ .008]}, {Dashing[{ .02,  .02}], 
              Thickness[ .008]}}];\)\)}], "Input"],

Cell[BoxData[
    \(23.66806606668979`\)], "Print"],

Cell[BoxData[
    \({5.27`, 3.8470999999999997`, 7}\)], "Print"],

Cell[BoxData[
    \({4.`, 3.86`, 9}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 1.38778e-017 0.0561849 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .11237 -6 -4.5 ]
[-0.0125 .11237 0 4.5 ]
[-0.0125 .22474 -6 -4.5 ]
[-0.0125 .22474 0 4.5 ]
[-0.0125 .33711 -6 -4.5 ]
[-0.0125 .33711 0 4.5 ]
[-0.0125 .44948 -6 -4.5 ]
[-0.0125 .44948 0 4.5 ]
[-0.0125 .56185 -12 -4.5 ]
[-0.0125 .56185 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11237 m
.00625 .11237 L
s
[(2)] -0.0125 .11237 1 0 Mshowa
0 .22474 m
.00625 .22474 L
s
[(4)] -0.0125 .22474 1 0 Mshowa
0 .33711 m
.00625 .33711 L
s
[(6)] -0.0125 .33711 1 0 Mshowa
0 .44948 m
.00625 .44948 L
s
[(8)] -0.0125 .44948 1 0 Mshowa
0 .56185 m
.00625 .56185 L
s
[(10)] -0.0125 .56185 1 0 Mshowa
.125 Mabswid
0 .02809 m
.00375 .02809 L
s
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .14046 m
.00375 .14046 L
s
0 .16855 m
.00375 .16855 L
s
0 .19665 m
.00375 .19665 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .47757 m
.00375 .47757 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .58994 m
.00375 .58994 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.06 .5175 m
.06454 .50486 L
.06877 .49345 L
.07115 .48716 L
.0734 .48132 L
.07465 .47813 L
.07535 .50879 L
.076 .50733 L
.07715 .50656 L
.07837 .50387 L
.07954 .50128 L
.08066 .49885 L
.08194 .5257 L
.08312 .52521 L
.08423 .52308 L
.08525 .52112 L
.08637 .51899 L
.08758 .5167 L
.08827 .51539 L
.08891 .54067 L
.09016 .5403 L
.09129 .53834 L
.09249 .53629 L
.09523 .53165 L
.09653 .52947 L
.09773 .52746 L
.09893 .5487 L
.09957 .5477 L
.10024 .5484 L
.10137 .54662 L
.10262 .54467 L
.10515 .54074 L
.10787 .53654 L
.10911 .53464 L
.10979 .53361 L
.11042 .53265 L
.11154 .55066 L
.11276 .54885 L
.11734 .54377 L
.1227 .53595 L
.12775 .52866 L
.12911 .52672 L
.13055 .52467 L
.1313 .5236 L
.13212 .53827 L
.13288 .5372 L
.13358 .5362 L
.13887 .53021 L
.14903 .51596 L
.15404 .50906 L
Mistroke
.15868 .50273 L
.16084 .49981 L
.16288 .49707 L
.164 .49556 L
.16522 .51673 L
.16633 .5197 L
.16734 .51853 L
.17678 .50782 L
.18139 .50269 L
.18271 .50122 L
.18397 .49984 L
.18509 .51558 L
.18632 .51435 L
.18738 .51754 L
.18856 .51638 L
.1897 .51525 L
.19094 .51404 L
.19208 .52803 L
.19314 .52697 L
.1952 .52488 L
.20567 .51444 L
.21077 .50943 L
.21185 .50837 L
.21299 .50726 L
.21424 .50735 L
.21539 .50622 L
.21653 .50511 L
.21759 .51884 L
.21876 .51775 L
.22001 .51659 L
.22117 .51551 L
.22228 .51792 L
.22327 .517 L
.22435 .516 L
.23391 .50722 L
.25414 .48904 L
.27304 .47161 L
.27822 .46725 L
.28381 .46258 L
.28638 .46045 L
.28909 .45822 L
.2914 .45632 L
.29203 .4558 L
.29271 .45525 L
.29393 .44135 L
.29518 .4404 L
.2965 .4394 L
.29888 .43761 L
.30425 .4336 L
.314 .42643 L
Mistroke
.31818 .42341 L
.32268 .42018 L
.324 .41924 L
.32526 .41834 L
.32639 .42976 L
.32762 .42898 L
.32878 .42824 L
.33002 .4377 L
.33118 .44483 L
.33224 .4442 L
.37139 .4272 L
.38935 .41556 L
.39954 .41045 L
.40452 .40798 L
.40905 .40575 L
.41137 .40462 L
.412 .40431 L
.41267 .40398 L
.41388 .41207 L
.415 .41155 L
.41606 .41107 L
.4172 .41054 L
.41846 .40996 L
.41969 .40695 L
.42036 .40666 L
.42099 .40639 L
.42211 .4059 L
.42331 .41241 L
.42399 .41212 L
.42472 .41181 L
.42605 .41125 L
.42854 .4102 L
.44911 .40158 L
.46853 .39086 L
.46969 .38902 L
.47096 .38855 L
.47325 .3877 L
.4759 .38672 L
.47717 .38625 L
.47832 .38582 L
.47904 .36907 L
.47972 .36885 L
.48121 .36838 L
.48389 .36753 L
.48909 .36589 L
.49365 .36445 L
.4949 .36406 L
.49624 .36364 L
.49751 .36324 L
.49866 .35266 L
Mistroke
.49928 .35247 L
.49995 .35227 L
.50114 .35191 L
.50384 .35109 L
.50497 .35075 L
.50618 .35039 L
.50687 .34792 L
.5075 .34775 L
.50875 .3474 L
.5268 .3424 L
.56557 .3291 L
.60285 .31995 L
.60799 .31868 L
.61356 .31731 L
.61612 .31669 L
.61882 .31602 L
.62112 .31545 L
.62176 .3153 L
.62243 .31513 L
.62366 .31087 L
.62492 .3106 L
.62608 .31036 L
.62872 .3098 L
.63353 .30877 L
.64253 .30684 L
.65133 .30493 L
.65374 .30441 L
.65501 .30413 L
.65634 .30384 L
.65751 .30359 L
.65879 .30023 L
.65996 .3 L
.66105 .29978 L
.66228 .29953 L
.66361 .29927 L
.66487 .29901 L
.66603 .28997 L
.66708 .28979 L
.66823 .2896 L
.67056 .2892 L
.68073 .28744 L
.68581 .28656 L
.68832 .28613 L
.69064 .28572 L
.69274 .28536 L
.69392 .28515 L
.69498 .28096 L
.69615 .28079 L
.69741 .28061 L
.69971 .28028 L
Mistroke
.70944 .27888 L
.71459 .27813 L
.72011 .27731 L
.72282 .27691 L
.72539 .27653 L
.72769 .27618 L
.72832 .27608 L
.72899 .27598 L
.73019 .29608 L
.73131 .29602 L
.7325 .29595 L
.73467 .29583 L
.7396 .29555 L
.76018 .2944 L
.77034 .29383 L
.77529 .29355 L
.77978 .2933 L
.78096 .29323 L
.78223 .29316 L
.78344 .28092 L
.78455 .28092 L
.78963 .28092 L
.8004 .28092 L
.8203 .28092 L
.83891 .28092 L
.84808 .28092 L
.85259 .28092 L
.85678 .28092 L
.85797 .28092 L
.8591 .28092 L
.86028 .23259 L
.8609 .23255 L
.86157 .23252 L
.8668 .23222 L
.87595 .23171 L
.87828 .23158 L
.87956 .23151 L
.88078 .23144 L
.88191 .23137 L
.88313 .22474 L
.88424 .22474 L
.88527 .22474 L
.89548 .22474 L
.91608 .22474 L
.95451 .22474 L
.99 .22474 L
Mfstroke
[ .02 .02 ] 0 setdash
.06 .03105 m
.09773 .05155 L
.13887 .07363 L
.17751 .09 L
.21468 .10882 L
.21596 .1092 L
.21715 .11276 L
.2184 .11315 L
.21978 .11358 L
.22049 .11381 L
.22117 .11402 L
.22195 .11502 L
.22266 .11524 L
.22532 .11607 L
.23539 .11908 L
.25423 .12431 L
.29231 .13317 L
.29353 .13343 L
.29466 .12988 L
.29585 .13014 L
.29715 .13042 L
.29987 .131 L
.30238 .13153 L
.31187 .13348 L
.32043 .13515 L
.32289 .13562 L
.32411 .13585 L
.32523 .13606 L
.32625 .14024 L
.32732 .14048 L
.32851 .14074 L
.3296 .14098 L
.33071 .14461 L
.33187 .14749 L
.33304 .14778 L
.33431 .1481 L
.33874 .14918 L
.34882 .1516 L
.35146 .15222 L
.35434 .15289 L
.35565 .1532 L
.35637 .15337 L
.35705 .15352 L
.35824 .15566 L
.35887 .15581 L
.35955 .15597 L
.3693 .15819 L
.38844 .1616 L
.39906 .16389 L
.40423 .16497 L
Mistroke
.4089 .16594 L
.41009 .16618 L
.41137 .16645 L
.41258 .16669 L
.41369 .17051 L
.41488 .17077 L
.41618 .17105 L
.41752 .17135 L
.4188 .17163 L
.41947 .17074 L
.42021 .17091 L
.42149 .1712 L
.42222 .17136 L
.42299 .17153 L
.42365 .17466 L
.42438 .17483 L
.42958 .17602 L
.43983 .17833 L
.44921 .18037 L
.45399 .18139 L
.45632 .18188 L
.45844 .18233 L
.45959 .18257 L
.46068 .18144 L
.46183 .18169 L
.46307 .18196 L
.46569 .18252 L
.46697 .1828 L
.46814 .18305 L
.46932 .18264 L
.4706 .18291 L
.4733 .18349 L
.47464 .18377 L
.4761 .18408 L
.47676 .18422 L
.47747 .18437 L
.47875 .17674 L
.4799 .17699 L
.48114 .17725 L
.48339 .17774 L
.48852 .17883 L
.49085 .17933 L
.49335 .17985 L
.49456 .1801 L
.49571 .18034 L
.49673 .18055 L
.49785 .17569 L
.49908 .17594 L
.50043 .17621 L
.50316 .17676 L
Mistroke
.50438 .177 L
.50506 .17713 L
.50569 .17726 L
.50693 .17637 L
.50807 .1766 L
.52866 .18074 L
.56598 .1862 L
.58681 .19006 L
.60569 .19337 L
.61515 .19495 L
.61774 .19538 L
.62047 .19583 L
.6216 .19601 L
.62281 .19621 L
.62351 .19385 L
.62414 .19396 L
.62538 .19418 L
.64391 .19738 L
.64861 .19817 L
.6536 .19898 L
.65566 .19931 L
.65673 .19949 L
.65787 .19967 L
.65913 .19785 L
.66029 .19804 L
.66257 .19842 L
.66381 .19863 L
.66499 .19882 L
.66564 .19306 L
.66635 .19319 L
.66758 .1934 L
.67225 .19422 L
.68284 .19603 L
.6873 .19678 L
.69209 .19757 L
.6935 .1978 L
.6942 .19792 L
.69484 .19802 L
.69604 .19545 L
.69668 .19557 L
.69735 .19569 L
.70227 .19658 L
.71298 .19847 L
.72282 .20016 L
.72536 .20058 L
.72773 .20098 L
.72892 .20118 L
.73019 .2162 L
.73092 .21638 L
.73161 .21656 L
Mistroke
.7329 .21689 L
.74378 .21965 L
.75335 .22207 L
.7635 .22463 L
.77277 .22696 L
.77531 .22759 L
.77805 .22827 L
.77937 .22861 L
.78063 .22892 L
.78176 .2292 L
.78299 .21996 L
.78421 .2203 L
.78536 .22063 L
.78751 .22123 L
.79233 .22258 L
.80099 .22502 L
.83863 .23559 L
.84869 .23842 L
.85361 .2398 L
.85575 .2404 L
.85809 .24106 L
.85935 .24141 L
.86052 .20014 L
.86163 .20034 L
.86282 .20056 L
.86789 .20149 L
.87351 .20252 L
.87596 .20297 L
.87865 .20346 L
.87977 .20366 L
.88096 .20388 L
.88209 .20408 L
.88311 .19847 L
.88427 .19873 L
.88552 .19901 L
.8878 .19952 L
.89766 .20174 L
.91551 .20575 L
.95545 .21473 L
.99 .22249 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00AP3oool2000000@0oooo0P0000030?ooo`@00000803oool2000000@0oooo0P0000050?oo
o`<00000803oool2000000@0oooo0P0000030?ooo`<000008@3oool2000000@0oooo0P0000040?oo
o`8000009`3oool500000180oooo00150?ooo`040000003oool0oooo000000P0oooo00<000000?oo
o`3oool0803oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo01h0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000O0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool00000:03oool00`000000oooo0?ooo`0B0?ooo`00A@3oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo01l0oooo00@000000?ooo`3oool00000203oool5
000001l0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000O0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool00000:03oool00`000000oooo0?ooo`0B0?oo
o`00A@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo01h0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`00000P0?ooo`040000003oool0oooo000000P0oooo
0`00000P0?ooo`040000003oool0oooo000000T0oooo0P00000Y0?ooo`030000003oool0oooo0180
oooo00150?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000007`3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool000000200oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo0?ooo`0O0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000:03oool00`000000oooo0?ooo`0B0?ooo`00AP3oool2000000X0oooo0P00000Q0?ooo`800000
2`3oool200000240oooo0P00000:0?ooo`<00000803oool2000000X0oooo0P00000X0?ooo`800000
503oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo503oool3000000X0
oooo003o0?oooaL0oooo00<000000?ooo`3oool01`3oool001h0ooookP0000070?ooo`<000002P3o
ool001h0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo00D0oooo100000090?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool00`000000
oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?oo
o`3o0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?ooo`3o0?oo
o`007P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?ooo`0>0?ooo`800000
k`3oool001h0oooo00<000000?ooo`3oool0403oool200000>d0oooo000N0?ooo`030000003oool0
oooo0180oooo0P00003[0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo0>D0oooo000N0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool0i03oool001h0oooo00<000000?ooo`3oool06@3oool200000>@0oooo000N
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0h@3oool001h0oooo00<000000?oo
o`3oool0o`3oool001h0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3M0?ooo`00
7P3oool00`000000oooo0?ooo`0P0?ooo`800000g@3oool001h0oooo00<000000?ooo`3oool08P3o
ool200000=/0oooo000N0?ooo`030000003oool0oooo0?l0oooo000N0?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool0e03oool001h0oooo00<000000?ooo`3oool0:@3oool200000=@0
oooo000F0?ooo`@00000103oool00`000000oooo0?ooo`0[0?ooo`800000dP3oool001H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooo`005`3oool00`000000oooo0?ooo`04
0?ooo`800000<@3oool200000<d0oooo000H0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0<@3oool200000<`0oooo000F0?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0<`3oool200000<X0oooo000G0?ooo`8000001@3oool00`000000oooo0?ooo`0i0?ooo`80
0000a03oool001h0oooo00<000000?ooo`3oool0>`3oool3000000@0oooo0P00002k0?ooo`007P3o
ool00`000000oooo0?ooo`120?ooo`030000003oool0000000800000^03oool001h0oooo00<00000
0?ooo`3oool0o`3oool001h0oooo00<000000?ooo`3oool0BP3oool200000;<0oooo000N0?ooo`03
0000003oool0oooo04/0oooo00<000000?ooo`3oool0/@3oool001h0oooo00<000000?ooo`3oool0
B`3oool300000;40oooo000N0?ooo`030000003oool0oooo0?l0oooo000N0?ooo`030000003oool0
oooo0580oooo1@00002X0?ooo`007P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo
0:40oooo000N0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0X03oool001h0oooo
00<000000?ooo`3oool0H03oool2000009d0oooo000N0?ooo`030000003oool0oooo0640oooo0P00
000@0?ooo`@00000R03oool001h0oooo00<000000?ooo`3oool0H`3oool2000000/0oooo0`000004
0?ooo`<00000Q@3oool001h0oooo00<000000?ooo`3oool0J@3oool500000100oooo0`00001n0?oo
o`007P3oool00`000000oooo0?ooo`210?ooo`<00000N`3oool001h0oooo00<000000?ooo`3oool0
Q`3oool6000000<0oooo00<000000?ooo`3oool01`3oool2000006<0oooo000N0?ooo`030000003o
ool0oooo0900oooo1P0000040?ooo`040000003oool00000000000<0oooo1000001J0?ooo`007P3o
ool00`000000oooo0?ooo`2I0?ooo`8000002P3oool200000240oooo0P0000040?ooo`@00000;@3o
ool001h0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01@3oool2000002L0oooo000N0?ooo`030000003oool0oooo
0:T0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0=0?ooo`<00000903oool001h0
oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01@0
oooo0`00000M0?ooo`00603oool3000000<0oooo00<000000?ooo`3oool0ZP3oool2000001`0oooo
00<000000?ooo`3oool05`3oool3000001X0oooo000I0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0[03oool4000000H0oooo0P0000170?ooo`005P3oool5000000<0oooo0P00002e
0?ooo`030000003oool0000000@0oooo0`00000@0?oooaX000005`3oool001H0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`2e0?ooo`8000001`3oool3000000/0oooo0`00000`
0?ooo`005`3oool00`000000oooo000000040?ooo`030000003oool0oooo0<P0oooo1000000c0?oo
o`00603oool2000000@0oooo00<000000?ooo`3oool0a03oool5000003H0oooo000N0?ooo`030000
003oool0oooo0<L0oooo0P00000f0?ooo`007P3oool00`000000oooo0?ooo`380?ooo`030000003o
ool0oooo03@0oooo000N0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0=03oool0
01h0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0d0?ooo`007P3oool00`000000
oooo0?ooo`380?ooo`030000003oool0oooo03@0oooo000N0?ooo`030000003oool0oooo0<P0oooo
00<000000?ooo`3oool0=03oool001h0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?oo
o`0d0?ooo`007P3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03@0oooo000N0?oo
o`030000003oool0oooo0:H0oooo1000000N0?ooo`030000003oool0oooo03@0oooo000N0?ooo`03
0000003oool0oooo0:40oooo1@0000030?ooo`030000003oool0oooo00X0oooo4`00000f0?ooo`00
7P3oool00`000000oooo0?ooo`2O0?ooo`<000001`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo04H0oooo000N0?ooo`030000003oool0oooo09X0oooo1@00000;0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0AP3oool001h0oooo00<000000?ooo`3oool0VP3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo200000180?ooo`007P3oool00`00
0000oooo0?ooo`2J0?ooo`030000003oool0oooo00d0oooo1@00001@0?ooo`007P3oool00`000000
oooo0?ooo`2H0?ooo`<00000I03oool001h0oooo00<000000?ooo`3oool0U@3oool4000006H0oooo
000N0?ooo`030000003oool0oooo0900oooo1@00001Z0?ooo`007P3oool00`000000oooo0?ooo`2?
0?ooo`800000KP3oool001h0oooo00<000000?ooo`3oool0RP3oool6000006l0oooo000N0?ooo`03
0000003oool0oooo08P0oooo0P00001e0?ooo`005P3oool3000000D0oooo00<000000?ooo`3oool0
Q@3oool3000007L0oooo000F0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
PP3oool3000007X0oooo000F0?ooo`040000003oool0oooo000000@0oooo0P0000200?ooo`<00000
O@3oool001H0oooo0`0000050?ooo`030000003oool0oooo07/0oooo100000200?ooo`005`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo07P0oooo0`0000240?ooo`005`3oool30000
00@0oooo00<000000?ooo`3oool0M@3oool3000008L0oooo000N0?ooo`030000003oool0oooo07<0
oooo0`0000290?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo08T0oooo
000N0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0RP3oool001h0oooo00<00000
0?ooo`3oool0L03oool3000008`0oooo000N0?ooo`030000003oool0oooo06h0oooo0P00002?0?oo
o`007P3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo08h0oooo000N0?ooo`030000
003oool0oooo06h0oooo00<000000?ooo`3oool0SP3oool001h0oooo00<000000?ooo`3oool0KP3o
ool00`000000oooo0?ooo`2>0?ooo`007P3oool00`000000oooo0?ooo`1]0?ooo`800000T03oool0
01h0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`2@0?ooo`007P3oool00`000000
oooo0?ooo`1Z0?ooo`800000T`3oool001h0oooo00<000000?ooo`3oool0J03oool2000009D0oooo
000N0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool01@3oool2000009L0oooo000N
0?ooo`030000003oool0oooo05`0oooo0P000000103oool000000000000000020?ooo`800000V@3o
ool001h0oooo00<000000?ooo`3oool0F`3oool010000000oooo0?ooo`3oool5000009/0oooo000N
0?ooo`030000003oool0oooo05T0oooo0P00002T0?ooo`007P3oool00`000000oooo0?ooo`190?oo
o`8000003@3oool00`000000oooo0?ooo`2T0?ooo`007P3oool00`000000oooo0?ooo`180?ooo`03
0000003oool0000000/0oooo0P00002W0?ooo`007P3oool00`000000oooo0?ooo`170?ooo`040000
003oool0oooo000000T0oooo0P00002Y0?ooo`007P3oool00`000000oooo0?ooo`150?ooo`800000
103oool00`000000oooo0?ooo`040?ooo`800000Z`3oool001h0oooo00<000000?ooo`3oool0@`3o
ool2000000H0oooo00@000000?ooo`3oool0oooo0`00002]0?ooo`005`3oool2000000D0oooo00<0
00000?ooo`3oool0@P3oool2000000L0oooo00@000000?ooo`0000000000/03oool001H0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00H0oooo
0P00002b0?ooo`005P3oool010000000oooo0?ooo`0000040?ooo`800000@`3oool00`000000oooo
0?ooo`2j0?ooo`005`3oool2000000D0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`2j0?ooo`005P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0440oooo0P00
002l0?ooo`005`3oool2000000D0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2l
0?ooo`007P3oool00`000000oooo0?ooo`0n0?ooo`800000_`3oool001h0oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2o0?ooo`007P3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo0<00oooo000N0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`310?ooo`007P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0`P3oool001h0oooo00<000000?ooo`3oool03@3oool20000
02X0oooo00<000000?ooo`3oool0``3oool001h0oooo00<000000?ooo`3oool03@3oool2000002T0
oooo00<000000?ooo`3oool0a03oool001h0oooo00<000000?ooo`3oool03@3oool2000001@0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`350?ooo`007P3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool00000008000004P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0aP3oool001h0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0000000200000140oooo0P0000040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`370?ooo`007P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0000000800000403oool01@000000oooo0?ooo`000000oooo00<000001@3oool3
000000<0oooo00<000000?ooo`3oool0b03oool001h0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool0oooo0P000002
0?ooo`<000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0<T0oooo000N
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool2000000h0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`<0000000<0oooo0000003oool00P3oool300000<`0oooo000N
0?ooo`030000003oool0oooo0100oooo0P00000=0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0000003B0?ooo`007P3oool00`000000oooo0?ooo`0@0?oo
o`8000002@3oool2000000030?ooo`000000oooo00X0oooo0P00003C0?ooo`007P3oool00`000000
oooo0?ooo`0B0?ooo`<000001P3oool3000000`0oooo00<000000?ooo`3oool0dP3oool001h0oooo
00<000000?ooo`3oool04P3oool3000000030?ooo`00000000000080oooo00<000000?ooo`000000
hP3oool001h0oooo00<000000?ooo`3oool04P3oool010000000oooo0000003oool200000080oooo
00<000000?ooo`000000hP3oool001h0oooo00<000000?ooo`3oool04P3oool01@000000oooo0000
00000000oooo00<00000i@3oool001h0oooo00<000000?ooo`3oool0503oool2000000030?ooo`00
0000oooo0>H0oooo000N0?ooo`030000003oool0oooo01@0oooo00@000000?ooo`3oool00000i`3o
ool00100oooo1@0000020?ooo`8000001@3oool00`000000oooo0?ooo`3o0?ooo`004P3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o
0?ooo`004P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool2
00000?l0oooo0@3oool00180oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0o`3oool00180oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3oool00140oooo0P0000040?oo
o`8000001@3oool00`000000oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`00
7P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool0
0`000000oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool00`000000
oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?oo
o`3o0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?ooo`3o0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00203oool3000000050?ooo`00000000000000003oool00P0000020?ooo`<000000P3oool30000
00@0oooo100000000`3oool0000000000002000000<0oooo0`0000000`3oool00000000000020?oo
o`800000jP3oool000L0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
003[0?ooo`001`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool00P3oool400000080oooo00@000000?ooo`3oool00000j`3oool000L0oooo
00<000000?ooo`3oool00`3oool3000000@0oooo0P0000040?ooo`030000003oool0oooo00<0oooo
0`0000020?ooo`@000000`3oool200000080oooo1000003/0?ooo`001`3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`3k0?ooo`00203oool3000000030?ooo`000000000000L0oooo00@000000?ooo`3oool0oooo
0P0000060?ooo`800000o@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.89837, \
0.00421906, 0.0750924}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(NTarget = 5;\)\), "\[IndentingNewLine]", 
    \(\(sigmaset =  .01;\)\), "\[IndentingNewLine]", 
    \(\(epsset =  .01;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(Vlo = 0;\)\), "\[IndentingNewLine]", 
    \(\(Vset = 0.5;\)\), "\[IndentingNewLine]", 
    \(\(Vhi = 1000;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(it = 1;\)\), "\[IndentingNewLine]", 
    \(While[
      it < 30, \[IndentingNewLine]Clear[Util, Birth, prob, 
        FR]; \[IndentingNewLine]prepar = {\[Sigma] \[Rule] 
            sigmaset, \[Epsilon] \[Rule] epsset, \[Beta] \[Rule] 
            1, \[Gamma] \[Rule]  .95, p \[Rule] 5/24, q \[Rule] 1/24, 
          V \[Rule] Vset, 
          w \[Rule] 
            1}; \[IndentingNewLine]\[IndentingNewLine]If[\(TFRNFRAge[ .73, 
              1]\)[\([1]\)] > NTarget, Vhi = Vset; 
        Vset =  .5\ Vset\  + \  .5\ Vlo, Vlo = Vset; 
        Vset =  .5\ Vset\  + \  .5\ Vhi]; \[IndentingNewLine]\
\[IndentingNewLine]it = 
        it + 1;\[IndentingNewLine]]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(Print[Vset];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(prepar = {\[Sigma] \[Rule] sigmaset, \[Epsilon] \[Rule] 
            epsset, \[Beta] \[Rule] 1, \[Gamma] \[Rule]  .95, p \[Rule] 5/24, 
          q \[Rule] 1/24, V \[Rule] Vset, 
          w \[Rule] 1};\)\), "\[IndentingNewLine]", 
    \(\(Print[{\(TFRNFRAge[ .73, 1]\)[\([1]\)], \(TFRNFRAge[ .73, 
              1]\)[\([2]\)], \(TFRNFRAge[ .73, 
              1]\)[\([3]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(Print[{\(TFRNFRAge[ .965, 1]\)[\([1]\)], \(TFRNFRAge[ .965, 
              1]\)[\([2]\)], \(TFRNFRAge[ .965, 
              1]\)[\([3]\)]}];\)\[IndentingNewLine]\), "\[IndentingNewLine]", \

    \(\(Plot[{\(TFRNFRAge[s, 1]\)[\([1]\)], \(TFRNFRAge[s, 
              1]\)[\([2]\)]}, {s, 0.06,  .99}, 
        PlotRange \[Rule] {{0, 1}, {0, 11}}, 
        AxesLabel \[Rule] {"\<s\>", "\<Children\>"}, 
        PlotStyle \[Rule] {{Thickness[ .008]}, {Dashing[{ .02,  .02}], 
              Thickness[ .008]}}];\)\)}], "Input"],

Cell[BoxData[
    \(124.91810604464263`\)], "Print"],

Cell[BoxData[
    \({4.961540021611`, 3.6219242157760303`, 6}\)], "Print"],

Cell[BoxData[
    \({4.`, 3.86`, 9}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 1.38778e-017 0.0561849 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .11237 -6 -4.5 ]
[-0.0125 .11237 0 4.5 ]
[-0.0125 .22474 -6 -4.5 ]
[-0.0125 .22474 0 4.5 ]
[-0.0125 .33711 -6 -4.5 ]
[-0.0125 .33711 0 4.5 ]
[-0.0125 .44948 -6 -4.5 ]
[-0.0125 .44948 0 4.5 ]
[-0.0125 .56185 -12 -4.5 ]
[-0.0125 .56185 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11237 m
.00625 .11237 L
s
[(2)] -0.0125 .11237 1 0 Mshowa
0 .22474 m
.00625 .22474 L
s
[(4)] -0.0125 .22474 1 0 Mshowa
0 .33711 m
.00625 .33711 L
s
[(6)] -0.0125 .33711 1 0 Mshowa
0 .44948 m
.00625 .44948 L
s
[(8)] -0.0125 .44948 1 0 Mshowa
0 .56185 m
.00625 .56185 L
s
[(10)] -0.0125 .56185 1 0 Mshowa
.125 Mabswid
0 .02809 m
.00375 .02809 L
s
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .14046 m
.00375 .14046 L
s
0 .16855 m
.00375 .16855 L
s
0 .19665 m
.00375 .19665 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .47757 m
.00375 .47757 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .58994 m
.00375 .58994 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.06 .5175 m
.07837 .53455 L
.08772 .54452 L
.09019 .54024 L
.09086 .53908 L
.09158 .53785 L
.09286 .56015 L
.09406 .55823 L
.09518 .55643 L
.09773 .55237 L
.10029 .54832 L
.10171 .5461 L
.1024 .54501 L
.10305 .544 L
.10426 .5633 L
.1049 .56233 L
.10558 .5613 L
.10789 .55782 L
.11244 .55102 L
.11736 .54374 L
.11883 .54158 L
.11964 .54041 L
.12039 .53931 L
.12103 .55426 L
.12172 .5549 L
.12248 .55379 L
.12317 .55278 L
.12864 .54484 L
.13887 .53021 L
.14791 .51753 L
.15286 .51068 L
.15529 .50736 L
.15635 .50591 L
.15751 .50432 L
.15868 .52443 L
.15992 .52713 L
.16057 .54003 L
.16126 .5392 L
.16251 .53927 L
.16323 .53841 L
.164 .53749 L
.16541 .53582 L
.16804 .5327 L
.1705 .5298 L
.17311 .52674 L
.17533 .52414 L
.1766 .52267 L
.17778 .54433 L
.179 .54306 L
.1803 .5417 L
Mistroke
.18264 .53927 L
.18794 .5338 L
.19291 .52871 L
.19759 .52395 L
.20216 .51935 L
.20341 .5181 L
.20473 .51678 L
.20586 .51565 L
.20709 .52871 L
.20822 .53109 L
.20924 .53012 L
.21154 .52796 L
.21569 .52406 L
.23594 .50537 L
.25465 .48859 L
.27284 .47277 L
.28202 .46498 L
.28453 .46287 L
.28585 .46176 L
.28657 .46116 L
.28724 .4606 L
.28846 .4685 L
.2891 .46797 L
.28979 .46739 L
.29102 .46637 L
.29213 .4683 L
.2933 .46733 L
.2944 .46641 L
.29688 .46434 L
.30191 .46019 L
.3109 .45283 L
.31354 .4507 L
.31603 .44869 L
.31827 .44689 L
.31954 .44588 L
.32071 .46628 L
.32196 .4734 L
.32313 .47261 L
.32453 .47168 L
.32581 .47082 L
.32708 .46911 L
.32771 .46869 L
.32841 .46823 L
.32912 .45146 L
.32987 .45101 L
.33123 .4502 L
.35065 .43885 L
.37172 .42702 L
.38157 .42166 L
.39201 .4161 L
Mistroke
.3963 .41384 L
.39867 .41261 L
.39983 .412 L
.40092 .41144 L
.40218 .41929 L
.40285 .41896 L
.40356 .41861 L
.40483 .42505 L
.40598 .42449 L
.41073 .42221 L
.44987 .40405 L
.46783 .39607 L
.47803 .39096 L
.483 .38887 L
.48754 .38697 L
.48985 .386 L
.49107 .38549 L
.49174 .38522 L
.49237 .38496 L
.4935 .38419 L
.49474 .3663 L
.4958 .36594 L
.49694 .36555 L
.50702 .36215 L
.51685 .35832 L
.5276 .35485 L
.5325 .35328 L
.53774 .3516 L
.54029 .35079 L
.54269 .35003 L
.54484 .34935 L
.54606 .34896 L
.54718 .33894 L
.54837 .33859 L
.54964 .33821 L
.55085 .33722 L
.55195 .3369 L
.55719 .33539 L
.56779 .33237 L
.60663 .32082 L
.644 .31099 L
.6452 .31067 L
.64632 .30924 L
.64749 .30895 L
.64877 .30864 L
.65146 .30798 L
.65393 .30737 L
.66326 .30506 L
.66846 .30378 L
.66996 .30341 L
Mistroke
.67069 .30323 L
.67137 .30307 L
.67264 .30183 L
.67331 .30167 L
.67402 .29015 L
.67517 .28993 L
.67641 .28969 L
.67866 .28927 L
.68376 .28831 L
.703 .28356 L
.71316 .28176 L
.71875 .28077 L
.724 .27984 L
.72647 .2794 L
.72781 .27916 L
.72907 .27893 L
.72972 .27881 L
.73043 .30015 L
.73121 .30009 L
.73192 .30002 L
.73454 .2998 L
.7441 .29898 L
.7538 .29816 L
.75842 .29778 L
.76051 .2976 L
.76161 .29751 L
.76277 .29742 L
.76384 .29733 L
.76501 .29413 L
.76607 .29407 L
.76706 .29401 L
.7718 .29375 L
.7814 .29321 L
.80166 .29207 L
.81193 .29149 L
.82163 .29095 L
.82586 .29071 L
.83034 .29046 L
.83268 .29033 L
.83332 .29029 L
.83401 .29025 L
.83525 .28092 L
.83646 .28092 L
.83762 .28092 L
.83978 .28092 L
.84916 .28092 L
.85915 .28092 L
.86401 .28092 L
.86639 .28092 L
.86743 .28092 L
Mistroke
.86858 .28092 L
.86961 .28092 L
.87057 .23201 L
.87159 .23195 L
.87268 .23189 L
.87711 .23164 L
.88707 .23108 L
.89789 .23048 L
.90284 .2302 L
.90556 .23005 L
.90688 .22997 L
.9081 .2299 L
.90915 .22984 L
.91026 .22474 L
.91138 .22474 L
.91259 .22474 L
.91754 .22474 L
.95719 .22474 L
.99 .22474 L
Mfstroke
[ .02 .02 ] 0 setdash
.06 .03105 m
.09773 .05398 L
.13887 .07363 L
.17751 .09604 L
.19697 .10333 L
.20109 .10465 L
.20335 .10537 L
.20546 .10603 L
.20656 .10637 L
.20774 .10971 L
.20841 .11065 L
.20905 .11086 L
.21025 .11126 L
.21468 .11271 L
.2245 .11581 L
.23379 .11861 L
.25423 .12431 L
.29153 .13667 L
.33122 .14912 L
.36943 .15822 L
.37947 .16044 L
.39034 .16276 L
.39533 .1638 L
.39805 .16437 L
.39938 .16464 L
.4006 .16489 L
.40171 .16512 L
.40277 .16876 L
.40388 .17186 L
.40509 .17213 L
.41003 .17326 L
.44986 .18177 L
.46963 .18564 L
.47932 .18714 L
.48356 .18793 L
.4882 .18878 L
.49037 .18918 L
.49155 .18939 L
.49268 .1896 L
.49372 .18964 L
.49486 .18125 L
.49589 .18145 L
.49684 .18164 L
.50594 .18341 L
.52506 .18675 L
.5339 .18838 L
.53877 .18926 L
.54339 .19008 L
.54465 .19031 L
.54534 .19043 L
Mistroke
.54599 .19054 L
.54676 .18539 L
.54746 .18551 L
.54813 .18563 L
.54883 .18575 L
.55007 .18562 L
.55122 .18582 L
.5538 .18628 L
.56354 .18799 L
.60067 .19366 L
.62136 .19692 L
.6402 .19973 L
.64254 .20007 L
.64369 .20023 L
.64474 .20038 L
.64585 .1998 L
.64704 .19998 L
.64957 .20035 L
.65486 .20113 L
.65975 .20184 L
.66442 .2025 L
.66876 .20311 L
.67095 .20341 L
.67218 .20358 L
.67329 .20312 L
.67452 .19565 L
.67521 .19576 L
.67584 .19586 L
.67824 .19625 L
.69816 .19938 L
.70055 .19975 L
.70121 .19985 L
.7019 .19996 L
.70316 .19937 L
.70432 .19955 L
.70541 .19973 L
.70789 .20012 L
.71677 .2015 L
.72096 .20214 L
.72537 .20281 L
.72768 .20315 L
.72831 .20325 L
.72899 .20335 L
.7302 .21919 L
.7314 .21947 L
.73253 .21974 L
.73464 .22024 L
.75382 .22476 L
.79135 .23159 L
.81035 .23628 L
Mistroke
.82044 .23876 L
.82599 .24012 L
.82873 .24079 L
.83127 .24141 L
.83251 .24171 L
.83368 .24199 L
.83432 .23438 L
.83502 .23458 L
.83623 .23492 L
.84165 .23644 L
.85113 .2391 L
.86075 .2418 L
.86544 .24312 L
.86749 .2437 L
.86857 .244 L
.86972 .24433 L
.87092 .20205 L
.87202 .20225 L
.87421 .20265 L
.87901 .20352 L
.8892 .20537 L
.89911 .20716 L
.90431 .2081 L
.90714 .2086 L
.90852 .20885 L
.90978 .20908 L
.91096 .20473 L
.91207 .20498 L
.91452 .20553 L
.91971 .20669 L
.92881 .20874 L
.94666 .21275 L
.98424 .2212 L
.99 .22249 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00AP3oool2000000@0oooo0P0000030?ooo`@00000803oool2000000@0oooo0P0000050?oo
o`<00000803oool2000000@0oooo0P0000030?ooo`<000008@3oool2000000@0oooo0P0000040?oo
o`8000009`3oool500000180oooo00150?ooo`040000003oool0oooo000000P0oooo00<000000?oo
o`3oool0803oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo01h0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000O0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool00000:03oool00`000000oooo0?ooo`0B0?ooo`00A@3oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo01l0oooo00@000000?ooo`3oool00000203oool5
000001l0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000O0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool00000:03oool00`000000oooo0?ooo`0B0?oo
o`00A@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo01h0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`00000P0?ooo`040000003oool0oooo000000P0oooo
0`00000P0?ooo`040000003oool0oooo000000T0oooo0P00000Y0?ooo`030000003oool0oooo0180
oooo00150?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000007`3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool000000200oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo0?ooo`0O0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000:03oool00`000000oooo0?ooo`0B0?ooo`00AP3oool2000000X0oooo0P00000Q0?ooo`800000
2`3oool200000240oooo0P00000:0?ooo`<00000803oool2000000X0oooo0P00000X0?ooo`800000
503oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo503oool3000000X0
oooo003o0?oooaL0oooo00<000000?ooo`3oool01`3oool001h0ooookP0000070?ooo`<000002P3o
ool001h0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo00D0oooo100000090?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool00`000000
oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?oo
o`3o0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo0?40oooo000N0?ooo`030000003oool0oooo00`0oooo0P00003a0?ooo`00
7P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool0
0`000000oooo0?ooo`0A0?ooo`800000k03oool001h0oooo00<000000?ooo`3oool04`3oool20000
0>X0oooo000N0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0i`3oool001h0oooo
00<000000?ooo`3oool0o`3oool001h0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`3S0?ooo`007P3oool00`000000oooo0?ooo`0J0?ooo`800000h`3oool001h0oooo00<000000?oo
o`3oool0703oool300000>00oooo000N0?ooo`030000003oool0oooo0?l0oooo000N0?ooo`030000
003oool0oooo0?l0oooo000N0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0fP3o
ool001h0oooo00<000000?ooo`3oool08`3oool200000=X0oooo000N0?ooo`030000003oool0oooo
02D0oooo0P00003H0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`005P3oool4000000@0oooo
00<000000?ooo`3oool0:P3oool400000=40oooo000F0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`3?0?ooo`005`3oool00`000000oooo0?ooo`04
0?ooo`800000;`3oool00`000000oooo0?ooo`3>0?ooo`00603oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo03<0oooo00<000000?ooo`3oool0b@3oool001H0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`0d0?ooo`800000b@3oool001L0oooo0P0000050?ooo`03
0000003oool0oooo03H0oooo0P0000370?ooo`007P3oool00`000000oooo0?ooo`0l0?ooo`800000
`@3oool001h0oooo00<000000?ooo`3oool0?P3oool300000;h0oooo000N0?ooo`030000003oool0
oooo0?l0oooo000N0?ooo`030000003oool0oooo04D0oooo0P00002h0?ooo`007P3oool00`000000
oooo0?ooo`170?ooo`<00000]@3oool001h0oooo00<000000?ooo`3oool0o`3oool001h0oooo00<0
00000?ooo`3oool0CP3oool200000:l0oooo000N0?ooo`030000003oool0oooo0500oooo0`00002/
0?ooo`007P3oool00`000000oooo0?ooo`1G0?ooo`D00000X`3oool001h0oooo00<000000?ooo`3o
ool0F`3oool200000:80oooo000N0?ooo`030000003oool0oooo0?l0oooo000N0?ooo`030000003o
ool0oooo05l0oooo0`00002M0?ooo`007P3oool00`000000oooo0?ooo`1R0?ooo`<000003@3oool0
0`000000oooo0?ooo`2:0?ooo`007P3oool00`000000oooo0?ooo`1X0?ooo`800000203oool40000
08T0oooo000N0?ooo`030000003oool0oooo06X0oooo100000040?ooo`030000003oool0oooo00@0
oooo100000030?ooo`@00000N`3oool001h0oooo00<000000?ooo`3oool0O@3oool2000000D0oooo
0P0000040?ooo`<00000LP3oool001h0oooo00<000000?ooo`3oool0S@3oool2000000d0oooo1@00
001N0?ooo`007P3oool00`000000oooo0?ooo`2C0?ooo`H000000`3oool00`000000oooo0?ooo`05
0?ooo`@000008`3oool00`000000oooo0?ooo`0a0?ooo`007P3oool00`000000oooo0?ooo`2X0?oo
o`8000008@3oool2000000L0oooo0P00000Y0?ooo`007P3oool00`000000oooo0?ooo`3;0?ooo`03
0000003oool0oooo00<0oooo100000040?ooo`800000903oool001h0oooo00<000000?ooo`3oool0
b`3oool00`000000oooo0?ooo`0=0?ooo`@00000803oool001P0oooo0`0000030?ooo`030000003o
ool0oooo0</0oooo00<000000?ooo`3oool0503oool2000001/0oooo000I0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0ZP3oool3000003L0oooo1000000G0?ooo`005P3oool50000
00<0oooo0P00002^0?ooo`<00000903ooolD000001L0oooo000F0?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0/`3oool600000180oooo2P00000Z0?ooo`005`3oool00`000000
oooo000000040?ooo`030000003oool0oooo0<80oooo0P0000070?ooo`030000003oool0oooo0340
oooo000H0?ooo`800000103oool00`000000oooo0?ooo`300?ooo`030000003oool0000000P0oooo
00<000000?ooo`3oool0<@3oool001h0oooo00<000000?ooo`3oool0`@3oool2000000D0oooo1000
000c0?ooo`007P3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo0340oooo000N0?oo
o`030000003oool0oooo0</0oooo00<000000?ooo`3oool0<@3oool001h0oooo00<000000?ooo`3o
ool0b`3oool00`000000oooo0?ooo`0a0?ooo`007P3oool00`000000oooo0?ooo`3;0?ooo`030000
003oool0oooo0340oooo000N0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool0<@3o
ool001h0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0a0?ooo`007P3oool00`00
0000oooo0?ooo`3;0?ooo`030000003oool0oooo0340oooo000N0?ooo`030000003oool0oooo0</0
oooo00<000000?ooo`3oool0<@3oool001h0oooo00<000000?ooo`3oool0Y@3oool5000001T0oooo
2@00000c0?ooo`007P3oool00`000000oooo0?ooo`2R0?ooo`<00000103oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo03X0oooo000N0?ooo`030000003oool0oooo09`0oooo1P000007
0?ooo`030000003oool0oooo01<0oooo1000000l0?ooo`007P3oool00`000000oooo0?ooo`2L0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool01@3oool=00000400oooo000N0?ooo`03
0000003oool0oooo09`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`06000004`0
oooo000N0?ooo`030000003oool0oooo09/0oooo0P00000=0?ooo`<00000DP3oool001h0oooo00<0
00000?ooo`3oool0V03oool4000006<0oooo000N0?ooo`030000003oool0oooo09@0oooo1000001W
0?ooo`007P3oool00`000000oooo0?ooo`2A0?ooo`<00000J`3oool001h0oooo00<000000?ooo`3o
ool0SP3oool3000006h0oooo000N0?ooo`030000003oool0oooo08X0oooo1000001a0?ooo`005P3o
ool3000000D0oooo00<000000?ooo`3oool0QP3oool4000007D0oooo000F0?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0P`3oool3000007T0oooo000F0?ooo`040000003oool0
oooo000000@0oooo0P0000200?ooo`@00000O03oool001H0oooo0`0000050?ooo`030000003oool0
oooo07h0oooo0P00001o0?ooo`005`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
07h0oooo00<000000?ooo`3oool0OP3oool001L0oooo0`0000040?ooo`030000003oool0oooo07d0
oooo0P0000200?ooo`007P3oool00`000000oooo0?ooo`1k0?ooo`<00000P@3oool001h0oooo00<0
00000?ooo`3oool0M`3oool4000008@0oooo000N0?ooo`030000003oool0oooo07@0oooo0`000028
0?ooo`007P3oool00`000000oooo0?ooo`1b0?ooo`800000R`3oool001h0oooo00<000000?ooo`3o
ool0LP3oool00`000000oooo0?ooo`2:0?ooo`007P3oool00`000000oooo0?ooo`1b0?ooo`030000
003oool0oooo08X0oooo000N0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0R`3o
ool001h0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`2;0?ooo`007P3oool00`00
0000oooo0?ooo`1`0?ooo`800000S@3oool001h0oooo00<000000?ooo`3oool0K@3oool3000008l0
oooo000N0?ooo`030000003oool0oooo06/0oooo0P00002B0?ooo`007P3oool00`000000oooo0?oo
o`1Y0?ooo`800000U03oool001h0oooo00<000000?ooo`3oool0I`3oool2000009H0oooo000N0?oo
o`030000003oool0oooo06D0oooo0P00002H0?ooo`007P3oool00`000000oooo0?ooo`1K0?ooo`80
00001P3oool2000009X0oooo000N0?ooo`030000003oool0oooo05T0oooo0P0000000`3oool00000
0?ooo`030?ooo`800000W03oool001h0oooo00<000000?ooo`3oool0E`3oool2000000<0oooo00<0
00000?ooo`3oool00P00002N0?ooo`007P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo00<0oooo0`00002P0?ooo`007P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo
0:L0oooo000N0?ooo`030000003oool0oooo05<0oooo0P00002Z0?ooo`007P3oool00`000000oooo
0?ooo`1A0?ooo`800000[03oool001L0oooo0P0000050?ooo`030000003oool0oooo04l0oooo0P00
002^0?ooo`005P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo04P0oooo00<0
00000?ooo`3oool00P3oool200000;00oooo000F0?ooo`040000003oool0oooo000000@0oooo0P00
00180?ooo`8000000P3oool200000;80oooo000G0?ooo`8000001@3oool00`000000oooo0?ooo`16
0?ooo`030000003oool000000080oooo00<000000?ooo`3oool0/@3oool001H0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`150?ooo`070000003oool0oooo0?ooo`000000oooo
0000002c0?ooo`005`3oool2000000D0oooo00<000000?ooo`3oool0@03oool200000080oooo00<0
00000?ooo`3oool00P3oool200000;@0oooo000N0?ooo`030000003oool0oooo03l0oooo00<00000
0?ooo`0000000P0000050?ooo`800000]03oool001h0oooo00<000000?ooo`3oool0?P3oool00`00
0000oooo0?ooo`02000000H0oooo0P00002d0?ooo`007P3oool00`000000oooo0?ooo`0m0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0/`3oool001h0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`300?ooo`007P3oool00`000000oooo0?ooo`0j0?ooo`800000``3o
ool001h0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`330?ooo`007P3oool00`00
0000oooo0?ooo`0h0?ooo`030000003oool0oooo0<@0oooo000N0?ooo`030000003oool0oooo03H0
oooo0P0000370?ooo`007P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0<L0oooo
000N0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`380?ooo`007P3oool00`000000oooo0?ooo`0Q0?ooo`800000403oool00`000000oooo0?ooo`39
0?ooo`007P3oool00`000000oooo0?ooo`0Q0?ooo`8000003`3oool00`000000oooo0?ooo`3:0?oo
o`007P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0180oooo00<000000?ooo`00
00002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0<X0oooo000N0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo00<0oooo0P0000030?ooo`030000003oool0oooo0</0oooo000N0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`000000oooo00000<h0oooo000N0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo008000000`3oool010000000oooo0?ooo`3oool200000<l0oooo000N0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?oo
o`8000000P3oool00`000000oooo0000003E0?ooo`007P3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0000000H0oooo00@000000?ooo`3oool000001P3oool200000080oooo0P00003F0?oo
o`007P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool000000080oooo00<000000?ooo`3o
ool00P0000000`3oool000000?ooo`060?ooo`050000003oool0oooo0?ooo`000000e`3oool001h0
oooo00<000000?ooo`3oool04@3oool2000000090?ooo`00000000000?ooo`000000oooo0000003o
ool0000000/0oooo00<000000?ooo`3oool0e@3oool001h0oooo00<000000?ooo`3oool04`3oool3
000000030?ooo`000000oooo00800000i03oool00100oooo1@0000020?ooo`8000001@3oool00`00
0000oooo0?ooo`0C0?ooo`040000003oool0000000000080oooo0P00003T0?ooo`004P3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0C
0?ooo`040000003oool0000000000>P0oooo000B0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`020?ooo`8000005P3oool200000>P0oooo000B0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo000B
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0?l0oooo000A0?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0o`3oool0
01h0oooo00<000000?ooo`3oool0o`3oool001h0oooo00<000000?ooo`3oool0o`3oool001h0oooo
00<000000?ooo`3oool0o`3oool001h0oooo00<000000?ooo`3oool0o`3oool001h0oooo00<00000
0?ooo`3oool0o`3oool001h0oooo00<000000?ooo`3oool0o`3oool001h0oooo00<000000?ooo`3o
ool0o`3oool001h0oooo00<000000?ooo`3oool0o`3oool001h0oooo00<000000?ooo`3oool0o`3o
ool001h0oooo00<000000?ooo`3oool0o`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool000P0oooo0`0000001@3oool00000000000000000
oooo008000000P3oool300000080oooo0`0000040?ooo`@0000000<0oooo0000000000000P000003
0?ooo`<0000000<0oooo0000000000000P3oool200000>X0oooo00070?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool00000j`3oool000L0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo100000020?ooo`04
0000003oool0oooo00000>/0oooo00070?ooo`030000003oool0oooo00<0oooo0`0000040?ooo`80
0000103oool00`000000oooo0?ooo`030?ooo`<000000P3oool4000000<0oooo0P0000020?ooo`@0
0000k03oool000L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0n`3oool000P0oooo0`0000000`3oool00000
000000070?ooo`040000003oool0oooo0?ooo`8000001P3oool200000?d0oooo003o0?ooob40oooo
003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.89837, \
0.00421906, 0.0750924}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowSize->{1019, 668},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 52, 0, 115, "Title"],
Cell[1782, 54, 132, 3, 53, "Subsubtitle"],

Cell[CellGroupData[{
Cell[1939, 61, 24, 0, 59, "Section"],
Cell[1966, 63, 231, 4, 52, "Text"],
Cell[2200, 69, 91, 2, 50, "Input"],
Cell[2294, 73, 37, 0, 33, "Text"],
Cell[2334, 75, 84, 1, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2455, 81, 40, 0, 59, "Section"],
Cell[2498, 83, 65, 0, 33, "Text"],
Cell[2566, 85, 4894, 78, 1310, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7497, 168, 61, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[7583, 172, 4557, 80, 1385, "Input"],
Cell[12143, 254, 221, 5, 24, "Message"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12413, 265, 40, 0, 59, "Section"],
Cell[12456, 267, 298, 5, 140, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12791, 277, 41, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[12857, 281, 2083, 39, 530, "Input"],
Cell[14943, 322, 52, 1, 25, "Print"],
Cell[14998, 325, 74, 1, 25, "Print"],
Cell[15075, 328, 48, 1, 25, "Print"],
Cell[15126, 331, 21341, 743, 186, 9057, 587, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36504, 1079, 2083, 39, 530, "Input"],
Cell[38590, 1120, 51, 1, 25, "Print"],
Cell[38644, 1123, 64, 1, 25, "Print"],
Cell[38711, 1126, 48, 1, 25, "Print"],
Cell[38762, 1129, 24383, 879, 186, 10953, 709, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[63182, 2013, 2083, 39, 530, "Input"],
Cell[65268, 2054, 52, 1, 25, "Print"],
Cell[65323, 2057, 74, 1, 25, "Print"],
Cell[65400, 2060, 48, 1, 25, "Print"],
Cell[65451, 2063, 22864, 793, 186, 9640, 625, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

